PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE fixes (id integer primary key, lg text, inLg text, name text, unique(lg, inLg) on conflict replace);
INSERT INTO "fixes" VALUES(NULL,'ky','ar','арабча');
INSERT INTO "fixes" VALUES(NULL,'ky','ba','башкортчо');
INSERT INTO "fixes" VALUES(NULL,'ky','cv','чубашча');
INSERT INTO "fixes" VALUES(NULL,'ky','he','ивритче');
INSERT INTO "fixes" VALUES(NULL,'ky','ku','куртча');
INSERT INTO "fixes" VALUES(NULL,'ky','kum','кумукча');
INSERT INTO "fixes" VALUES(NULL,'ky','tk','түркмөнчө');
INSERT INTO "fixes" VALUES(NULL,'ky','tr','түркчө');
INSERT INTO "fixes" VALUES(NULL,'ky','uz','өзбекче');
INSERT INTO "fixes" VALUES(NULL,'kk','az','әзірбайжан тілі');
INSERT INTO "fixes" VALUES(NULL,'kk','ba','башқортша');
INSERT INTO "fixes" VALUES(NULL,'kk','en','ағылшынша');
INSERT INTO "fixes" VALUES(NULL,'kk','gd','шотландиялық гэл тілі');
INSERT INTO "fixes" VALUES(NULL,'kk','kk','қазақша');
INSERT INTO "fixes" VALUES(NULL,'kk','kum','құмықша');
INSERT INTO "fixes" VALUES(NULL,'kk','cv','чувашша');
INSERT INTO "fixes" VALUES(NULL,'kk','ky','қырғызша');
INSERT INTO "fixes" VALUES(NULL,'kk','tk','түрікменше');
INSERT INTO "fixes" VALUES(NULL,'kk','tr','түрікше');
INSERT INTO "fixes" VALUES(NULL,'kk','tt','татарша');
INSERT INTO "fixes" VALUES(NULL,'kk','uz','өзбекше');
INSERT INTO "fixes" VALUES(NULL,'en','kaa','Karakalpak');
INSERT INTO "fixes" VALUES(NULL,'en','ky','Kyrgyz');
INSERT INTO "fixes" VALUES(NULL,'en','os','Ossetian');
INSERT INTO "fixes" VALUES(NULL,'ba','ba','башҡортса');
INSERT INTO "fixes" VALUES(NULL,'tt','kk','казакъча');
INSERT INTO "fixes" VALUES(NULL,'tt','tt','татарча');
INSERT INTO "fixes" VALUES(NULL,'tt','ky','кыргызча');
INSERT INTO "fixes" VALUES(NULL,'tt','tr','төрекчә');
INSERT INTO "fixes" VALUES(NULL,'tt','cv','чувашча');
INSERT INTO "fixes" VALUES(NULL,'tt','kum','кумыкча');
INSERT INTO "fixes" VALUES(NULL,'tt','uz','үзбәкчә');
INSERT INTO "fixes" VALUES(NULL,'tt','ba','башкортча');
INSERT INTO "fixes" VALUES(NULL,'tt','tk','төрекмәнчә');
INSERT INTO "fixes" VALUES(NULL,'tt','kaa','каракалпакча');
INSERT INTO "fixes" VALUES(NULL,'tt','tyv','тувача');
INSERT INTO "fixes" VALUES(NULL,'tt','az','азәрбайҗанча');
INSERT INTO "fixes" VALUES(NULL,'tt','az','урысча');
INSERT INTO "fixes" VALUES(NULL,'ba','ba','башҡортса');
INSERT INTO "fixes" VALUES(NULL,'ug','kk','قازاقچا');
INSERT INTO "fixes" VALUES(NULL,'ug','tt','تاتارچا');
INSERT INTO "fixes" VALUES(NULL,'ug','ky','قىرغىزچا');
INSERT INTO "fixes" VALUES(NULL,'ug','uz','ئۆزبەكچا');
INSERT INTO "fixes" VALUES(NULL,'ug','kaa','قاراقالپاقچا');
INSERT INTO "fixes" VALUES(NULL,'ug','ug','ئۇيغۇرچا');
INSERT INTO "fixes" VALUES(NULL,'tt','ru','урысча');
INSERT INTO "fixes" VALUES(NULL,'en','ug','Uyghur');
INSERT INTO "fixes" VALUES(NULL,'ru','ug','уйгурский');
INSERT INTO "fixes" VALUES(NULL,'uz','ug','uyg\'urcha');
INSERT INTO "fixes" VALUES(NULL,'kk','ug','ұйғұрша');
INSERT INTO "fixes" VALUES(NULL,'ky','ug','уйгурча');
INSERT INTO "fixes" VALUES(NULL,'en','crh','Crimean Tatar');
CREATE TABLE languageNames (id integer primary key, lg text, inLg text, name text, unique(lg, inLg) on conflict replace);
INSERT INTO "languageNames" VALUES(NULL,'sah','af','Аппырыкааныстыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ar','Араабтыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','az','Адьырбайдьаанныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','be','Бөлөрүүстүү');
INSERT INTO "languageNames" VALUES(NULL,'sah','bg','Булҕаардыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','bn','Бенгаллыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ca','Каталаанныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','cs','Чиэскэйдии');
INSERT INTO "languageNames" VALUES(NULL,'sah','da','Даатскайдыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','de','Ниэмэстии');
INSERT INTO "languageNames" VALUES(NULL,'sah','el','Гириэктии');
INSERT INTO "languageNames" VALUES(NULL,'sah','en','Аҥылычаанныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','es','Ыспаанныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','et','Эстиэнийэлии');
INSERT INTO "languageNames" VALUES(NULL,'sah','fa','Пиэрсийэлии');
INSERT INTO "languageNames" VALUES(NULL,'sah','fi','Пииннии');
INSERT INTO "languageNames" VALUES(NULL,'sah','fr','Пырансуустуу');
INSERT INTO "languageNames" VALUES(NULL,'sah','hu','Бэҥгиэрдии');
INSERT INTO "languageNames" VALUES(NULL,'sah','hy','Эрмээннии');
INSERT INTO "languageNames" VALUES(NULL,'sah','it','Ытаалыйалыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','kk','Хаһаахтыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ko','Кэриэйдии');
INSERT INTO "languageNames" VALUES(NULL,'sah','ky','Кыргыстыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','la','Латыынныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ne','Ньыпааллыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','pa','Пандьаабтыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','pt','Португааллыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ro','Румыынныы');
INSERT INTO "languageNames" VALUES(NULL,'sah','ru','Нууччалыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','sk','Словаактыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','sq','Албаанскайдыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','te','Төлүгүлүү');
INSERT INTO "languageNames" VALUES(NULL,'sah','tg','Тадьыыктыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','uk','Украйыыньыстыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','uz','Үзбиэктии');
INSERT INTO "languageNames" VALUES(NULL,'sah','zh','Кытайдыы');
INSERT INTO "languageNames" VALUES(NULL,'sah','zu','Зуулулуу');
INSERT INTO "languageNames" VALUES(NULL,'ky','af','африкаанча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ar','арабча');
INSERT INTO "languageNames" VALUES(NULL,'ky','as','ассамча');
INSERT INTO "languageNames" VALUES(NULL,'ky','az','азербайжанча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ba','башкортчо');
INSERT INTO "languageNames" VALUES(NULL,'ky','cv','чубашча');
INSERT INTO "languageNames" VALUES(NULL,'ky','be','беларусча');
INSERT INTO "languageNames" VALUES(NULL,'ky','bg','болгарияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','bn','бангладешче');
INSERT INTO "languageNames" VALUES(NULL,'ky','br','бретон');
INSERT INTO "languageNames" VALUES(NULL,'ky','ca','каталанча');
INSERT INTO "languageNames" VALUES(NULL,'ky','cs','чех тили');
INSERT INTO "languageNames" VALUES(NULL,'ky','cy','уелшче');
INSERT INTO "languageNames" VALUES(NULL,'ky','da','датча');
INSERT INTO "languageNames" VALUES(NULL,'ky','de','немисче');
INSERT INTO "languageNames" VALUES(NULL,'ky','el','грекче');
INSERT INTO "languageNames" VALUES(NULL,'ky','en','англисче');
INSERT INTO "languageNames" VALUES(NULL,'ky','eo','эсперанто');
INSERT INTO "languageNames" VALUES(NULL,'ky','es','испанча');
INSERT INTO "languageNames" VALUES(NULL,'ky','et','эстончо');
INSERT INTO "languageNames" VALUES(NULL,'ky','eu','баскча');
INSERT INTO "languageNames" VALUES(NULL,'ky','fa','Фарзча');
INSERT INTO "languageNames" VALUES(NULL,'ky','fi','финче');
INSERT INTO "languageNames" VALUES(NULL,'ky','fo','фароэче');
INSERT INTO "languageNames" VALUES(NULL,'ky','fr','французча');
INSERT INTO "languageNames" VALUES(NULL,'ky','fy','батыш фризче');
INSERT INTO "languageNames" VALUES(NULL,'ky','ga','ирландча');
INSERT INTO "languageNames" VALUES(NULL,'ky','gn','гуараш');
INSERT INTO "languageNames" VALUES(NULL,'ky','he','ивритче');
INSERT INTO "languageNames" VALUES(NULL,'ky','hi','индусча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ht','гаитиче');
INSERT INTO "languageNames" VALUES(NULL,'ky','hu','венгрияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','hy','армянча');
INSERT INTO "languageNames" VALUES(NULL,'ky','id','индонезияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','is','исландча');
INSERT INTO "languageNames" VALUES(NULL,'ky','it','италиянча');
INSERT INTO "languageNames" VALUES(NULL,'ky','kk','казакча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ko','корейче');
INSERT INTO "languageNames" VALUES(NULL,'ky','ku','куртча');
INSERT INTO "languageNames" VALUES(NULL,'ky','kum','кумукча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ky','кыргызча');
INSERT INTO "languageNames" VALUES(NULL,'ky','la','латынча');
INSERT INTO "languageNames" VALUES(NULL,'ky','lb','Люксембургча');
INSERT INTO "languageNames" VALUES(NULL,'ky','lo','лаочо');
INSERT INTO "languageNames" VALUES(NULL,'ky','lt','литвача');
INSERT INTO "languageNames" VALUES(NULL,'ky','lv','латвияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','mk','македонияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ml','малайаламча');
INSERT INTO "languageNames" VALUES(NULL,'ky','mr','маратиче');
INSERT INTO "languageNames" VALUES(NULL,'ky','mt','малтизче');
INSERT INTO "languageNames" VALUES(NULL,'ky','nb','норвежче букмалча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ne','непалча');
INSERT INTO "languageNames" VALUES(NULL,'ky','nl','голландча');
INSERT INTO "languageNames" VALUES(NULL,'ky','nn','норвегияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','no','норвежче');
INSERT INTO "languageNames" VALUES(NULL,'ky','pa','пунжабиче');
INSERT INTO "languageNames" VALUES(NULL,'ky','pl','полякча');
INSERT INTO "languageNames" VALUES(NULL,'ky','pt','португалча');
INSERT INTO "languageNames" VALUES(NULL,'ky','rm','романшча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ro','румынияча');
INSERT INTO "languageNames" VALUES(NULL,'ky','ru','орусча');
INSERT INTO "languageNames" VALUES(NULL,'ky','sa','санскритче');
INSERT INTO "languageNames" VALUES(NULL,'ky','sh','серб-хорват');
INSERT INTO "languageNames" VALUES(NULL,'ky','si','сингалача');
INSERT INTO "languageNames" VALUES(NULL,'ky','sk','словакча');
INSERT INTO "languageNames" VALUES(NULL,'ky','sl','словенче');
INSERT INTO "languageNames" VALUES(NULL,'ky','sq','албанча');
INSERT INTO "languageNames" VALUES(NULL,'ky','sv','шведче');
INSERT INTO "languageNames" VALUES(NULL,'ky','sw','суахиличе');
INSERT INTO "languageNames" VALUES(NULL,'ky','te','телугуча');
INSERT INTO "languageNames" VALUES(NULL,'ky','tg','тажикче');
INSERT INTO "languageNames" VALUES(NULL,'ky','th','тайча');
INSERT INTO "languageNames" VALUES(NULL,'ky','tk','түркмөнчө');
INSERT INTO "languageNames" VALUES(NULL,'ky','tr','түркчө');
INSERT INTO "languageNames" VALUES(NULL,'ky','tt','татарча');
INSERT INTO "languageNames" VALUES(NULL,'ky','uk','украинче');
INSERT INTO "languageNames" VALUES(NULL,'ky','ur','урдуча');
INSERT INTO "languageNames" VALUES(NULL,'ky','uz','өзбекче');
INSERT INTO "languageNames" VALUES(NULL,'ky','vi','вьетнамча');
INSERT INTO "languageNames" VALUES(NULL,'ky','xh','косача');
INSERT INTO "languageNames" VALUES(NULL,'ky','zh','кытайча');
INSERT INTO "languageNames" VALUES(NULL,'ky','zu','зулуча');
INSERT INTO "languageNames" VALUES(NULL,'kk','af','африкаанс');
INSERT INTO "languageNames" VALUES(NULL,'kk','ar','араб');
INSERT INTO "languageNames" VALUES(NULL,'kk','as','ассам');
INSERT INTO "languageNames" VALUES(NULL,'kk','az','әзірбайжан тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','ba','башқортша');
INSERT INTO "languageNames" VALUES(NULL,'kk','be','беларус');
INSERT INTO "languageNames" VALUES(NULL,'kk','bg','болгар');
INSERT INTO "languageNames" VALUES(NULL,'kk','bn','бенгал');
INSERT INTO "languageNames" VALUES(NULL,'kk','br','брит');
INSERT INTO "languageNames" VALUES(NULL,'kk','ca','каталан');
INSERT INTO "languageNames" VALUES(NULL,'kk','cs','чех');
INSERT INTO "languageNames" VALUES(NULL,'kk','cy','валлий');
INSERT INTO "languageNames" VALUES(NULL,'kk','da','дат');
INSERT INTO "languageNames" VALUES(NULL,'kk','de','неміс тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','el','грек');
INSERT INTO "languageNames" VALUES(NULL,'kk','en','ағылшынша');
INSERT INTO "languageNames" VALUES(NULL,'kk','eo','эсперанто');
INSERT INTO "languageNames" VALUES(NULL,'kk','es','испан тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','et','эстон');
INSERT INTO "languageNames" VALUES(NULL,'kk','eu','баск');
INSERT INTO "languageNames" VALUES(NULL,'kk','fa','парсы');
INSERT INTO "languageNames" VALUES(NULL,'kk','fi','фин');
INSERT INTO "languageNames" VALUES(NULL,'kk','fo','фарер');
INSERT INTO "languageNames" VALUES(NULL,'kk','fr','француз тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','fy','батыс фриз');
INSERT INTO "languageNames" VALUES(NULL,'kk','ga','ирланд');
INSERT INTO "languageNames" VALUES(NULL,'kk','gd','шотландиялық гэл тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','gn','гуарани');
INSERT INTO "languageNames" VALUES(NULL,'kk','he','иврит');
INSERT INTO "languageNames" VALUES(NULL,'kk','hi','хинди');
INSERT INTO "languageNames" VALUES(NULL,'kk','ht','гаитян');
INSERT INTO "languageNames" VALUES(NULL,'kk','hu','венгер');
INSERT INTO "languageNames" VALUES(NULL,'kk','hy','армян');
INSERT INTO "languageNames" VALUES(NULL,'kk','ia','интерлингва');
INSERT INTO "languageNames" VALUES(NULL,'kk','id','индонезия');
INSERT INTO "languageNames" VALUES(NULL,'kk','is','исланд');
INSERT INTO "languageNames" VALUES(NULL,'kk','it','итальян тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','kk','қазақша');
INSERT INTO "languageNames" VALUES(NULL,'kk','ko','кәріс');
INSERT INTO "languageNames" VALUES(NULL,'kk','ku','күрд');
INSERT INTO "languageNames" VALUES(NULL,'kk','kum','құмықша');
INSERT INTO "languageNames" VALUES(NULL,'kk','cv','чувашша');
INSERT INTO "languageNames" VALUES(NULL,'kk','ky','қырғызша');
INSERT INTO "languageNames" VALUES(NULL,'kk','la','латын');
INSERT INTO "languageNames" VALUES(NULL,'kk','lb','люксембург');
INSERT INTO "languageNames" VALUES(NULL,'kk','lo','лаос');
INSERT INTO "languageNames" VALUES(NULL,'kk','lt','литва');
INSERT INTO "languageNames" VALUES(NULL,'kk','lv','латыш');
INSERT INTO "languageNames" VALUES(NULL,'kk','mk','македон');
INSERT INTO "languageNames" VALUES(NULL,'kk','ml','малайялам');
INSERT INTO "languageNames" VALUES(NULL,'kk','mr','маратхи');
INSERT INTO "languageNames" VALUES(NULL,'kk','mt','мальта');
INSERT INTO "languageNames" VALUES(NULL,'kk','nb','норвегиялық букмол');
INSERT INTO "languageNames" VALUES(NULL,'kk','ne','непал');
INSERT INTO "languageNames" VALUES(NULL,'kk','nl','голланд');
INSERT INTO "languageNames" VALUES(NULL,'kk','nn','норвегиялық нинорск');
INSERT INTO "languageNames" VALUES(NULL,'kk','no','норвег');
INSERT INTO "languageNames" VALUES(NULL,'kk','oc','окситан');
INSERT INTO "languageNames" VALUES(NULL,'kk','os','осетин');
INSERT INTO "languageNames" VALUES(NULL,'kk','pa','панджаб');
INSERT INTO "languageNames" VALUES(NULL,'kk','pl','поляк');
INSERT INTO "languageNames" VALUES(NULL,'kk','pt','португал тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','rm','романш');
INSERT INTO "languageNames" VALUES(NULL,'kk','rn','рунди');
INSERT INTO "languageNames" VALUES(NULL,'kk','ro','румын');
INSERT INTO "languageNames" VALUES(NULL,'kk','ru','орыс тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','sa','санскрит');
INSERT INTO "languageNames" VALUES(NULL,'kk','se','Солтүстік саам');
INSERT INTO "languageNames" VALUES(NULL,'kk','sh','сербхорват');
INSERT INTO "languageNames" VALUES(NULL,'kk','si','сингал');
INSERT INTO "languageNames" VALUES(NULL,'kk','sk','словак');
INSERT INTO "languageNames" VALUES(NULL,'kk','sl','словен');
INSERT INTO "languageNames" VALUES(NULL,'kk','sq','албан');
INSERT INTO "languageNames" VALUES(NULL,'kk','sv','швед');
INSERT INTO "languageNames" VALUES(NULL,'kk','sw','суахили');
INSERT INTO "languageNames" VALUES(NULL,'kk','te','телугу');
INSERT INTO "languageNames" VALUES(NULL,'kk','tg','тәжік');
INSERT INTO "languageNames" VALUES(NULL,'kk','th','тай');
INSERT INTO "languageNames" VALUES(NULL,'kk','tk','түрікменше');
INSERT INTO "languageNames" VALUES(NULL,'kk','tr','түрікше');
INSERT INTO "languageNames" VALUES(NULL,'kk','tt','татарша');
INSERT INTO "languageNames" VALUES(NULL,'kk','uk','украин');
INSERT INTO "languageNames" VALUES(NULL,'kk','ur','урду');
INSERT INTO "languageNames" VALUES(NULL,'kk','uz','өзбекше');
INSERT INTO "languageNames" VALUES(NULL,'kk','vi','вьетнам');
INSERT INTO "languageNames" VALUES(NULL,'kk','xh','ксоза');
INSERT INTO "languageNames" VALUES(NULL,'kk','zh','қытай тілі');
INSERT INTO "languageNames" VALUES(NULL,'kk','zu','зулу');
INSERT INTO "languageNames" VALUES(NULL,'tr','af','Afrikaanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','ar','Arapça');
INSERT INTO "languageNames" VALUES(NULL,'tr','as','Assamca');
INSERT INTO "languageNames" VALUES(NULL,'tr','av','Avar Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','az','Azerice');
INSERT INTO "languageNames" VALUES(NULL,'tr','ba','Başkırtça');
INSERT INTO "languageNames" VALUES(NULL,'tr','be','Beyaz Rusça');
INSERT INTO "languageNames" VALUES(NULL,'tr','bg','Bulgarca');
INSERT INTO "languageNames" VALUES(NULL,'tr','bi','Bislama');
INSERT INTO "languageNames" VALUES(NULL,'tr','bn','Bengalce');
INSERT INTO "languageNames" VALUES(NULL,'tr','br','Breton');
INSERT INTO "languageNames" VALUES(NULL,'tr','bua','Buryat');
INSERT INTO "languageNames" VALUES(NULL,'tr','ca','Katalanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(NULL,'tr','ckb','Orta Kürtçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','co','Korsikaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','cs','Çekçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','csb','Kashubian');
INSERT INTO "languageNames" VALUES(NULL,'tr','cu','Kilise Slavcası');
INSERT INTO "languageNames" VALUES(NULL,'tr','cv','Çuvaşça');
INSERT INTO "languageNames" VALUES(NULL,'tr','cy','Galce');
INSERT INTO "languageNames" VALUES(NULL,'tr','da','Danca');
INSERT INTO "languageNames" VALUES(NULL,'tr','de','Almanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','dsb','Aşağı Sorbça');
INSERT INTO "languageNames" VALUES(NULL,'tr','el','Yunanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','en','İngilizce');
INSERT INTO "languageNames" VALUES(NULL,'tr','eo','Esperanto');
INSERT INTO "languageNames" VALUES(NULL,'tr','es','İspanyolca');
INSERT INTO "languageNames" VALUES(NULL,'tr','et','Estonca');
INSERT INTO "languageNames" VALUES(NULL,'tr','eu','Baskça');
INSERT INTO "languageNames" VALUES(NULL,'tr','fa','Farsça');
INSERT INTO "languageNames" VALUES(NULL,'tr','fi','Fince');
INSERT INTO "languageNames" VALUES(NULL,'tr','fo','Faroe Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','fr','Fransızca');
INSERT INTO "languageNames" VALUES(NULL,'tr','fy','Batı Frizcesi');
INSERT INTO "languageNames" VALUES(NULL,'tr','ga','İrlandaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','gd','İskoç Gal Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','gn','Guarani Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','gv','Manks');
INSERT INTO "languageNames" VALUES(NULL,'tr','he','İbranice');
INSERT INTO "languageNames" VALUES(NULL,'tr','hi','Hintçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','hsb','Yukarı Sorbça');
INSERT INTO "languageNames" VALUES(NULL,'tr','ht','Haiti Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','hu','Macarca');
INSERT INTO "languageNames" VALUES(NULL,'tr','hy','Ermenice');
INSERT INTO "languageNames" VALUES(NULL,'tr','ia','Interlingua');
INSERT INTO "languageNames" VALUES(NULL,'tr','id','Endonezce');
INSERT INTO "languageNames" VALUES(NULL,'tr','is','İzlandaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','it','İtalyanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','kaa','Karakalpakça');
INSERT INTO "languageNames" VALUES(NULL,'tr','kk','Kazakça');
INSERT INTO "languageNames" VALUES(NULL,'tr','ko','Korece');
INSERT INTO "languageNames" VALUES(NULL,'tr','ku','Kürtçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','kum','Kumukça');
INSERT INTO "languageNames" VALUES(NULL,'tr','kv','Komi');
INSERT INTO "languageNames" VALUES(NULL,'tr','ky','Kırgızca');
INSERT INTO "languageNames" VALUES(NULL,'tr','la','Latince');
INSERT INTO "languageNames" VALUES(NULL,'tr','lb','Lüksemburgca');
INSERT INTO "languageNames" VALUES(NULL,'tr','lg','Ganda');
INSERT INTO "languageNames" VALUES(NULL,'tr','lo','Laoca');
INSERT INTO "languageNames" VALUES(NULL,'tr','lt','Litvanyaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','lv','Letonca');
INSERT INTO "languageNames" VALUES(NULL,'tr','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(NULL,'tr','mk','Makedonca');
INSERT INTO "languageNames" VALUES(NULL,'tr','ml','Malayalam');
INSERT INTO "languageNames" VALUES(NULL,'tr','mr','Marathi');
INSERT INTO "languageNames" VALUES(NULL,'tr','mt','Maltaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','myv','Erzya');
INSERT INTO "languageNames" VALUES(NULL,'tr','nb','Norveççe Bokmål');
INSERT INTO "languageNames" VALUES(NULL,'tr','ne','Nepalce');
INSERT INTO "languageNames" VALUES(NULL,'tr','nl','Hollandaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','nn','Norveççe Nynorsk');
INSERT INTO "languageNames" VALUES(NULL,'tr','no','Norveççe');
INSERT INTO "languageNames" VALUES(NULL,'tr','nog','Nogayca');
INSERT INTO "languageNames" VALUES(NULL,'tr','oc','Occitan');
INSERT INTO "languageNames" VALUES(NULL,'tr','os','Osetçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','pa','Pencapça');
INSERT INTO "languageNames" VALUES(NULL,'tr','pl','Lehçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','pt','Portekizce');
INSERT INTO "languageNames" VALUES(NULL,'tr','rm','Romanşça');
INSERT INTO "languageNames" VALUES(NULL,'tr','rn','Kirundi');
INSERT INTO "languageNames" VALUES(NULL,'tr','ro','Romence');
INSERT INTO "languageNames" VALUES(NULL,'tr','ru','Rusça');
INSERT INTO "languageNames" VALUES(NULL,'tr','rup','Ulahça');
INSERT INTO "languageNames" VALUES(NULL,'tr','sa','Sanskritçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','sc','Sardunya Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','sco','Scots');
INSERT INTO "languageNames" VALUES(NULL,'tr','se','Kuzey Sami');
INSERT INTO "languageNames" VALUES(NULL,'tr','sh','Sırp-Hırvat Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','si','Seylanca');
INSERT INTO "languageNames" VALUES(NULL,'tr','sk','Slovakça');
INSERT INTO "languageNames" VALUES(NULL,'tr','sl','Slovence');
INSERT INTO "languageNames" VALUES(NULL,'tr','sma','Güney Sami');
INSERT INTO "languageNames" VALUES(NULL,'tr','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(NULL,'tr','sq','Arnavutça');
INSERT INTO "languageNames" VALUES(NULL,'tr','sv','İsveççe');
INSERT INTO "languageNames" VALUES(NULL,'tr','sw','Svahili');
INSERT INTO "languageNames" VALUES(NULL,'tr','te','Telugu Dili');
INSERT INTO "languageNames" VALUES(NULL,'tr','tet','Tetum');
INSERT INTO "languageNames" VALUES(NULL,'tr','tg','Tacikçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','th','Tayca');
INSERT INTO "languageNames" VALUES(NULL,'tr','tk','Türkmence');
INSERT INTO "languageNames" VALUES(NULL,'tr','tl','Takalotça');
INSERT INTO "languageNames" VALUES(NULL,'tr','tr','Türkçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','tt','Tatarca');
INSERT INTO "languageNames" VALUES(NULL,'tr','tyv','Tuvaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','udm','Udmurtça');
INSERT INTO "languageNames" VALUES(NULL,'tr','uk','Ukraynaca');
INSERT INTO "languageNames" VALUES(NULL,'tr','ur','Urduca');
INSERT INTO "languageNames" VALUES(NULL,'tr','uz','Özbekçe');
INSERT INTO "languageNames" VALUES(NULL,'tr','vi','Vietnamca');
INSERT INTO "languageNames" VALUES(NULL,'tr','xh','Zosa');
INSERT INTO "languageNames" VALUES(NULL,'tr','zh','Çince');
INSERT INTO "languageNames" VALUES(NULL,'tr','zu','Zuluca');
INSERT INTO "languageNames" VALUES(NULL,'uz','af','afrikancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ar','arabcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','as','assamcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','az','ozarbayjoncha');
INSERT INTO "languageNames" VALUES(NULL,'uz','be','belaruscha');
INSERT INTO "languageNames" VALUES(NULL,'uz','bg','bolgarcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','bn','bengalcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ca','katalancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','cs','chexcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','cy','uelscha');
INSERT INTO "languageNames" VALUES(NULL,'uz','da','daniyacha');
INSERT INTO "languageNames" VALUES(NULL,'uz','de','olmoncha');
INSERT INTO "languageNames" VALUES(NULL,'uz','el','grekcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','en','inglizcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','eo','esperanto');
INSERT INTO "languageNames" VALUES(NULL,'uz','es','ispancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','et','estoncha');
INSERT INTO "languageNames" VALUES(NULL,'uz','eu','baskcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','fa','forscha');
INSERT INTO "languageNames" VALUES(NULL,'uz','fi','fincha');
INSERT INTO "languageNames" VALUES(NULL,'uz','fo','farercha');
INSERT INTO "languageNames" VALUES(NULL,'uz','fr','fransuzcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','fy','gʻarbiy friziancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ga','irlandcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','gn','guarani');
INSERT INTO "languageNames" VALUES(NULL,'uz','he','ibroniy');
INSERT INTO "languageNames" VALUES(NULL,'uz','hi','hindcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ht','gaitiancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','hu','vengrcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','hy','armancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','id','indoneziyacha');
INSERT INTO "languageNames" VALUES(NULL,'uz','is','islandcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','it','italyancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','kk','qozoqcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ko','koreyscha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ku','kurdcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ky','qirgʻizcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','la','lotincha');
INSERT INTO "languageNames" VALUES(NULL,'uz','lb','lyuksemburgcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','lo','lao');
INSERT INTO "languageNames" VALUES(NULL,'uz','lt','litvacha');
INSERT INTO "languageNames" VALUES(NULL,'uz','lv','latishcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','mk','makedoncha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ml','malayalam');
INSERT INTO "languageNames" VALUES(NULL,'uz','mr','marati');
INSERT INTO "languageNames" VALUES(NULL,'uz','mt','maltacha');
INSERT INTO "languageNames" VALUES(NULL,'uz','nb','norvegcha bokmal');
INSERT INTO "languageNames" VALUES(NULL,'uz','ne','nepalcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','nl','gollandcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','nn','norvegcha ninorsk');
INSERT INTO "languageNames" VALUES(NULL,'uz','pa','panjobcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','pl','polyakcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','pt','portugalcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','rm','romancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ro','rumincha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ru','ruscha');
INSERT INTO "languageNames" VALUES(NULL,'uz','sa','sanskritcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','si','sinxala');
INSERT INTO "languageNames" VALUES(NULL,'uz','sk','slovakcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','sl','slovencha');
INSERT INTO "languageNames" VALUES(NULL,'uz','sq','albancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','sv','shvedcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','sw','suaxili');
INSERT INTO "languageNames" VALUES(NULL,'uz','te','telugu');
INSERT INTO "languageNames" VALUES(NULL,'uz','tg','tojikcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','th','taycha');
INSERT INTO "languageNames" VALUES(NULL,'uz','tk','turkmancha');
INSERT INTO "languageNames" VALUES(NULL,'uz','tr','turkcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','tt','tatarcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','uk','ukraincha');
INSERT INTO "languageNames" VALUES(NULL,'uz','ur','urdu');
INSERT INTO "languageNames" VALUES(NULL,'uz','uz','oʻzbekcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','vi','vyetnamcha');
INSERT INTO "languageNames" VALUES(NULL,'uz','xh','xosa');
INSERT INTO "languageNames" VALUES(NULL,'uz','zh','xitoycha');
INSERT INTO "languageNames" VALUES(NULL,'uz','zu','zulu');
INSERT INTO "languageNames" VALUES(NULL,'az','af','afrikaans');
INSERT INTO "languageNames" VALUES(NULL,'az','ar','ərəb');
INSERT INTO "languageNames" VALUES(NULL,'az','as','assam');
INSERT INTO "languageNames" VALUES(NULL,'az','av','avarikcə');
INSERT INTO "languageNames" VALUES(NULL,'az','az','azərbaycan');
INSERT INTO "languageNames" VALUES(NULL,'az','ba','başkir dili');
INSERT INTO "languageNames" VALUES(NULL,'az','be','belarus');
INSERT INTO "languageNames" VALUES(NULL,'az','bg','bolqar');
INSERT INTO "languageNames" VALUES(NULL,'az','bi','bislama dili');
INSERT INTO "languageNames" VALUES(NULL,'az','bn','benqal');
INSERT INTO "languageNames" VALUES(NULL,'az','br','Bretonca');
INSERT INTO "languageNames" VALUES(NULL,'az','bua','buryat dili');
INSERT INTO "languageNames" VALUES(NULL,'az','ca','katalan');
INSERT INTO "languageNames" VALUES(NULL,'az','ceb','kebuano dili');
INSERT INTO "languageNames" VALUES(NULL,'az','co','korsikan dili');
INSERT INTO "languageNames" VALUES(NULL,'az','cs','çex');
INSERT INTO "languageNames" VALUES(NULL,'az','csb','kaşubyan dili');
INSERT INTO "languageNames" VALUES(NULL,'az','cu','kilsə slav dili');
INSERT INTO "languageNames" VALUES(NULL,'az','cv','çuvaş dili');
INSERT INTO "languageNames" VALUES(NULL,'az','cy','uels');
INSERT INTO "languageNames" VALUES(NULL,'az','da','danimarka');
INSERT INTO "languageNames" VALUES(NULL,'az','de','alman');
INSERT INTO "languageNames" VALUES(NULL,'az','dsb','aşağı sorbca');
INSERT INTO "languageNames" VALUES(NULL,'az','el','yunan');
INSERT INTO "languageNames" VALUES(NULL,'az','en','ingilis');
INSERT INTO "languageNames" VALUES(NULL,'az','eo','esperanto');
INSERT INTO "languageNames" VALUES(NULL,'az','es','ispan');
INSERT INTO "languageNames" VALUES(NULL,'az','et','eston');
INSERT INTO "languageNames" VALUES(NULL,'az','eu','bask');
INSERT INTO "languageNames" VALUES(NULL,'az','fa','fars');
INSERT INTO "languageNames" VALUES(NULL,'az','fi','fin');
INSERT INTO "languageNames" VALUES(NULL,'az','fo','farer');
INSERT INTO "languageNames" VALUES(NULL,'az','fr','fransız');
INSERT INTO "languageNames" VALUES(NULL,'az','fy','friz');
INSERT INTO "languageNames" VALUES(NULL,'az','ga','irland');
INSERT INTO "languageNames" VALUES(NULL,'az','gd','skot gaelik dili');
INSERT INTO "languageNames" VALUES(NULL,'az','gn','quarani');
INSERT INTO "languageNames" VALUES(NULL,'az','gv','manks dili');
INSERT INTO "languageNames" VALUES(NULL,'az','he','ivrit');
INSERT INTO "languageNames" VALUES(NULL,'az','hi','hindi');
INSERT INTO "languageNames" VALUES(NULL,'az','hsb','yuxarı sorbca');
INSERT INTO "languageNames" VALUES(NULL,'az','ht','haiti');
INSERT INTO "languageNames" VALUES(NULL,'az','hu','macar');
INSERT INTO "languageNames" VALUES(NULL,'az','hy','erməni');
INSERT INTO "languageNames" VALUES(NULL,'az','ia','interlingua dili');
INSERT INTO "languageNames" VALUES(NULL,'az','id','indoneziya');
INSERT INTO "languageNames" VALUES(NULL,'az','is','island');
INSERT INTO "languageNames" VALUES(NULL,'az','it','italyan');
INSERT INTO "languageNames" VALUES(NULL,'az','kaa','qara-qalpaq dili');
INSERT INTO "languageNames" VALUES(NULL,'az','kk','qazax');
INSERT INTO "languageNames" VALUES(NULL,'az','ko','koreya');
INSERT INTO "languageNames" VALUES(NULL,'az','ku','kürd');
INSERT INTO "languageNames" VALUES(NULL,'az','kum','kumuk dili');
INSERT INTO "languageNames" VALUES(NULL,'az','kv','komi dili');
INSERT INTO "languageNames" VALUES(NULL,'az','ky','qırğız');
INSERT INTO "languageNames" VALUES(NULL,'az','la','latın');
INSERT INTO "languageNames" VALUES(NULL,'az','lb','lüksemburq');
INSERT INTO "languageNames" VALUES(NULL,'az','lg','qanda dili');
INSERT INTO "languageNames" VALUES(NULL,'az','lo','laos');
INSERT INTO "languageNames" VALUES(NULL,'az','lt','litva');
INSERT INTO "languageNames" VALUES(NULL,'az','lv','latış');
INSERT INTO "languageNames" VALUES(NULL,'az','mk','makedon');
INSERT INTO "languageNames" VALUES(NULL,'az','ml','malayalam');
INSERT INTO "languageNames" VALUES(NULL,'az','mr','marati');
INSERT INTO "languageNames" VALUES(NULL,'az','mt','malta');
INSERT INTO "languageNames" VALUES(NULL,'az','myv','erzya dili');
INSERT INTO "languageNames" VALUES(NULL,'az','nb','bokmal norveç');
INSERT INTO "languageNames" VALUES(NULL,'az','ne','nepal');
INSERT INTO "languageNames" VALUES(NULL,'az','nl','holland');
INSERT INTO "languageNames" VALUES(NULL,'az','nn','nünorsk norveç');
INSERT INTO "languageNames" VALUES(NULL,'az','no','norveç dili');
INSERT INTO "languageNames" VALUES(NULL,'az','nog','noqay dili');
INSERT INTO "languageNames" VALUES(NULL,'az','oc','oksitanca');
INSERT INTO "languageNames" VALUES(NULL,'az','os','osetik dili');
INSERT INTO "languageNames" VALUES(NULL,'az','pa','pəncab');
INSERT INTO "languageNames" VALUES(NULL,'az','pl','polyak');
INSERT INTO "languageNames" VALUES(NULL,'az','pt','portuqal');
INSERT INTO "languageNames" VALUES(NULL,'az','rm','retoroman');
INSERT INTO "languageNames" VALUES(NULL,'az','rn','rundi dili');
INSERT INTO "languageNames" VALUES(NULL,'az','ro','rumın');
INSERT INTO "languageNames" VALUES(NULL,'az','ru','rus');
INSERT INTO "languageNames" VALUES(NULL,'az','rup','aromanca');
INSERT INTO "languageNames" VALUES(NULL,'az','sa','sanskrit');
INSERT INTO "languageNames" VALUES(NULL,'az','sc','sardin dili');
INSERT INTO "languageNames" VALUES(NULL,'az','sco','skots dili');
INSERT INTO "languageNames" VALUES(NULL,'az','se','şimal sami dili');
INSERT INTO "languageNames" VALUES(NULL,'az','sh','serb-xorvatca');
INSERT INTO "languageNames" VALUES(NULL,'az','si','sinhal');
INSERT INTO "languageNames" VALUES(NULL,'az','sk','slovak');
INSERT INTO "languageNames" VALUES(NULL,'az','sl','sloven');
INSERT INTO "languageNames" VALUES(NULL,'az','sma','cənub sami dili');
INSERT INTO "languageNames" VALUES(NULL,'az','smj','lule sami dili');
INSERT INTO "languageNames" VALUES(NULL,'az','sq','alban');
INSERT INTO "languageNames" VALUES(NULL,'az','sv','isveç');
INSERT INTO "languageNames" VALUES(NULL,'az','sw','suahili');
INSERT INTO "languageNames" VALUES(NULL,'az','te','teluqu');
INSERT INTO "languageNames" VALUES(NULL,'az','tet','tetum dili');
INSERT INTO "languageNames" VALUES(NULL,'az','tg','tacik');
INSERT INTO "languageNames" VALUES(NULL,'az','th','tay');
INSERT INTO "languageNames" VALUES(NULL,'az','tk','türkmən');
INSERT INTO "languageNames" VALUES(NULL,'az','tl','taqaloq dili');
INSERT INTO "languageNames" VALUES(NULL,'az','tr','türk');
INSERT INTO "languageNames" VALUES(NULL,'az','tt','tatar');
INSERT INTO "languageNames" VALUES(NULL,'az','tyv','tuvinyan dili');
INSERT INTO "languageNames" VALUES(NULL,'az','udm','udmurt dili');
INSERT INTO "languageNames" VALUES(NULL,'az','uk','ukrayna');
INSERT INTO "languageNames" VALUES(NULL,'az','ur','urdu');
INSERT INTO "languageNames" VALUES(NULL,'az','uz','özbək');
INSERT INTO "languageNames" VALUES(NULL,'az','vi','vyetnam');
INSERT INTO "languageNames" VALUES(NULL,'az','xh','xosa');
INSERT INTO "languageNames" VALUES(NULL,'az','zh','çin');
INSERT INTO "languageNames" VALUES(NULL,'az','zu','zulu');
INSERT INTO "languageNames" VALUES(NULL,'ru','af','африкаанс');
INSERT INTO "languageNames" VALUES(NULL,'ru','ar','арабский');
INSERT INTO "languageNames" VALUES(NULL,'ru','as','ассамский');
INSERT INTO "languageNames" VALUES(NULL,'ru','av','аварский');
INSERT INTO "languageNames" VALUES(NULL,'ru','az','азербайджанский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ba','башкирский');
INSERT INTO "languageNames" VALUES(NULL,'ru','be','белорусский');
INSERT INTO "languageNames" VALUES(NULL,'ru','bg','болгарский');
INSERT INTO "languageNames" VALUES(NULL,'ru','bi','бислама');
INSERT INTO "languageNames" VALUES(NULL,'ru','bn','бенгальский');
INSERT INTO "languageNames" VALUES(NULL,'ru','br','бретонский');
INSERT INTO "languageNames" VALUES(NULL,'ru','bua','бурятский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ca','каталанский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ceb','кебуано');
INSERT INTO "languageNames" VALUES(NULL,'ru','ckb','сорани курдский');
INSERT INTO "languageNames" VALUES(NULL,'ru','co','корсиканский');
INSERT INTO "languageNames" VALUES(NULL,'ru','cs','чешский');
INSERT INTO "languageNames" VALUES(NULL,'ru','csb','кашубианский');
INSERT INTO "languageNames" VALUES(NULL,'ru','cu','церковнославянский');
INSERT INTO "languageNames" VALUES(NULL,'ru','cv','чувашский');
INSERT INTO "languageNames" VALUES(NULL,'ru','cy','валлийский');
INSERT INTO "languageNames" VALUES(NULL,'ru','da','датский');
INSERT INTO "languageNames" VALUES(NULL,'ru','de','немецкий');
INSERT INTO "languageNames" VALUES(NULL,'ru','dsb','нижнелужицкий');
INSERT INTO "languageNames" VALUES(NULL,'ru','el','греческий');
INSERT INTO "languageNames" VALUES(NULL,'ru','en','английский');
INSERT INTO "languageNames" VALUES(NULL,'ru','eo','эсперанто');
INSERT INTO "languageNames" VALUES(NULL,'ru','es','испанский');
INSERT INTO "languageNames" VALUES(NULL,'ru','et','эстонский');
INSERT INTO "languageNames" VALUES(NULL,'ru','eu','баскский');
INSERT INTO "languageNames" VALUES(NULL,'ru','fa','персидский');
INSERT INTO "languageNames" VALUES(NULL,'ru','fi','финский');
INSERT INTO "languageNames" VALUES(NULL,'ru','fo','фарерский');
INSERT INTO "languageNames" VALUES(NULL,'ru','fr','французский');
INSERT INTO "languageNames" VALUES(NULL,'ru','fy','западно-фризский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ga','ирландский');
INSERT INTO "languageNames" VALUES(NULL,'ru','gd','гэльский');
INSERT INTO "languageNames" VALUES(NULL,'ru','gn','гуарани');
INSERT INTO "languageNames" VALUES(NULL,'ru','gv','мэнский');
INSERT INTO "languageNames" VALUES(NULL,'ru','he','иврит');
INSERT INTO "languageNames" VALUES(NULL,'ru','hi','хинди');
INSERT INTO "languageNames" VALUES(NULL,'ru','hsb','верхнелужицкий');
INSERT INTO "languageNames" VALUES(NULL,'ru','ht','гаитянский');
INSERT INTO "languageNames" VALUES(NULL,'ru','hu','венгерский');
INSERT INTO "languageNames" VALUES(NULL,'ru','hy','армянский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ia','интерлингва');
INSERT INTO "languageNames" VALUES(NULL,'ru','id','индонезийский');
INSERT INTO "languageNames" VALUES(NULL,'ru','is','исландский');
INSERT INTO "languageNames" VALUES(NULL,'ru','it','итальянский');
INSERT INTO "languageNames" VALUES(NULL,'ru','kaa','каракалпакский');
INSERT INTO "languageNames" VALUES(NULL,'ru','kk','казахский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ko','корейский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ku','курдский');
INSERT INTO "languageNames" VALUES(NULL,'ru','kum','кумыкский');
INSERT INTO "languageNames" VALUES(NULL,'ru','kv','коми');
INSERT INTO "languageNames" VALUES(NULL,'ru','ky','кыргызский');
INSERT INTO "languageNames" VALUES(NULL,'ru','la','латинский');
INSERT INTO "languageNames" VALUES(NULL,'ru','lb','люксембургский');
INSERT INTO "languageNames" VALUES(NULL,'ru','lg','ганда');
INSERT INTO "languageNames" VALUES(NULL,'ru','lo','лаосский');
INSERT INTO "languageNames" VALUES(NULL,'ru','lt','литовский');
INSERT INTO "languageNames" VALUES(NULL,'ru','lv','латышский');
INSERT INTO "languageNames" VALUES(NULL,'ru','mfe','маврикийский креольский');
INSERT INTO "languageNames" VALUES(NULL,'ru','mk','македонский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ml','малаялам');
INSERT INTO "languageNames" VALUES(NULL,'ru','mr','маратхи');
INSERT INTO "languageNames" VALUES(NULL,'ru','mt','мальтийский');
INSERT INTO "languageNames" VALUES(NULL,'ru','myv','эрзя');
INSERT INTO "languageNames" VALUES(NULL,'ru','nb','норвежский букмол');
INSERT INTO "languageNames" VALUES(NULL,'ru','ne','непальский');
INSERT INTO "languageNames" VALUES(NULL,'ru','nl','голландский');
INSERT INTO "languageNames" VALUES(NULL,'ru','nn','норвежский нюнорск');
INSERT INTO "languageNames" VALUES(NULL,'ru','no','норвежский');
INSERT INTO "languageNames" VALUES(NULL,'ru','nog','ногайский');
INSERT INTO "languageNames" VALUES(NULL,'ru','oc','окситанский');
INSERT INTO "languageNames" VALUES(NULL,'ru','os','осетинский');
INSERT INTO "languageNames" VALUES(NULL,'ru','pa','панджаби');
INSERT INTO "languageNames" VALUES(NULL,'ru','pl','польский');
INSERT INTO "languageNames" VALUES(NULL,'ru','pt','португальский');
INSERT INTO "languageNames" VALUES(NULL,'ru','rm','романшский');
INSERT INTO "languageNames" VALUES(NULL,'ru','rn','рунди');
INSERT INTO "languageNames" VALUES(NULL,'ru','ro','румынский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ru','русский');
INSERT INTO "languageNames" VALUES(NULL,'ru','rup','арумынский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sa','санскрит');
INSERT INTO "languageNames" VALUES(NULL,'ru','sc','сардинский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sco','шотландский');
INSERT INTO "languageNames" VALUES(NULL,'ru','se','северносаамский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sh','сербскохорватский');
INSERT INTO "languageNames" VALUES(NULL,'ru','si','сингальский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sk','словацкий');
INSERT INTO "languageNames" VALUES(NULL,'ru','sl','словенский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sma','саамский (южный)');
INSERT INTO "languageNames" VALUES(NULL,'ru','smj','луле-саамский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sq','албанский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sv','шведский');
INSERT INTO "languageNames" VALUES(NULL,'ru','sw','суахили');
INSERT INTO "languageNames" VALUES(NULL,'ru','te','телугу');
INSERT INTO "languageNames" VALUES(NULL,'ru','tet','тетум');
INSERT INTO "languageNames" VALUES(NULL,'ru','tg','таджикский');
INSERT INTO "languageNames" VALUES(NULL,'ru','th','тайский');
INSERT INTO "languageNames" VALUES(NULL,'ru','tk','туркменский');
INSERT INTO "languageNames" VALUES(NULL,'ru','tl','тагалог');
INSERT INTO "languageNames" VALUES(NULL,'ru','tr','турецкий');
INSERT INTO "languageNames" VALUES(NULL,'ru','tt','татарский');
INSERT INTO "languageNames" VALUES(NULL,'ru','tyv','тувинский');
INSERT INTO "languageNames" VALUES(NULL,'ru','udm','удмуртский');
INSERT INTO "languageNames" VALUES(NULL,'ru','uk','украинский');
INSERT INTO "languageNames" VALUES(NULL,'ru','ur','урду');
INSERT INTO "languageNames" VALUES(NULL,'ru','uz','узбекский');
INSERT INTO "languageNames" VALUES(NULL,'ru','vi','вьетнамский');
INSERT INTO "languageNames" VALUES(NULL,'ru','xh','ксоза');
INSERT INTO "languageNames" VALUES(NULL,'ru','zh','китайский');
INSERT INTO "languageNames" VALUES(NULL,'ru','zu','зулу');
INSERT INTO "languageNames" VALUES(NULL,'en','af','Afrikaans');
INSERT INTO "languageNames" VALUES(NULL,'en','ar','Arabic');
INSERT INTO "languageNames" VALUES(NULL,'en','as','Assamese');
INSERT INTO "languageNames" VALUES(NULL,'en','av','Avaric');
INSERT INTO "languageNames" VALUES(NULL,'en','az','Azeri');
INSERT INTO "languageNames" VALUES(NULL,'en','ba','Bashkir');
INSERT INTO "languageNames" VALUES(NULL,'en','be','Belarusian');
INSERT INTO "languageNames" VALUES(NULL,'en','bg','Bulgarian');
INSERT INTO "languageNames" VALUES(NULL,'en','bi','Bislama');
INSERT INTO "languageNames" VALUES(NULL,'en','bn','Bengali');
INSERT INTO "languageNames" VALUES(NULL,'en','br','Breton');
INSERT INTO "languageNames" VALUES(NULL,'en','bua','Buriat');
INSERT INTO "languageNames" VALUES(NULL,'en','ca','Catalan');
INSERT INTO "languageNames" VALUES(NULL,'en','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(NULL,'en','ckb','Sorani Kurdish');
INSERT INTO "languageNames" VALUES(NULL,'en','co','Corsican');
INSERT INTO "languageNames" VALUES(NULL,'en','cs','Czech');
INSERT INTO "languageNames" VALUES(NULL,'en','csb','Kashubian');
INSERT INTO "languageNames" VALUES(NULL,'en','cu','Church Slavic');
INSERT INTO "languageNames" VALUES(NULL,'en','cv','Chuvash');
INSERT INTO "languageNames" VALUES(NULL,'en','cy','Welsh');
INSERT INTO "languageNames" VALUES(NULL,'en','da','Danish');
INSERT INTO "languageNames" VALUES(NULL,'en','de','German');
INSERT INTO "languageNames" VALUES(NULL,'en','dsb','Lower Sorbian');
INSERT INTO "languageNames" VALUES(NULL,'en','el','Greek');
INSERT INTO "languageNames" VALUES(NULL,'en','en','English');
INSERT INTO "languageNames" VALUES(NULL,'en','eo','Esperanto');
INSERT INTO "languageNames" VALUES(NULL,'en','es','Spanish');
INSERT INTO "languageNames" VALUES(NULL,'en','et','Estonian');
INSERT INTO "languageNames" VALUES(NULL,'en','eu','Basque');
INSERT INTO "languageNames" VALUES(NULL,'en','fa','Persian');
INSERT INTO "languageNames" VALUES(NULL,'en','fi','Finnish');
INSERT INTO "languageNames" VALUES(NULL,'en','fo','Faroese');
INSERT INTO "languageNames" VALUES(NULL,'en','fr','French');
INSERT INTO "languageNames" VALUES(NULL,'en','fy','Western Frisian');
INSERT INTO "languageNames" VALUES(NULL,'en','ga','Irish');
INSERT INTO "languageNames" VALUES(NULL,'en','gd','Scottish Gaelic');
INSERT INTO "languageNames" VALUES(NULL,'en','gn','Guarani');
INSERT INTO "languageNames" VALUES(NULL,'en','gv','Manx');
INSERT INTO "languageNames" VALUES(NULL,'en','he','Hebrew');
INSERT INTO "languageNames" VALUES(NULL,'en','hi','Hindi');
INSERT INTO "languageNames" VALUES(NULL,'en','hsb','Upper Sorbian');
INSERT INTO "languageNames" VALUES(NULL,'en','ht','Haitian');
INSERT INTO "languageNames" VALUES(NULL,'en','hu','Hungarian');
INSERT INTO "languageNames" VALUES(NULL,'en','hy','Armenian');
INSERT INTO "languageNames" VALUES(NULL,'en','ia','Interlingua');
INSERT INTO "languageNames" VALUES(NULL,'en','id','Indonesian');
INSERT INTO "languageNames" VALUES(NULL,'en','is','Icelandic');
INSERT INTO "languageNames" VALUES(NULL,'en','it','Italian');
INSERT INTO "languageNames" VALUES(NULL,'en','kaa','Karakalpak');
INSERT INTO "languageNames" VALUES(NULL,'en','kk','Kazakh');
INSERT INTO "languageNames" VALUES(NULL,'en','ko','Korean');
INSERT INTO "languageNames" VALUES(NULL,'en','ku','Kurdish');
INSERT INTO "languageNames" VALUES(NULL,'en','kum','Kumyk');
INSERT INTO "languageNames" VALUES(NULL,'en','kv','Komi');
INSERT INTO "languageNames" VALUES(NULL,'en','ky','Kyrgyz');
INSERT INTO "languageNames" VALUES(NULL,'en','la','Latin');
INSERT INTO "languageNames" VALUES(NULL,'en','lb','Luxembourgish');
INSERT INTO "languageNames" VALUES(NULL,'en','lg','Ganda');
INSERT INTO "languageNames" VALUES(NULL,'en','lo','Lao');
INSERT INTO "languageNames" VALUES(NULL,'en','lt','Lithuanian');
INSERT INTO "languageNames" VALUES(NULL,'en','lv','Latvian');
INSERT INTO "languageNames" VALUES(NULL,'en','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(NULL,'en','mk','Macedonian');
INSERT INTO "languageNames" VALUES(NULL,'en','ml','Malayalam');
INSERT INTO "languageNames" VALUES(NULL,'en','mr','Marathi');
INSERT INTO "languageNames" VALUES(NULL,'en','mt','Maltese');
INSERT INTO "languageNames" VALUES(NULL,'en','myv','Erzya');
INSERT INTO "languageNames" VALUES(NULL,'en','nb','Norwegian Bokmål');
INSERT INTO "languageNames" VALUES(NULL,'en','ne','Nepali');
INSERT INTO "languageNames" VALUES(NULL,'en','nl','Dutch');
INSERT INTO "languageNames" VALUES(NULL,'en','nn','Norwegian Nynorsk');
INSERT INTO "languageNames" VALUES(NULL,'en','no','Norwegian');
INSERT INTO "languageNames" VALUES(NULL,'en','nog','Nogai');
INSERT INTO "languageNames" VALUES(NULL,'en','oc','Occitan');
INSERT INTO "languageNames" VALUES(NULL,'en','os','Ossetian');
INSERT INTO "languageNames" VALUES(NULL,'en','pa','Punjabi');
INSERT INTO "languageNames" VALUES(NULL,'en','pl','Polish');
INSERT INTO "languageNames" VALUES(NULL,'en','pt','Portuguese');
INSERT INTO "languageNames" VALUES(NULL,'en','rm','Romansh');
INSERT INTO "languageNames" VALUES(NULL,'en','rn','Rundi');
INSERT INTO "languageNames" VALUES(NULL,'en','ro','Romanian');
INSERT INTO "languageNames" VALUES(NULL,'en','ru','Russian');
INSERT INTO "languageNames" VALUES(NULL,'en','rup','Aromanian');
INSERT INTO "languageNames" VALUES(NULL,'en','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(NULL,'en','sc','Sardinian');
INSERT INTO "languageNames" VALUES(NULL,'en','sco','Scots');
INSERT INTO "languageNames" VALUES(NULL,'en','se','Northern Sami');
INSERT INTO "languageNames" VALUES(NULL,'en','sh','Serbo-Croatian');
INSERT INTO "languageNames" VALUES(NULL,'en','si','Sinhala');
INSERT INTO "languageNames" VALUES(NULL,'en','sk','Slovak');
INSERT INTO "languageNames" VALUES(NULL,'en','sl','Slovenian');
INSERT INTO "languageNames" VALUES(NULL,'en','sma','Southern Sami');
INSERT INTO "languageNames" VALUES(NULL,'en','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(NULL,'en','sq','Albanian');
INSERT INTO "languageNames" VALUES(NULL,'en','sv','Swedish');
INSERT INTO "languageNames" VALUES(NULL,'en','sw','Swahili');
INSERT INTO "languageNames" VALUES(NULL,'en','te','Telugu');
INSERT INTO "languageNames" VALUES(NULL,'en','tet','Tetum');
INSERT INTO "languageNames" VALUES(NULL,'en','tg','Tajik');
INSERT INTO "languageNames" VALUES(NULL,'en','th','Thai');
INSERT INTO "languageNames" VALUES(NULL,'en','tk','Turkmen');
INSERT INTO "languageNames" VALUES(NULL,'en','tl','Tagalog');
INSERT INTO "languageNames" VALUES(NULL,'en','tr','Turkish');
INSERT INTO "languageNames" VALUES(NULL,'en','tt','Tatar');
INSERT INTO "languageNames" VALUES(NULL,'en','tyv','Tuvan');
INSERT INTO "languageNames" VALUES(NULL,'en','udm','Udmurt');
INSERT INTO "languageNames" VALUES(NULL,'en','uk','Ukrainian');
INSERT INTO "languageNames" VALUES(NULL,'en','ur','Urdu');
INSERT INTO "languageNames" VALUES(NULL,'en','uz','Uzbek');
INSERT INTO "languageNames" VALUES(NULL,'en','vi','Vietnamese');
INSERT INTO "languageNames" VALUES(NULL,'en','xh','Xhosa');
INSERT INTO "languageNames" VALUES(NULL,'en','zh','Chinese');
INSERT INTO "languageNames" VALUES(NULL,'en','zu','Zulu');
COMMIT;

