BEGIN TRANSACTION;
INSERT INTO "languageNames" VALUES(NULL,"an","cat_valencia","valenciana");
INSERT INTO "languageNames" VALUES(NULL,"an","por_BR","portugués brasileño");
INSERT INTO "languageNames" VALUES(NULL,"an","oci_aran","aranés");
INSERT INTO "languageNames" VALUES(NULL,"ca","cat_valencia","valencià");
INSERT INTO "languageNames" VALUES(NULL,"ca","por_BR","portuguès brasiler");
INSERT INTO "languageNames" VALUES(NULL,"ca","oci_aran","aranès");
INSERT INTO "languageNames" VALUES(NULL,"de","cat_valencia","valencianische");
INSERT INTO "languageNames" VALUES(NULL,"de","por_BR","brasilianisches portugiesisch");
INSERT INTO "languageNames" VALUES(NULL,"de","oci_aran","aranesische");
INSERT INTO "languageNames" VALUES(NULL,"en","cat_valencia","Valencian");
INSERT INTO "languageNames" VALUES(NULL,"en","eng_US","American English");
INSERT INTO "languageNames" VALUES(NULL,"en","eng_GB","British English");
INSERT INTO "languageNames" VALUES(NULL,"en","fra_eco","Quebec French");
INSERT INTO "languageNames" VALUES(NULL,"en","hbs_HR","Croatian");
INSERT INTO "languageNames" VALUES(NULL,"en","hbs_BS","Bosnian");
INSERT INTO "languageNames" VALUES(NULL,"en","hbs_SR","Serbian");
INSERT INTO "languageNames" VALUES(NULL,"en","mlt_translit","Maltese Transliterated");
INSERT INTO "languageNames" VALUES(NULL,"en","nno_e","East Norwegian");
INSERT INTO "languageNames" VALUES(NULL,"en","oci_aran","Aranese");
INSERT INTO "languageNames" VALUES(NULL,"en","oci_gascon","Gascon");
INSERT INTO "languageNames" VALUES(NULL,"en","por_BR","Brazilian Portuguese");
INSERT INTO "languageNames" VALUES(NULL,"en","tgk_translit","Tajik Transliterated");
INSERT INTO "languageNames" VALUES(NULL,"es","cat_valencia","valenciano");
INSERT INTO "languageNames" VALUES(NULL,"es","por_BR","portugués brasileño");
INSERT INTO "languageNames" VALUES(NULL,"es","oci_aran","aranés");
INSERT INTO "languageNames" VALUES(NULL,"eu","cat_valencia","valentziera");
INSERT INTO "languageNames" VALUES(NULL,"eu","por_BR","brasilgo portugesa");
INSERT INTO "languageNames" VALUES(NULL,"eu","oci_aran","aranera");
INSERT INTO "languageNames" VALUES(NULL,"fr","cat_valencia","valencien");
INSERT INTO "languageNames" VALUES(NULL,"fr","por_BR","portugais brésilien");
INSERT INTO "languageNames" VALUES(NULL,"fr","oci_aran","aranais");
INSERT INTO "languageNames" VALUES(NULL,"no","cat_valencia","valensiansk");
INSERT INTO "languageNames" VALUES(NULL,"no","por_BR","brasiliansk portugisisk");
INSERT INTO "languageNames" VALUES(NULL,"no","oci_aran","araneisk");
INSERT INTO "languageNames" VALUES(NULL,"pt","cat_valencia","valenciana");
INSERT INTO "languageNames" VALUES(NULL,"pt","por_BR","português brasileiro");
INSERT INTO "languageNames" VALUES(NULL,"pt","oci_aran","aranês");
INSERT INTO "languageNames" VALUES(NULL,"fi","cat_valencia","valencian");
INSERT INTO "languageNames" VALUES(NULL,"fi","por_BR","brasilianportugali");
INSERT INTO "languageNames" VALUES(NULL,"fi","oci_aran","araneesi");
INSERT INTO "languageNames" VALUES(NULL,"sv","cat_valencia","valencianska");
INSERT INTO "languageNames" VALUES(NULL,"sv","por_BR","brasiliansk portugisiska");
INSERT INTO "languageNames" VALUES(NULL,"sv","oci_aran","araneiska");
INSERT INTO "languageNames" VALUES(NULL,"szl","cat_valencia","walyncjańskŏ");
INSERT INTO "languageNames" VALUES(NULL,"szl","por_BR","portugalskŏ brazylijskŏ");
INSERT INTO "languageNames" VALUES(NULL,"szl","oci_aran","arańskŏ");
INSERT INTO "languageNames" VALUES(NULL,"tr","cat_valencia","valensiyaca");
INSERT INTO "languageNames" VALUES(NULL,"tr","por_BR","Brezilya Portekizcesi");
INSERT INTO "languageNames" VALUES(NULL,"tr","oci_aran","Aranca");
INSERT INTO "languageNames" VALUES(NULL,"ru","cat_valencia","валенсийский");
INSERT INTO "languageNames" VALUES(NULL,"ru","por_BR","брази́льский португа́льский");
INSERT INTO "languageNames" VALUES(NULL,"ru","oci_aran","aра́нский");
COMMIT;
