PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE languageNames (
    id INTEGER PRIMARY KEY,
    lg TEXT,
    inLg TEXT,
    name TEXT,
    UNIQUE(lg, inLg) ON CONFLICT REPLACE
);
INSERT INTO "languageNames" VALUES(1,'te','af','ఆఫ్రికాన్స్');
INSERT INTO "languageNames" VALUES(2,'te','alt','దక్షిణ ఆల్టై');
INSERT INTO "languageNames" VALUES(3,'te','an','అరగోనిస్');
INSERT INTO "languageNames" VALUES(4,'te','ar','అరబిక్');
INSERT INTO "languageNames" VALUES(5,'te','as','అస్సామీస్');
INSERT INTO "languageNames" VALUES(6,'te','ast','ఆస్టూరియన్');
INSERT INTO "languageNames" VALUES(7,'te','av','అవారిక్');
INSERT INTO "languageNames" VALUES(9,'te','az','అజెరి');
INSERT INTO "languageNames" VALUES(10,'te','ba','బష్కిర్');
INSERT INTO "languageNames" VALUES(11,'te','be','బెలరుషియన్');
INSERT INTO "languageNames" VALUES(12,'te','bg','బల్గేరియన్');
INSERT INTO "languageNames" VALUES(13,'te','bi','బిస్లామా');
INSERT INTO "languageNames" VALUES(14,'te','bn','బాంగ్లా');
INSERT INTO "languageNames" VALUES(15,'te','br','బ్రెటన్');
INSERT INTO "languageNames" VALUES(16,'te','bs','బోస్నియన్');
INSERT INTO "languageNames" VALUES(17,'te','bua','బురియట్');
INSERT INTO "languageNames" VALUES(18,'te','ca','కాటలాన్');
INSERT INTO "languageNames" VALUES(19,'te','ceb','సెబుయానో');
INSERT INTO "languageNames" VALUES(20,'te','chm','మారి');
INSERT INTO "languageNames" VALUES(21,'te','ckb','సెంట్రల్ కర్డిష్');
INSERT INTO "languageNames" VALUES(22,'te','co','కోర్సికన్');
INSERT INTO "languageNames" VALUES(23,'te','crh','క్రిమియన్ టర్కిష్');
INSERT INTO "languageNames" VALUES(24,'te','cs','చెక్');
INSERT INTO "languageNames" VALUES(25,'te','csb','కషుబియన్');
INSERT INTO "languageNames" VALUES(26,'te','cu','చర్చ్ స్లావిక్');
INSERT INTO "languageNames" VALUES(27,'te','cv','చువాష్');
INSERT INTO "languageNames" VALUES(28,'te','cy','వెల్ష్');
INSERT INTO "languageNames" VALUES(29,'te','da','డానిష్');
INSERT INTO "languageNames" VALUES(30,'te','dar','డార్గ్వా');
INSERT INTO "languageNames" VALUES(31,'te','de','జర్మన్');
INSERT INTO "languageNames" VALUES(32,'te','dsb','లోయర్ సోర్బియన్');
INSERT INTO "languageNames" VALUES(33,'te','el','గ్రీక్');
INSERT INTO "languageNames" VALUES(34,'te','en','ఆంగ్లం');
INSERT INTO "languageNames" VALUES(35,'te','eo','ఎస్పెరాంటో');
INSERT INTO "languageNames" VALUES(36,'te','es','స్పానిష్');
INSERT INTO "languageNames" VALUES(37,'te','et','ఎస్టోనియన్');
INSERT INTO "languageNames" VALUES(38,'te','eu','బాస్క్యూ');
INSERT INTO "languageNames" VALUES(39,'te','fa','పర్షియన్');
INSERT INTO "languageNames" VALUES(40,'te','fi','ఫిన్నిష్');
INSERT INTO "languageNames" VALUES(41,'te','fo','ఫారోయీజ్');
INSERT INTO "languageNames" VALUES(42,'te','fr','ఫ్రెంచ్');
INSERT INTO "languageNames" VALUES(43,'te','fy','పశ్చిమ ఫ్రిసియన్');
INSERT INTO "languageNames" VALUES(44,'te','ga','ఐరిష్');
INSERT INTO "languageNames" VALUES(45,'te','gag','గాగౌజ్');
INSERT INTO "languageNames" VALUES(46,'te','gd','స్కాటిష్ గేలిక్');
INSERT INTO "languageNames" VALUES(47,'te','gl','గాలిషియన్');
INSERT INTO "languageNames" VALUES(48,'te','gn','గ్వారనీ');
INSERT INTO "languageNames" VALUES(49,'te','gu','గుజరాతి');
INSERT INTO "languageNames" VALUES(50,'te','gv','మాంక్స్');
INSERT INTO "languageNames" VALUES(51,'te','ha','హౌసా');
INSERT INTO "languageNames" VALUES(52,'te','haw','హవాయియన్');
INSERT INTO "languageNames" VALUES(53,'te','he','హీబ్రూ');
INSERT INTO "languageNames" VALUES(54,'te','hi','హిందీ');
INSERT INTO "languageNames" VALUES(55,'te','hr','క్రోయేషియన్');
INSERT INTO "languageNames" VALUES(56,'te','hsb','అప్పర్ సోర్బియన్');
INSERT INTO "languageNames" VALUES(57,'te','ht','హైటియన్ క్రియోల్');
INSERT INTO "languageNames" VALUES(58,'te','hu','హంగేరియన్');
INSERT INTO "languageNames" VALUES(59,'te','hy','ఆర్మేనియన్');
INSERT INTO "languageNames" VALUES(60,'te','ia','ఇంటర్లింగ్వా');
INSERT INTO "languageNames" VALUES(61,'te','id','ఇండోనేషియన్');
INSERT INTO "languageNames" VALUES(62,'te','ig','ఇగ్బో');
INSERT INTO "languageNames" VALUES(63,'te','is','ఐస్లాండిక్');
INSERT INTO "languageNames" VALUES(64,'te','it','ఇటాలియన్');
INSERT INTO "languageNames" VALUES(65,'te','ka','జార్జియన్');
INSERT INTO "languageNames" VALUES(66,'te','kaa','కారా-కల్పాక్');
INSERT INTO "languageNames" VALUES(67,'te','kk','కజఖ్');
INSERT INTO "languageNames" VALUES(68,'te','ko','కొరియన్');
INSERT INTO "languageNames" VALUES(69,'te','krc','కరచే-బల్కార్');
INSERT INTO "languageNames" VALUES(70,'te','krl','కరేలియన్');
INSERT INTO "languageNames" VALUES(71,'te','ks','కాశ్మీరి');
INSERT INTO "languageNames" VALUES(72,'te','kum','కుమ్యిక్');
INSERT INTO "languageNames" VALUES(73,'te','kv','కోమి');
INSERT INTO "languageNames" VALUES(74,'te','ky','కిర్గిజ్');
INSERT INTO "languageNames" VALUES(75,'te','la','లాటిన్');
INSERT INTO "languageNames" VALUES(76,'te','lb','లక్సెంబర్గిష్');
INSERT INTO "languageNames" VALUES(77,'te','lg','గాండా');
INSERT INTO "languageNames" VALUES(78,'te','ln','లింగాల');
INSERT INTO "languageNames" VALUES(79,'te','lo','లావో');
INSERT INTO "languageNames" VALUES(80,'te','lt','లిథువేనియన్');
INSERT INTO "languageNames" VALUES(81,'te','lv','లాట్వియన్');
INSERT INTO "languageNames" VALUES(82,'te','mdf','మోక్ష');
INSERT INTO "languageNames" VALUES(83,'te','mfe','మొరిస్యేన్');
INSERT INTO "languageNames" VALUES(84,'te','mk','మసడోనియన్');
INSERT INTO "languageNames" VALUES(85,'te','ml','మలయాళం');
INSERT INTO "languageNames" VALUES(86,'te','mr','మరాఠీ');
INSERT INTO "languageNames" VALUES(87,'te','ms','మలాయ్');
INSERT INTO "languageNames" VALUES(88,'te','mt','మాల్టీస్');
INSERT INTO "languageNames" VALUES(89,'te','myv','ఎర్జియా');
INSERT INTO "languageNames" VALUES(90,'te','nap','నియాపోలిటన్');
INSERT INTO "languageNames" VALUES(91,'te','nb','నార్వేజియన్ బొక్మాల్');
INSERT INTO "languageNames" VALUES(92,'te','ne','నేపాలి');
INSERT INTO "languageNames" VALUES(93,'te','nl','డచ్');
INSERT INTO "languageNames" VALUES(94,'te','nn','నార్వేజియాన్ న్యోర్స్క్');
INSERT INTO "languageNames" VALUES(95,'te','no','నార్వేజియన్');
INSERT INTO "languageNames" VALUES(96,'te','nog','నోగై');
INSERT INTO "languageNames" VALUES(97,'te','oc','ఆక్సిటన్');
INSERT INTO "languageNames" VALUES(98,'te','os','ఒసేటిక్');
INSERT INTO "languageNames" VALUES(99,'te','ota','ఒట్టోమన్ టర్కిష్');
INSERT INTO "languageNames" VALUES(100,'te','pa','పంజాబీ');
INSERT INTO "languageNames" VALUES(101,'te','pl','పోలిష్');
INSERT INTO "languageNames" VALUES(102,'te','pt','పోర్చుగీస్');
INSERT INTO "languageNames" VALUES(103,'te','rm','రోమన్ష్');
INSERT INTO "languageNames" VALUES(104,'te','rn','రుండి');
INSERT INTO "languageNames" VALUES(105,'te','ro','రోమానియన్');
INSERT INTO "languageNames" VALUES(106,'te','ru','రష్యన్');
INSERT INTO "languageNames" VALUES(107,'te','rup','ఆరోమేనియన్');
INSERT INTO "languageNames" VALUES(108,'te','sa','సంస్కృతం');
INSERT INTO "languageNames" VALUES(109,'te','sah','సఖా');
INSERT INTO "languageNames" VALUES(110,'te','sc','సార్డీనియన్');
INSERT INTO "languageNames" VALUES(111,'te','scn','సిసిలియన్');
INSERT INTO "languageNames" VALUES(112,'te','sco','స్కాట్స్');
INSERT INTO "languageNames" VALUES(113,'te','sd','సింధీ');
INSERT INTO "languageNames" VALUES(114,'te','se','ఉత్తర సామి');
INSERT INTO "languageNames" VALUES(115,'te','sh','సేర్బో-క్రొయేషియన్');
INSERT INTO "languageNames" VALUES(116,'te','si','సింహళం');
INSERT INTO "languageNames" VALUES(117,'te','sk','స్లోవాక్');
INSERT INTO "languageNames" VALUES(118,'te','sl','స్లోవేనియన్');
INSERT INTO "languageNames" VALUES(119,'te','sma','దక్షిణ సామి');
INSERT INTO "languageNames" VALUES(120,'te','smj','లులే సామి');
INSERT INTO "languageNames" VALUES(121,'te','smn','ఇనారి సామి');
INSERT INTO "languageNames" VALUES(122,'te','sq','అల్బేనియన్');
INSERT INTO "languageNames" VALUES(123,'te','sr','సెర్బియన్');
INSERT INTO "languageNames" VALUES(124,'te','srn','స్రానన్ టోంగో');
INSERT INTO "languageNames" VALUES(125,'te','ss','స్వాతి');
INSERT INTO "languageNames" VALUES(126,'te','sv','స్వీడిష్');
INSERT INTO "languageNames" VALUES(127,'te','sw','స్వాహిలి');
INSERT INTO "languageNames" VALUES(128,'te','ta','తమిళము');
INSERT INTO "languageNames" VALUES(129,'te','te','తెలుగు');
INSERT INTO "languageNames" VALUES(130,'te','tet','టేటం');
INSERT INTO "languageNames" VALUES(131,'te','tg','తజిక్');
INSERT INTO "languageNames" VALUES(132,'te','th','థాయ్');
INSERT INTO "languageNames" VALUES(133,'te','tk','తుర్క్‌మెన్');
INSERT INTO "languageNames" VALUES(134,'te','tl','టగలాగ్');
INSERT INTO "languageNames" VALUES(135,'te','tr','టర్కిష్');
INSERT INTO "languageNames" VALUES(136,'te','tt','టాటర్');
INSERT INTO "languageNames" VALUES(137,'te','tyv','టువినియన్');
INSERT INTO "languageNames" VALUES(138,'te','udm','ఉడ్ముర్ట్');
INSERT INTO "languageNames" VALUES(139,'te','ug','ఉయ్‌ఘర్');
INSERT INTO "languageNames" VALUES(140,'te','uk','ఉక్రేనియన్');
INSERT INTO "languageNames" VALUES(141,'te','ur','ఉర్దూ');
INSERT INTO "languageNames" VALUES(142,'te','uz','ఉజ్బెక్');
INSERT INTO "languageNames" VALUES(143,'te','vi','వియత్నామీస్');
INSERT INTO "languageNames" VALUES(144,'te','wal','వాలేట్టా');
INSERT INTO "languageNames" VALUES(145,'te','xh','షోసా');
INSERT INTO "languageNames" VALUES(146,'te','yi','ఇడ్డిష్');
INSERT INTO "languageNames" VALUES(147,'te','yo','యోరుబా');
INSERT INTO "languageNames" VALUES(148,'te','zh','చైనీస్');
INSERT INTO "languageNames" VALUES(149,'te','zu','జూలూ');
INSERT INTO "languageNames" VALUES(150,'eu','af','afrikaansa');
INSERT INTO "languageNames" VALUES(151,'eu','alt','hegoaldeko altaiera');
INSERT INTO "languageNames" VALUES(152,'eu','an','aragoiera');
INSERT INTO "languageNames" VALUES(153,'eu','ar','arabiera');
INSERT INTO "languageNames" VALUES(154,'eu','as','assamera');
INSERT INTO "languageNames" VALUES(155,'eu','ast','asturiera');
INSERT INTO "languageNames" VALUES(156,'eu','av','avarera');
INSERT INTO "languageNames" VALUES(158,'eu','az','azeriera');
INSERT INTO "languageNames" VALUES(159,'eu','ba','bashkirrera');
INSERT INTO "languageNames" VALUES(160,'eu','be','bielorrusiera');
INSERT INTO "languageNames" VALUES(161,'eu','bg','bulgariera');
INSERT INTO "languageNames" VALUES(162,'eu','bi','bislama');
INSERT INTO "languageNames" VALUES(163,'eu','bn','bengalera');
INSERT INTO "languageNames" VALUES(164,'eu','br','bretoiera');
INSERT INTO "languageNames" VALUES(165,'eu','bs','bosniera');
INSERT INTO "languageNames" VALUES(166,'eu','ca','katalana');
INSERT INTO "languageNames" VALUES(167,'eu','ceb','cebuera');
INSERT INTO "languageNames" VALUES(168,'eu','chm','mariera');
INSERT INTO "languageNames" VALUES(169,'eu','ckb','sorania');
INSERT INTO "languageNames" VALUES(170,'eu','co','korsikera');
INSERT INTO "languageNames" VALUES(171,'eu','cs','txekiera');
INSERT INTO "languageNames" VALUES(172,'eu','cu','Elizako eslaviera');
INSERT INTO "languageNames" VALUES(173,'eu','cv','chuvashera');
INSERT INTO "languageNames" VALUES(174,'eu','cy','galesa');
INSERT INTO "languageNames" VALUES(175,'eu','da','daniera');
INSERT INTO "languageNames" VALUES(176,'eu','dar','dargvera');
INSERT INTO "languageNames" VALUES(177,'eu','de','alemana');
INSERT INTO "languageNames" VALUES(178,'eu','dsb','behe-sorabiera');
INSERT INTO "languageNames" VALUES(179,'eu','el','greziera');
INSERT INTO "languageNames" VALUES(180,'eu','en','ingelesa');
INSERT INTO "languageNames" VALUES(181,'eu','eo','esperantoa');
INSERT INTO "languageNames" VALUES(182,'eu','es','espainiera');
INSERT INTO "languageNames" VALUES(183,'eu','et','estoniera');
INSERT INTO "languageNames" VALUES(184,'eu','eu','euskara');
INSERT INTO "languageNames" VALUES(185,'eu','fa','persiera');
INSERT INTO "languageNames" VALUES(186,'eu','fi','finlandiera');
INSERT INTO "languageNames" VALUES(187,'eu','fo','faroera');
INSERT INTO "languageNames" VALUES(188,'eu','fr','frantsesa');
INSERT INTO "languageNames" VALUES(189,'eu','fy','frisiera');
INSERT INTO "languageNames" VALUES(190,'eu','ga','gaelikoa');
INSERT INTO "languageNames" VALUES(191,'eu','gag','gagauzera');
INSERT INTO "languageNames" VALUES(192,'eu','gd','Eskoziako gaelikoa');
INSERT INTO "languageNames" VALUES(193,'eu','gl','galiziera');
INSERT INTO "languageNames" VALUES(194,'eu','gn','guaraniera');
INSERT INTO "languageNames" VALUES(195,'eu','gu','gujaratera');
INSERT INTO "languageNames" VALUES(196,'eu','gv','manxera');
INSERT INTO "languageNames" VALUES(197,'eu','ha','hausa');
INSERT INTO "languageNames" VALUES(198,'eu','haw','hawaiiera');
INSERT INTO "languageNames" VALUES(199,'eu','he','hebreera');
INSERT INTO "languageNames" VALUES(200,'eu','hi','hindia');
INSERT INTO "languageNames" VALUES(201,'eu','hr','kroaziera');
INSERT INTO "languageNames" VALUES(202,'eu','hsb','goi-sorabiera');
INSERT INTO "languageNames" VALUES(203,'eu','ht','Haitiko kreolera');
INSERT INTO "languageNames" VALUES(204,'eu','hu','hungariera');
INSERT INTO "languageNames" VALUES(205,'eu','hy','armeniera');
INSERT INTO "languageNames" VALUES(206,'eu','ia','interlingua');
INSERT INTO "languageNames" VALUES(207,'eu','id','indonesiera');
INSERT INTO "languageNames" VALUES(208,'eu','ig','igboera');
INSERT INTO "languageNames" VALUES(209,'eu','is','islandiera');
INSERT INTO "languageNames" VALUES(210,'eu','it','italiera');
INSERT INTO "languageNames" VALUES(211,'eu','ka','georgiera');
INSERT INTO "languageNames" VALUES(212,'eu','kk','kazakhera');
INSERT INTO "languageNames" VALUES(213,'eu','ko','koreera');
INSERT INTO "languageNames" VALUES(214,'eu','krc','karachayera-balkarera');
INSERT INTO "languageNames" VALUES(215,'eu','krl','kareliera');
INSERT INTO "languageNames" VALUES(216,'eu','ks','kaxmirera');
INSERT INTO "languageNames" VALUES(217,'eu','kum','kumykera');
INSERT INTO "languageNames" VALUES(218,'eu','kv','komiera');
INSERT INTO "languageNames" VALUES(219,'eu','ky','kirgizera');
INSERT INTO "languageNames" VALUES(220,'eu','la','latina');
INSERT INTO "languageNames" VALUES(221,'eu','lb','luxenburgera');
INSERT INTO "languageNames" VALUES(222,'eu','lg','gandera');
INSERT INTO "languageNames" VALUES(223,'eu','ln','lingala');
INSERT INTO "languageNames" VALUES(224,'eu','lo','laosera');
INSERT INTO "languageNames" VALUES(225,'eu','lt','lituaniera');
INSERT INTO "languageNames" VALUES(226,'eu','lv','letoniera');
INSERT INTO "languageNames" VALUES(227,'eu','mdf','mokxera');
INSERT INTO "languageNames" VALUES(228,'eu','mfe','Mauritaniako kreolera');
INSERT INTO "languageNames" VALUES(229,'eu','mk','mazedoniera');
INSERT INTO "languageNames" VALUES(230,'eu','ml','malabarera');
INSERT INTO "languageNames" VALUES(231,'eu','mr','marathera');
INSERT INTO "languageNames" VALUES(232,'eu','ms','malaysiera');
INSERT INTO "languageNames" VALUES(233,'eu','mt','maltera');
INSERT INTO "languageNames" VALUES(234,'eu','myv','erziera');
INSERT INTO "languageNames" VALUES(235,'eu','nap','napoliera');
INSERT INTO "languageNames" VALUES(236,'eu','nb','bokmala (Norvegia)');
INSERT INTO "languageNames" VALUES(237,'eu','ne','nepalera');
INSERT INTO "languageNames" VALUES(238,'eu','nl','nederlandera');
INSERT INTO "languageNames" VALUES(239,'eu','nn','nynorsk norvegiera');
INSERT INTO "languageNames" VALUES(240,'eu','no','norvegiera');
INSERT INTO "languageNames" VALUES(241,'eu','nog','nogaiera');
INSERT INTO "languageNames" VALUES(242,'eu','oc','okzitaniera');
INSERT INTO "languageNames" VALUES(243,'eu','os','osetiera');
INSERT INTO "languageNames" VALUES(244,'eu','pa','punjabera');
INSERT INTO "languageNames" VALUES(245,'eu','pl','poloniera');
INSERT INTO "languageNames" VALUES(246,'eu','pt','portugesa');
INSERT INTO "languageNames" VALUES(247,'eu','rm','erretorromaniera');
INSERT INTO "languageNames" VALUES(248,'eu','rn','rundiera');
INSERT INTO "languageNames" VALUES(249,'eu','ro','errumaniera');
INSERT INTO "languageNames" VALUES(250,'eu','ru','errusiera');
INSERT INTO "languageNames" VALUES(251,'eu','rup','aromania');
INSERT INTO "languageNames" VALUES(252,'eu','sa','sanskritoa');
INSERT INTO "languageNames" VALUES(253,'eu','sah','sakhera');
INSERT INTO "languageNames" VALUES(254,'eu','sc','sardiniera');
INSERT INTO "languageNames" VALUES(255,'eu','scn','siziliera');
INSERT INTO "languageNames" VALUES(256,'eu','sco','eskoziera');
INSERT INTO "languageNames" VALUES(257,'eu','sd','sindhia');
INSERT INTO "languageNames" VALUES(258,'eu','se','iparraldeko samiera');
INSERT INTO "languageNames" VALUES(259,'eu','sh','serbokroaziera');
INSERT INTO "languageNames" VALUES(260,'eu','si','sinhala');
INSERT INTO "languageNames" VALUES(261,'eu','sk','eslovakiera');
INSERT INTO "languageNames" VALUES(262,'eu','sl','esloveniera');
INSERT INTO "languageNames" VALUES(263,'eu','sma','hegoaldeko samiera');
INSERT INTO "languageNames" VALUES(264,'eu','smj','lule samiera');
INSERT INTO "languageNames" VALUES(265,'eu','smn','inari-samiera');
INSERT INTO "languageNames" VALUES(266,'eu','sq','albaniera');
INSERT INTO "languageNames" VALUES(267,'eu','sr','serbiera');
INSERT INTO "languageNames" VALUES(268,'eu','srn','srananera');
INSERT INTO "languageNames" VALUES(269,'eu','ss','swatiera');
INSERT INTO "languageNames" VALUES(270,'eu','sv','suediera');
INSERT INTO "languageNames" VALUES(271,'eu','sw','swahilia');
INSERT INTO "languageNames" VALUES(272,'eu','ta','tamilera');
INSERT INTO "languageNames" VALUES(273,'eu','te','telugua');
INSERT INTO "languageNames" VALUES(274,'eu','tet','tetuma');
INSERT INTO "languageNames" VALUES(275,'eu','tg','tajikera');
INSERT INTO "languageNames" VALUES(276,'eu','th','thailandiera');
INSERT INTO "languageNames" VALUES(277,'eu','tk','turkmenera');
INSERT INTO "languageNames" VALUES(278,'eu','tl','tagalog');
INSERT INTO "languageNames" VALUES(279,'eu','tr','turkiera');
INSERT INTO "languageNames" VALUES(280,'eu','tt','tatarera');
INSERT INTO "languageNames" VALUES(281,'eu','tyv','tuvera');
INSERT INTO "languageNames" VALUES(282,'eu','udm','udmurtera');
INSERT INTO "languageNames" VALUES(283,'eu','ug','uigurrera');
INSERT INTO "languageNames" VALUES(284,'eu','uk','ukrainera');
INSERT INTO "languageNames" VALUES(285,'eu','ur','urdua');
INSERT INTO "languageNames" VALUES(286,'eu','uz','uzbekera');
INSERT INTO "languageNames" VALUES(287,'eu','vi','vietnamera');
INSERT INTO "languageNames" VALUES(288,'eu','wal','welayta');
INSERT INTO "languageNames" VALUES(289,'eu','xh','xhosera');
INSERT INTO "languageNames" VALUES(290,'eu','yi','yiddisha');
INSERT INTO "languageNames" VALUES(291,'eu','yo','jorubera');
INSERT INTO "languageNames" VALUES(292,'eu','zh','txinera');
INSERT INTO "languageNames" VALUES(293,'eu','zu','zuluera');
INSERT INTO "languageNames" VALUES(294,'he','af','אפריקאנס');
INSERT INTO "languageNames" VALUES(295,'he','alt','אלטאי דרומית');
INSERT INTO "languageNames" VALUES(296,'he','an','אראגונית');
INSERT INTO "languageNames" VALUES(297,'he','ar','ערבית');
INSERT INTO "languageNames" VALUES(298,'he','as','אסאמית');
INSERT INTO "languageNames" VALUES(299,'he','ast','אסטורית');
INSERT INTO "languageNames" VALUES(300,'he','av','אווארית');
INSERT INTO "languageNames" VALUES(302,'he','az','אזרית');
INSERT INTO "languageNames" VALUES(303,'he','ba','בשקירית');
INSERT INTO "languageNames" VALUES(304,'he','be','בלארוסית');
INSERT INTO "languageNames" VALUES(305,'he','bg','בולגרית');
INSERT INTO "languageNames" VALUES(306,'he','bi','ביסלמה');
INSERT INTO "languageNames" VALUES(307,'he','bn','בנגלית');
INSERT INTO "languageNames" VALUES(308,'he','br','ברטונית');
INSERT INTO "languageNames" VALUES(309,'he','bs','בוסנית');
INSERT INTO "languageNames" VALUES(310,'he','bua','בוריאט');
INSERT INTO "languageNames" VALUES(311,'he','byv','מדומבה');
INSERT INTO "languageNames" VALUES(312,'he','ca','קטלאנית');
INSERT INTO "languageNames" VALUES(313,'he','ceb','סבואנו');
INSERT INTO "languageNames" VALUES(314,'he','chm','מארי');
INSERT INTO "languageNames" VALUES(315,'he','ckb','כורדית סוראנית');
INSERT INTO "languageNames" VALUES(316,'he','co','קורסיקנית');
INSERT INTO "languageNames" VALUES(317,'he','crh','טטרית של קרים');
INSERT INTO "languageNames" VALUES(318,'he','cs','צ׳כית');
INSERT INTO "languageNames" VALUES(319,'he','csb','קשובית');
INSERT INTO "languageNames" VALUES(320,'he','cu','סלאבית כנסייתית עתיקה');
INSERT INTO "languageNames" VALUES(321,'he','cv','צ׳ובאש');
INSERT INTO "languageNames" VALUES(322,'he','cy','וולשית');
INSERT INTO "languageNames" VALUES(323,'he','da','דנית');
INSERT INTO "languageNames" VALUES(324,'he','dar','דרגווה');
INSERT INTO "languageNames" VALUES(325,'he','de','גרמנית');
INSERT INTO "languageNames" VALUES(326,'he','dsb','סורבית תחתית');
INSERT INTO "languageNames" VALUES(327,'he','el','יוונית');
INSERT INTO "languageNames" VALUES(328,'he','en','אנגלית');
INSERT INTO "languageNames" VALUES(329,'he','eo','אספרנטו');
INSERT INTO "languageNames" VALUES(330,'he','es','ספרדית');
INSERT INTO "languageNames" VALUES(331,'he','et','אסטונית');
INSERT INTO "languageNames" VALUES(332,'he','eu','בסקית');
INSERT INTO "languageNames" VALUES(333,'he','fa','פרסית');
INSERT INTO "languageNames" VALUES(334,'he','fi','פינית');
INSERT INTO "languageNames" VALUES(335,'he','fo','פארואזית');
INSERT INTO "languageNames" VALUES(336,'he','fr','צרפתית');
INSERT INTO "languageNames" VALUES(337,'he','fy','פריזית מערבית');
INSERT INTO "languageNames" VALUES(338,'he','ga','אירית');
INSERT INTO "languageNames" VALUES(339,'he','gag','גגאוזית');
INSERT INTO "languageNames" VALUES(340,'he','gd','גאלית סקוטית');
INSERT INTO "languageNames" VALUES(341,'he','gl','גליציאנית');
INSERT INTO "languageNames" VALUES(342,'he','gn','גוארני');
INSERT INTO "languageNames" VALUES(343,'he','gu','גוג׳ארטי');
INSERT INTO "languageNames" VALUES(344,'he','gv','מאנית');
INSERT INTO "languageNames" VALUES(345,'he','ha','האוסה');
INSERT INTO "languageNames" VALUES(346,'he','haw','הוואית');
INSERT INTO "languageNames" VALUES(347,'he','he','עברית');
INSERT INTO "languageNames" VALUES(348,'he','hi','הינדי');
INSERT INTO "languageNames" VALUES(349,'he','hr','קרואטית');
INSERT INTO "languageNames" VALUES(350,'he','hsb','סורבית גבוהה');
INSERT INTO "languageNames" VALUES(351,'he','ht','קריאולית (האיטי)');
INSERT INTO "languageNames" VALUES(352,'he','hu','הונגרית');
INSERT INTO "languageNames" VALUES(353,'he','hy','ארמנית');
INSERT INTO "languageNames" VALUES(354,'he','ia','‏אינטרלינגואה');
INSERT INTO "languageNames" VALUES(355,'he','id','אינדונזית');
INSERT INTO "languageNames" VALUES(356,'he','ig','איגבו');
INSERT INTO "languageNames" VALUES(357,'he','is','איסלנדית');
INSERT INTO "languageNames" VALUES(358,'he','it','איטלקית');
INSERT INTO "languageNames" VALUES(359,'he','ka','גאורגית');
INSERT INTO "languageNames" VALUES(360,'he','kaa','קארא-קלפאק');
INSERT INTO "languageNames" VALUES(361,'he','kk','קזחית');
INSERT INTO "languageNames" VALUES(362,'he','ko','קוריאנית');
INSERT INTO "languageNames" VALUES(363,'he','krc','קראצ׳י-בלקר');
INSERT INTO "languageNames" VALUES(364,'he','krl','קארלית');
INSERT INTO "languageNames" VALUES(365,'he','ks','קשמירית');
INSERT INTO "languageNames" VALUES(366,'he','kum','קומיקית');
INSERT INTO "languageNames" VALUES(367,'he','kv','קומי');
INSERT INTO "languageNames" VALUES(368,'he','ky','קירגיזית');
INSERT INTO "languageNames" VALUES(369,'he','la','לטינית');
INSERT INTO "languageNames" VALUES(370,'he','lb','לוקסמבורגית');
INSERT INTO "languageNames" VALUES(371,'he','lg','גאנדה');
INSERT INTO "languageNames" VALUES(372,'he','ln','לינגלה');
INSERT INTO "languageNames" VALUES(373,'he','lo','לאו');
INSERT INTO "languageNames" VALUES(374,'he','lt','ליטאית');
INSERT INTO "languageNames" VALUES(375,'he','lv','לטבית');
INSERT INTO "languageNames" VALUES(376,'he','mdf','מוקשה');
INSERT INTO "languageNames" VALUES(377,'he','mfe','קריאולית מאוריציאנית');
INSERT INTO "languageNames" VALUES(378,'he','mk','מקדונית');
INSERT INTO "languageNames" VALUES(379,'he','ml','מליאלאם');
INSERT INTO "languageNames" VALUES(380,'he','mr','מראטהי');
INSERT INTO "languageNames" VALUES(381,'he','ms','מלאית');
INSERT INTO "languageNames" VALUES(382,'he','mt','מלטית');
INSERT INTO "languageNames" VALUES(383,'he','myv','ארזיה');
INSERT INTO "languageNames" VALUES(384,'he','nap','נפוליטנית');
INSERT INTO "languageNames" VALUES(385,'he','nb','נורווגית ספרותית');
INSERT INTO "languageNames" VALUES(386,'he','ne','נפאלית');
INSERT INTO "languageNames" VALUES(387,'he','nl','הולנדית');
INSERT INTO "languageNames" VALUES(388,'he','nn','נורווגית חדשה');
INSERT INTO "languageNames" VALUES(389,'he','no','נורווגית');
INSERT INTO "languageNames" VALUES(390,'he','nog','נוגאי');
INSERT INTO "languageNames" VALUES(391,'he','oc','אוקסיטנית');
INSERT INTO "languageNames" VALUES(392,'he','os','אוסטית');
INSERT INTO "languageNames" VALUES(393,'he','ota','טורקית עות׳מנית');
INSERT INTO "languageNames" VALUES(394,'he','pa','פנג׳אבי');
INSERT INTO "languageNames" VALUES(395,'he','pl','פולנית');
INSERT INTO "languageNames" VALUES(396,'he','pt','פורטוגזית');
INSERT INTO "languageNames" VALUES(397,'he','rm','רומאנש');
INSERT INTO "languageNames" VALUES(398,'he','rn','קירונדי');
INSERT INTO "languageNames" VALUES(399,'he','ro','רומנית');
INSERT INTO "languageNames" VALUES(400,'he','ru','רוסית');
INSERT INTO "languageNames" VALUES(401,'he','rup','ארומנית');
INSERT INTO "languageNames" VALUES(402,'he','sa','סנסקריט');
INSERT INTO "languageNames" VALUES(403,'he','sah','סאחה');
INSERT INTO "languageNames" VALUES(404,'he','sc','סרדינית');
INSERT INTO "languageNames" VALUES(405,'he','scn','סיציליאנית');
INSERT INTO "languageNames" VALUES(406,'he','sco','סקוטית');
INSERT INTO "languageNames" VALUES(407,'he','sd','סינדהית');
INSERT INTO "languageNames" VALUES(408,'he','se','סמי צפונית');
INSERT INTO "languageNames" VALUES(409,'he','sh','סרבו-קרואטית');
INSERT INTO "languageNames" VALUES(410,'he','si','סינהלה');
INSERT INTO "languageNames" VALUES(411,'he','sk','סלובקית');
INSERT INTO "languageNames" VALUES(412,'he','sl','סלובנית');
INSERT INTO "languageNames" VALUES(413,'he','sma','סאמי דרומית');
INSERT INTO "languageNames" VALUES(414,'he','smj','לולה סאמי');
INSERT INTO "languageNames" VALUES(415,'he','smn','אינארי סאמי');
INSERT INTO "languageNames" VALUES(416,'he','sq','אלבנית');
INSERT INTO "languageNames" VALUES(417,'he','sr','סרבית');
INSERT INTO "languageNames" VALUES(418,'he','srn','סרנאן טונגו');
INSERT INTO "languageNames" VALUES(419,'he','ss','סאווזי');
INSERT INTO "languageNames" VALUES(420,'he','sv','שוודית');
INSERT INTO "languageNames" VALUES(421,'he','sw','סווהילי');
INSERT INTO "languageNames" VALUES(422,'he','ta','טמילית');
INSERT INTO "languageNames" VALUES(423,'he','te','טלוגו');
INSERT INTO "languageNames" VALUES(424,'he','tet','טטום');
INSERT INTO "languageNames" VALUES(425,'he','tg','טג׳יקית');
INSERT INTO "languageNames" VALUES(426,'he','th','תאית');
INSERT INTO "languageNames" VALUES(427,'he','tk','טורקמנית');
INSERT INTO "languageNames" VALUES(428,'he','tl','טאגאלוג');
INSERT INTO "languageNames" VALUES(429,'he','tr','טורקית');
INSERT INTO "languageNames" VALUES(430,'he','tt','טטרית');
INSERT INTO "languageNames" VALUES(431,'he','tyv','טובינית');
INSERT INTO "languageNames" VALUES(432,'he','udm','אודמורט');
INSERT INTO "languageNames" VALUES(433,'he','ug','אויגור');
INSERT INTO "languageNames" VALUES(434,'he','uk','אוקראינית');
INSERT INTO "languageNames" VALUES(435,'he','ur','אורדו');
INSERT INTO "languageNames" VALUES(436,'he','uz','אוזבקית');
INSERT INTO "languageNames" VALUES(437,'he','vi','ויאטנמית');
INSERT INTO "languageNames" VALUES(438,'he','wal','ווליאטה');
INSERT INTO "languageNames" VALUES(439,'he','xh','קוסה');
INSERT INTO "languageNames" VALUES(440,'he','yi','יידיש');
INSERT INTO "languageNames" VALUES(441,'he','yo','יורובה');
INSERT INTO "languageNames" VALUES(442,'he','zh','סינית');
INSERT INTO "languageNames" VALUES(443,'he','zu','זולו');
INSERT INTO "languageNames" VALUES(444,'lt','af','afrikanų');
INSERT INTO "languageNames" VALUES(445,'lt','alt','pietų Altajaus');
INSERT INTO "languageNames" VALUES(446,'lt','an','aragonesų');
INSERT INTO "languageNames" VALUES(447,'lt','ar','arabų');
INSERT INTO "languageNames" VALUES(448,'lt','as','asamų');
INSERT INTO "languageNames" VALUES(449,'lt','ast','asturianų');
INSERT INTO "languageNames" VALUES(450,'lt','av','avarikų');
INSERT INTO "languageNames" VALUES(452,'lt','az','azeri');
INSERT INTO "languageNames" VALUES(453,'lt','ba','baškirų');
INSERT INTO "languageNames" VALUES(454,'lt','be','baltarusių');
INSERT INTO "languageNames" VALUES(455,'lt','bg','bulgarų');
INSERT INTO "languageNames" VALUES(456,'lt','bi','bislama');
INSERT INTO "languageNames" VALUES(457,'lt','bn','bengalų');
INSERT INTO "languageNames" VALUES(458,'lt','br','bretonų');
INSERT INTO "languageNames" VALUES(459,'lt','bs','bosnių');
INSERT INTO "languageNames" VALUES(460,'lt','bua','buriatų');
INSERT INTO "languageNames" VALUES(461,'lt','byv','medumbų');
INSERT INTO "languageNames" VALUES(462,'lt','ca','katalonų');
INSERT INTO "languageNames" VALUES(463,'lt','ceb','sebuanų');
INSERT INTO "languageNames" VALUES(464,'lt','chm','marių');
INSERT INTO "languageNames" VALUES(465,'lt','ckb','soranių kurdų');
INSERT INTO "languageNames" VALUES(466,'lt','co','korsikiečių');
INSERT INTO "languageNames" VALUES(467,'lt','crh','Krymo turkų');
INSERT INTO "languageNames" VALUES(468,'lt','cs','čekų');
INSERT INTO "languageNames" VALUES(469,'lt','csb','kašubų');
INSERT INTO "languageNames" VALUES(470,'lt','cu','bažnytinė slavų');
INSERT INTO "languageNames" VALUES(471,'lt','cv','čiuvašų');
INSERT INTO "languageNames" VALUES(472,'lt','cy','valų');
INSERT INTO "languageNames" VALUES(473,'lt','da','danų');
INSERT INTO "languageNames" VALUES(474,'lt','dar','dargva');
INSERT INTO "languageNames" VALUES(475,'lt','de','vokiečių');
INSERT INTO "languageNames" VALUES(476,'lt','dsb','žemutinių sorbų');
INSERT INTO "languageNames" VALUES(477,'lt','el','graikų');
INSERT INTO "languageNames" VALUES(478,'lt','en','anglų');
INSERT INTO "languageNames" VALUES(479,'lt','eo','esperanto');
INSERT INTO "languageNames" VALUES(480,'lt','es','ispanų');
INSERT INTO "languageNames" VALUES(481,'lt','et','estų');
INSERT INTO "languageNames" VALUES(482,'lt','eu','baskų');
INSERT INTO "languageNames" VALUES(483,'lt','fa','persų');
INSERT INTO "languageNames" VALUES(484,'lt','fi','suomių');
INSERT INTO "languageNames" VALUES(485,'lt','fo','farerų');
INSERT INTO "languageNames" VALUES(486,'lt','fr','prancūzų');
INSERT INTO "languageNames" VALUES(487,'lt','fy','vakarų fryzų');
INSERT INTO "languageNames" VALUES(488,'lt','ga','airių');
INSERT INTO "languageNames" VALUES(489,'lt','gag','gagaūzų');
INSERT INTO "languageNames" VALUES(490,'lt','gd','škotų (gėlų)');
INSERT INTO "languageNames" VALUES(491,'lt','gl','galisų');
INSERT INTO "languageNames" VALUES(492,'lt','glk','gilaki');
INSERT INTO "languageNames" VALUES(493,'lt','gn','gvaranių');
INSERT INTO "languageNames" VALUES(494,'lt','gu','gudžaratų');
INSERT INTO "languageNames" VALUES(495,'lt','guc','vajų');
INSERT INTO "languageNames" VALUES(496,'lt','gv','meniečių');
INSERT INTO "languageNames" VALUES(497,'lt','ha','hausų');
INSERT INTO "languageNames" VALUES(498,'lt','haw','havajiečių');
INSERT INTO "languageNames" VALUES(499,'lt','he','hebrajų');
INSERT INTO "languageNames" VALUES(500,'lt','hi','hindi');
INSERT INTO "languageNames" VALUES(501,'lt','hr','kroatų');
INSERT INTO "languageNames" VALUES(502,'lt','hsb','aukštutinių sorbų');
INSERT INTO "languageNames" VALUES(503,'lt','ht','Haičio');
INSERT INTO "languageNames" VALUES(504,'lt','hu','vengrų');
INSERT INTO "languageNames" VALUES(505,'lt','hy','armėnų');
INSERT INTO "languageNames" VALUES(506,'lt','ia','tarpinė');
INSERT INTO "languageNames" VALUES(507,'lt','id','indoneziečių');
INSERT INTO "languageNames" VALUES(508,'lt','ig','igbų');
INSERT INTO "languageNames" VALUES(509,'lt','is','islandų');
INSERT INTO "languageNames" VALUES(510,'lt','it','italų');
INSERT INTO "languageNames" VALUES(511,'lt','ka','gruzinų');
INSERT INTO "languageNames" VALUES(512,'lt','kaa','karakalpakų');
INSERT INTO "languageNames" VALUES(513,'lt','kk','kazachų');
INSERT INTO "languageNames" VALUES(514,'lt','ko','korėjiečių');
INSERT INTO "languageNames" VALUES(515,'lt','krc','karačiajų balkarijos');
INSERT INTO "languageNames" VALUES(516,'lt','krl','karelų');
INSERT INTO "languageNames" VALUES(517,'lt','ks','kašmyrų');
INSERT INTO "languageNames" VALUES(518,'lt','kum','kumikų');
INSERT INTO "languageNames" VALUES(519,'lt','kv','komi');
INSERT INTO "languageNames" VALUES(520,'lt','ky','kirgizų');
INSERT INTO "languageNames" VALUES(521,'lt','la','lotynų');
INSERT INTO "languageNames" VALUES(522,'lt','lb','liuksemburgiečių');
INSERT INTO "languageNames" VALUES(523,'lt','lg','ganda');
INSERT INTO "languageNames" VALUES(524,'lt','liv','lyvių');
INSERT INTO "languageNames" VALUES(525,'lt','ln','ngalų');
INSERT INTO "languageNames" VALUES(526,'lt','lo','laosiečių');
INSERT INTO "languageNames" VALUES(527,'lt','lt','lietuvių');
INSERT INTO "languageNames" VALUES(528,'lt','lv','latvių');
INSERT INTO "languageNames" VALUES(529,'lt','mdf','mokša');
INSERT INTO "languageNames" VALUES(530,'lt','mfe','morisijų');
INSERT INTO "languageNames" VALUES(531,'lt','mk','makedonų');
INSERT INTO "languageNames" VALUES(532,'lt','ml','malajalių');
INSERT INTO "languageNames" VALUES(533,'lt','mr','maratų');
INSERT INTO "languageNames" VALUES(534,'lt','mrj','vakarų mari');
INSERT INTO "languageNames" VALUES(535,'lt','ms','malajiečių');
INSERT INTO "languageNames" VALUES(536,'lt','mt','maltiečių');
INSERT INTO "languageNames" VALUES(537,'lt','myv','erzyjų');
INSERT INTO "languageNames" VALUES(538,'lt','nap','neapoliečių');
INSERT INTO "languageNames" VALUES(539,'lt','nb','norvegų bukmolas');
INSERT INTO "languageNames" VALUES(540,'lt','ne','nepaliečių');
INSERT INTO "languageNames" VALUES(541,'lt','nl','olandų');
INSERT INTO "languageNames" VALUES(542,'lt','nn','naujoji norvegų');
INSERT INTO "languageNames" VALUES(543,'lt','no','norvegų');
INSERT INTO "languageNames" VALUES(544,'lt','nog','nogų');
INSERT INTO "languageNames" VALUES(545,'lt','oc','očitarų');
INSERT INTO "languageNames" VALUES(546,'lt','os','osetinų');
INSERT INTO "languageNames" VALUES(547,'lt','ota','osmanų turkų');
INSERT INTO "languageNames" VALUES(548,'lt','pa','pendžabų');
INSERT INTO "languageNames" VALUES(549,'lt','pl','lenkų');
INSERT INTO "languageNames" VALUES(550,'lt','pt','portugalų');
INSERT INTO "languageNames" VALUES(551,'lt','rm','retoromanų');
INSERT INTO "languageNames" VALUES(552,'lt','rn','rundi');
INSERT INTO "languageNames" VALUES(553,'lt','ro','rumunų');
INSERT INTO "languageNames" VALUES(554,'lt','ru','rusų');
INSERT INTO "languageNames" VALUES(555,'lt','rup','aromanių');
INSERT INTO "languageNames" VALUES(556,'lt','sa','sanskritas');
INSERT INTO "languageNames" VALUES(557,'lt','sah','jakutų');
INSERT INTO "languageNames" VALUES(558,'lt','sc','sardiniečių');
INSERT INTO "languageNames" VALUES(559,'lt','scn','siciliečių');
INSERT INTO "languageNames" VALUES(560,'lt','sco','škotų');
INSERT INTO "languageNames" VALUES(561,'lt','sd','sindų');
INSERT INTO "languageNames" VALUES(562,'lt','se','šiaurės samių');
INSERT INTO "languageNames" VALUES(563,'lt','sh','serbų-kroatų');
INSERT INTO "languageNames" VALUES(564,'lt','si','sinhalų');
INSERT INTO "languageNames" VALUES(565,'lt','sk','slovakų');
INSERT INTO "languageNames" VALUES(566,'lt','sl','slovėnų');
INSERT INTO "languageNames" VALUES(567,'lt','sma','pietų samių');
INSERT INTO "languageNames" VALUES(568,'lt','smj','Liuleo samių');
INSERT INTO "languageNames" VALUES(569,'lt','smn','Inario samių');
INSERT INTO "languageNames" VALUES(570,'lt','sq','albanų');
INSERT INTO "languageNames" VALUES(571,'lt','sr','serbų');
INSERT INTO "languageNames" VALUES(572,'lt','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(573,'lt','ss','svatų');
INSERT INTO "languageNames" VALUES(574,'lt','sv','švedų');
INSERT INTO "languageNames" VALUES(575,'lt','sw','suahilių');
INSERT INTO "languageNames" VALUES(576,'lt','ta','tamilų');
INSERT INTO "languageNames" VALUES(577,'lt','te','telugų');
INSERT INTO "languageNames" VALUES(578,'lt','tet','tetum');
INSERT INTO "languageNames" VALUES(579,'lt','tg','tadžikų');
INSERT INTO "languageNames" VALUES(580,'lt','th','tajų');
INSERT INTO "languageNames" VALUES(581,'lt','tk','turkmėnų');
INSERT INTO "languageNames" VALUES(582,'lt','tl','tagalogų');
INSERT INTO "languageNames" VALUES(583,'lt','tr','turkų');
INSERT INTO "languageNames" VALUES(584,'lt','tt','totorių');
INSERT INTO "languageNames" VALUES(585,'lt','tyv','tuvių');
INSERT INTO "languageNames" VALUES(586,'lt','udm','udmurtų');
INSERT INTO "languageNames" VALUES(587,'lt','ug','uigūrų');
INSERT INTO "languageNames" VALUES(588,'lt','uk','ukrainiečių');
INSERT INTO "languageNames" VALUES(589,'lt','ur','urdų');
INSERT INTO "languageNames" VALUES(590,'lt','uz','uzbekų');
INSERT INTO "languageNames" VALUES(591,'lt','vi','vietnamiečių');
INSERT INTO "languageNames" VALUES(592,'lt','vro','veru');
INSERT INTO "languageNames" VALUES(593,'lt','wal','valamo');
INSERT INTO "languageNames" VALUES(594,'lt','xh','kosų');
INSERT INTO "languageNames" VALUES(595,'lt','yi','jidiš');
INSERT INTO "languageNames" VALUES(596,'lt','yo','jorubų');
INSERT INTO "languageNames" VALUES(597,'lt','zh','kinų');
INSERT INTO "languageNames" VALUES(598,'lt','zu','zulų');
INSERT INTO "languageNames" VALUES(599,'lv','af','afrikandu');
INSERT INTO "languageNames" VALUES(600,'lv','alt','dienvidaltajiešu');
INSERT INTO "languageNames" VALUES(601,'lv','an','aragoniešu');
INSERT INTO "languageNames" VALUES(602,'lv','ar','arābu');
INSERT INTO "languageNames" VALUES(603,'lv','as','asamiešu');
INSERT INTO "languageNames" VALUES(604,'lv','ast','astūriešu');
INSERT INTO "languageNames" VALUES(605,'lv','av','avāru');
INSERT INTO "languageNames" VALUES(607,'lv','az','azerbaidžāņu');
INSERT INTO "languageNames" VALUES(608,'lv','ba','baškīru');
INSERT INTO "languageNames" VALUES(609,'lv','be','baltkrievu');
INSERT INTO "languageNames" VALUES(610,'lv','bg','bulgāru');
INSERT INTO "languageNames" VALUES(611,'lv','bi','bišlamā');
INSERT INTO "languageNames" VALUES(612,'lv','bn','bengāļu');
INSERT INTO "languageNames" VALUES(613,'lv','br','bretoņu');
INSERT INTO "languageNames" VALUES(614,'lv','bs','bosniešu');
INSERT INTO "languageNames" VALUES(615,'lv','bua','burjatu');
INSERT INTO "languageNames" VALUES(616,'lv','byv','medumbu');
INSERT INTO "languageNames" VALUES(617,'lv','ca','katalāņu');
INSERT INTO "languageNames" VALUES(618,'lv','ceb','sebuāņu');
INSERT INTO "languageNames" VALUES(619,'lv','chm','mariešu');
INSERT INTO "languageNames" VALUES(620,'lv','ckb','centrālkurdu');
INSERT INTO "languageNames" VALUES(621,'lv','co','korsikāņu');
INSERT INTO "languageNames" VALUES(622,'lv','crh','Krimas tatāru');
INSERT INTO "languageNames" VALUES(623,'lv','cs','čehu');
INSERT INTO "languageNames" VALUES(624,'lv','csb','kašubu');
INSERT INTO "languageNames" VALUES(625,'lv','cu','baznīcslāvu');
INSERT INTO "languageNames" VALUES(626,'lv','cv','čuvašu');
INSERT INTO "languageNames" VALUES(627,'lv','cy','velsiešu');
INSERT INTO "languageNames" VALUES(628,'lv','da','dāņu');
INSERT INTO "languageNames" VALUES(629,'lv','dar','dargu');
INSERT INTO "languageNames" VALUES(630,'lv','de','vācu');
INSERT INTO "languageNames" VALUES(631,'lv','dsb','lejassorbu');
INSERT INTO "languageNames" VALUES(632,'lv','el','grieķu');
INSERT INTO "languageNames" VALUES(633,'lv','en','angļu');
INSERT INTO "languageNames" VALUES(634,'lv','eo','esperanto');
INSERT INTO "languageNames" VALUES(635,'lv','es','spāņu');
INSERT INTO "languageNames" VALUES(636,'lv','et','igauņu');
INSERT INTO "languageNames" VALUES(637,'lv','eu','basku');
INSERT INTO "languageNames" VALUES(638,'lv','fa','persiešu');
INSERT INTO "languageNames" VALUES(639,'lv','fi','somu');
INSERT INTO "languageNames" VALUES(640,'lv','fo','fēru');
INSERT INTO "languageNames" VALUES(641,'lv','fr','franču');
INSERT INTO "languageNames" VALUES(642,'lv','fy','rietumfrīzu');
INSERT INTO "languageNames" VALUES(643,'lv','ga','īru');
INSERT INTO "languageNames" VALUES(644,'lv','gag','gagauzu');
INSERT INTO "languageNames" VALUES(645,'lv','gd','gēlu');
INSERT INTO "languageNames" VALUES(646,'lv','gl','galisiešu');
INSERT INTO "languageNames" VALUES(647,'lv','gn','gvaranu');
INSERT INTO "languageNames" VALUES(648,'lv','gu','gudžaratu');
INSERT INTO "languageNames" VALUES(649,'lv','gv','meniešu');
INSERT INTO "languageNames" VALUES(650,'lv','ha','hausu');
INSERT INTO "languageNames" VALUES(651,'lv','haw','havajiešu');
INSERT INTO "languageNames" VALUES(652,'lv','he','ivrits');
INSERT INTO "languageNames" VALUES(653,'lv','hi','hindi');
INSERT INTO "languageNames" VALUES(654,'lv','hr','horvātu');
INSERT INTO "languageNames" VALUES(655,'lv','hsb','augšsorbu');
INSERT INTO "languageNames" VALUES(656,'lv','ht','haitiešu');
INSERT INTO "languageNames" VALUES(657,'lv','hu','ungāru');
INSERT INTO "languageNames" VALUES(658,'lv','hy','armēņu');
INSERT INTO "languageNames" VALUES(659,'lv','ia','interlingva');
INSERT INTO "languageNames" VALUES(660,'lv','id','indonēziešu');
INSERT INTO "languageNames" VALUES(661,'lv','ig','igbo');
INSERT INTO "languageNames" VALUES(662,'lv','is','islandiešu');
INSERT INTO "languageNames" VALUES(663,'lv','it','itāļu');
INSERT INTO "languageNames" VALUES(664,'lv','ka','gruzīnu');
INSERT INTO "languageNames" VALUES(665,'lv','kaa','karakalpaku');
INSERT INTO "languageNames" VALUES(666,'lv','kk','kazahu');
INSERT INTO "languageNames" VALUES(667,'lv','ko','korejiešu');
INSERT INTO "languageNames" VALUES(668,'lv','krc','karačaju un balkāru');
INSERT INTO "languageNames" VALUES(669,'lv','krl','karēļu');
INSERT INTO "languageNames" VALUES(670,'lv','ks','kašmiriešu');
INSERT INTO "languageNames" VALUES(671,'lv','kum','kumiku');
INSERT INTO "languageNames" VALUES(672,'lv','kv','komiešu');
INSERT INTO "languageNames" VALUES(673,'lv','ky','kirgīzu');
INSERT INTO "languageNames" VALUES(674,'lv','la','latīņu');
INSERT INTO "languageNames" VALUES(675,'lv','lb','luksemburgiešu');
INSERT INTO "languageNames" VALUES(676,'lv','lg','gandu');
INSERT INTO "languageNames" VALUES(677,'lv','ln','lingala');
INSERT INTO "languageNames" VALUES(678,'lv','lo','laosiešu');
INSERT INTO "languageNames" VALUES(679,'lv','lt','lietuviešu');
INSERT INTO "languageNames" VALUES(680,'lv','lv','latviešu');
INSERT INTO "languageNames" VALUES(681,'lv','mdf','mokšu');
INSERT INTO "languageNames" VALUES(682,'lv','mfe','Maurīcijas kreolu');
INSERT INTO "languageNames" VALUES(683,'lv','mk','maķedoniešu');
INSERT INTO "languageNames" VALUES(684,'lv','ml','malajalu');
INSERT INTO "languageNames" VALUES(685,'lv','mr','marathu');
INSERT INTO "languageNames" VALUES(686,'lv','ms','malajiešu');
INSERT INTO "languageNames" VALUES(687,'lv','mt','maltiešu');
INSERT INTO "languageNames" VALUES(688,'lv','myv','erzju');
INSERT INTO "languageNames" VALUES(689,'lv','nap','neapoliešu');
INSERT INTO "languageNames" VALUES(690,'lv','nb','norvēģu bukmols');
INSERT INTO "languageNames" VALUES(691,'lv','ne','nepāliešu');
INSERT INTO "languageNames" VALUES(692,'lv','nl','holandiešu');
INSERT INTO "languageNames" VALUES(693,'lv','nn','jaunnorvēģu');
INSERT INTO "languageNames" VALUES(694,'lv','no','norvēģu');
INSERT INTO "languageNames" VALUES(695,'lv','nog','nogaju');
INSERT INTO "languageNames" VALUES(696,'lv','oc','oksitāņu');
INSERT INTO "languageNames" VALUES(697,'lv','os','osetīnu');
INSERT INTO "languageNames" VALUES(698,'lv','ota','turku osmaņu');
INSERT INTO "languageNames" VALUES(699,'lv','pa','pandžabu');
INSERT INTO "languageNames" VALUES(700,'lv','pl','poļu');
INSERT INTO "languageNames" VALUES(701,'lv','pt','portugāļu');
INSERT INTO "languageNames" VALUES(702,'lv','rm','retoromāņu');
INSERT INTO "languageNames" VALUES(703,'lv','rn','rundu');
INSERT INTO "languageNames" VALUES(704,'lv','ro','rumāņu');
INSERT INTO "languageNames" VALUES(705,'lv','ru','krievu');
INSERT INTO "languageNames" VALUES(706,'lv','rup','aromūnu');
INSERT INTO "languageNames" VALUES(707,'lv','sa','sanskrits');
INSERT INTO "languageNames" VALUES(708,'lv','sah','jakutu');
INSERT INTO "languageNames" VALUES(709,'lv','sc','sardīniešu');
INSERT INTO "languageNames" VALUES(710,'lv','scn','sicīliešu');
INSERT INTO "languageNames" VALUES(711,'lv','sco','skotu');
INSERT INTO "languageNames" VALUES(712,'lv','sd','sindhu');
INSERT INTO "languageNames" VALUES(713,'lv','se','ziemeļsāmu');
INSERT INTO "languageNames" VALUES(714,'lv','sh','serbu–horvātu');
INSERT INTO "languageNames" VALUES(715,'lv','si','singāļu');
INSERT INTO "languageNames" VALUES(716,'lv','sk','slovāku');
INSERT INTO "languageNames" VALUES(717,'lv','sl','slovēņu');
INSERT INTO "languageNames" VALUES(718,'lv','sma','dienvidsāmu');
INSERT INTO "languageNames" VALUES(719,'lv','smj','Luleo sāmu');
INSERT INTO "languageNames" VALUES(720,'lv','smn','Inari sāmu');
INSERT INTO "languageNames" VALUES(721,'lv','sq','albāņu');
INSERT INTO "languageNames" VALUES(722,'lv','sr','serbu');
INSERT INTO "languageNames" VALUES(723,'lv','srn','sranantogo');
INSERT INTO "languageNames" VALUES(724,'lv','ss','svatu');
INSERT INTO "languageNames" VALUES(725,'lv','sv','zviedru');
INSERT INTO "languageNames" VALUES(726,'lv','sw','svahili');
INSERT INTO "languageNames" VALUES(727,'lv','ta','tamilu');
INSERT INTO "languageNames" VALUES(728,'lv','te','telugu');
INSERT INTO "languageNames" VALUES(729,'lv','tet','tetumu');
INSERT INTO "languageNames" VALUES(730,'lv','tg','tadžiku');
INSERT INTO "languageNames" VALUES(731,'lv','th','taju');
INSERT INTO "languageNames" VALUES(732,'lv','tk','turkmēņu');
INSERT INTO "languageNames" VALUES(733,'lv','tl','tagalu');
INSERT INTO "languageNames" VALUES(734,'lv','tr','turku');
INSERT INTO "languageNames" VALUES(735,'lv','tt','tatāru');
INSERT INTO "languageNames" VALUES(736,'lv','tyv','tuviešu');
INSERT INTO "languageNames" VALUES(737,'lv','udm','udmurtu');
INSERT INTO "languageNames" VALUES(738,'lv','ug','uiguru');
INSERT INTO "languageNames" VALUES(739,'lv','uk','ukraiņu');
INSERT INTO "languageNames" VALUES(740,'lv','ur','urdu');
INSERT INTO "languageNames" VALUES(741,'lv','uz','uzbeku');
INSERT INTO "languageNames" VALUES(742,'lv','vi','vjetnamiešu');
INSERT INTO "languageNames" VALUES(743,'lv','wal','valamu');
INSERT INTO "languageNames" VALUES(744,'lv','xh','khosu');
INSERT INTO "languageNames" VALUES(745,'lv','yi','jidišs');
INSERT INTO "languageNames" VALUES(746,'lv','yo','jorubu');
INSERT INTO "languageNames" VALUES(747,'lv','zh','ķīniešu');
INSERT INTO "languageNames" VALUES(748,'lv','zu','zulu');
INSERT INTO "languageNames" VALUES(749,'fo','af','afrikaans');
INSERT INTO "languageNames" VALUES(750,'fo','alt','suður altai');
INSERT INTO "languageNames" VALUES(751,'fo','an','aragoniskt');
INSERT INTO "languageNames" VALUES(752,'fo','ar','arabiskt');
INSERT INTO "languageNames" VALUES(753,'fo','as','assamesiskt');
INSERT INTO "languageNames" VALUES(754,'fo','ast','asturianskt');
INSERT INTO "languageNames" VALUES(755,'fo','av','avariskt');
INSERT INTO "languageNames" VALUES(757,'fo','az','azeri');
INSERT INTO "languageNames" VALUES(758,'fo','ba','bashkir');
INSERT INTO "languageNames" VALUES(759,'fo','be','hvitarussiskt');
INSERT INTO "languageNames" VALUES(760,'fo','bg','bulgarskt');
INSERT INTO "languageNames" VALUES(761,'fo','bi','bislama');
INSERT INTO "languageNames" VALUES(762,'fo','bn','bengalskt');
INSERT INTO "languageNames" VALUES(763,'fo','br','bretonskt');
INSERT INTO "languageNames" VALUES(764,'fo','bs','bosniskt');
INSERT INTO "languageNames" VALUES(765,'fo','ca','katalani');
INSERT INTO "languageNames" VALUES(766,'fo','ceb','cebuano');
INSERT INTO "languageNames" VALUES(767,'fo','chm','mari');
INSERT INTO "languageNames" VALUES(768,'fo','ckb','miðkurdiskt');
INSERT INTO "languageNames" VALUES(769,'fo','co','korsikanskt');
INSERT INTO "languageNames" VALUES(770,'fo','cs','kekkiskt');
INSERT INTO "languageNames" VALUES(771,'fo','cu','kirkju sláviskt');
INSERT INTO "languageNames" VALUES(772,'fo','cv','chuvash');
INSERT INTO "languageNames" VALUES(773,'fo','cy','walisiskt');
INSERT INTO "languageNames" VALUES(774,'fo','da','danskt');
INSERT INTO "languageNames" VALUES(775,'fo','dar','dargwa');
INSERT INTO "languageNames" VALUES(776,'fo','de','týskt');
INSERT INTO "languageNames" VALUES(777,'fo','dsb','lágt sorbian');
INSERT INTO "languageNames" VALUES(778,'fo','el','grikskt');
INSERT INTO "languageNames" VALUES(779,'fo','en','enskt');
INSERT INTO "languageNames" VALUES(780,'fo','eo','esperanto');
INSERT INTO "languageNames" VALUES(781,'fo','es','spanskt');
INSERT INTO "languageNames" VALUES(782,'fo','et','estiskt');
INSERT INTO "languageNames" VALUES(783,'fo','eu','baskiskt');
INSERT INTO "languageNames" VALUES(784,'fo','fa','persiskt');
INSERT INTO "languageNames" VALUES(785,'fo','fi','finskt');
INSERT INTO "languageNames" VALUES(786,'fo','fo','føroyskt');
INSERT INTO "languageNames" VALUES(787,'fo','fr','franskt');
INSERT INTO "languageNames" VALUES(788,'fo','fy','vestur frísiskt');
INSERT INTO "languageNames" VALUES(789,'fo','ga','írskt');
INSERT INTO "languageNames" VALUES(790,'fo','gag','gagauz');
INSERT INTO "languageNames" VALUES(791,'fo','gd','skotskt gæliskt');
INSERT INTO "languageNames" VALUES(792,'fo','gl','galisiskt');
INSERT INTO "languageNames" VALUES(793,'fo','gn','guarani');
INSERT INTO "languageNames" VALUES(794,'fo','gu','gujarati');
INSERT INTO "languageNames" VALUES(795,'fo','gv','manx');
INSERT INTO "languageNames" VALUES(796,'fo','ha','hausa');
INSERT INTO "languageNames" VALUES(797,'fo','haw','hawaiianskt');
INSERT INTO "languageNames" VALUES(798,'fo','he','hebraiskt');
INSERT INTO "languageNames" VALUES(799,'fo','hi','hindi');
INSERT INTO "languageNames" VALUES(800,'fo','hr','kroatiskt');
INSERT INTO "languageNames" VALUES(801,'fo','hsb','ovara sorbian');
INSERT INTO "languageNames" VALUES(802,'fo','ht','haitiskt');
INSERT INTO "languageNames" VALUES(803,'fo','hu','ungarskt');
INSERT INTO "languageNames" VALUES(804,'fo','hy','armenskt');
INSERT INTO "languageNames" VALUES(805,'fo','ia','interlingua');
INSERT INTO "languageNames" VALUES(806,'fo','id','indonesiskt');
INSERT INTO "languageNames" VALUES(807,'fo','ig','igbo');
INSERT INTO "languageNames" VALUES(808,'fo','is','íslendskt');
INSERT INTO "languageNames" VALUES(809,'fo','it','italskt');
INSERT INTO "languageNames" VALUES(810,'fo','ka','georgiskt');
INSERT INTO "languageNames" VALUES(811,'fo','kk','kazakh');
INSERT INTO "languageNames" VALUES(812,'fo','ko','koreanskt');
INSERT INTO "languageNames" VALUES(813,'fo','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(814,'fo','krl','karelskt');
INSERT INTO "languageNames" VALUES(815,'fo','ks','kashmiri');
INSERT INTO "languageNames" VALUES(816,'fo','kum','kumyk');
INSERT INTO "languageNames" VALUES(817,'fo','kv','komi');
INSERT INTO "languageNames" VALUES(818,'fo','ky','kyrgyz');
INSERT INTO "languageNames" VALUES(819,'fo','la','latín');
INSERT INTO "languageNames" VALUES(820,'fo','lb','luksemborgskt');
INSERT INTO "languageNames" VALUES(821,'fo','lg','ganda');
INSERT INTO "languageNames" VALUES(822,'fo','ln','lingala');
INSERT INTO "languageNames" VALUES(823,'fo','lo','laoskt');
INSERT INTO "languageNames" VALUES(824,'fo','lt','litaviskt');
INSERT INTO "languageNames" VALUES(825,'fo','lv','lettiskt');
INSERT INTO "languageNames" VALUES(826,'fo','mdf','moksha');
INSERT INTO "languageNames" VALUES(827,'fo','mfe','morisyen');
INSERT INTO "languageNames" VALUES(828,'fo','mk','makedónskt');
INSERT INTO "languageNames" VALUES(829,'fo','ml','malayalam');
INSERT INTO "languageNames" VALUES(830,'fo','mr','marathi');
INSERT INTO "languageNames" VALUES(831,'fo','ms','malaiiskt');
INSERT INTO "languageNames" VALUES(832,'fo','mt','maltiskt');
INSERT INTO "languageNames" VALUES(833,'fo','myv','erzya');
INSERT INTO "languageNames" VALUES(834,'fo','nap','napolitanskt');
INSERT INTO "languageNames" VALUES(835,'fo','nb','norskt bókmál');
INSERT INTO "languageNames" VALUES(836,'fo','ne','nepalskt');
INSERT INTO "languageNames" VALUES(837,'fo','nl','hálendskt');
INSERT INTO "languageNames" VALUES(838,'fo','nn','nýnorskt');
INSERT INTO "languageNames" VALUES(839,'fo','no','norskt');
INSERT INTO "languageNames" VALUES(840,'fo','nog','nogai');
INSERT INTO "languageNames" VALUES(841,'fo','oc','occitanskt');
INSERT INTO "languageNames" VALUES(842,'fo','os','ossetiskt');
INSERT INTO "languageNames" VALUES(843,'fo','pa','punjabi');
INSERT INTO "languageNames" VALUES(844,'fo','pl','pólskt');
INSERT INTO "languageNames" VALUES(845,'fo','pt','portugiskiskt');
INSERT INTO "languageNames" VALUES(846,'fo','rm','retoromanskt');
INSERT INTO "languageNames" VALUES(847,'fo','rn','rundi');
INSERT INTO "languageNames" VALUES(848,'fo','ro','rumenskt');
INSERT INTO "languageNames" VALUES(849,'fo','ru','russiskt');
INSERT INTO "languageNames" VALUES(850,'fo','rup','aromenskt');
INSERT INTO "languageNames" VALUES(851,'fo','sa','sanskrit');
INSERT INTO "languageNames" VALUES(852,'fo','sah','sakha');
INSERT INTO "languageNames" VALUES(853,'fo','sc','sardiskt');
INSERT INTO "languageNames" VALUES(854,'fo','scn','sisilanskt');
INSERT INTO "languageNames" VALUES(855,'fo','sco','skotskt');
INSERT INTO "languageNames" VALUES(856,'fo','sd','sindhi');
INSERT INTO "languageNames" VALUES(857,'fo','se','norður sámiskt');
INSERT INTO "languageNames" VALUES(858,'fo','sh','serbokroatiskt');
INSERT INTO "languageNames" VALUES(859,'fo','si','singalesiskt');
INSERT INTO "languageNames" VALUES(860,'fo','sk','slovakiskt');
INSERT INTO "languageNames" VALUES(861,'fo','sl','slovenskt');
INSERT INTO "languageNames" VALUES(862,'fo','sma','suður sámiskt');
INSERT INTO "languageNames" VALUES(863,'fo','smj','lule sámiskt');
INSERT INTO "languageNames" VALUES(864,'fo','smn','inari sami');
INSERT INTO "languageNames" VALUES(865,'fo','sq','albanskt');
INSERT INTO "languageNames" VALUES(866,'fo','sr','serbiskt');
INSERT INTO "languageNames" VALUES(867,'fo','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(868,'fo','ss','swatiskt');
INSERT INTO "languageNames" VALUES(869,'fo','sv','svenskt');
INSERT INTO "languageNames" VALUES(870,'fo','sw','swahili');
INSERT INTO "languageNames" VALUES(871,'fo','ta','tamilskt');
INSERT INTO "languageNames" VALUES(872,'fo','te','telugu');
INSERT INTO "languageNames" VALUES(873,'fo','tet','tetum');
INSERT INTO "languageNames" VALUES(874,'fo','tg','tajik');
INSERT INTO "languageNames" VALUES(875,'fo','th','tailendskt');
INSERT INTO "languageNames" VALUES(876,'fo','tk','turkmenskt');
INSERT INTO "languageNames" VALUES(877,'fo','tl','tagalog');
INSERT INTO "languageNames" VALUES(878,'fo','tr','turkiskt');
INSERT INTO "languageNames" VALUES(879,'fo','tt','tatar');
INSERT INTO "languageNames" VALUES(880,'fo','tyv','tuvinian');
INSERT INTO "languageNames" VALUES(881,'fo','udm','udmurt');
INSERT INTO "languageNames" VALUES(882,'fo','ug','uyghur');
INSERT INTO "languageNames" VALUES(883,'fo','uk','ukrainskt');
INSERT INTO "languageNames" VALUES(884,'fo','ur','urdu');
INSERT INTO "languageNames" VALUES(885,'fo','uz','usbekiskt');
INSERT INTO "languageNames" VALUES(886,'fo','vi','vjetnamesiskt');
INSERT INTO "languageNames" VALUES(887,'fo','wal','wolaytta');
INSERT INTO "languageNames" VALUES(888,'fo','xh','xhosa');
INSERT INTO "languageNames" VALUES(889,'fo','yi','jiddiskt');
INSERT INTO "languageNames" VALUES(890,'fo','yo','yoruba');
INSERT INTO "languageNames" VALUES(891,'fo','zh','kinesiskt');
INSERT INTO "languageNames" VALUES(892,'fo','zu','sulu');
INSERT INTO "languageNames" VALUES(893,'cu','ar','а҆ра́вскїй');
INSERT INTO "languageNames" VALUES(894,'cu','az','а҆зербайджа́нскїй');
INSERT INTO "languageNames" VALUES(895,'cu','be','бѣлорꙋ́сскїй');
INSERT INTO "languageNames" VALUES(896,'cu','bg','бо́лгарскїй');
INSERT INTO "languageNames" VALUES(897,'cu','cu','церковнослове́нскїй');
INSERT INTO "languageNames" VALUES(898,'cu','de','нѣме́цкїй');
INSERT INTO "languageNames" VALUES(899,'cu','el','є҆́ллинскїй');
INSERT INTO "languageNames" VALUES(900,'cu','en','а҆нглі́йскїй');
INSERT INTO "languageNames" VALUES(901,'cu','es','і҆спа́нскїй');
INSERT INTO "languageNames" VALUES(902,'cu','et','є҆сто́нскїй');
INSERT INTO "languageNames" VALUES(903,'cu','fi','фі́нскїй');
INSERT INTO "languageNames" VALUES(904,'cu','fr','францꙋ́зскїй');
INSERT INTO "languageNames" VALUES(905,'cu','he','є҆вре́йскїй');
INSERT INTO "languageNames" VALUES(906,'cu','hy','а҆рме́нскїй');
INSERT INTO "languageNames" VALUES(907,'cu','it','і҆талїа́нскїй');
INSERT INTO "languageNames" VALUES(908,'cu','ka','і҆́верскїй');
INSERT INTO "languageNames" VALUES(909,'cu','kk','каза́хскїй');
INSERT INTO "languageNames" VALUES(910,'cu','la','латі́нскїй');
INSERT INTO "languageNames" VALUES(911,'cu','lt','лїто́вскїй');
INSERT INTO "languageNames" VALUES(912,'cu','lv','латві́йскїй');
INSERT INTO "languageNames" VALUES(913,'cu','pt','портога́льскїй');
INSERT INTO "languageNames" VALUES(914,'cu','ro','дакорꙋмы́нскїй');
INSERT INTO "languageNames" VALUES(915,'cu','ru','рꙋ́сскїй');
INSERT INTO "languageNames" VALUES(916,'cu','sr','се́рбскїй');
INSERT INTO "languageNames" VALUES(917,'cu','uk','ᲂу҆краи́нскїй');
INSERT INTO "languageNames" VALUES(918,'cu','zh','хи́нскїй');
INSERT INTO "languageNames" VALUES(919,'fa','af','آفریکانس');
INSERT INTO "languageNames" VALUES(920,'fa','alt','آلتایی جنوبی');
INSERT INTO "languageNames" VALUES(921,'fa','an','آراگونی');
INSERT INTO "languageNames" VALUES(922,'fa','ar','عربی');
INSERT INTO "languageNames" VALUES(923,'fa','as','آسامی');
INSERT INTO "languageNames" VALUES(924,'fa','ast','آستوری');
INSERT INTO "languageNames" VALUES(925,'fa','av','آواری');
INSERT INTO "languageNames" VALUES(928,'fa','az','آذربایجانی');
INSERT INTO "languageNames" VALUES(929,'fa','ba','باشغیری');
INSERT INTO "languageNames" VALUES(930,'fa','be','بلاروسی');
INSERT INTO "languageNames" VALUES(931,'fa','bg','بلغاری');
INSERT INTO "languageNames" VALUES(932,'fa','bi','بیسلاما');
INSERT INTO "languageNames" VALUES(933,'fa','bn','بنگالی');
INSERT INTO "languageNames" VALUES(934,'fa','br','برتون');
INSERT INTO "languageNames" VALUES(935,'fa','bs','بوسنیایی');
INSERT INTO "languageNames" VALUES(936,'fa','bua','بوریاتی');
INSERT INTO "languageNames" VALUES(937,'fa','ca','کاتالان');
INSERT INTO "languageNames" VALUES(938,'fa','ceb','سبویی');
INSERT INTO "languageNames" VALUES(939,'fa','chm','ماریایی');
INSERT INTO "languageNames" VALUES(940,'fa','ckb','کردی مرکزی');
INSERT INTO "languageNames" VALUES(941,'fa','co','کورسی');
INSERT INTO "languageNames" VALUES(942,'fa','crh','ترکی کریمه');
INSERT INTO "languageNames" VALUES(943,'fa','cs','چکی');
INSERT INTO "languageNames" VALUES(944,'fa','csb','کاشوبی');
INSERT INTO "languageNames" VALUES(945,'fa','cu','اسلاوی کلیسایی');
INSERT INTO "languageNames" VALUES(946,'fa','cv','چوواشی');
INSERT INTO "languageNames" VALUES(947,'fa','cy','ولزی');
INSERT INTO "languageNames" VALUES(948,'fa','da','دانمارکی');
INSERT INTO "languageNames" VALUES(949,'fa','dar','دارقینی');
INSERT INTO "languageNames" VALUES(950,'fa','de','آلمانی');
INSERT INTO "languageNames" VALUES(951,'fa','dsb','صُربی سفلی');
INSERT INTO "languageNames" VALUES(952,'fa','el','یونانی');
INSERT INTO "languageNames" VALUES(953,'fa','en','انگلیسی');
INSERT INTO "languageNames" VALUES(954,'fa','eo','اسپرانتو');
INSERT INTO "languageNames" VALUES(955,'fa','es','اسپانیایی');
INSERT INTO "languageNames" VALUES(956,'fa','et','استونیایی');
INSERT INTO "languageNames" VALUES(957,'fa','eu','باسکی');
INSERT INTO "languageNames" VALUES(958,'fa','fa','فارسی');
INSERT INTO "languageNames" VALUES(959,'fa','fi','فنلاندی');
INSERT INTO "languageNames" VALUES(960,'fa','fo','فارویی');
INSERT INTO "languageNames" VALUES(961,'fa','fr','فرانسوی');
INSERT INTO "languageNames" VALUES(962,'fa','fy','فریزی غربی');
INSERT INTO "languageNames" VALUES(963,'fa','ga','ایرلندی');
INSERT INTO "languageNames" VALUES(964,'fa','gag','گاگائوزیایی');
INSERT INTO "languageNames" VALUES(965,'fa','gd','گیلی اسکاتلندی');
INSERT INTO "languageNames" VALUES(966,'fa','gl','گالیسیایی');
INSERT INTO "languageNames" VALUES(967,'fa','glk','گیلکی');
INSERT INTO "languageNames" VALUES(968,'fa','gn','گوارانی');
INSERT INTO "languageNames" VALUES(969,'fa','gu','گجراتی');
INSERT INTO "languageNames" VALUES(970,'fa','gv','مانی');
INSERT INTO "languageNames" VALUES(971,'fa','ha','هوسیایی');
INSERT INTO "languageNames" VALUES(972,'fa','haw','هاوائیایی');
INSERT INTO "languageNames" VALUES(973,'fa','he','عبری');
INSERT INTO "languageNames" VALUES(974,'fa','hi','هندی');
INSERT INTO "languageNames" VALUES(975,'fa','hr','کروات');
INSERT INTO "languageNames" VALUES(976,'fa','hsb','صُربی علیا');
INSERT INTO "languageNames" VALUES(977,'fa','ht','هائیتیایی');
INSERT INTO "languageNames" VALUES(978,'fa','hu','مجاری');
INSERT INTO "languageNames" VALUES(979,'fa','hy','ارمنی');
INSERT INTO "languageNames" VALUES(980,'fa','ia','میان‌زبان');
INSERT INTO "languageNames" VALUES(981,'fa','id','اندونزیایی');
INSERT INTO "languageNames" VALUES(982,'fa','ig','ایگبویی');
INSERT INTO "languageNames" VALUES(983,'fa','is','ایسلندی');
INSERT INTO "languageNames" VALUES(984,'fa','it','ایتالیایی');
INSERT INTO "languageNames" VALUES(985,'fa','ka','گرجی');
INSERT INTO "languageNames" VALUES(986,'fa','kaa','قره‌قالپاقی');
INSERT INTO "languageNames" VALUES(987,'fa','kk','قزاقی');
INSERT INTO "languageNames" VALUES(988,'fa','ko','کره‌ای');
INSERT INTO "languageNames" VALUES(989,'fa','krc','قره‌چایی‐بالکاری');
INSERT INTO "languageNames" VALUES(990,'fa','krl','کاریلیانی');
INSERT INTO "languageNames" VALUES(991,'fa','ks','کشمیری');
INSERT INTO "languageNames" VALUES(992,'fa','kum','کومیکی');
INSERT INTO "languageNames" VALUES(993,'fa','kv','کومیایی');
INSERT INTO "languageNames" VALUES(994,'fa','ky','قرقیزی');
INSERT INTO "languageNames" VALUES(995,'fa','la','لاتین');
INSERT INTO "languageNames" VALUES(996,'fa','lb','لوگزامبورگی');
INSERT INTO "languageNames" VALUES(997,'fa','lg','گاندایی');
INSERT INTO "languageNames" VALUES(998,'fa','ln','لینگالا');
INSERT INTO "languageNames" VALUES(999,'fa','lo','لائوسی');
INSERT INTO "languageNames" VALUES(1000,'fa','lt','لیتوانیایی');
INSERT INTO "languageNames" VALUES(1001,'fa','lv','لتونیایی');
INSERT INTO "languageNames" VALUES(1002,'fa','mdf','مکشایی');
INSERT INTO "languageNames" VALUES(1003,'fa','mfe','موریسین');
INSERT INTO "languageNames" VALUES(1004,'fa','mk','مقدونی');
INSERT INTO "languageNames" VALUES(1005,'fa','ml','مالایالامی');
INSERT INTO "languageNames" VALUES(1006,'fa','mr','مراتی');
INSERT INTO "languageNames" VALUES(1007,'fa','ms','مالایی');
INSERT INTO "languageNames" VALUES(1008,'fa','mt','مالتی');
INSERT INTO "languageNames" VALUES(1009,'fa','myv','ارزیایی');
INSERT INTO "languageNames" VALUES(1010,'fa','nap','ناپلی');
INSERT INTO "languageNames" VALUES(1011,'fa','nb','نروژی بوک‌مُل');
INSERT INTO "languageNames" VALUES(1012,'fa','ne','نپالی');
INSERT INTO "languageNames" VALUES(1013,'fa','nl','هلندی');
INSERT INTO "languageNames" VALUES(1014,'fa','nn','نروژی نی‌نُشک');
INSERT INTO "languageNames" VALUES(1015,'fa','no','نروژی');
INSERT INTO "languageNames" VALUES(1016,'fa','nog','نغایی');
INSERT INTO "languageNames" VALUES(1017,'fa','oc','اوکیتایی');
INSERT INTO "languageNames" VALUES(1018,'fa','os','آسی');
INSERT INTO "languageNames" VALUES(1019,'fa','ota','ترکی عثمانی');
INSERT INTO "languageNames" VALUES(1020,'fa','pa','پنجابی');
INSERT INTO "languageNames" VALUES(1021,'fa','pl','لهستانی');
INSERT INTO "languageNames" VALUES(1022,'fa','pt','پرتغالی');
INSERT INTO "languageNames" VALUES(1023,'fa','rm','رومانش');
INSERT INTO "languageNames" VALUES(1024,'fa','rn','روندیایی');
INSERT INTO "languageNames" VALUES(1025,'fa','ro','رومانیایی');
INSERT INTO "languageNames" VALUES(1026,'fa','ru','روسی');
INSERT INTO "languageNames" VALUES(1027,'fa','rup','آرومانی');
INSERT INTO "languageNames" VALUES(1028,'fa','sa','سانسکریت');
INSERT INTO "languageNames" VALUES(1029,'fa','sah','یاقوتی');
INSERT INTO "languageNames" VALUES(1030,'fa','sc','ساردینیایی');
INSERT INTO "languageNames" VALUES(1031,'fa','scn','سیسیلی');
INSERT INTO "languageNames" VALUES(1032,'fa','sco','اسکاتلندی');
INSERT INTO "languageNames" VALUES(1033,'fa','sd','سندی');
INSERT INTO "languageNames" VALUES(1034,'fa','se','سامی شمالی');
INSERT INTO "languageNames" VALUES(1035,'fa','sh','صرب و کرواتی');
INSERT INTO "languageNames" VALUES(1036,'fa','si','سینهالی');
INSERT INTO "languageNames" VALUES(1037,'fa','sk','اسلواکی');
INSERT INTO "languageNames" VALUES(1038,'fa','sl','اسلوونیایی');
INSERT INTO "languageNames" VALUES(1039,'fa','sma','سامی جنوبی');
INSERT INTO "languageNames" VALUES(1040,'fa','smj','لوله سامی');
INSERT INTO "languageNames" VALUES(1041,'fa','smn','ایناری سامی');
INSERT INTO "languageNames" VALUES(1042,'fa','sq','آلبانیایی');
INSERT INTO "languageNames" VALUES(1043,'fa','sr','صربی');
INSERT INTO "languageNames" VALUES(1044,'fa','srn','تاکی‌تاکی');
INSERT INTO "languageNames" VALUES(1045,'fa','ss','سوازیایی');
INSERT INTO "languageNames" VALUES(1046,'fa','sv','سوئدی');
INSERT INTO "languageNames" VALUES(1047,'fa','sw','سواحیلی');
INSERT INTO "languageNames" VALUES(1048,'fa','ta','تامیلی');
INSERT INTO "languageNames" VALUES(1049,'fa','te','تلوگویی');
INSERT INTO "languageNames" VALUES(1050,'fa','tet','تتومی');
INSERT INTO "languageNames" VALUES(1051,'fa','tg','تاجیکی');
INSERT INTO "languageNames" VALUES(1052,'fa','th','تایلندی');
INSERT INTO "languageNames" VALUES(1053,'fa','tk','ترکمنی');
INSERT INTO "languageNames" VALUES(1054,'fa','tl','تاگالوگی');
INSERT INTO "languageNames" VALUES(1056,'fa','tr','ترکی');
INSERT INTO "languageNames" VALUES(1057,'fa','tt','تاتاری');
INSERT INTO "languageNames" VALUES(1058,'fa','tyv','تووایی');
INSERT INTO "languageNames" VALUES(1059,'fa','udm','اودمورتی');
INSERT INTO "languageNames" VALUES(1060,'fa','ug','اویغوری');
INSERT INTO "languageNames" VALUES(1061,'fa','uk','اوکراینی');
INSERT INTO "languageNames" VALUES(1062,'fa','ur','اردو');
INSERT INTO "languageNames" VALUES(1063,'fa','uz','ازبکی');
INSERT INTO "languageNames" VALUES(1064,'fa','vi','ویتنامی');
INSERT INTO "languageNames" VALUES(1065,'fa','wal','والامو');
INSERT INTO "languageNames" VALUES(1066,'fa','xh','خوسایی');
INSERT INTO "languageNames" VALUES(1067,'fa','yi','یدی');
INSERT INTO "languageNames" VALUES(1068,'fa','yo','یوروبایی');
INSERT INTO "languageNames" VALUES(1069,'fa','zh','چینی');
INSERT INTO "languageNames" VALUES(1070,'fa','zu','زولویی');
INSERT INTO "languageNames" VALUES(1071,'ln','af','afrikansi');
INSERT INTO "languageNames" VALUES(1072,'ln','ar','lialabo');
INSERT INTO "languageNames" VALUES(1073,'ln','be','libyelorisí');
INSERT INTO "languageNames" VALUES(1074,'ln','bg','libiligali');
INSERT INTO "languageNames" VALUES(1075,'ln','bn','libengali');
INSERT INTO "languageNames" VALUES(1076,'ln','cs','litshekɛ');
INSERT INTO "languageNames" VALUES(1077,'ln','de','lialemá');
INSERT INTO "languageNames" VALUES(1078,'ln','el','ligeleki');
INSERT INTO "languageNames" VALUES(1079,'ln','en','lingɛlɛ́sa');
INSERT INTO "languageNames" VALUES(1080,'ln','es','lisipanye');
INSERT INTO "languageNames" VALUES(1081,'ln','fa','lipelésanɛ');
INSERT INTO "languageNames" VALUES(1082,'ln','fr','lifalansɛ́');
INSERT INTO "languageNames" VALUES(1083,'ln','ha','hausa');
INSERT INTO "languageNames" VALUES(1084,'ln','he','liébeleo');
INSERT INTO "languageNames" VALUES(1085,'ln','hi','lihindi');
INSERT INTO "languageNames" VALUES(1086,'ln','hu','liongili');
INSERT INTO "languageNames" VALUES(1087,'ln','id','lindonezi');
INSERT INTO "languageNames" VALUES(1088,'ln','ig','igbo');
INSERT INTO "languageNames" VALUES(1089,'ln','it','litaliano');
INSERT INTO "languageNames" VALUES(1090,'ln','ko','likoreya');
INSERT INTO "languageNames" VALUES(1091,'ln','la','latina');
INSERT INTO "languageNames" VALUES(1092,'ln','ln','lingála');
INSERT INTO "languageNames" VALUES(1093,'ln','ms','limalezi');
INSERT INTO "languageNames" VALUES(1094,'ln','ne','linepalɛ');
INSERT INTO "languageNames" VALUES(1095,'ln','nl','lifalamá');
INSERT INTO "languageNames" VALUES(1096,'ln','pa','lipendzabi');
INSERT INTO "languageNames" VALUES(1097,'ln','pl','lipolonɛ');
INSERT INTO "languageNames" VALUES(1098,'ln','pt','lipulutugɛ́si');
INSERT INTO "languageNames" VALUES(1099,'ln','rm','liromansh');
INSERT INTO "languageNames" VALUES(1100,'ln','ro','liromani');
INSERT INTO "languageNames" VALUES(1101,'ln','ru','lirisí');
INSERT INTO "languageNames" VALUES(1102,'ln','sv','lisuwedɛ');
INSERT INTO "languageNames" VALUES(1103,'ln','sw','kiswahíli');
INSERT INTO "languageNames" VALUES(1104,'ln','ta','litamuli');
INSERT INTO "languageNames" VALUES(1105,'ln','th','litaye');
INSERT INTO "languageNames" VALUES(1106,'ln','tr','litiliki');
INSERT INTO "languageNames" VALUES(1107,'ln','uk','likrɛni');
INSERT INTO "languageNames" VALUES(1108,'ln','ur','liurdu');
INSERT INTO "languageNames" VALUES(1109,'ln','vi','liviyetinámi');
INSERT INTO "languageNames" VALUES(1110,'ln','yo','yoruba');
INSERT INTO "languageNames" VALUES(1111,'ln','zh','lisinwa');
INSERT INTO "languageNames" VALUES(1112,'ln','zu','zulu');
INSERT INTO "languageNames" VALUES(1113,'vi','af','Tiếng Afrikaans');
INSERT INTO "languageNames" VALUES(1114,'vi','alt','Tiếng Altai Miền Nam');
INSERT INTO "languageNames" VALUES(1115,'vi','an','Tiếng Aragon');
INSERT INTO "languageNames" VALUES(1116,'vi','ar','Tiếng Ả Rập');
INSERT INTO "languageNames" VALUES(1117,'vi','as','Tiếng Assam');
INSERT INTO "languageNames" VALUES(1118,'vi','ast','Tiếng Asturias');
INSERT INTO "languageNames" VALUES(1119,'vi','av','Tiếng Avaric');
INSERT INTO "languageNames" VALUES(1121,'vi','az','Tiếng Azeri');
INSERT INTO "languageNames" VALUES(1122,'vi','ba','Tiếng Bashkir');
INSERT INTO "languageNames" VALUES(1123,'vi','be','Tiếng Belarus');
INSERT INTO "languageNames" VALUES(1124,'vi','bg','Tiếng Bulgaria');
INSERT INTO "languageNames" VALUES(1125,'vi','bi','Tiếng Bislama');
INSERT INTO "languageNames" VALUES(1126,'vi','bn','Tiếng Bangla');
INSERT INTO "languageNames" VALUES(1127,'vi','br','Tiếng Breton');
INSERT INTO "languageNames" VALUES(1128,'vi','bs','Tiếng Bosnia');
INSERT INTO "languageNames" VALUES(1129,'vi','bua','Tiếng Buriat');
INSERT INTO "languageNames" VALUES(1130,'vi','byv','Tiếng Medumba');
INSERT INTO "languageNames" VALUES(1131,'vi','ca','Tiếng Catalan');
INSERT INTO "languageNames" VALUES(1132,'vi','ceb','Tiếng Cebuano');
INSERT INTO "languageNames" VALUES(1133,'vi','chm','Tiếng Mari');
INSERT INTO "languageNames" VALUES(1134,'vi','ckb','Tiếng Kurd Miền Trung');
INSERT INTO "languageNames" VALUES(1135,'vi','co','Tiếng Corsica');
INSERT INTO "languageNames" VALUES(1136,'vi','crh','Tiếng Thổ Nhĩ Kỳ Crimean');
INSERT INTO "languageNames" VALUES(1137,'vi','cs','Tiếng Séc');
INSERT INTO "languageNames" VALUES(1138,'vi','csb','Tiếng Kashubia');
INSERT INTO "languageNames" VALUES(1139,'vi','cu','Tiếng Slavơ Nhà thờ');
INSERT INTO "languageNames" VALUES(1140,'vi','cv','Tiếng Chuvash');
INSERT INTO "languageNames" VALUES(1141,'vi','cy','Tiếng Wales');
INSERT INTO "languageNames" VALUES(1142,'vi','da','Tiếng Đan Mạch');
INSERT INTO "languageNames" VALUES(1143,'vi','dar','Tiếng Dargwa');
INSERT INTO "languageNames" VALUES(1144,'vi','de','Tiếng Đức');
INSERT INTO "languageNames" VALUES(1145,'vi','dsb','Tiếng Hạ Sorbia');
INSERT INTO "languageNames" VALUES(1146,'vi','el','Tiếng Hy Lạp');
INSERT INTO "languageNames" VALUES(1147,'vi','en','Tiếng Anh');
INSERT INTO "languageNames" VALUES(1148,'vi','eo','Tiếng Quốc Tế Ngữ');
INSERT INTO "languageNames" VALUES(1149,'vi','es','Tiếng Tây Ban Nha');
INSERT INTO "languageNames" VALUES(1150,'vi','et','Tiếng Estonia');
INSERT INTO "languageNames" VALUES(1151,'vi','eu','Tiếng Basque');
INSERT INTO "languageNames" VALUES(1152,'vi','fa','Tiếng Ba Tư');
INSERT INTO "languageNames" VALUES(1153,'vi','fi','Tiếng Phần Lan');
INSERT INTO "languageNames" VALUES(1154,'vi','fo','Tiếng Faroe');
INSERT INTO "languageNames" VALUES(1155,'vi','fr','Tiếng Pháp');
INSERT INTO "languageNames" VALUES(1156,'vi','fy','Tiếng Frisia');
INSERT INTO "languageNames" VALUES(1157,'vi','ga','Tiếng Ireland');
INSERT INTO "languageNames" VALUES(1158,'vi','gag','Tiếng Gagauz');
INSERT INTO "languageNames" VALUES(1159,'vi','gd','Tiếng Gael Scotland');
INSERT INTO "languageNames" VALUES(1160,'vi','gl','Tiếng Galician');
INSERT INTO "languageNames" VALUES(1161,'vi','glk','Tiếng Gilaki');
INSERT INTO "languageNames" VALUES(1162,'vi','gn','Tiếng Guarani');
INSERT INTO "languageNames" VALUES(1163,'vi','gu','Tiếng Gujarati');
INSERT INTO "languageNames" VALUES(1164,'vi','gv','Tiếng Manx');
INSERT INTO "languageNames" VALUES(1165,'vi','ha','Tiếng Hausa');
INSERT INTO "languageNames" VALUES(1166,'vi','haw','Tiếng Hawaii');
INSERT INTO "languageNames" VALUES(1167,'vi','he','Tiếng Do Thái');
INSERT INTO "languageNames" VALUES(1168,'vi','hi','Tiếng Hindi');
INSERT INTO "languageNames" VALUES(1169,'vi','hr','Tiếng Croatia');
INSERT INTO "languageNames" VALUES(1170,'vi','hsb','Tiếng Thượng Sorbia');
INSERT INTO "languageNames" VALUES(1171,'vi','ht','Tiếng Haiti');
INSERT INTO "languageNames" VALUES(1172,'vi','hu','Tiếng Hungary');
INSERT INTO "languageNames" VALUES(1173,'vi','hy','Tiếng Armenia');
INSERT INTO "languageNames" VALUES(1174,'vi','ia','Tiếng Khoa Học Quốc Tế');
INSERT INTO "languageNames" VALUES(1175,'vi','id','Tiếng Indonesia');
INSERT INTO "languageNames" VALUES(1176,'vi','ig','Tiếng Igbo');
INSERT INTO "languageNames" VALUES(1177,'vi','is','Tiếng Iceland');
INSERT INTO "languageNames" VALUES(1178,'vi','it','Tiếng Italy');
INSERT INTO "languageNames" VALUES(1179,'vi','ka','Tiếng Georgia');
INSERT INTO "languageNames" VALUES(1180,'vi','kaa','Tiếng Kara-Kalpak');
INSERT INTO "languageNames" VALUES(1181,'vi','kk','Tiếng Kazakh');
INSERT INTO "languageNames" VALUES(1182,'vi','ko','Tiếng Hàn');
INSERT INTO "languageNames" VALUES(1183,'vi','krc','Tiếng Karachay-Balkar');
INSERT INTO "languageNames" VALUES(1184,'vi','krl','Tiếng Karelian');
INSERT INTO "languageNames" VALUES(1185,'vi','ks','Tiếng Kashmir');
INSERT INTO "languageNames" VALUES(1186,'vi','kum','Tiếng Kumyk');
INSERT INTO "languageNames" VALUES(1187,'vi','kv','Tiếng Komi');
INSERT INTO "languageNames" VALUES(1188,'vi','ky','Tiếng Kyrgyz');
INSERT INTO "languageNames" VALUES(1189,'vi','la','Tiếng La-tinh');
INSERT INTO "languageNames" VALUES(1190,'vi','lb','Tiếng Luxembourg');
INSERT INTO "languageNames" VALUES(1191,'vi','lg','Tiếng Ganda');
INSERT INTO "languageNames" VALUES(1192,'vi','ln','Tiếng Lingala');
INSERT INTO "languageNames" VALUES(1193,'vi','lo','Tiếng Lào');
INSERT INTO "languageNames" VALUES(1194,'vi','lt','Tiếng Litva');
INSERT INTO "languageNames" VALUES(1195,'vi','lv','Tiếng Latvia');
INSERT INTO "languageNames" VALUES(1196,'vi','mdf','Tiếng Moksha');
INSERT INTO "languageNames" VALUES(1197,'vi','mfe','Tiếng Morisyen');
INSERT INTO "languageNames" VALUES(1198,'vi','mk','Tiếng Macedonia');
INSERT INTO "languageNames" VALUES(1199,'vi','ml','Tiếng Malayalam');
INSERT INTO "languageNames" VALUES(1200,'vi','mr','Tiếng Marathi');
INSERT INTO "languageNames" VALUES(1201,'vi','ms','Tiếng Mã Lai');
INSERT INTO "languageNames" VALUES(1202,'vi','mt','Tiếng Malta');
INSERT INTO "languageNames" VALUES(1203,'vi','myv','Tiếng Erzya');
INSERT INTO "languageNames" VALUES(1204,'vi','nap','Tiếng Napoli');
INSERT INTO "languageNames" VALUES(1205,'vi','nb','Tiếng Na Uy (Bokmål)');
INSERT INTO "languageNames" VALUES(1206,'vi','ne','Tiếng Nepal');
INSERT INTO "languageNames" VALUES(1207,'vi','nl','Tiếng Hà Lan');
INSERT INTO "languageNames" VALUES(1208,'vi','nn','Tiếng Na Uy (Nynorsk)');
INSERT INTO "languageNames" VALUES(1209,'vi','no','Tiếng Na Uy');
INSERT INTO "languageNames" VALUES(1210,'vi','nog','Tiếng Nogai');
INSERT INTO "languageNames" VALUES(1211,'vi','oc','Tiếng Occitan');
INSERT INTO "languageNames" VALUES(1212,'vi','os','Tiếng Ossetic');
INSERT INTO "languageNames" VALUES(1213,'vi','ota','Tiếng Thổ Nhĩ Kỳ Ottoman');
INSERT INTO "languageNames" VALUES(1214,'vi','pa','Tiếng Punjab');
INSERT INTO "languageNames" VALUES(1215,'vi','pl','Tiếng Ba Lan');
INSERT INTO "languageNames" VALUES(1216,'vi','pt','Tiếng Bồ Đào Nha');
INSERT INTO "languageNames" VALUES(1217,'vi','rm','Tiếng Romansh');
INSERT INTO "languageNames" VALUES(1218,'vi','rn','Tiếng Rundi');
INSERT INTO "languageNames" VALUES(1219,'vi','ro','Tiếng Romania');
INSERT INTO "languageNames" VALUES(1220,'vi','ru','Tiếng Nga');
INSERT INTO "languageNames" VALUES(1221,'vi','rup','Tiếng Aromania');
INSERT INTO "languageNames" VALUES(1222,'vi','sa','Tiếng Phạn');
INSERT INTO "languageNames" VALUES(1223,'vi','sah','Tiếng Sakha');
INSERT INTO "languageNames" VALUES(1224,'vi','sc','Tiếng Sardinia');
INSERT INTO "languageNames" VALUES(1225,'vi','scn','Tiếng Sicilia');
INSERT INTO "languageNames" VALUES(1226,'vi','sco','Tiếng Scots');
INSERT INTO "languageNames" VALUES(1227,'vi','sd','Tiếng Sindhi');
INSERT INTO "languageNames" VALUES(1228,'vi','se','Tiếng Sami Miền Bắc');
INSERT INTO "languageNames" VALUES(1229,'vi','sh','Tiếng Serbo-Croatia');
INSERT INTO "languageNames" VALUES(1230,'vi','si','Tiếng Sinhala');
INSERT INTO "languageNames" VALUES(1231,'vi','sk','Tiếng Slovak');
INSERT INTO "languageNames" VALUES(1232,'vi','sl','Tiếng Slovenia');
INSERT INTO "languageNames" VALUES(1233,'vi','sma','Tiếng Sami Miền Nam');
INSERT INTO "languageNames" VALUES(1234,'vi','smj','Tiếng Lule Sami');
INSERT INTO "languageNames" VALUES(1235,'vi','smn','Tiếng Inari Sami');
INSERT INTO "languageNames" VALUES(1236,'vi','sq','Tiếng Albania');
INSERT INTO "languageNames" VALUES(1237,'vi','sr','Tiếng Serbia');
INSERT INTO "languageNames" VALUES(1238,'vi','srn','Tiếng Sranan Tongo');
INSERT INTO "languageNames" VALUES(1239,'vi','ss','Tiếng Swati');
INSERT INTO "languageNames" VALUES(1240,'vi','sv','Tiếng Thụy Điển');
INSERT INTO "languageNames" VALUES(1241,'vi','sw','Tiếng Swahili');
INSERT INTO "languageNames" VALUES(1242,'vi','ta','Tiếng Tamil');
INSERT INTO "languageNames" VALUES(1243,'vi','te','Tiếng Telugu');
INSERT INTO "languageNames" VALUES(1244,'vi','tet','Tiếng Tetum');
INSERT INTO "languageNames" VALUES(1245,'vi','tg','Tiếng Tajik');
INSERT INTO "languageNames" VALUES(1246,'vi','th','Tiếng Thái');
INSERT INTO "languageNames" VALUES(1247,'vi','tk','Tiếng Turkmen');
INSERT INTO "languageNames" VALUES(1248,'vi','tl','Tiếng Tagalog');
INSERT INTO "languageNames" VALUES(1249,'vi','tr','Tiếng Thổ Nhĩ Kỳ');
INSERT INTO "languageNames" VALUES(1250,'vi','tt','Tiếng Tatar');
INSERT INTO "languageNames" VALUES(1251,'vi','tyv','Tiếng Tuvinian');
INSERT INTO "languageNames" VALUES(1252,'vi','udm','Tiếng Udmurt');
INSERT INTO "languageNames" VALUES(1253,'vi','ug','Tiếng Uyghur');
INSERT INTO "languageNames" VALUES(1254,'vi','uk','Tiếng Ucraina');
INSERT INTO "languageNames" VALUES(1255,'vi','ur','Tiếng Urdu');
INSERT INTO "languageNames" VALUES(1256,'vi','uz','Tiếng Uzbek');
INSERT INTO "languageNames" VALUES(1257,'vi','vi','Tiếng Việt');
INSERT INTO "languageNames" VALUES(1258,'vi','wal','Tiếng Walamo');
INSERT INTO "languageNames" VALUES(1259,'vi','xh','Tiếng Xhosa');
INSERT INTO "languageNames" VALUES(1260,'vi','yi','Tiếng Yiddish');
INSERT INTO "languageNames" VALUES(1261,'vi','yo','Tiếng Yoruba');
INSERT INTO "languageNames" VALUES(1262,'vi','zh','Tiếng Trung');
INSERT INTO "languageNames" VALUES(1263,'vi','zu','Tiếng Zulu');
INSERT INTO "languageNames" VALUES(1264,'ks','af','اَفریٖکانٛز');
INSERT INTO "languageNames" VALUES(1265,'ks','alt','جنوٗبی اَلتایی');
INSERT INTO "languageNames" VALUES(1266,'ks','an','اَراگونی');
INSERT INTO "languageNames" VALUES(1267,'ks','ar','عربی');
INSERT INTO "languageNames" VALUES(1268,'ks','as','اسٲمۍ');
INSERT INTO "languageNames" VALUES(1269,'ks','ast','ایسٹوٗریَن');
INSERT INTO "languageNames" VALUES(1270,'ks','av','اَوارِک');
INSERT INTO "languageNames" VALUES(1271,'ks','az','اَزَربیجانی');
INSERT INTO "languageNames" VALUES(1272,'ks','ba','بَشکیٖر');
INSERT INTO "languageNames" VALUES(1273,'ks','be','بیلَروٗشیَن');
INSERT INTO "languageNames" VALUES(1274,'ks','bg','بینا');
INSERT INTO "languageNames" VALUES(1275,'ks','bi','بِسلاما');
INSERT INTO "languageNames" VALUES(1276,'ks','bn','بَنٛگٲلۍ');
INSERT INTO "languageNames" VALUES(1277,'ks','br','بریٹَن');
INSERT INTO "languageNames" VALUES(1278,'ks','bs','بوسنِیَن');
INSERT INTO "languageNames" VALUES(1279,'ks','bua','بُرِیَت');
INSERT INTO "languageNames" VALUES(1280,'ks','ca','کَتلان');
INSERT INTO "languageNames" VALUES(1281,'ks','ceb','سیباونو');
INSERT INTO "languageNames" VALUES(1282,'ks','chm','ماری');
INSERT INTO "languageNames" VALUES(1283,'ks','co','کارسِکَن');
INSERT INTO "languageNames" VALUES(1284,'ks','crh','کرٕمیٖن تُرکی');
INSERT INTO "languageNames" VALUES(1285,'ks','cs','چیٚک');
INSERT INTO "languageNames" VALUES(1286,'ks','csb','کَشوٗبِیَن');
INSERT INTO "languageNames" VALUES(1287,'ks','cu','چٔرچ سلاوِک');
INSERT INTO "languageNames" VALUES(1288,'ks','cv','چُواش');
INSERT INTO "languageNames" VALUES(1289,'ks','cy','ویٚلش');
INSERT INTO "languageNames" VALUES(1290,'ks','da','ڈینِش');
INSERT INTO "languageNames" VALUES(1291,'ks','dar','دَرگوا');
INSERT INTO "languageNames" VALUES(1292,'ks','de','جٔرمَن');
INSERT INTO "languageNames" VALUES(1293,'ks','dsb','بوٚنِم ساربِیَن');
INSERT INTO "languageNames" VALUES(1294,'ks','el','یوٗنٲنی');
INSERT INTO "languageNames" VALUES(1295,'ks','en','اَنٛگیٖزۍ');
INSERT INTO "languageNames" VALUES(1296,'ks','eo','ایٚسپَرینٹو');
INSERT INTO "languageNames" VALUES(1297,'ks','es','سپینِش');
INSERT INTO "languageNames" VALUES(1298,'ks','et','ایٚسٹونیَن');
INSERT INTO "languageNames" VALUES(1299,'ks','eu','باسک');
INSERT INTO "languageNames" VALUES(1300,'ks','fa','فارسی');
INSERT INTO "languageNames" VALUES(1301,'ks','fi','فِنِش');
INSERT INTO "languageNames" VALUES(1302,'ks','fo','فَروس');
INSERT INTO "languageNames" VALUES(1303,'ks','fr','فریٚنچ');
INSERT INTO "languageNames" VALUES(1304,'ks','fy','مغربی فرِشیَن');
INSERT INTO "languageNames" VALUES(1305,'ks','ga','اَیرِش');
INSERT INTO "languageNames" VALUES(1306,'ks','gd','سکوٹِش گیےلِک');
INSERT INTO "languageNames" VALUES(1307,'ks','gl','گیلِشِیَن');
INSERT INTO "languageNames" VALUES(1308,'ks','gn','گُوارَنی');
INSERT INTO "languageNames" VALUES(1309,'ks','gu','گُجرٲتی');
INSERT INTO "languageNames" VALUES(1310,'ks','gv','مینٛکس');
INSERT INTO "languageNames" VALUES(1311,'ks','ha','ہاوسا');
INSERT INTO "languageNames" VALUES(1312,'ks','haw','ہوایِیَن');
INSERT INTO "languageNames" VALUES(1313,'ks','he','عبرٲنۍ');
INSERT INTO "languageNames" VALUES(1314,'ks','hi','ہِندی');
INSERT INTO "languageNames" VALUES(1315,'ks','hr','کروشِیَن');
INSERT INTO "languageNames" VALUES(1316,'ks','hsb','ہیٚرِم ساربِیَن');
INSERT INTO "languageNames" VALUES(1317,'ks','ht','ہیتِیاں');
INSERT INTO "languageNames" VALUES(1318,'ks','hu','ہَنٛگیریَن');
INSERT INTO "languageNames" VALUES(1319,'ks','hy','اَرمینیَن');
INSERT INTO "languageNames" VALUES(1320,'ks','ia','اِنٹَرلِنٛگوا');
INSERT INTO "languageNames" VALUES(1321,'ks','id','اِنڈونیشیا');
INSERT INTO "languageNames" VALUES(1322,'ks','ig','اِگبو');
INSERT INTO "languageNames" VALUES(1323,'ks','is','آیِسلینڈِک');
INSERT INTO "languageNames" VALUES(1324,'ks','it','اِٹیلیَن');
INSERT INTO "languageNames" VALUES(1325,'ks','ka','جارجِیَن');
INSERT INTO "languageNames" VALUES(1326,'ks','kaa','کارا کَلپَک');
INSERT INTO "languageNames" VALUES(1327,'ks','kk','کازَخ');
INSERT INTO "languageNames" VALUES(1328,'ks','ko','کوریَن');
INSERT INTO "languageNames" VALUES(1329,'ks','krc','کراچیے بَلکار');
INSERT INTO "languageNames" VALUES(1330,'ks','krl','کَریلِیَن');
INSERT INTO "languageNames" VALUES(1331,'ks','ks','کٲشُر');
INSERT INTO "languageNames" VALUES(1332,'ks','kum','کُمِک');
INSERT INTO "languageNames" VALUES(1333,'ks','kv','کومی');
INSERT INTO "languageNames" VALUES(1334,'ks','ky','کِرگِز');
INSERT INTO "languageNames" VALUES(1335,'ks','la','لاتیٖنی');
INSERT INTO "languageNames" VALUES(1336,'ks','lb','لُکھزیمبورگِش');
INSERT INTO "languageNames" VALUES(1337,'ks','lg','گاندا');
INSERT INTO "languageNames" VALUES(1338,'ks','ln','لِنگالا');
INSERT INTO "languageNames" VALUES(1339,'ks','lo','لاو');
INSERT INTO "languageNames" VALUES(1340,'ks','lt','لِتھوانِیَن');
INSERT INTO "languageNames" VALUES(1341,'ks','lv','لَتوِیَن');
INSERT INTO "languageNames" VALUES(1342,'ks','mdf','موکشا');
INSERT INTO "languageNames" VALUES(1343,'ks','mk','میکَڈونیَن');
INSERT INTO "languageNames" VALUES(1344,'ks','ml','مٔلیالَم');
INSERT INTO "languageNames" VALUES(1345,'ks','mr','مَرٲٹھۍ');
INSERT INTO "languageNames" VALUES(1346,'ks','ms','مَلَے');
INSERT INTO "languageNames" VALUES(1347,'ks','mt','مَلتیٖس');
INSERT INTO "languageNames" VALUES(1348,'ks','myv','ایٚرزِیا');
INSERT INTO "languageNames" VALUES(1349,'ks','nap','نیٖپالیٹَن');
INSERT INTO "languageNames" VALUES(1350,'ks','nb','ناروییَن بوکمال');
INSERT INTO "languageNames" VALUES(1351,'ks','ne','نیٚپٲلۍ');
INSERT INTO "languageNames" VALUES(1352,'ks','nl','ڈَچ');
INSERT INTO "languageNames" VALUES(1353,'ks','nn','ناروییَن نَے نورسک');
INSERT INTO "languageNames" VALUES(1354,'ks','no','ناروییَن');
INSERT INTO "languageNames" VALUES(1355,'ks','nog','نوگاے');
INSERT INTO "languageNames" VALUES(1356,'ks','oc','اوکسیٖٹَن');
INSERT INTO "languageNames" VALUES(1357,'ks','os','اوٚسیٚٹِک');
INSERT INTO "languageNames" VALUES(1358,'ks','ota','اوٹومَن تُرکِش');
INSERT INTO "languageNames" VALUES(1359,'ks','pa','پَنجٲبۍ');
INSERT INTO "languageNames" VALUES(1360,'ks','pl','پالِش');
INSERT INTO "languageNames" VALUES(1361,'ks','pt','پُرتَگیٖز');
INSERT INTO "languageNames" VALUES(1362,'ks','rm','رومانش');
INSERT INTO "languageNames" VALUES(1363,'ks','rn','رُندی');
INSERT INTO "languageNames" VALUES(1364,'ks','ro','رومٲنی');
INSERT INTO "languageNames" VALUES(1365,'ks','ru','روٗسی');
INSERT INTO "languageNames" VALUES(1366,'ks','rup','اَرومانی');
INSERT INTO "languageNames" VALUES(1367,'ks','sa','سَنسکرٕت');
INSERT INTO "languageNames" VALUES(1368,'ks','sah','یاکُت');
INSERT INTO "languageNames" VALUES(1369,'ks','sc','سراڈیٖنی');
INSERT INTO "languageNames" VALUES(1370,'ks','scn','سِچِلِیَن');
INSERT INTO "languageNames" VALUES(1371,'ks','sco','سکاٹس');
INSERT INTO "languageNames" VALUES(1372,'ks','sd','سِندی');
INSERT INTO "languageNames" VALUES(1373,'ks','se','شُمٲلی سَمی');
INSERT INTO "languageNames" VALUES(1374,'ks','sh','سیٚربو کروشِیَن');
INSERT INTO "languageNames" VALUES(1375,'ks','si','سِنہالا');
INSERT INTO "languageNames" VALUES(1376,'ks','sk','سلووَک');
INSERT INTO "languageNames" VALUES(1377,'ks','sl','سلووینیَن');
INSERT INTO "languageNames" VALUES(1378,'ks','sma','جنوٗبی سَمی');
INSERT INTO "languageNames" VALUES(1379,'ks','smj','لولیے سَمی');
INSERT INTO "languageNames" VALUES(1380,'ks','smn','اِناری سَمی');
INSERT INTO "languageNames" VALUES(1381,'ks','sq','البانِیَن');
INSERT INTO "languageNames" VALUES(1382,'ks','sr','سٔربِیَن');
INSERT INTO "languageNames" VALUES(1383,'ks','srn','سرٛانَن ٹونٛگو');
INSERT INTO "languageNames" VALUES(1384,'ks','ss','سواتی');
INSERT INTO "languageNames" VALUES(1385,'ks','sv','سویٖڈِش');
INSERT INTO "languageNames" VALUES(1386,'ks','sw','سواہِلی');
INSERT INTO "languageNames" VALUES(1387,'ks','ta','تَمِل');
INSERT INTO "languageNames" VALUES(1388,'ks','te','تیلگوٗ');
INSERT INTO "languageNames" VALUES(1389,'ks','tet','ٹیٹَم');
INSERT INTO "languageNames" VALUES(1390,'ks','tg','تاجِک');
INSERT INTO "languageNames" VALUES(1391,'ks','th','تھاے');
INSERT INTO "languageNames" VALUES(1392,'ks','tk','تُرکمین');
INSERT INTO "languageNames" VALUES(1393,'ks','tl','تَماشیک');
INSERT INTO "languageNames" VALUES(1394,'ks','tr','تُرکِش');
INSERT INTO "languageNames" VALUES(1395,'ks','tt','تَتار');
INSERT INTO "languageNames" VALUES(1396,'ks','tyv','تُویٖنیَن');
INSERT INTO "languageNames" VALUES(1397,'ks','udm','اُدمُرت');
INSERT INTO "languageNames" VALUES(1398,'ks','uk','یوٗکرینیٲیی');
INSERT INTO "languageNames" VALUES(1399,'ks','ur','اُردوٗ');
INSERT INTO "languageNames" VALUES(1400,'ks','uz','اُزبیک');
INSERT INTO "languageNames" VALUES(1401,'ks','vi','وِیَتنَمیٖز');
INSERT INTO "languageNames" VALUES(1402,'ks','wal','والامو');
INSERT INTO "languageNames" VALUES(1403,'ks','xh','کھوسا');
INSERT INTO "languageNames" VALUES(1404,'ks','yi','یِدِش');
INSERT INTO "languageNames" VALUES(1405,'ks','yo','یورُبا');
INSERT INTO "languageNames" VALUES(1406,'ks','zh','چیٖنی');
INSERT INTO "languageNames" VALUES(1407,'ks','zu','زُلوٗ');
INSERT INTO "languageNames" VALUES(1408,'bn','af','আফ্রিকান');
INSERT INTO "languageNames" VALUES(1409,'bn','alt','দক্ষিন আলতাই');
INSERT INTO "languageNames" VALUES(1410,'bn','an','আর্গোনিজ');
INSERT INTO "languageNames" VALUES(1411,'bn','ar','আরবী');
INSERT INTO "languageNames" VALUES(1412,'bn','as','আসামি');
INSERT INTO "languageNames" VALUES(1413,'bn','ast','আস্তুরিয়');
INSERT INTO "languageNames" VALUES(1414,'bn','av','আভেরিক');
INSERT INTO "languageNames" VALUES(1416,'bn','az','আজেরি');
INSERT INTO "languageNames" VALUES(1417,'bn','ba','বাশকির');
INSERT INTO "languageNames" VALUES(1418,'bn','be','বেলারুশিয়');
INSERT INTO "languageNames" VALUES(1419,'bn','bg','বুলগেরিয়');
INSERT INTO "languageNames" VALUES(1420,'bn','bi','বিসলামা');
INSERT INTO "languageNames" VALUES(1421,'bn','bn','বাংলা');
INSERT INTO "languageNames" VALUES(1422,'bn','br','ব্রেটন');
INSERT INTO "languageNames" VALUES(1423,'bn','bs','বসনীয়ান');
INSERT INTO "languageNames" VALUES(1424,'bn','bua','বুরিয়াত');
INSERT INTO "languageNames" VALUES(1425,'bn','ca','কাতালান');
INSERT INTO "languageNames" VALUES(1426,'bn','ceb','চেবুয়ানো');
INSERT INTO "languageNames" VALUES(1427,'bn','chm','মারি');
INSERT INTO "languageNames" VALUES(1428,'bn','ckb','মধ্য কুর্দিশ');
INSERT INTO "languageNames" VALUES(1429,'bn','co','কর্সিকান');
INSERT INTO "languageNames" VALUES(1430,'bn','crh','ক্রিমিয়ান তুর্কি');
INSERT INTO "languageNames" VALUES(1431,'bn','cs','চেক');
INSERT INTO "languageNames" VALUES(1432,'bn','csb','কাশুবিয়ান');
INSERT INTO "languageNames" VALUES(1433,'bn','cu','চার্চ স্লাভিক');
INSERT INTO "languageNames" VALUES(1434,'bn','cv','চুবাস');
INSERT INTO "languageNames" VALUES(1435,'bn','cy','ওয়েলশ');
INSERT INTO "languageNames" VALUES(1436,'bn','da','ডেনিশ');
INSERT INTO "languageNames" VALUES(1437,'bn','dar','দার্গওয়া');
INSERT INTO "languageNames" VALUES(1438,'bn','de','জার্মান');
INSERT INTO "languageNames" VALUES(1439,'bn','dsb','নিম্নতর সোর্বিয়ান');
INSERT INTO "languageNames" VALUES(1440,'bn','el','গ্রিক');
INSERT INTO "languageNames" VALUES(1441,'bn','en','ইংরেজি');
INSERT INTO "languageNames" VALUES(1442,'bn','eo','এস্পেরান্তো');
INSERT INTO "languageNames" VALUES(1443,'bn','es','স্প্যানিশ');
INSERT INTO "languageNames" VALUES(1444,'bn','et','এস্তোনীয়');
INSERT INTO "languageNames" VALUES(1445,'bn','eu','বাস্ক');
INSERT INTO "languageNames" VALUES(1446,'bn','fa','ফার্সি');
INSERT INTO "languageNames" VALUES(1447,'bn','fi','ফিনিশ');
INSERT INTO "languageNames" VALUES(1448,'bn','fo','ফারোস');
INSERT INTO "languageNames" VALUES(1449,'bn','fr','ফরাসি');
INSERT INTO "languageNames" VALUES(1450,'bn','fy','পশ্চিম ফ্রিসিয়ান');
INSERT INTO "languageNames" VALUES(1451,'bn','ga','আইরিশ');
INSERT INTO "languageNames" VALUES(1452,'bn','gag','গাগাউজ');
INSERT INTO "languageNames" VALUES(1453,'bn','gd','স্কটস-গ্যেলিক');
INSERT INTO "languageNames" VALUES(1454,'bn','gl','গ্যালিশিয়');
INSERT INTO "languageNames" VALUES(1455,'bn','gn','গুয়ারানি');
INSERT INTO "languageNames" VALUES(1456,'bn','gu','গুজরাটি');
INSERT INTO "languageNames" VALUES(1457,'bn','gv','ম্যাঙ্কস');
INSERT INTO "languageNames" VALUES(1458,'bn','ha','হাউসা');
INSERT INTO "languageNames" VALUES(1459,'bn','haw','হাওয়াইয়ান');
INSERT INTO "languageNames" VALUES(1460,'bn','he','হিব্রু');
INSERT INTO "languageNames" VALUES(1461,'bn','hi','হিন্দি');
INSERT INTO "languageNames" VALUES(1462,'bn','hr','ক্রোয়েশীয়');
INSERT INTO "languageNames" VALUES(1463,'bn','hsb','উচ্চ সোর্বিয়ান');
INSERT INTO "languageNames" VALUES(1464,'bn','ht','হাইতিয়ান ক্রেওল');
INSERT INTO "languageNames" VALUES(1465,'bn','hu','হাঙ্গেরীয়');
INSERT INTO "languageNames" VALUES(1466,'bn','hy','আর্মেনিয়');
INSERT INTO "languageNames" VALUES(1467,'bn','ia','ইন্টারলিঙ্গুয়া');
INSERT INTO "languageNames" VALUES(1468,'bn','id','ইন্দোনেশীয়');
INSERT INTO "languageNames" VALUES(1469,'bn','ig','ইগ্‌বো');
INSERT INTO "languageNames" VALUES(1470,'bn','is','আইসল্যান্ডীয়');
INSERT INTO "languageNames" VALUES(1471,'bn','it','ইতালিয়');
INSERT INTO "languageNames" VALUES(1472,'bn','ka','জর্জিয়ান');
INSERT INTO "languageNames" VALUES(1473,'bn','kaa','কারা-কাল্পাক');
INSERT INTO "languageNames" VALUES(1474,'bn','kk','কাজাখ');
INSERT INTO "languageNames" VALUES(1475,'bn','ko','কোরিয়ান');
INSERT INTO "languageNames" VALUES(1476,'bn','krc','কারচে-বাল্কার');
INSERT INTO "languageNames" VALUES(1477,'bn','krl','কারেলিয়ান');
INSERT INTO "languageNames" VALUES(1478,'bn','ks','কাশ্মীরি');
INSERT INTO "languageNames" VALUES(1479,'bn','kum','কুমিক');
INSERT INTO "languageNames" VALUES(1480,'bn','kv','কোমি');
INSERT INTO "languageNames" VALUES(1481,'bn','ky','কির্গিজ');
INSERT INTO "languageNames" VALUES(1482,'bn','la','লাটিন');
INSERT INTO "languageNames" VALUES(1483,'bn','lb','লুক্সেমবার্গীয়');
INSERT INTO "languageNames" VALUES(1484,'bn','lg','গান্ডা');
INSERT INTO "languageNames" VALUES(1485,'bn','ln','লিঙ্গালা');
INSERT INTO "languageNames" VALUES(1486,'bn','lo','লাও');
INSERT INTO "languageNames" VALUES(1487,'bn','lt','লিথুয়েনীয়');
INSERT INTO "languageNames" VALUES(1488,'bn','lv','লাত্‌ভীয়');
INSERT INTO "languageNames" VALUES(1489,'bn','mdf','মোকশা');
INSERT INTO "languageNames" VALUES(1490,'bn','mfe','মরিসিয়ান');
INSERT INTO "languageNames" VALUES(1491,'bn','mk','ম্যাসিডোনীয়');
INSERT INTO "languageNames" VALUES(1492,'bn','ml','মালায়ালাম');
INSERT INTO "languageNames" VALUES(1493,'bn','mr','মারাঠি');
INSERT INTO "languageNames" VALUES(1494,'bn','ms','মালয়');
INSERT INTO "languageNames" VALUES(1495,'bn','mt','মল্টিয়');
INSERT INTO "languageNames" VALUES(1496,'bn','myv','এরজিয়া');
INSERT INTO "languageNames" VALUES(1497,'bn','nap','নেয়াপোলিটান');
INSERT INTO "languageNames" VALUES(1498,'bn','nb','নরওয়েজিয়ান বোকমাল');
INSERT INTO "languageNames" VALUES(1499,'bn','ne','নেপালী');
INSERT INTO "languageNames" VALUES(1500,'bn','nl','ডাচ');
INSERT INTO "languageNames" VALUES(1501,'bn','nn','নরওয়েজীয়ান নিনর্স্ক');
INSERT INTO "languageNames" VALUES(1502,'bn','no','নরওয়েজীয়');
INSERT INTO "languageNames" VALUES(1503,'bn','nog','নোগাই');
INSERT INTO "languageNames" VALUES(1504,'bn','oc','অক্সিটান');
INSERT INTO "languageNames" VALUES(1505,'bn','os','ওসেটিক');
INSERT INTO "languageNames" VALUES(1506,'bn','ota','অটোমান তুর্কি');
INSERT INTO "languageNames" VALUES(1507,'bn','pa','পাঞ্জাবী');
INSERT INTO "languageNames" VALUES(1508,'bn','pl','পোলিশ');
INSERT INTO "languageNames" VALUES(1509,'bn','pt','পর্তুগীজ');
INSERT INTO "languageNames" VALUES(1510,'bn','rm','রোমান্স');
INSERT INTO "languageNames" VALUES(1511,'bn','rn','রুন্দি');
INSERT INTO "languageNames" VALUES(1512,'bn','ro','রোমানীয়');
INSERT INTO "languageNames" VALUES(1513,'bn','ru','রুশ');
INSERT INTO "languageNames" VALUES(1514,'bn','rup','আরমেনিয়ান');
INSERT INTO "languageNames" VALUES(1515,'bn','sa','সংস্কৃত');
INSERT INTO "languageNames" VALUES(1516,'bn','sah','শাখা');
INSERT INTO "languageNames" VALUES(1517,'bn','sc','সার্ডিনিয়ান');
INSERT INTO "languageNames" VALUES(1518,'bn','scn','সিসিলিয়ান');
INSERT INTO "languageNames" VALUES(1519,'bn','sco','স্কটস');
INSERT INTO "languageNames" VALUES(1520,'bn','sd','সিন্ধি');
INSERT INTO "languageNames" VALUES(1521,'bn','se','উত্তরাঞ্চলীয় সামি');
INSERT INTO "languageNames" VALUES(1522,'bn','sh','সার্বো-ক্রোয়েশিয়');
INSERT INTO "languageNames" VALUES(1523,'bn','si','সিংহলী');
INSERT INTO "languageNames" VALUES(1524,'bn','sk','স্লোভাক');
INSERT INTO "languageNames" VALUES(1525,'bn','sl','স্লোভেনীয়');
INSERT INTO "languageNames" VALUES(1526,'bn','sma','দক্ষিণাঞ্চলীয় সামি');
INSERT INTO "languageNames" VALUES(1527,'bn','smj','লুলে সামি');
INSERT INTO "languageNames" VALUES(1528,'bn','smn','ইনারি সামি');
INSERT INTO "languageNames" VALUES(1529,'bn','sq','আলবেনীয়');
INSERT INTO "languageNames" VALUES(1530,'bn','sr','সার্বীয়');
INSERT INTO "languageNames" VALUES(1531,'bn','srn','স্রানান টোঙ্গো');
INSERT INTO "languageNames" VALUES(1532,'bn','ss','সোয়াতি');
INSERT INTO "languageNames" VALUES(1533,'bn','sv','সুইডিশ');
INSERT INTO "languageNames" VALUES(1534,'bn','sw','সোয়াহিলি');
INSERT INTO "languageNames" VALUES(1535,'bn','ta','তামিল');
INSERT INTO "languageNames" VALUES(1536,'bn','te','তেলেগু');
INSERT INTO "languageNames" VALUES(1537,'bn','tet','তেতুম');
INSERT INTO "languageNames" VALUES(1538,'bn','tg','তাজিক');
INSERT INTO "languageNames" VALUES(1539,'bn','th','থাই');
INSERT INTO "languageNames" VALUES(1540,'bn','tk','তুর্কমেনী');
INSERT INTO "languageNames" VALUES(1541,'bn','tl','তাগালগ');
INSERT INTO "languageNames" VALUES(1542,'bn','tr','তুর্কী');
INSERT INTO "languageNames" VALUES(1543,'bn','tt','তাতার');
INSERT INTO "languageNames" VALUES(1544,'bn','tyv','টুভিনিয়ান');
INSERT INTO "languageNames" VALUES(1545,'bn','udm','উডমুর্ট');
INSERT INTO "languageNames" VALUES(1546,'bn','ug','উইঘুর');
INSERT INTO "languageNames" VALUES(1547,'bn','uk','ইউক্রেনীয়');
INSERT INTO "languageNames" VALUES(1548,'bn','ur','উর্দু');
INSERT INTO "languageNames" VALUES(1549,'bn','uz','উজবেকীয়');
INSERT INTO "languageNames" VALUES(1550,'bn','vi','ভিয়েতনামী');
INSERT INTO "languageNames" VALUES(1551,'bn','wal','ওয়ালামো');
INSERT INTO "languageNames" VALUES(1552,'bn','xh','জোসা');
INSERT INTO "languageNames" VALUES(1553,'bn','yi','ইয়েদ্দিশ');
INSERT INTO "languageNames" VALUES(1554,'bn','yo','ইওরুবা');
INSERT INTO "languageNames" VALUES(1555,'bn','zh','চীনা');
INSERT INTO "languageNames" VALUES(1556,'bn','zu','জুলু');
INSERT INTO "languageNames" VALUES(1557,'hu','af','afrikaans');
INSERT INTO "languageNames" VALUES(1558,'hu','alt','dél-altaji');
INSERT INTO "languageNames" VALUES(1559,'hu','an','aragonéz');
INSERT INTO "languageNames" VALUES(1560,'hu','ar','arab');
INSERT INTO "languageNames" VALUES(1561,'hu','as','asszámi');
INSERT INTO "languageNames" VALUES(1562,'hu','ast','asztúr');
INSERT INTO "languageNames" VALUES(1563,'hu','av','avar');
INSERT INTO "languageNames" VALUES(1565,'hu','az','azeri');
INSERT INTO "languageNames" VALUES(1566,'hu','ba','baskír');
INSERT INTO "languageNames" VALUES(1567,'hu','be','belarusz');
INSERT INTO "languageNames" VALUES(1568,'hu','bg','bolgár');
INSERT INTO "languageNames" VALUES(1569,'hu','bi','bislama');
INSERT INTO "languageNames" VALUES(1570,'hu','bn','bangla');
INSERT INTO "languageNames" VALUES(1571,'hu','br','breton');
INSERT INTO "languageNames" VALUES(1572,'hu','bs','bosnyák');
INSERT INTO "languageNames" VALUES(1573,'hu','bua','burját');
INSERT INTO "languageNames" VALUES(1574,'hu','byv','medumba');
INSERT INTO "languageNames" VALUES(1575,'hu','ca','katalán');
INSERT INTO "languageNames" VALUES(1576,'hu','ceb','szebuano');
INSERT INTO "languageNames" VALUES(1577,'hu','chm','mari');
INSERT INTO "languageNames" VALUES(1578,'hu','ckb','közép-ázsiai kurd');
INSERT INTO "languageNames" VALUES(1579,'hu','co','korzikai');
INSERT INTO "languageNames" VALUES(1580,'hu','crh','krími tatár');
INSERT INTO "languageNames" VALUES(1581,'hu','cs','cseh');
INSERT INTO "languageNames" VALUES(1582,'hu','csb','kasub');
INSERT INTO "languageNames" VALUES(1583,'hu','cu','egyházi szláv');
INSERT INTO "languageNames" VALUES(1584,'hu','cv','csuvas');
INSERT INTO "languageNames" VALUES(1585,'hu','cy','walesi');
INSERT INTO "languageNames" VALUES(1586,'hu','da','dán');
INSERT INTO "languageNames" VALUES(1587,'hu','dar','dargva');
INSERT INTO "languageNames" VALUES(1588,'hu','de','német');
INSERT INTO "languageNames" VALUES(1589,'hu','dsb','alsó-szorb');
INSERT INTO "languageNames" VALUES(1590,'hu','el','görög');
INSERT INTO "languageNames" VALUES(1591,'hu','en','angol');
INSERT INTO "languageNames" VALUES(1592,'hu','eo','eszperantó');
INSERT INTO "languageNames" VALUES(1593,'hu','es','spanyol');
INSERT INTO "languageNames" VALUES(1594,'hu','et','észt');
INSERT INTO "languageNames" VALUES(1595,'hu','eu','baszk');
INSERT INTO "languageNames" VALUES(1596,'hu','fa','perzsa');
INSERT INTO "languageNames" VALUES(1597,'hu','fi','finn');
INSERT INTO "languageNames" VALUES(1598,'hu','fo','feröeri');
INSERT INTO "languageNames" VALUES(1599,'hu','fr','francia');
INSERT INTO "languageNames" VALUES(1600,'hu','fy','nyugati fríz');
INSERT INTO "languageNames" VALUES(1601,'hu','ga','ír');
INSERT INTO "languageNames" VALUES(1602,'hu','gag','gagauz');
INSERT INTO "languageNames" VALUES(1603,'hu','gd','skóciai kelta');
INSERT INTO "languageNames" VALUES(1604,'hu','gl','gallego');
INSERT INTO "languageNames" VALUES(1605,'hu','gn','guarani');
INSERT INTO "languageNames" VALUES(1606,'hu','gu','gudzsaráti');
INSERT INTO "languageNames" VALUES(1607,'hu','gv','man-szigeti');
INSERT INTO "languageNames" VALUES(1608,'hu','ha','hausza');
INSERT INTO "languageNames" VALUES(1609,'hu','haw','hawaii');
INSERT INTO "languageNames" VALUES(1610,'hu','he','héber');
INSERT INTO "languageNames" VALUES(1611,'hu','hi','hindi');
INSERT INTO "languageNames" VALUES(1612,'hu','hr','horvát');
INSERT INTO "languageNames" VALUES(1613,'hu','hsb','felső-szorb');
INSERT INTO "languageNames" VALUES(1614,'hu','ht','haiti kreol');
INSERT INTO "languageNames" VALUES(1615,'hu','hu','magyar');
INSERT INTO "languageNames" VALUES(1616,'hu','hy','örmény');
INSERT INTO "languageNames" VALUES(1617,'hu','ia','interlingva');
INSERT INTO "languageNames" VALUES(1618,'hu','id','indonéz');
INSERT INTO "languageNames" VALUES(1619,'hu','ig','igbó');
INSERT INTO "languageNames" VALUES(1620,'hu','is','izlandi');
INSERT INTO "languageNames" VALUES(1621,'hu','it','olasz');
INSERT INTO "languageNames" VALUES(1622,'hu','ka','grúz');
INSERT INTO "languageNames" VALUES(1623,'hu','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(1624,'hu','kk','kazah');
INSERT INTO "languageNames" VALUES(1625,'hu','ko','koreai');
INSERT INTO "languageNames" VALUES(1626,'hu','krc','karacsáj-balkár');
INSERT INTO "languageNames" VALUES(1627,'hu','krl','karelai');
INSERT INTO "languageNames" VALUES(1628,'hu','ks','kasmíri');
INSERT INTO "languageNames" VALUES(1629,'hu','kum','kumük');
INSERT INTO "languageNames" VALUES(1630,'hu','kv','komi');
INSERT INTO "languageNames" VALUES(1631,'hu','ky','kirgiz');
INSERT INTO "languageNames" VALUES(1632,'hu','la','latin');
INSERT INTO "languageNames" VALUES(1633,'hu','lb','luxemburgi');
INSERT INTO "languageNames" VALUES(1634,'hu','lg','ganda');
INSERT INTO "languageNames" VALUES(1635,'hu','ln','lingala');
INSERT INTO "languageNames" VALUES(1636,'hu','lo','lao');
INSERT INTO "languageNames" VALUES(1637,'hu','lt','litván');
INSERT INTO "languageNames" VALUES(1638,'hu','lv','lett');
INSERT INTO "languageNames" VALUES(1639,'hu','mdf','moksán');
INSERT INTO "languageNames" VALUES(1640,'hu','mfe','mauritiusi kreol');
INSERT INTO "languageNames" VALUES(1641,'hu','mk','macedón');
INSERT INTO "languageNames" VALUES(1642,'hu','ml','malajálam');
INSERT INTO "languageNames" VALUES(1643,'hu','mr','maráthi');
INSERT INTO "languageNames" VALUES(1644,'hu','ms','maláj');
INSERT INTO "languageNames" VALUES(1645,'hu','mt','máltai');
INSERT INTO "languageNames" VALUES(1646,'hu','myv','erzjány');
INSERT INTO "languageNames" VALUES(1647,'hu','nap','nápolyi');
INSERT INTO "languageNames" VALUES(1648,'hu','nb','norvég (bokmål)');
INSERT INTO "languageNames" VALUES(1649,'hu','ne','nepáli');
INSERT INTO "languageNames" VALUES(1650,'hu','nl','holland');
INSERT INTO "languageNames" VALUES(1651,'hu','nn','norvég (nynorsk)');
INSERT INTO "languageNames" VALUES(1652,'hu','no','norvég');
INSERT INTO "languageNames" VALUES(1653,'hu','nog','nogaj');
INSERT INTO "languageNames" VALUES(1654,'hu','oc','okszitán');
INSERT INTO "languageNames" VALUES(1655,'hu','os','oszét');
INSERT INTO "languageNames" VALUES(1656,'hu','ota','ottomán török');
INSERT INTO "languageNames" VALUES(1657,'hu','pa','pandzsábi');
INSERT INTO "languageNames" VALUES(1658,'hu','pl','lengyel');
INSERT INTO "languageNames" VALUES(1659,'hu','pt','portugál');
INSERT INTO "languageNames" VALUES(1660,'hu','rm','rétoromán');
INSERT INTO "languageNames" VALUES(1661,'hu','rn','kirundi');
INSERT INTO "languageNames" VALUES(1662,'hu','ro','román');
INSERT INTO "languageNames" VALUES(1663,'hu','ru','orosz');
INSERT INTO "languageNames" VALUES(1664,'hu','rup','aromán');
INSERT INTO "languageNames" VALUES(1665,'hu','sa','szanszkrit');
INSERT INTO "languageNames" VALUES(1666,'hu','sah','szaha');
INSERT INTO "languageNames" VALUES(1667,'hu','sc','szardíniai');
INSERT INTO "languageNames" VALUES(1668,'hu','scn','szicíliai');
INSERT INTO "languageNames" VALUES(1669,'hu','sco','skót');
INSERT INTO "languageNames" VALUES(1670,'hu','sd','szindhi');
INSERT INTO "languageNames" VALUES(1671,'hu','se','északi számi');
INSERT INTO "languageNames" VALUES(1672,'hu','sh','szerbhorvát');
INSERT INTO "languageNames" VALUES(1673,'hu','si','szingaléz');
INSERT INTO "languageNames" VALUES(1674,'hu','sk','szlovák');
INSERT INTO "languageNames" VALUES(1675,'hu','sl','szlovén');
INSERT INTO "languageNames" VALUES(1676,'hu','sma','déli számi');
INSERT INTO "languageNames" VALUES(1677,'hu','smj','lulei számi');
INSERT INTO "languageNames" VALUES(1678,'hu','smn','inari számi');
INSERT INTO "languageNames" VALUES(1679,'hu','sq','albán');
INSERT INTO "languageNames" VALUES(1680,'hu','sr','szerb');
INSERT INTO "languageNames" VALUES(1681,'hu','srn','szranai tongó');
INSERT INTO "languageNames" VALUES(1682,'hu','ss','sziszuati');
INSERT INTO "languageNames" VALUES(1683,'hu','sv','svéd');
INSERT INTO "languageNames" VALUES(1684,'hu','sw','szuahéli');
INSERT INTO "languageNames" VALUES(1685,'hu','ta','tamil');
INSERT INTO "languageNames" VALUES(1686,'hu','te','telugu');
INSERT INTO "languageNames" VALUES(1687,'hu','tet','tetum');
INSERT INTO "languageNames" VALUES(1688,'hu','tg','tadzsik');
INSERT INTO "languageNames" VALUES(1689,'hu','th','thai');
INSERT INTO "languageNames" VALUES(1690,'hu','tk','türkmén');
INSERT INTO "languageNames" VALUES(1691,'hu','tl','tagalog');
INSERT INTO "languageNames" VALUES(1692,'hu','tr','török');
INSERT INTO "languageNames" VALUES(1693,'hu','tt','tatár');
INSERT INTO "languageNames" VALUES(1694,'hu','tyv','tuvai');
INSERT INTO "languageNames" VALUES(1695,'hu','udm','udmurt');
INSERT INTO "languageNames" VALUES(1696,'hu','ug','ujgur');
INSERT INTO "languageNames" VALUES(1697,'hu','uk','ukrán');
INSERT INTO "languageNames" VALUES(1698,'hu','ur','urdu');
INSERT INTO "languageNames" VALUES(1699,'hu','uz','üzbég');
INSERT INTO "languageNames" VALUES(1700,'hu','vi','vietnami');
INSERT INTO "languageNames" VALUES(1701,'hu','wal','valamo');
INSERT INTO "languageNames" VALUES(1702,'hu','xh','xhosza');
INSERT INTO "languageNames" VALUES(1703,'hu','yi','jiddis');
INSERT INTO "languageNames" VALUES(1704,'hu','yo','joruba');
INSERT INTO "languageNames" VALUES(1705,'hu','zh','kínai');
INSERT INTO "languageNames" VALUES(1706,'hu','zu','zulu');
INSERT INTO "languageNames" VALUES(1707,'ta','af','ஆஃப்ரிகான்ஸ்');
INSERT INTO "languageNames" VALUES(1708,'ta','alt','தெற்கு அல்தை');
INSERT INTO "languageNames" VALUES(1709,'ta','an','ஆர்கோனீஸ்');
INSERT INTO "languageNames" VALUES(1710,'ta','ar','அரபிக்');
INSERT INTO "languageNames" VALUES(1711,'ta','as','அஸ்ஸாமீஸ்');
INSERT INTO "languageNames" VALUES(1712,'ta','ast','அஸ்துரியன்');
INSERT INTO "languageNames" VALUES(1713,'ta','av','அவேரிக்');
INSERT INTO "languageNames" VALUES(1715,'ta','az','அஸேரி');
INSERT INTO "languageNames" VALUES(1716,'ta','ba','பஷ்கிர்');
INSERT INTO "languageNames" VALUES(1717,'ta','be','பெலாருஷியன்');
INSERT INTO "languageNames" VALUES(1718,'ta','bg','பல்கேரியன்');
INSERT INTO "languageNames" VALUES(1719,'ta','bi','பிஸ்லாமா');
INSERT INTO "languageNames" VALUES(1720,'ta','bn','வங்காளம்');
INSERT INTO "languageNames" VALUES(1721,'ta','br','பிரெட்டன்');
INSERT INTO "languageNames" VALUES(1722,'ta','bs','போஸ்னியன்');
INSERT INTO "languageNames" VALUES(1723,'ta','bua','புரியாத்');
INSERT INTO "languageNames" VALUES(1724,'ta','ca','கேட்டலான்');
INSERT INTO "languageNames" VALUES(1725,'ta','ceb','செபுவானோ');
INSERT INTO "languageNames" VALUES(1726,'ta','chm','மாரி');
INSERT INTO "languageNames" VALUES(1727,'ta','ckb','மத்திய குர்திஷ்');
INSERT INTO "languageNames" VALUES(1728,'ta','co','கார்சிகன்');
INSERT INTO "languageNames" VALUES(1729,'ta','crh','கிரிமியன் துர்க்கி');
INSERT INTO "languageNames" VALUES(1730,'ta','cs','செக்');
INSERT INTO "languageNames" VALUES(1731,'ta','csb','கஷுபியன்');
INSERT INTO "languageNames" VALUES(1732,'ta','cu','சர்ச் ஸ்லாவிக்');
INSERT INTO "languageNames" VALUES(1733,'ta','cv','சுவாஷ்');
INSERT INTO "languageNames" VALUES(1734,'ta','cy','வேல்ஷ்');
INSERT INTO "languageNames" VALUES(1735,'ta','da','டேனிஷ்');
INSERT INTO "languageNames" VALUES(1736,'ta','dar','தார்குவா');
INSERT INTO "languageNames" VALUES(1737,'ta','de','ஜெர்மன்');
INSERT INTO "languageNames" VALUES(1738,'ta','dsb','லோயர் சோர்பியன்');
INSERT INTO "languageNames" VALUES(1739,'ta','el','கிரேக்கம்');
INSERT INTO "languageNames" VALUES(1740,'ta','en','ஆங்கிலம்');
INSERT INTO "languageNames" VALUES(1741,'ta','eo','எஸ்பரேன்டோ');
INSERT INTO "languageNames" VALUES(1742,'ta','es','ஸ்பானிஷ்');
INSERT INTO "languageNames" VALUES(1743,'ta','et','எஸ்டோனியன்');
INSERT INTO "languageNames" VALUES(1744,'ta','eu','பாஸ்க்');
INSERT INTO "languageNames" VALUES(1745,'ta','fa','பெர்ஷியன்');
INSERT INTO "languageNames" VALUES(1746,'ta','fi','ஃபின்னிஷ்');
INSERT INTO "languageNames" VALUES(1747,'ta','fo','ஃபரோயிஸ்');
INSERT INTO "languageNames" VALUES(1748,'ta','fr','பிரெஞ்சு');
INSERT INTO "languageNames" VALUES(1749,'ta','fy','மேற்கு ஃப்ரிஷியன்');
INSERT INTO "languageNames" VALUES(1750,'ta','ga','ஐரிஷ்');
INSERT INTO "languageNames" VALUES(1751,'ta','gag','காகௌஸ்');
INSERT INTO "languageNames" VALUES(1752,'ta','gd','ஸ்காட்ஸ் கேலிக்');
INSERT INTO "languageNames" VALUES(1753,'ta','gl','காலிஸியன்');
INSERT INTO "languageNames" VALUES(1754,'ta','gn','க்வாரனி');
INSERT INTO "languageNames" VALUES(1755,'ta','gu','குஜராத்தி');
INSERT INTO "languageNames" VALUES(1756,'ta','gv','மேங்க்ஸ்');
INSERT INTO "languageNames" VALUES(1757,'ta','ha','ஹௌஸா');
INSERT INTO "languageNames" VALUES(1758,'ta','haw','ஹவாயியன்');
INSERT INTO "languageNames" VALUES(1759,'ta','he','ஹீப்ரூ');
INSERT INTO "languageNames" VALUES(1760,'ta','hi','இந்தி');
INSERT INTO "languageNames" VALUES(1761,'ta','hr','குரோஷியன்');
INSERT INTO "languageNames" VALUES(1762,'ta','hsb','அப்பர் சோர்பியான்');
INSERT INTO "languageNames" VALUES(1763,'ta','ht','ஹைத்தியன் க்ரியோலி');
INSERT INTO "languageNames" VALUES(1764,'ta','hu','ஹங்கேரியன்');
INSERT INTO "languageNames" VALUES(1765,'ta','hy','ஆர்மேனியன்');
INSERT INTO "languageNames" VALUES(1766,'ta','ia','இன்டர்லிங்வா');
INSERT INTO "languageNames" VALUES(1767,'ta','id','இந்தோனேஷியன்');
INSERT INTO "languageNames" VALUES(1768,'ta','ig','இக்போ');
INSERT INTO "languageNames" VALUES(1769,'ta','is','ஐஸ்லேண்டிக்');
INSERT INTO "languageNames" VALUES(1770,'ta','it','இத்தாலியன்');
INSERT INTO "languageNames" VALUES(1771,'ta','ka','ஜார்ஜியன்');
INSERT INTO "languageNames" VALUES(1772,'ta','kaa','காரா-கல்பாக்');
INSERT INTO "languageNames" VALUES(1773,'ta','kk','கசாக்');
INSERT INTO "languageNames" VALUES(1774,'ta','ko','கொரியன்');
INSERT INTO "languageNames" VALUES(1775,'ta','krc','கராசே-பல்கார்');
INSERT INTO "languageNames" VALUES(1776,'ta','krl','கரேலியன்');
INSERT INTO "languageNames" VALUES(1777,'ta','ks','காஷ்மிரி');
INSERT INTO "languageNames" VALUES(1778,'ta','kum','கும்இக்');
INSERT INTO "languageNames" VALUES(1779,'ta','kv','கொமி');
INSERT INTO "languageNames" VALUES(1780,'ta','ky','கிர்கிஸ்');
INSERT INTO "languageNames" VALUES(1781,'ta','la','லத்தின்');
INSERT INTO "languageNames" VALUES(1782,'ta','lb','லக்ஸம்போர்கிஷ்');
INSERT INTO "languageNames" VALUES(1783,'ta','lg','கான்டா');
INSERT INTO "languageNames" VALUES(1784,'ta','ln','லிங்காலா');
INSERT INTO "languageNames" VALUES(1785,'ta','lo','லாவோ');
INSERT INTO "languageNames" VALUES(1786,'ta','lt','லிதுவேனியன்');
INSERT INTO "languageNames" VALUES(1787,'ta','lv','லாட்வியன்');
INSERT INTO "languageNames" VALUES(1788,'ta','mdf','மோக்க்ஷா');
INSERT INTO "languageNames" VALUES(1789,'ta','mfe','மொரிசியன்');
INSERT INTO "languageNames" VALUES(1790,'ta','mk','மாஸிடோனியன்');
INSERT INTO "languageNames" VALUES(1791,'ta','ml','மலையாளம்');
INSERT INTO "languageNames" VALUES(1792,'ta','mr','மராத்தி');
INSERT INTO "languageNames" VALUES(1793,'ta','ms','மலாய்');
INSERT INTO "languageNames" VALUES(1794,'ta','mt','மால்டிஸ்');
INSERT INTO "languageNames" VALUES(1795,'ta','myv','ஏர்ஜியா');
INSERT INTO "languageNames" VALUES(1796,'ta','nap','நியோபோலிடன்');
INSERT INTO "languageNames" VALUES(1797,'ta','nb','நார்வேஜியன் பொக்மால்');
INSERT INTO "languageNames" VALUES(1798,'ta','ne','நேபாளி');
INSERT INTO "languageNames" VALUES(1799,'ta','nl','டச்சு');
INSERT INTO "languageNames" VALUES(1800,'ta','nn','நார்வேஜியன் நியூநார்ஸ்க்');
INSERT INTO "languageNames" VALUES(1801,'ta','no','நார்வேஜியன்');
INSERT INTO "languageNames" VALUES(1802,'ta','nog','நோகை');
INSERT INTO "languageNames" VALUES(1803,'ta','oc','ஒக்கிடன்');
INSERT INTO "languageNames" VALUES(1804,'ta','os','ஒசெட்டிக்');
INSERT INTO "languageNames" VALUES(1805,'ta','ota','ஓட்டோமான் துருக்கிஷ்');
INSERT INTO "languageNames" VALUES(1806,'ta','pa','பஞ்சாபி');
INSERT INTO "languageNames" VALUES(1807,'ta','pl','போலிஷ்');
INSERT INTO "languageNames" VALUES(1808,'ta','pt','போர்ச்சுக்கீஸ்');
INSERT INTO "languageNames" VALUES(1809,'ta','rm','ரோமான்ஷ்');
INSERT INTO "languageNames" VALUES(1810,'ta','rn','ருண்டி');
INSERT INTO "languageNames" VALUES(1811,'ta','ro','ரோமேனியன்');
INSERT INTO "languageNames" VALUES(1812,'ta','ru','ரஷியன்');
INSERT INTO "languageNames" VALUES(1813,'ta','rup','அரோமானியன்');
INSERT INTO "languageNames" VALUES(1814,'ta','sa','சமஸ்கிருதம்');
INSERT INTO "languageNames" VALUES(1815,'ta','sah','சகா');
INSERT INTO "languageNames" VALUES(1816,'ta','sc','சார்தீனியன்');
INSERT INTO "languageNames" VALUES(1817,'ta','scn','சிசிலியன்');
INSERT INTO "languageNames" VALUES(1818,'ta','sco','ஸ்காட்ஸ்');
INSERT INTO "languageNames" VALUES(1819,'ta','sd','சிந்தி');
INSERT INTO "languageNames" VALUES(1820,'ta','se','வடக்கு சமி');
INSERT INTO "languageNames" VALUES(1821,'ta','sh','செர்போ-குரோஷியன்');
INSERT INTO "languageNames" VALUES(1822,'ta','si','சிங்களம்');
INSERT INTO "languageNames" VALUES(1823,'ta','sk','ஸ்லோவாக்');
INSERT INTO "languageNames" VALUES(1824,'ta','sl','ஸ்லோவேனியன்');
INSERT INTO "languageNames" VALUES(1825,'ta','sma','தெற்கு சமி');
INSERT INTO "languageNames" VALUES(1826,'ta','smj','லுலே சமி');
INSERT INTO "languageNames" VALUES(1827,'ta','smn','இனாரி சமி');
INSERT INTO "languageNames" VALUES(1828,'ta','sq','அல்பேனியன்');
INSERT INTO "languageNames" VALUES(1829,'ta','sr','செர்பியன்');
INSERT INTO "languageNames" VALUES(1830,'ta','srn','ஸ்ரானன் டோங்கோ');
INSERT INTO "languageNames" VALUES(1831,'ta','ss','ஸ்வாடீ');
INSERT INTO "languageNames" VALUES(1832,'ta','sv','ஸ்வீடிஷ்');
INSERT INTO "languageNames" VALUES(1833,'ta','sw','ஸ்வாஹிலி');
INSERT INTO "languageNames" VALUES(1834,'ta','ta','தமிழ்');
INSERT INTO "languageNames" VALUES(1835,'ta','te','தெலுங்கு');
INSERT INTO "languageNames" VALUES(1836,'ta','tet','டெடும்');
INSERT INTO "languageNames" VALUES(1837,'ta','tg','தஜிக்');
INSERT INTO "languageNames" VALUES(1838,'ta','th','தாய்');
INSERT INTO "languageNames" VALUES(1839,'ta','tk','துருக்மென்');
INSERT INTO "languageNames" VALUES(1840,'ta','tl','டாகாலோக்');
INSERT INTO "languageNames" VALUES(1841,'ta','tr','துருக்கிஷ்');
INSERT INTO "languageNames" VALUES(1842,'ta','tt','டாடர்');
INSERT INTO "languageNames" VALUES(1843,'ta','tyv','டுவினியன்');
INSERT INTO "languageNames" VALUES(1844,'ta','udm','உட்முர்ட்');
INSERT INTO "languageNames" VALUES(1845,'ta','ug','உய்குர்');
INSERT INTO "languageNames" VALUES(1846,'ta','uk','உக்ரைனியன்');
INSERT INTO "languageNames" VALUES(1847,'ta','ur','உருது');
INSERT INTO "languageNames" VALUES(1848,'ta','uz','உஸ்பெக்');
INSERT INTO "languageNames" VALUES(1849,'ta','vi','வியட்நாமீஸ்');
INSERT INTO "languageNames" VALUES(1850,'ta','wal','வோலாய்ட்டா');
INSERT INTO "languageNames" VALUES(1851,'ta','xh','ஹோசா');
INSERT INTO "languageNames" VALUES(1852,'ta','yi','யெட்டிஷ்');
INSERT INTO "languageNames" VALUES(1853,'ta','yo','யோருபா');
INSERT INTO "languageNames" VALUES(1854,'ta','zh','சீனம்');
INSERT INTO "languageNames" VALUES(1855,'ta','zu','ஜுலு');
INSERT INTO "languageNames" VALUES(1856,'dsb','af','afrikans');
INSERT INTO "languageNames" VALUES(1857,'dsb','an','aragonšćina');
INSERT INTO "languageNames" VALUES(1858,'dsb','ar','arabšćina');
INSERT INTO "languageNames" VALUES(1859,'dsb','as','asamšćina');
INSERT INTO "languageNames" VALUES(1860,'dsb','ast','asturšćina');
INSERT INTO "languageNames" VALUES(1861,'dsb','av','awaršćina');
INSERT INTO "languageNames" VALUES(1862,'dsb','az','azerbajdžanšćina');
INSERT INTO "languageNames" VALUES(1863,'dsb','ba','baškiršćina');
INSERT INTO "languageNames" VALUES(1864,'dsb','be','běłorušćina');
INSERT INTO "languageNames" VALUES(1865,'dsb','bg','bulgaršćina');
INSERT INTO "languageNames" VALUES(1866,'dsb','bi','bislamšćina');
INSERT INTO "languageNames" VALUES(1867,'dsb','bn','bengalšćina');
INSERT INTO "languageNames" VALUES(1868,'dsb','br','bretonšćina');
INSERT INTO "languageNames" VALUES(1869,'dsb','bs','bosnišćina');
INSERT INTO "languageNames" VALUES(1870,'dsb','ca','katanlanšćina');
INSERT INTO "languageNames" VALUES(1871,'dsb','ckb','sorani');
INSERT INTO "languageNames" VALUES(1872,'dsb','co','korsišćina');
INSERT INTO "languageNames" VALUES(1873,'dsb','cs','češćina');
INSERT INTO "languageNames" VALUES(1874,'dsb','cy','walizišćina');
INSERT INTO "languageNames" VALUES(1875,'dsb','da','danšćina');
INSERT INTO "languageNames" VALUES(1876,'dsb','de','nimšćina');
INSERT INTO "languageNames" VALUES(1877,'dsb','dsb','dolnoserbšćina');
INSERT INTO "languageNames" VALUES(1878,'dsb','el','grichišćina');
INSERT INTO "languageNames" VALUES(1879,'dsb','en','engelšćina');
INSERT INTO "languageNames" VALUES(1880,'dsb','eo','esperanto');
INSERT INTO "languageNames" VALUES(1881,'dsb','es','špańšćina');
INSERT INTO "languageNames" VALUES(1882,'dsb','et','estišćina');
INSERT INTO "languageNames" VALUES(1883,'dsb','eu','baskišćina');
INSERT INTO "languageNames" VALUES(1884,'dsb','fa','persišćina');
INSERT INTO "languageNames" VALUES(1885,'dsb','fi','finšćina');
INSERT INTO "languageNames" VALUES(1886,'dsb','fo','ferejšćina');
INSERT INTO "languageNames" VALUES(1887,'dsb','fr','francojšćina');
INSERT INTO "languageNames" VALUES(1888,'dsb','fy','frizišćina');
INSERT INTO "languageNames" VALUES(1889,'dsb','ga','iršćina');
INSERT INTO "languageNames" VALUES(1890,'dsb','gag','gagauzšćina');
INSERT INTO "languageNames" VALUES(1891,'dsb','gd','šotišćina');
INSERT INTO "languageNames" VALUES(1892,'dsb','gl','galicišćina');
INSERT INTO "languageNames" VALUES(1893,'dsb','gn','guarani');
INSERT INTO "languageNames" VALUES(1894,'dsb','gu','gudžaratšćina');
INSERT INTO "languageNames" VALUES(1895,'dsb','gv','manšćina');
INSERT INTO "languageNames" VALUES(1896,'dsb','ha','hausa');
INSERT INTO "languageNames" VALUES(1897,'dsb','haw','hawaiišćina');
INSERT INTO "languageNames" VALUES(1898,'dsb','he','hebrejšćina');
INSERT INTO "languageNames" VALUES(1899,'dsb','hi','hindišćina');
INSERT INTO "languageNames" VALUES(1900,'dsb','hr','chorwatšćina');
INSERT INTO "languageNames" VALUES(1901,'dsb','hsb','górnoserbšćina');
INSERT INTO "languageNames" VALUES(1902,'dsb','ht','haitišćina');
INSERT INTO "languageNames" VALUES(1903,'dsb','hu','hungoršćina');
INSERT INTO "languageNames" VALUES(1904,'dsb','hy','armeńšćina');
INSERT INTO "languageNames" VALUES(1905,'dsb','ia','interlingua');
INSERT INTO "languageNames" VALUES(1906,'dsb','id','indonešćina');
INSERT INTO "languageNames" VALUES(1907,'dsb','ig','igbo');
INSERT INTO "languageNames" VALUES(1908,'dsb','is','islandšćina');
INSERT INTO "languageNames" VALUES(1909,'dsb','it','italšćina');
INSERT INTO "languageNames" VALUES(1910,'dsb','ka','georgišćina');
INSERT INTO "languageNames" VALUES(1911,'dsb','kk','kazachšćina');
INSERT INTO "languageNames" VALUES(1912,'dsb','ko','korejańšćina');
INSERT INTO "languageNames" VALUES(1913,'dsb','ks','kašmiršćina');
INSERT INTO "languageNames" VALUES(1914,'dsb','ky','kirgišćina');
INSERT INTO "languageNames" VALUES(1915,'dsb','la','łatyńšćina');
INSERT INTO "languageNames" VALUES(1916,'dsb','lb','luxemburgšćina');
INSERT INTO "languageNames" VALUES(1917,'dsb','lg','gandšćina');
INSERT INTO "languageNames" VALUES(1918,'dsb','ln','lingala');
INSERT INTO "languageNames" VALUES(1919,'dsb','lo','laošćina');
INSERT INTO "languageNames" VALUES(1920,'dsb','lt','litawšćina');
INSERT INTO "languageNames" VALUES(1921,'dsb','lv','letišćina');
INSERT INTO "languageNames" VALUES(1922,'dsb','mfe','mauriciska kreolšćina');
INSERT INTO "languageNames" VALUES(1923,'dsb','mk','makedońšćina');
INSERT INTO "languageNames" VALUES(1924,'dsb','ml','malajamšćina');
INSERT INTO "languageNames" VALUES(1925,'dsb','mr','maratišćina');
INSERT INTO "languageNames" VALUES(1926,'dsb','ms','malajšćina');
INSERT INTO "languageNames" VALUES(1927,'dsb','mt','maltašćina');
INSERT INTO "languageNames" VALUES(1928,'dsb','nb','norwegske bokmål');
INSERT INTO "languageNames" VALUES(1929,'dsb','ne','nepalšćina');
INSERT INTO "languageNames" VALUES(1930,'dsb','nl','nižozemšćina');
INSERT INTO "languageNames" VALUES(1931,'dsb','nn','norwegske nynorsk');
INSERT INTO "languageNames" VALUES(1932,'dsb','no','norwegšćina');
INSERT INTO "languageNames" VALUES(1933,'dsb','oc','okcitanšćina');
INSERT INTO "languageNames" VALUES(1934,'dsb','pa','pandžabšćina');
INSERT INTO "languageNames" VALUES(1935,'dsb','pl','pólšćina');
INSERT INTO "languageNames" VALUES(1936,'dsb','pt','portugalšćina');
INSERT INTO "languageNames" VALUES(1937,'dsb','rm','retoromańšćina');
INSERT INTO "languageNames" VALUES(1938,'dsb','rn','kirundišćina');
INSERT INTO "languageNames" VALUES(1939,'dsb','ro','rumunšćina');
INSERT INTO "languageNames" VALUES(1940,'dsb','ru','rušćina');
INSERT INTO "languageNames" VALUES(1941,'dsb','sa','sanskrit');
INSERT INTO "languageNames" VALUES(1942,'dsb','sc','sardinšćina');
INSERT INTO "languageNames" VALUES(1943,'dsb','scn','sicilianišćina');
INSERT INTO "languageNames" VALUES(1944,'dsb','sd','sindšćina');
INSERT INTO "languageNames" VALUES(1945,'dsb','se','lapšćina');
INSERT INTO "languageNames" VALUES(1946,'dsb','sh','serbochorwatšćina');
INSERT INTO "languageNames" VALUES(1947,'dsb','si','singalšćina');
INSERT INTO "languageNames" VALUES(1948,'dsb','sk','słowakšćina');
INSERT INTO "languageNames" VALUES(1949,'dsb','sl','słowjeńšćina');
INSERT INTO "languageNames" VALUES(1950,'dsb','sma','pódpołdnjowa samišćina');
INSERT INTO "languageNames" VALUES(1951,'dsb','smj','lule-samišćina');
INSERT INTO "languageNames" VALUES(1952,'dsb','smn','inari-samišćina');
INSERT INTO "languageNames" VALUES(1953,'dsb','sq','albanšćina');
INSERT INTO "languageNames" VALUES(1954,'dsb','sr','serbišćina');
INSERT INTO "languageNames" VALUES(1955,'dsb','ss','siswati');
INSERT INTO "languageNames" VALUES(1956,'dsb','sv','šwedšćina');
INSERT INTO "languageNames" VALUES(1957,'dsb','sw','swahilišćina');
INSERT INTO "languageNames" VALUES(1958,'dsb','ta','tamilšćina');
INSERT INTO "languageNames" VALUES(1959,'dsb','te','telugšćina');
INSERT INTO "languageNames" VALUES(1960,'dsb','tg','tadžikišćina');
INSERT INTO "languageNames" VALUES(1961,'dsb','th','thailandšćina');
INSERT INTO "languageNames" VALUES(1962,'dsb','tk','turkmeńšćina');
INSERT INTO "languageNames" VALUES(1963,'dsb','tl','tagalog');
INSERT INTO "languageNames" VALUES(1964,'dsb','tr','turkojšćina');
INSERT INTO "languageNames" VALUES(1965,'dsb','tt','tataršćina');
INSERT INTO "languageNames" VALUES(1966,'dsb','ug','ujguršćina');
INSERT INTO "languageNames" VALUES(1967,'dsb','uk','ukrainšćina');
INSERT INTO "languageNames" VALUES(1968,'dsb','ur','urdušćina');
INSERT INTO "languageNames" VALUES(1969,'dsb','uz','usbekšćina');
INSERT INTO "languageNames" VALUES(1970,'dsb','vi','vietnamšćina');
INSERT INTO "languageNames" VALUES(1971,'dsb','xh','xhosa');
INSERT INTO "languageNames" VALUES(1972,'dsb','yi','jidišćina');
INSERT INTO "languageNames" VALUES(1973,'dsb','yo','jorubšćina');
INSERT INTO "languageNames" VALUES(1974,'dsb','zh','chinšćina');
INSERT INTO "languageNames" VALUES(1975,'dsb','zu','zulu');
INSERT INTO "languageNames" VALUES(1976,'is','af','afríkanska');
INSERT INTO "languageNames" VALUES(1977,'is','alt','suðuraltaíska');
INSERT INTO "languageNames" VALUES(1978,'is','an','aragonska');
INSERT INTO "languageNames" VALUES(1979,'is','ar','arabíska');
INSERT INTO "languageNames" VALUES(1980,'is','as','assamska');
INSERT INTO "languageNames" VALUES(1981,'is','ast','astúríska');
INSERT INTO "languageNames" VALUES(1982,'is','av','avaríska');
INSERT INTO "languageNames" VALUES(1984,'is','az','aserska');
INSERT INTO "languageNames" VALUES(1985,'is','ba','baskír');
INSERT INTO "languageNames" VALUES(1986,'is','be','hvítrússneska');
INSERT INTO "languageNames" VALUES(1987,'is','bg','búlgarska');
INSERT INTO "languageNames" VALUES(1988,'is','bi','bíslama');
INSERT INTO "languageNames" VALUES(1989,'is','bn','bengalska');
INSERT INTO "languageNames" VALUES(1990,'is','br','bretónska');
INSERT INTO "languageNames" VALUES(1991,'is','bs','bosníska');
INSERT INTO "languageNames" VALUES(1992,'is','bua','búríat');
INSERT INTO "languageNames" VALUES(1993,'is','ca','katalónska');
INSERT INTO "languageNames" VALUES(1994,'is','ceb','kebúanó');
INSERT INTO "languageNames" VALUES(1995,'is','chm','marí');
INSERT INTO "languageNames" VALUES(1996,'is','ckb','sorani-kúrdíska');
INSERT INTO "languageNames" VALUES(1997,'is','co','korsíska');
INSERT INTO "languageNames" VALUES(1998,'is','crh','krímtyrkneska');
INSERT INTO "languageNames" VALUES(1999,'is','cs','tékkneska');
INSERT INTO "languageNames" VALUES(2000,'is','csb','kasúbíska');
INSERT INTO "languageNames" VALUES(2001,'is','cu','kirkjuslavneska');
INSERT INTO "languageNames" VALUES(2002,'is','cv','sjúvas');
INSERT INTO "languageNames" VALUES(2003,'is','cy','velska');
INSERT INTO "languageNames" VALUES(2004,'is','da','danska');
INSERT INTO "languageNames" VALUES(2005,'is','dar','dargva');
INSERT INTO "languageNames" VALUES(2006,'is','de','þýska');
INSERT INTO "languageNames" VALUES(2007,'is','dsb','lágsorbneska');
INSERT INTO "languageNames" VALUES(2008,'is','el','gríska');
INSERT INTO "languageNames" VALUES(2009,'is','en','enska');
INSERT INTO "languageNames" VALUES(2010,'is','eo','esperantó');
INSERT INTO "languageNames" VALUES(2011,'is','es','spænska');
INSERT INTO "languageNames" VALUES(2012,'is','et','eistneska');
INSERT INTO "languageNames" VALUES(2013,'is','eu','baskneska');
INSERT INTO "languageNames" VALUES(2014,'is','fa','persneska');
INSERT INTO "languageNames" VALUES(2015,'is','fi','finnska');
INSERT INTO "languageNames" VALUES(2016,'is','fo','færeyska');
INSERT INTO "languageNames" VALUES(2017,'is','fr','franska');
INSERT INTO "languageNames" VALUES(2018,'is','fy','vesturfrísneska');
INSERT INTO "languageNames" VALUES(2019,'is','ga','írska');
INSERT INTO "languageNames" VALUES(2020,'is','gag','gagás');
INSERT INTO "languageNames" VALUES(2021,'is','gd','skosk gelíska');
INSERT INTO "languageNames" VALUES(2022,'is','gl','galíanska');
INSERT INTO "languageNames" VALUES(2023,'is','gn','gvaraní');
INSERT INTO "languageNames" VALUES(2024,'is','gu','gújaratí');
INSERT INTO "languageNames" VALUES(2025,'is','gv','manska');
INSERT INTO "languageNames" VALUES(2026,'is','ha','hása');
INSERT INTO "languageNames" VALUES(2027,'is','haw','havaíska');
INSERT INTO "languageNames" VALUES(2028,'is','he','hebreska');
INSERT INTO "languageNames" VALUES(2029,'is','hi','hindí');
INSERT INTO "languageNames" VALUES(2030,'is','hr','króatíska');
INSERT INTO "languageNames" VALUES(2031,'is','hsb','hásorbneska');
INSERT INTO "languageNames" VALUES(2032,'is','ht','haítíska');
INSERT INTO "languageNames" VALUES(2033,'is','hu','ungverska');
INSERT INTO "languageNames" VALUES(2034,'is','hy','armenska');
INSERT INTO "languageNames" VALUES(2035,'is','ia','alþjóðatunga');
INSERT INTO "languageNames" VALUES(2036,'is','id','indónesíska');
INSERT INTO "languageNames" VALUES(2037,'is','ig','ígbó');
INSERT INTO "languageNames" VALUES(2038,'is','is','íslenska');
INSERT INTO "languageNames" VALUES(2039,'is','it','ítalska');
INSERT INTO "languageNames" VALUES(2040,'is','ka','georgíska');
INSERT INTO "languageNames" VALUES(2041,'is','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(2042,'is','kk','kasakska');
INSERT INTO "languageNames" VALUES(2043,'is','ko','kóreska');
INSERT INTO "languageNames" VALUES(2044,'is','krc','karasaíbalkar');
INSERT INTO "languageNames" VALUES(2045,'is','krl','karélska');
INSERT INTO "languageNames" VALUES(2046,'is','ks','kasmírska');
INSERT INTO "languageNames" VALUES(2047,'is','kum','kúmík');
INSERT INTO "languageNames" VALUES(2048,'is','kv','komíska');
INSERT INTO "languageNames" VALUES(2049,'is','ky','kirgiska');
INSERT INTO "languageNames" VALUES(2050,'is','la','latína');
INSERT INTO "languageNames" VALUES(2051,'is','lb','lúxemborgíska');
INSERT INTO "languageNames" VALUES(2052,'is','lg','ganda');
INSERT INTO "languageNames" VALUES(2053,'is','ln','lingala');
INSERT INTO "languageNames" VALUES(2054,'is','lo','laó');
INSERT INTO "languageNames" VALUES(2055,'is','lt','litháíska');
INSERT INTO "languageNames" VALUES(2056,'is','lv','lettneska');
INSERT INTO "languageNames" VALUES(2057,'is','mdf','moksa');
INSERT INTO "languageNames" VALUES(2058,'is','mfe','máritíska');
INSERT INTO "languageNames" VALUES(2059,'is','mk','makedónska');
INSERT INTO "languageNames" VALUES(2060,'is','ml','malajalam');
INSERT INTO "languageNames" VALUES(2061,'is','mr','maratí');
INSERT INTO "languageNames" VALUES(2062,'is','ms','malaíska');
INSERT INTO "languageNames" VALUES(2063,'is','mt','maltneska');
INSERT INTO "languageNames" VALUES(2064,'is','myv','ersja');
INSERT INTO "languageNames" VALUES(2065,'is','nap','napólíska');
INSERT INTO "languageNames" VALUES(2066,'is','nb','norskt bókmál');
INSERT INTO "languageNames" VALUES(2067,'is','ne','nepalska');
INSERT INTO "languageNames" VALUES(2068,'is','nl','hollenska');
INSERT INTO "languageNames" VALUES(2069,'is','nn','nýnorska');
INSERT INTO "languageNames" VALUES(2070,'is','no','norska');
INSERT INTO "languageNames" VALUES(2071,'is','nog','nógaí');
INSERT INTO "languageNames" VALUES(2072,'is','oc','oksítaníska');
INSERT INTO "languageNames" VALUES(2073,'is','os','ossetíska');
INSERT INTO "languageNames" VALUES(2074,'is','ota','tyrkneska, ottóman');
INSERT INTO "languageNames" VALUES(2075,'is','pa','púnjabí');
INSERT INTO "languageNames" VALUES(2076,'is','pl','pólska');
INSERT INTO "languageNames" VALUES(2077,'is','pt','portúgalska');
INSERT INTO "languageNames" VALUES(2078,'is','rm','rómanska');
INSERT INTO "languageNames" VALUES(2079,'is','rn','rúndí');
INSERT INTO "languageNames" VALUES(2080,'is','ro','rúmenska');
INSERT INTO "languageNames" VALUES(2081,'is','ru','rússneska');
INSERT INTO "languageNames" VALUES(2082,'is','rup','arúmenska');
INSERT INTO "languageNames" VALUES(2083,'is','sa','sanskrít');
INSERT INTO "languageNames" VALUES(2084,'is','sah','jakút');
INSERT INTO "languageNames" VALUES(2085,'is','sc','sardínska');
INSERT INTO "languageNames" VALUES(2086,'is','scn','sikileyska');
INSERT INTO "languageNames" VALUES(2087,'is','sco','skoska');
INSERT INTO "languageNames" VALUES(2088,'is','sd','sindí');
INSERT INTO "languageNames" VALUES(2089,'is','se','norðursamíska');
INSERT INTO "languageNames" VALUES(2090,'is','sh','serbókróatíska');
INSERT INTO "languageNames" VALUES(2091,'is','si','singalíska');
INSERT INTO "languageNames" VALUES(2092,'is','sk','slóvakíska');
INSERT INTO "languageNames" VALUES(2093,'is','sl','slóvenska');
INSERT INTO "languageNames" VALUES(2094,'is','sma','suðursamíska');
INSERT INTO "languageNames" VALUES(2095,'is','smj','lúlesamíska');
INSERT INTO "languageNames" VALUES(2096,'is','smn','enaresamíska');
INSERT INTO "languageNames" VALUES(2097,'is','sq','albanska');
INSERT INTO "languageNames" VALUES(2098,'is','sr','serbneska');
INSERT INTO "languageNames" VALUES(2099,'is','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(2100,'is','ss','svatí');
INSERT INTO "languageNames" VALUES(2101,'is','sv','sænska');
INSERT INTO "languageNames" VALUES(2102,'is','sw','svahílí');
INSERT INTO "languageNames" VALUES(2103,'is','ta','tamílska');
INSERT INTO "languageNames" VALUES(2104,'is','te','telúgú');
INSERT INTO "languageNames" VALUES(2105,'is','tet','tetúm');
INSERT INTO "languageNames" VALUES(2106,'is','tg','tadsjikska');
INSERT INTO "languageNames" VALUES(2107,'is','th','taílenska');
INSERT INTO "languageNames" VALUES(2108,'is','tk','túrkmenska');
INSERT INTO "languageNames" VALUES(2109,'is','tl','tagalog');
INSERT INTO "languageNames" VALUES(2110,'is','tr','tyrkneska');
INSERT INTO "languageNames" VALUES(2111,'is','tt','tatarska');
INSERT INTO "languageNames" VALUES(2112,'is','tyv','túvínska');
INSERT INTO "languageNames" VALUES(2113,'is','udm','údmúrt');
INSERT INTO "languageNames" VALUES(2114,'is','ug','úígúr');
INSERT INTO "languageNames" VALUES(2115,'is','uk','úkraínska');
INSERT INTO "languageNames" VALUES(2116,'is','ur','úrdú');
INSERT INTO "languageNames" VALUES(2117,'is','uz','úsbekska');
INSERT INTO "languageNames" VALUES(2118,'is','vi','víetnamska');
INSERT INTO "languageNames" VALUES(2119,'is','wal','volayatta');
INSERT INTO "languageNames" VALUES(2120,'is','xh','sósa');
INSERT INTO "languageNames" VALUES(2121,'is','yi','jiddíska');
INSERT INTO "languageNames" VALUES(2122,'is','yo','jórúba');
INSERT INTO "languageNames" VALUES(2123,'is','zh','kínverska');
INSERT INTO "languageNames" VALUES(2124,'is','zu','súlú');
INSERT INTO "languageNames" VALUES(2125,'sw','af','Kiafrikana');
INSERT INTO "languageNames" VALUES(2126,'sw','alt','Kialtai');
INSERT INTO "languageNames" VALUES(2127,'sw','an','Kiaragoni');
INSERT INTO "languageNames" VALUES(2128,'sw','ar','Kiarabu');
INSERT INTO "languageNames" VALUES(2129,'sw','as','Kiassam');
INSERT INTO "languageNames" VALUES(2130,'sw','ast','Kiasturia');
INSERT INTO "languageNames" VALUES(2131,'sw','av','Kiavari');
INSERT INTO "languageNames" VALUES(2133,'sw','az','Kiazeri');
INSERT INTO "languageNames" VALUES(2134,'sw','ba','Kibashkir');
INSERT INTO "languageNames" VALUES(2135,'sw','be','Kibelarusi');
INSERT INTO "languageNames" VALUES(2136,'sw','bg','Kibulgaria');
INSERT INTO "languageNames" VALUES(2137,'sw','bi','Kibislama');
INSERT INTO "languageNames" VALUES(2138,'sw','bn','Kibengali');
INSERT INTO "languageNames" VALUES(2139,'sw','br','Kibretoni');
INSERT INTO "languageNames" VALUES(2140,'sw','bs','Kibosnia');
INSERT INTO "languageNames" VALUES(2141,'sw','byv','Kimedumba');
INSERT INTO "languageNames" VALUES(2142,'sw','ca','Kikatalani');
INSERT INTO "languageNames" VALUES(2143,'sw','ceb','Kichebuano');
INSERT INTO "languageNames" VALUES(2144,'sw','chm','Kimari');
INSERT INTO "languageNames" VALUES(2145,'sw','ckb','Kikurdi cha Sorani');
INSERT INTO "languageNames" VALUES(2146,'sw','co','Kikosikani');
INSERT INTO "languageNames" VALUES(2147,'sw','cs','Kicheki');
INSERT INTO "languageNames" VALUES(2148,'sw','cu','Kislovakia cha Church');
INSERT INTO "languageNames" VALUES(2149,'sw','cv','Kichuvash');
INSERT INTO "languageNames" VALUES(2150,'sw','cy','Kiwelisi');
INSERT INTO "languageNames" VALUES(2151,'sw','da','Kidenmaki');
INSERT INTO "languageNames" VALUES(2152,'sw','dar','Kidaragwa');
INSERT INTO "languageNames" VALUES(2153,'sw','de','Kijerumani');
INSERT INTO "languageNames" VALUES(2154,'sw','dsb','Kidolnoserbski');
INSERT INTO "languageNames" VALUES(2155,'sw','el','Kigiriki');
INSERT INTO "languageNames" VALUES(2156,'sw','en','Kiingereza');
INSERT INTO "languageNames" VALUES(2157,'sw','eo','Kiesperanto');
INSERT INTO "languageNames" VALUES(2158,'sw','es','Kihispania');
INSERT INTO "languageNames" VALUES(2159,'sw','et','Kiestonia');
INSERT INTO "languageNames" VALUES(2160,'sw','eu','Kibasque');
INSERT INTO "languageNames" VALUES(2161,'sw','fa','Kiajemi');
INSERT INTO "languageNames" VALUES(2162,'sw','fi','Kifini');
INSERT INTO "languageNames" VALUES(2163,'sw','fo','Kifaroe');
INSERT INTO "languageNames" VALUES(2164,'sw','fr','Kifaransa');
INSERT INTO "languageNames" VALUES(2165,'sw','fy','Kifrisia cha Magharibi');
INSERT INTO "languageNames" VALUES(2166,'sw','ga','Kiayalandi');
INSERT INTO "languageNames" VALUES(2167,'sw','gag','Kigagauz');
INSERT INTO "languageNames" VALUES(2168,'sw','gd','Kigaeli cha Uskoti');
INSERT INTO "languageNames" VALUES(2169,'sw','gl','Kigalisi');
INSERT INTO "languageNames" VALUES(2170,'sw','gn','Kiguarani');
INSERT INTO "languageNames" VALUES(2171,'sw','gu','Kigujarati');
INSERT INTO "languageNames" VALUES(2172,'sw','gv','Kimanx');
INSERT INTO "languageNames" VALUES(2173,'sw','ha','Kihausa');
INSERT INTO "languageNames" VALUES(2174,'sw','haw','Kihawai');
INSERT INTO "languageNames" VALUES(2175,'sw','he','Kiebrania');
INSERT INTO "languageNames" VALUES(2176,'sw','hi','Kihindi');
INSERT INTO "languageNames" VALUES(2177,'sw','hr','Kikroeshia');
INSERT INTO "languageNames" VALUES(2178,'sw','hsb','Kisobia cha Ukanda wa Juu');
INSERT INTO "languageNames" VALUES(2179,'sw','ht','Kihaiti');
INSERT INTO "languageNames" VALUES(2180,'sw','hu','Kihangari');
INSERT INTO "languageNames" VALUES(2181,'sw','hy','Kiarmenia');
INSERT INTO "languageNames" VALUES(2182,'sw','ia','Kiintalingua');
INSERT INTO "languageNames" VALUES(2183,'sw','id','Kiindonesia');
INSERT INTO "languageNames" VALUES(2184,'sw','ig','Kiigbo');
INSERT INTO "languageNames" VALUES(2185,'sw','is','Kiaisilandi');
INSERT INTO "languageNames" VALUES(2186,'sw','it','Kiitaliano');
INSERT INTO "languageNames" VALUES(2187,'sw','ka','Kijojia');
INSERT INTO "languageNames" VALUES(2188,'sw','kk','Kikazakh');
INSERT INTO "languageNames" VALUES(2189,'sw','ko','Kikorea');
INSERT INTO "languageNames" VALUES(2190,'sw','krc','Kikarachay-Balkar');
INSERT INTO "languageNames" VALUES(2191,'sw','krl','Karjala');
INSERT INTO "languageNames" VALUES(2192,'sw','ks','Kikashmiri');
INSERT INTO "languageNames" VALUES(2193,'sw','kum','Kumyk');
INSERT INTO "languageNames" VALUES(2194,'sw','kv','Kikomi');
INSERT INTO "languageNames" VALUES(2195,'sw','ky','Kikyrgyz');
INSERT INTO "languageNames" VALUES(2196,'sw','la','Kilatini');
INSERT INTO "languageNames" VALUES(2197,'sw','lb','Kilasembagi');
INSERT INTO "languageNames" VALUES(2198,'sw','lg','Kiganda');
INSERT INTO "languageNames" VALUES(2199,'sw','ln','Kilingala');
INSERT INTO "languageNames" VALUES(2200,'sw','lo','Kilaosi');
INSERT INTO "languageNames" VALUES(2201,'sw','lt','Kilithuania');
INSERT INTO "languageNames" VALUES(2202,'sw','lv','Kilatvia');
INSERT INTO "languageNames" VALUES(2203,'sw','mdf','Lugha ya Moksha');
INSERT INTO "languageNames" VALUES(2204,'sw','mfe','Kimoriseni');
INSERT INTO "languageNames" VALUES(2205,'sw','mk','Kimacedonia');
INSERT INTO "languageNames" VALUES(2206,'sw','ml','Kimalayalam');
INSERT INTO "languageNames" VALUES(2207,'sw','mr','Kimarathi');
INSERT INTO "languageNames" VALUES(2208,'sw','ms','Kimalei');
INSERT INTO "languageNames" VALUES(2209,'sw','mt','Kimalta');
INSERT INTO "languageNames" VALUES(2210,'sw','myv','Kierzya');
INSERT INTO "languageNames" VALUES(2211,'sw','nap','Kinapoli');
INSERT INTO "languageNames" VALUES(2212,'sw','nb','Kinorwe cha Bokmal');
INSERT INTO "languageNames" VALUES(2213,'sw','ne','Kinepali');
INSERT INTO "languageNames" VALUES(2214,'sw','nl','Kiholanzi');
INSERT INTO "languageNames" VALUES(2215,'sw','nn','Kinorwe cha Nynorsk');
INSERT INTO "languageNames" VALUES(2216,'sw','no','Kinorwe');
INSERT INTO "languageNames" VALUES(2217,'sw','nog','Kinogai');
INSERT INTO "languageNames" VALUES(2218,'sw','oc','Kiokitani');
INSERT INTO "languageNames" VALUES(2219,'sw','os','Kiosetia');
INSERT INTO "languageNames" VALUES(2220,'sw','pa','Kipunjabi');
INSERT INTO "languageNames" VALUES(2221,'sw','pl','Kipolandi');
INSERT INTO "languageNames" VALUES(2222,'sw','pt','Kireno');
INSERT INTO "languageNames" VALUES(2223,'sw','rm','Kiromanshi');
INSERT INTO "languageNames" VALUES(2224,'sw','rn','Kirundi');
INSERT INTO "languageNames" VALUES(2225,'sw','ro','Kiromania');
INSERT INTO "languageNames" VALUES(2226,'sw','ru','Kirusi');
INSERT INTO "languageNames" VALUES(2227,'sw','rup','Kiaromania');
INSERT INTO "languageNames" VALUES(2228,'sw','sa','Kisanskriti');
INSERT INTO "languageNames" VALUES(2229,'sw','sah','Kisakha');
INSERT INTO "languageNames" VALUES(2230,'sw','sc','Kisardinia');
INSERT INTO "languageNames" VALUES(2231,'sw','scn','Kisicilia');
INSERT INTO "languageNames" VALUES(2232,'sw','sco','Kiskoti');
INSERT INTO "languageNames" VALUES(2233,'sw','sd','Kisindhi');
INSERT INTO "languageNames" VALUES(2234,'sw','se','Kisami cha Kaskazini');
INSERT INTO "languageNames" VALUES(2235,'sw','sh','Kiserbia-kroeshia');
INSERT INTO "languageNames" VALUES(2236,'sw','si','Kisinhala');
INSERT INTO "languageNames" VALUES(2237,'sw','sk','Kislovakia');
INSERT INTO "languageNames" VALUES(2238,'sw','sl','Kislovenia');
INSERT INTO "languageNames" VALUES(2239,'sw','sma','Kisami cha Kusini');
INSERT INTO "languageNames" VALUES(2240,'sw','smj','Kisami cha Lule');
INSERT INTO "languageNames" VALUES(2241,'sw','smn','Kisami cha Inari');
INSERT INTO "languageNames" VALUES(2242,'sw','sq','Kialbania');
INSERT INTO "languageNames" VALUES(2243,'sw','sr','Kiserbia');
INSERT INTO "languageNames" VALUES(2244,'sw','srn','Lugha ya Sranan Tongo');
INSERT INTO "languageNames" VALUES(2245,'sw','ss','Kiswati');
INSERT INTO "languageNames" VALUES(2246,'sw','sv','Kiswidi');
INSERT INTO "languageNames" VALUES(2247,'sw','sw','Kiswahili');
INSERT INTO "languageNames" VALUES(2248,'sw','ta','Kitamil');
INSERT INTO "languageNames" VALUES(2249,'sw','te','Kitelugu');
INSERT INTO "languageNames" VALUES(2250,'sw','tet','Kitetum');
INSERT INTO "languageNames" VALUES(2251,'sw','tg','Kitajiki');
INSERT INTO "languageNames" VALUES(2252,'sw','th','Kitailandi');
INSERT INTO "languageNames" VALUES(2253,'sw','tk','Kiturukimeni');
INSERT INTO "languageNames" VALUES(2254,'sw','tr','Kituruki');
INSERT INTO "languageNames" VALUES(2255,'sw','tt','Kitatari');
INSERT INTO "languageNames" VALUES(2256,'sw','tyv','Kituva');
INSERT INTO "languageNames" VALUES(2257,'sw','udm','Udmurt');
INSERT INTO "languageNames" VALUES(2258,'sw','ug','Kiuyghur');
INSERT INTO "languageNames" VALUES(2259,'sw','uk','Kiukraine');
INSERT INTO "languageNames" VALUES(2260,'sw','ur','Kiurdu');
INSERT INTO "languageNames" VALUES(2261,'sw','uz','Kiuzbeki');
INSERT INTO "languageNames" VALUES(2262,'sw','vi','Kivietinamu');
INSERT INTO "languageNames" VALUES(2263,'sw','wal','Kiwolaytta');
INSERT INTO "languageNames" VALUES(2264,'sw','xh','Kixhosa');
INSERT INTO "languageNames" VALUES(2265,'sw','yi','Kiyiddi');
INSERT INTO "languageNames" VALUES(2266,'sw','yo','Kiyoruba');
INSERT INTO "languageNames" VALUES(2267,'sw','zh','Kichina');
INSERT INTO "languageNames" VALUES(2268,'sw','zu','Kizulu');
INSERT INTO "languageNames" VALUES(2269,'hy','af','աֆրիկաանս');
INSERT INTO "languageNames" VALUES(2270,'hy','alt','հարավային ալթայերեն');
INSERT INTO "languageNames" VALUES(2271,'hy','an','արագոներեն');
INSERT INTO "languageNames" VALUES(2272,'hy','ar','արաբերեն');
INSERT INTO "languageNames" VALUES(2273,'hy','as','ասամերեն');
INSERT INTO "languageNames" VALUES(2274,'hy','ast','աստուրերեն');
INSERT INTO "languageNames" VALUES(2275,'hy','av','ավարերեն');
INSERT INTO "languageNames" VALUES(2277,'hy','az','ադրբեջաներեն');
INSERT INTO "languageNames" VALUES(2278,'hy','ba','բաշկիրերեն');
INSERT INTO "languageNames" VALUES(2279,'hy','be','բելառուսերեն');
INSERT INTO "languageNames" VALUES(2280,'hy','bg','բուլղարերեն');
INSERT INTO "languageNames" VALUES(2281,'hy','bi','բիսլամա');
INSERT INTO "languageNames" VALUES(2282,'hy','bn','բենգալերեն');
INSERT INTO "languageNames" VALUES(2283,'hy','br','բրետոներեն');
INSERT INTO "languageNames" VALUES(2284,'hy','bs','բոսնիերեն');
INSERT INTO "languageNames" VALUES(2285,'hy','ca','կատալաներեն');
INSERT INTO "languageNames" VALUES(2286,'hy','ceb','սեբուերեն');
INSERT INTO "languageNames" VALUES(2287,'hy','chm','մարի');
INSERT INTO "languageNames" VALUES(2288,'hy','ckb','սորանի քրդերեն');
INSERT INTO "languageNames" VALUES(2289,'hy','co','կորսիկերեն');
INSERT INTO "languageNames" VALUES(2290,'hy','crh','ղրիմյան թուրքերեն');
INSERT INTO "languageNames" VALUES(2291,'hy','cs','չեխերեն');
INSERT INTO "languageNames" VALUES(2292,'hy','cu','եկեղեցական սլավոներեն');
INSERT INTO "languageNames" VALUES(2293,'hy','cv','չուվաշերեն');
INSERT INTO "languageNames" VALUES(2294,'hy','cy','ուելսերեն');
INSERT INTO "languageNames" VALUES(2295,'hy','da','դանիերեն');
INSERT INTO "languageNames" VALUES(2296,'hy','dar','դարգիներեն');
INSERT INTO "languageNames" VALUES(2297,'hy','de','գերմաներեն');
INSERT INTO "languageNames" VALUES(2298,'hy','dsb','ստորին սորբերեն');
INSERT INTO "languageNames" VALUES(2299,'hy','el','հունարեն');
INSERT INTO "languageNames" VALUES(2300,'hy','en','անգլերեն');
INSERT INTO "languageNames" VALUES(2301,'hy','eo','էսպերանտո');
INSERT INTO "languageNames" VALUES(2302,'hy','es','իսպաներեն');
INSERT INTO "languageNames" VALUES(2303,'hy','et','էստոներեն');
INSERT INTO "languageNames" VALUES(2304,'hy','eu','բասկերեն');
INSERT INTO "languageNames" VALUES(2305,'hy','fa','պարսկերեն');
INSERT INTO "languageNames" VALUES(2306,'hy','fi','ֆիններեն');
INSERT INTO "languageNames" VALUES(2307,'hy','fo','ֆարյորերեն');
INSERT INTO "languageNames" VALUES(2308,'hy','fr','ֆրանսերեն');
INSERT INTO "languageNames" VALUES(2309,'hy','fy','արևմտաֆրիզերեն');
INSERT INTO "languageNames" VALUES(2310,'hy','ga','իռլանդերեն');
INSERT INTO "languageNames" VALUES(2311,'hy','gag','գագաուզերեն');
INSERT INTO "languageNames" VALUES(2312,'hy','gd','շոտլանդական գաելերեն');
INSERT INTO "languageNames" VALUES(2313,'hy','gl','գալիսերեն');
INSERT INTO "languageNames" VALUES(2314,'hy','gn','գուարանի');
INSERT INTO "languageNames" VALUES(2315,'hy','gu','գուջարաթի');
INSERT INTO "languageNames" VALUES(2316,'hy','guc','վայուու');
INSERT INTO "languageNames" VALUES(2317,'hy','gv','մեներեն');
INSERT INTO "languageNames" VALUES(2318,'hy','ha','հաուսա');
INSERT INTO "languageNames" VALUES(2319,'hy','haw','հավայիերեն');
INSERT INTO "languageNames" VALUES(2320,'hy','he','եբրայերեն');
INSERT INTO "languageNames" VALUES(2321,'hy','hi','հինդի');
INSERT INTO "languageNames" VALUES(2322,'hy','hr','խորվաթերեն');
INSERT INTO "languageNames" VALUES(2323,'hy','hsb','վերին սորբերեն');
INSERT INTO "languageNames" VALUES(2324,'hy','ht','խառնակերտ հայիթերեն');
INSERT INTO "languageNames" VALUES(2325,'hy','hu','հունգարերեն');
INSERT INTO "languageNames" VALUES(2326,'hy','hy','հայերեն');
INSERT INTO "languageNames" VALUES(2327,'hy','ia','ինտերլինգուա');
INSERT INTO "languageNames" VALUES(2328,'hy','id','ինդոնեզերեն');
INSERT INTO "languageNames" VALUES(2329,'hy','ig','իգբո');
INSERT INTO "languageNames" VALUES(2330,'hy','is','իսլանդերեն');
INSERT INTO "languageNames" VALUES(2331,'hy','it','իտալերեն');
INSERT INTO "languageNames" VALUES(2332,'hy','ka','վրացերեն');
INSERT INTO "languageNames" VALUES(2333,'hy','kk','ղազախերեն');
INSERT INTO "languageNames" VALUES(2334,'hy','ko','կորեերեն');
INSERT INTO "languageNames" VALUES(2335,'hy','krc','կարաչայ-բալկարերեն');
INSERT INTO "languageNames" VALUES(2336,'hy','krl','կարելերեն');
INSERT INTO "languageNames" VALUES(2337,'hy','ks','քաշմիրերեն');
INSERT INTO "languageNames" VALUES(2338,'hy','kum','կումիկերեն');
INSERT INTO "languageNames" VALUES(2339,'hy','kv','կոմիերեն');
INSERT INTO "languageNames" VALUES(2340,'hy','ky','ղրղզերեն');
INSERT INTO "languageNames" VALUES(2341,'hy','la','լատիներեն');
INSERT INTO "languageNames" VALUES(2342,'hy','lb','լյուքսեմբուրգերեն');
INSERT INTO "languageNames" VALUES(2343,'hy','lg','գանդա');
INSERT INTO "languageNames" VALUES(2344,'hy','ln','լինգալա');
INSERT INTO "languageNames" VALUES(2345,'hy','lo','լաոսերեն');
INSERT INTO "languageNames" VALUES(2346,'hy','lt','լիտվերեն');
INSERT INTO "languageNames" VALUES(2347,'hy','lv','լատվիերեն');
INSERT INTO "languageNames" VALUES(2348,'hy','mdf','մոկշայերեն');
INSERT INTO "languageNames" VALUES(2349,'hy','mfe','մորիսյեն');
INSERT INTO "languageNames" VALUES(2350,'hy','mk','մակեդոներեն');
INSERT INTO "languageNames" VALUES(2351,'hy','ml','մալայալամ');
INSERT INTO "languageNames" VALUES(2352,'hy','mr','մարաթի');
INSERT INTO "languageNames" VALUES(2353,'hy','mrj','արևմտամարիերեն');
INSERT INTO "languageNames" VALUES(2354,'hy','ms','մալայերեն');
INSERT INTO "languageNames" VALUES(2355,'hy','mt','մալթայերեն');
INSERT INTO "languageNames" VALUES(2356,'hy','myv','էրզյա');
INSERT INTO "languageNames" VALUES(2357,'hy','nap','նեապոլերեն');
INSERT INTO "languageNames" VALUES(2358,'hy','nb','գրքային նորվեգերեն');
INSERT INTO "languageNames" VALUES(2359,'hy','ne','նեպալերեն');
INSERT INTO "languageNames" VALUES(2360,'hy','nl','հոլանդերեն');
INSERT INTO "languageNames" VALUES(2361,'hy','nn','նոր նորվեգերեն');
INSERT INTO "languageNames" VALUES(2362,'hy','no','նորվեգերեն');
INSERT INTO "languageNames" VALUES(2363,'hy','nog','նոգայերեն');
INSERT INTO "languageNames" VALUES(2364,'hy','oc','օքսիտաներեն');
INSERT INTO "languageNames" VALUES(2365,'hy','os','օսերեն');
INSERT INTO "languageNames" VALUES(2366,'hy','ota','օսմաներեն');
INSERT INTO "languageNames" VALUES(2367,'hy','pa','փենջաբերեն');
INSERT INTO "languageNames" VALUES(2368,'hy','pl','լեհերեն');
INSERT INTO "languageNames" VALUES(2369,'hy','pt','պորտուգալերեն');
INSERT INTO "languageNames" VALUES(2370,'hy','rm','ռոմանշերեն');
INSERT INTO "languageNames" VALUES(2371,'hy','rn','ռունդի');
INSERT INTO "languageNames" VALUES(2372,'hy','ro','ռումիներեն');
INSERT INTO "languageNames" VALUES(2373,'hy','ru','ռուսերեն');
INSERT INTO "languageNames" VALUES(2374,'hy','rup','արոմաներեն');
INSERT INTO "languageNames" VALUES(2375,'hy','sa','սանսկրիտ');
INSERT INTO "languageNames" VALUES(2376,'hy','sah','յակուտերեն');
INSERT INTO "languageNames" VALUES(2377,'hy','sc','սարդիներեն');
INSERT INTO "languageNames" VALUES(2378,'hy','scn','սիցիլիերեն');
INSERT INTO "languageNames" VALUES(2379,'hy','sco','շոտլանդերեն');
INSERT INTO "languageNames" VALUES(2380,'hy','sd','սինդհի');
INSERT INTO "languageNames" VALUES(2381,'hy','se','հյուսիսային սաամի');
INSERT INTO "languageNames" VALUES(2382,'hy','sh','սերբա-խորվաթերեն');
INSERT INTO "languageNames" VALUES(2383,'hy','si','սինհալերեն');
INSERT INTO "languageNames" VALUES(2384,'hy','sk','սլովակերեն');
INSERT INTO "languageNames" VALUES(2385,'hy','sl','սլովեներեն');
INSERT INTO "languageNames" VALUES(2386,'hy','sma','հարավային սաամի');
INSERT INTO "languageNames" VALUES(2387,'hy','smj','լուլե սաամի');
INSERT INTO "languageNames" VALUES(2388,'hy','smn','ինարի սաամի');
INSERT INTO "languageNames" VALUES(2389,'hy','sq','ալբաներեն');
INSERT INTO "languageNames" VALUES(2390,'hy','sr','սերբերեն');
INSERT INTO "languageNames" VALUES(2391,'hy','srn','սրանան տոնգո');
INSERT INTO "languageNames" VALUES(2392,'hy','ss','սվազերեն');
INSERT INTO "languageNames" VALUES(2393,'hy','sv','շվեդերեն');
INSERT INTO "languageNames" VALUES(2394,'hy','sw','սուահիլի');
INSERT INTO "languageNames" VALUES(2395,'hy','ta','թամիլերեն');
INSERT INTO "languageNames" VALUES(2396,'hy','te','թելուգու');
INSERT INTO "languageNames" VALUES(2397,'hy','tet','տետում');
INSERT INTO "languageNames" VALUES(2398,'hy','tg','տաջիկերեն');
INSERT INTO "languageNames" VALUES(2399,'hy','th','թայերեն');
INSERT INTO "languageNames" VALUES(2400,'hy','tk','թուրքմեներեն');
INSERT INTO "languageNames" VALUES(2401,'hy','tl','տագալերեն');
INSERT INTO "languageNames" VALUES(2402,'hy','tr','թուրքերեն');
INSERT INTO "languageNames" VALUES(2403,'hy','tt','թաթարերեն');
INSERT INTO "languageNames" VALUES(2404,'hy','tyv','տուվերեն');
INSERT INTO "languageNames" VALUES(2405,'hy','udm','ուդմուրտերեն');
INSERT INTO "languageNames" VALUES(2406,'hy','ug','ույղուրերեն');
INSERT INTO "languageNames" VALUES(2407,'hy','uk','ուկրաիներեն');
INSERT INTO "languageNames" VALUES(2408,'hy','ur','ուրդու');
INSERT INTO "languageNames" VALUES(2409,'hy','uz','ուզբեկերեն');
INSERT INTO "languageNames" VALUES(2410,'hy','vi','վիետնամերեն');
INSERT INTO "languageNames" VALUES(2411,'hy','vro','վորո');
INSERT INTO "languageNames" VALUES(2412,'hy','wal','վոլայտա');
INSERT INTO "languageNames" VALUES(2413,'hy','xh','քոսա');
INSERT INTO "languageNames" VALUES(2414,'hy','yi','իդիշ');
INSERT INTO "languageNames" VALUES(2415,'hy','yo','յորուբա');
INSERT INTO "languageNames" VALUES(2416,'hy','zh','չինարեն');
INSERT INTO "languageNames" VALUES(2417,'hy','zu','զուլուերեն');
INSERT INTO "languageNames" VALUES(2418,'ast','af','afrikaans');
INSERT INTO "languageNames" VALUES(2419,'ast','alt','altai del sur');
INSERT INTO "languageNames" VALUES(2420,'ast','an','aragonés');
INSERT INTO "languageNames" VALUES(2421,'ast','ar','árabe');
INSERT INTO "languageNames" VALUES(2422,'ast','as','asamés');
INSERT INTO "languageNames" VALUES(2423,'ast','ast','asturianu');
INSERT INTO "languageNames" VALUES(2424,'ast','av','aváricu');
INSERT INTO "languageNames" VALUES(2426,'ast','az','azerí');
INSERT INTO "languageNames" VALUES(2427,'ast','ba','bashkir');
INSERT INTO "languageNames" VALUES(2428,'ast','be','bielorrusu');
INSERT INTO "languageNames" VALUES(2429,'ast','bg','búlgaru');
INSERT INTO "languageNames" VALUES(2430,'ast','bi','bislama');
INSERT INTO "languageNames" VALUES(2431,'ast','bn','bengalín');
INSERT INTO "languageNames" VALUES(2432,'ast','br','bretón');
INSERT INTO "languageNames" VALUES(2433,'ast','bs','bosniu');
INSERT INTO "languageNames" VALUES(2434,'ast','bua','buriat');
INSERT INTO "languageNames" VALUES(2435,'ast','byv','medumba');
INSERT INTO "languageNames" VALUES(2436,'ast','ca','catalán');
INSERT INTO "languageNames" VALUES(2437,'ast','ceb','cebuanu');
INSERT INTO "languageNames" VALUES(2438,'ast','chm','mari');
INSERT INTO "languageNames" VALUES(2439,'ast','ckb','kurdu central');
INSERT INTO "languageNames" VALUES(2440,'ast','co','corsu');
INSERT INTO "languageNames" VALUES(2441,'ast','crh','turcu de Crimea');
INSERT INTO "languageNames" VALUES(2442,'ast','cs','checu');
INSERT INTO "languageNames" VALUES(2443,'ast','csb','kashubianu');
INSERT INTO "languageNames" VALUES(2444,'ast','cu','eslávicu eclesiásticu');
INSERT INTO "languageNames" VALUES(2445,'ast','cv','chuvash');
INSERT INTO "languageNames" VALUES(2446,'ast','cy','galés');
INSERT INTO "languageNames" VALUES(2447,'ast','da','danés');
INSERT INTO "languageNames" VALUES(2448,'ast','dar','dargwa');
INSERT INTO "languageNames" VALUES(2449,'ast','de','alemán');
INSERT INTO "languageNames" VALUES(2450,'ast','dsb','baxu sorbiu');
INSERT INTO "languageNames" VALUES(2451,'ast','el','griegu');
INSERT INTO "languageNames" VALUES(2452,'ast','en','inglés');
INSERT INTO "languageNames" VALUES(2453,'ast','eo','esperanto');
INSERT INTO "languageNames" VALUES(2454,'ast','es','español');
INSERT INTO "languageNames" VALUES(2455,'ast','et','estoniu');
INSERT INTO "languageNames" VALUES(2456,'ast','eu','vascu');
INSERT INTO "languageNames" VALUES(2457,'ast','fa','persa');
INSERT INTO "languageNames" VALUES(2458,'ast','fi','finlandés');
INSERT INTO "languageNames" VALUES(2459,'ast','fo','feroés');
INSERT INTO "languageNames" VALUES(2460,'ast','fr','francés');
INSERT INTO "languageNames" VALUES(2461,'ast','fy','frisón occidental');
INSERT INTO "languageNames" VALUES(2462,'ast','ga','irlandés');
INSERT INTO "languageNames" VALUES(2463,'ast','gag','gagauz');
INSERT INTO "languageNames" VALUES(2464,'ast','gd','gaélicu escocés');
INSERT INTO "languageNames" VALUES(2465,'ast','gl','gallegu');
INSERT INTO "languageNames" VALUES(2466,'ast','glk','gilaki');
INSERT INTO "languageNames" VALUES(2467,'ast','gn','guaraní');
INSERT INTO "languageNames" VALUES(2468,'ast','gu','guyaratí');
INSERT INTO "languageNames" VALUES(2469,'ast','guc','wayuu');
INSERT INTO "languageNames" VALUES(2470,'ast','gv','manés');
INSERT INTO "languageNames" VALUES(2471,'ast','ha','ḥausa');
INSERT INTO "languageNames" VALUES(2472,'ast','haw','hawaianu');
INSERT INTO "languageNames" VALUES(2473,'ast','he','hebréu');
INSERT INTO "languageNames" VALUES(2474,'ast','hi','hindi');
INSERT INTO "languageNames" VALUES(2475,'ast','hr','croata');
INSERT INTO "languageNames" VALUES(2476,'ast','hsb','altu sorbiu');
INSERT INTO "languageNames" VALUES(2477,'ast','ht','haitianu');
INSERT INTO "languageNames" VALUES(2478,'ast','hu','húngaru');
INSERT INTO "languageNames" VALUES(2479,'ast','hy','armeniu');
INSERT INTO "languageNames" VALUES(2480,'ast','ia','interlingua');
INSERT INTO "languageNames" VALUES(2481,'ast','id','indonesiu');
INSERT INTO "languageNames" VALUES(2482,'ast','ig','igbo');
INSERT INTO "languageNames" VALUES(2483,'ast','is','islandés');
INSERT INTO "languageNames" VALUES(2484,'ast','it','italianu');
INSERT INTO "languageNames" VALUES(2485,'ast','ka','xeorxanu');
INSERT INTO "languageNames" VALUES(2486,'ast','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(2487,'ast','kk','kazaquistanín');
INSERT INTO "languageNames" VALUES(2488,'ast','ko','coreanu');
INSERT INTO "languageNames" VALUES(2489,'ast','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(2490,'ast','krl','karelianu');
INSERT INTO "languageNames" VALUES(2491,'ast','ks','cachemirés');
INSERT INTO "languageNames" VALUES(2492,'ast','kum','kumyk');
INSERT INTO "languageNames" VALUES(2493,'ast','kv','komi');
INSERT INTO "languageNames" VALUES(2494,'ast','ky','kirguistanín');
INSERT INTO "languageNames" VALUES(2495,'ast','la','llatín');
INSERT INTO "languageNames" VALUES(2496,'ast','lb','luxemburgués');
INSERT INTO "languageNames" VALUES(2497,'ast','lg','ganda');
INSERT INTO "languageNames" VALUES(2498,'ast','liv','livonianu');
INSERT INTO "languageNames" VALUES(2499,'ast','ln','lingala');
INSERT INTO "languageNames" VALUES(2500,'ast','lo','laosianu');
INSERT INTO "languageNames" VALUES(2501,'ast','lt','lituanu');
INSERT INTO "languageNames" VALUES(2502,'ast','lv','letón');
INSERT INTO "languageNames" VALUES(2503,'ast','mdf','moksha');
INSERT INTO "languageNames" VALUES(2504,'ast','mfe','morisyen');
INSERT INTO "languageNames" VALUES(2505,'ast','mk','macedoniu');
INSERT INTO "languageNames" VALUES(2506,'ast','ml','malayalam');
INSERT INTO "languageNames" VALUES(2507,'ast','mr','marathi');
INSERT INTO "languageNames" VALUES(2508,'ast','mrj','mari occidental');
INSERT INTO "languageNames" VALUES(2509,'ast','ms','malayu');
INSERT INTO "languageNames" VALUES(2510,'ast','mt','maltés');
INSERT INTO "languageNames" VALUES(2511,'ast','myv','erzya');
INSERT INTO "languageNames" VALUES(2512,'ast','nap','napolitanu');
INSERT INTO "languageNames" VALUES(2513,'ast','nb','noruegu Bokmål');
INSERT INTO "languageNames" VALUES(2514,'ast','ne','nepalés');
INSERT INTO "languageNames" VALUES(2515,'ast','nl','neerlandés');
INSERT INTO "languageNames" VALUES(2516,'ast','nn','noruegu Nynorsk');
INSERT INTO "languageNames" VALUES(2517,'ast','no','noruegu');
INSERT INTO "languageNames" VALUES(2518,'ast','nog','nogai');
INSERT INTO "languageNames" VALUES(2519,'ast','oc','occitanu');
INSERT INTO "languageNames" VALUES(2520,'ast','os','oséticu');
INSERT INTO "languageNames" VALUES(2521,'ast','ota','turcu otomanu');
INSERT INTO "languageNames" VALUES(2522,'ast','pa','punyabí');
INSERT INTO "languageNames" VALUES(2523,'ast','pl','polacu');
INSERT INTO "languageNames" VALUES(2524,'ast','pt','portugués');
INSERT INTO "languageNames" VALUES(2525,'ast','rm','romanche');
INSERT INTO "languageNames" VALUES(2526,'ast','rn','rundi');
INSERT INTO "languageNames" VALUES(2527,'ast','ro','rumanu');
INSERT INTO "languageNames" VALUES(2528,'ast','ru','rusu');
INSERT INTO "languageNames" VALUES(2529,'ast','rup','aromanianu');
INSERT INTO "languageNames" VALUES(2530,'ast','sa','sánscritu');
INSERT INTO "languageNames" VALUES(2531,'ast','sah','sakha');
INSERT INTO "languageNames" VALUES(2532,'ast','sc','sardu');
INSERT INTO "languageNames" VALUES(2533,'ast','scn','sicilianu');
INSERT INTO "languageNames" VALUES(2534,'ast','sco','scots');
INSERT INTO "languageNames" VALUES(2535,'ast','sd','sindhi');
INSERT INTO "languageNames" VALUES(2536,'ast','se','sami del norte');
INSERT INTO "languageNames" VALUES(2537,'ast','sh','serbo-croata');
INSERT INTO "languageNames" VALUES(2538,'ast','si','cingalés');
INSERT INTO "languageNames" VALUES(2539,'ast','sk','eslovacu');
INSERT INTO "languageNames" VALUES(2540,'ast','sl','eslovenu');
INSERT INTO "languageNames" VALUES(2541,'ast','sma','sami del sur');
INSERT INTO "languageNames" VALUES(2542,'ast','smj','lule sami');
INSERT INTO "languageNames" VALUES(2543,'ast','smn','inari sami');
INSERT INTO "languageNames" VALUES(2544,'ast','sq','albanu');
INSERT INTO "languageNames" VALUES(2545,'ast','sr','serbiu');
INSERT INTO "languageNames" VALUES(2546,'ast','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(2547,'ast','ss','swati');
INSERT INTO "languageNames" VALUES(2548,'ast','sv','suecu');
INSERT INTO "languageNames" VALUES(2549,'ast','sw','suaḥili');
INSERT INTO "languageNames" VALUES(2550,'ast','ta','tamil');
INSERT INTO "languageNames" VALUES(2551,'ast','te','telugu');
INSERT INTO "languageNames" VALUES(2552,'ast','tet','tetum');
INSERT INTO "languageNames" VALUES(2553,'ast','tg','taxiquistanín');
INSERT INTO "languageNames" VALUES(2554,'ast','th','tailandés');
INSERT INTO "languageNames" VALUES(2555,'ast','tk','turcomanu');
INSERT INTO "languageNames" VALUES(2556,'ast','tl','tagalog');
INSERT INTO "languageNames" VALUES(2557,'ast','tr','turcu');
INSERT INTO "languageNames" VALUES(2558,'ast','tt','tártaru');
INSERT INTO "languageNames" VALUES(2559,'ast','tyv','tuvinianu');
INSERT INTO "languageNames" VALUES(2560,'ast','udm','udmurt');
INSERT INTO "languageNames" VALUES(2561,'ast','ug','uigur');
INSERT INTO "languageNames" VALUES(2562,'ast','uk','ucraín');
INSERT INTO "languageNames" VALUES(2563,'ast','ur','urdu');
INSERT INTO "languageNames" VALUES(2564,'ast','uz','uzbequistanín');
INSERT INTO "languageNames" VALUES(2565,'ast','vi','vietnamín');
INSERT INTO "languageNames" VALUES(2566,'ast','vro','voro');
INSERT INTO "languageNames" VALUES(2567,'ast','wal','wolaytta');
INSERT INTO "languageNames" VALUES(2568,'ast','xh','xhosa');
INSERT INTO "languageNames" VALUES(2569,'ast','yi','yiddish');
INSERT INTO "languageNames" VALUES(2570,'ast','yo','yoruba');
INSERT INTO "languageNames" VALUES(2571,'ast','zh','chinu');
INSERT INTO "languageNames" VALUES(2572,'ast','zu','zulú');
INSERT INTO "languageNames" VALUES(2573,'sq','af','afrikanisht');
INSERT INTO "languageNames" VALUES(2574,'sq','alt','altaishte jugore');
INSERT INTO "languageNames" VALUES(2575,'sq','an','aragonezisht');
INSERT INTO "languageNames" VALUES(2576,'sq','ar','arabisht');
INSERT INTO "languageNames" VALUES(2577,'sq','as','asamezisht');
INSERT INTO "languageNames" VALUES(2578,'sq','ast','asturisht');
INSERT INTO "languageNames" VALUES(2579,'sq','av','avarikisht');
INSERT INTO "languageNames" VALUES(2581,'sq','az','azerisht');
INSERT INTO "languageNames" VALUES(2582,'sq','ba','bashkirisht');
INSERT INTO "languageNames" VALUES(2583,'sq','be','bjellorusisht');
INSERT INTO "languageNames" VALUES(2584,'sq','bg','bullgarisht');
INSERT INTO "languageNames" VALUES(2585,'sq','bi','bislamisht');
INSERT INTO "languageNames" VALUES(2586,'sq','bn','bengalisht');
INSERT INTO "languageNames" VALUES(2587,'sq','br','bretonisht');
INSERT INTO "languageNames" VALUES(2588,'sq','bs','boshnjakisht');
INSERT INTO "languageNames" VALUES(2589,'sq','ca','katalonisht');
INSERT INTO "languageNames" VALUES(2590,'sq','ceb','sebuanisht');
INSERT INTO "languageNames" VALUES(2591,'sq','chm','marisht');
INSERT INTO "languageNames" VALUES(2592,'sq','ckb','kurdishte qendrore');
INSERT INTO "languageNames" VALUES(2593,'sq','co','korsikisht');
INSERT INTO "languageNames" VALUES(2594,'sq','cs','çekisht');
INSERT INTO "languageNames" VALUES(2595,'sq','cu','sllavishte kishtare');
INSERT INTO "languageNames" VALUES(2596,'sq','cv','çuvashisht');
INSERT INTO "languageNames" VALUES(2597,'sq','cy','uellsisht');
INSERT INTO "languageNames" VALUES(2598,'sq','da','danisht');
INSERT INTO "languageNames" VALUES(2599,'sq','dar','darguaisht');
INSERT INTO "languageNames" VALUES(2600,'sq','de','gjermanisht');
INSERT INTO "languageNames" VALUES(2601,'sq','dsb','sorbishte e poshtme');
INSERT INTO "languageNames" VALUES(2602,'sq','el','greqisht');
INSERT INTO "languageNames" VALUES(2603,'sq','en','anglisht');
INSERT INTO "languageNames" VALUES(2604,'sq','eo','esperanto');
INSERT INTO "languageNames" VALUES(2605,'sq','es','spanjisht');
INSERT INTO "languageNames" VALUES(2606,'sq','et','estonisht');
INSERT INTO "languageNames" VALUES(2607,'sq','eu','baskisht');
INSERT INTO "languageNames" VALUES(2608,'sq','fa','persisht');
INSERT INTO "languageNames" VALUES(2609,'sq','fi','finlandisht');
INSERT INTO "languageNames" VALUES(2610,'sq','fo','faroisht');
INSERT INTO "languageNames" VALUES(2611,'sq','fr','frëngjisht');
INSERT INTO "languageNames" VALUES(2612,'sq','fy','frizianishte perëndimore');
INSERT INTO "languageNames" VALUES(2613,'sq','ga','irlandisht');
INSERT INTO "languageNames" VALUES(2614,'sq','gag','gagauzisht');
INSERT INTO "languageNames" VALUES(2615,'sq','gd','galishte skoceze');
INSERT INTO "languageNames" VALUES(2616,'sq','gl','galicisht');
INSERT INTO "languageNames" VALUES(2617,'sq','gn','guaranisht');
INSERT INTO "languageNames" VALUES(2618,'sq','gu','guxharatisht');
INSERT INTO "languageNames" VALUES(2619,'sq','gv','manksisht');
INSERT INTO "languageNames" VALUES(2620,'sq','ha','hausisht');
INSERT INTO "languageNames" VALUES(2621,'sq','haw','havaisht');
INSERT INTO "languageNames" VALUES(2622,'sq','he','hebraisht');
INSERT INTO "languageNames" VALUES(2623,'sq','hi','indisht');
INSERT INTO "languageNames" VALUES(2624,'sq','hr','kroatisht');
INSERT INTO "languageNames" VALUES(2625,'sq','hsb','sorbishte e sipërme');
INSERT INTO "languageNames" VALUES(2626,'sq','ht','haitisht');
INSERT INTO "languageNames" VALUES(2627,'sq','hu','hungarisht');
INSERT INTO "languageNames" VALUES(2628,'sq','hy','armenisht');
INSERT INTO "languageNames" VALUES(2629,'sq','ia','interlingua');
INSERT INTO "languageNames" VALUES(2630,'sq','id','indonezisht');
INSERT INTO "languageNames" VALUES(2631,'sq','ig','igboisht');
INSERT INTO "languageNames" VALUES(2632,'sq','is','islandisht');
INSERT INTO "languageNames" VALUES(2633,'sq','it','italisht');
INSERT INTO "languageNames" VALUES(2634,'sq','ka','gjeorgjisht');
INSERT INTO "languageNames" VALUES(2635,'sq','kk','kazakisht');
INSERT INTO "languageNames" VALUES(2636,'sq','ko','koreanisht');
INSERT INTO "languageNames" VALUES(2637,'sq','krc','karaçaj-balkarisht');
INSERT INTO "languageNames" VALUES(2638,'sq','krl','karelianisht');
INSERT INTO "languageNames" VALUES(2639,'sq','ks','kashmirisht');
INSERT INTO "languageNames" VALUES(2640,'sq','kum','kumikisht');
INSERT INTO "languageNames" VALUES(2641,'sq','kv','komisht');
INSERT INTO "languageNames" VALUES(2642,'sq','ky','kirgizisht');
INSERT INTO "languageNames" VALUES(2643,'sq','la','latinisht');
INSERT INTO "languageNames" VALUES(2644,'sq','lb','luksemburgisht');
INSERT INTO "languageNames" VALUES(2645,'sq','lg','gandaisht');
INSERT INTO "languageNames" VALUES(2646,'sq','ln','lingalisht');
INSERT INTO "languageNames" VALUES(2647,'sq','lo','laosisht');
INSERT INTO "languageNames" VALUES(2648,'sq','lt','lituanisht');
INSERT INTO "languageNames" VALUES(2649,'sq','lv','letonisht');
INSERT INTO "languageNames" VALUES(2650,'sq','mdf','mokshaisht');
INSERT INTO "languageNames" VALUES(2651,'sq','mfe','morisjenisht');
INSERT INTO "languageNames" VALUES(2652,'sq','mk','maqedonisht');
INSERT INTO "languageNames" VALUES(2653,'sq','ml','malajalamisht');
INSERT INTO "languageNames" VALUES(2654,'sq','mr','maratisht');
INSERT INTO "languageNames" VALUES(2655,'sq','ms','malajisht');
INSERT INTO "languageNames" VALUES(2656,'sq','mt','maltisht');
INSERT INTO "languageNames" VALUES(2657,'sq','myv','erzjaisht');
INSERT INTO "languageNames" VALUES(2658,'sq','nap','napoletanisht');
INSERT INTO "languageNames" VALUES(2659,'sq','nb','norvegjishte letrare');
INSERT INTO "languageNames" VALUES(2660,'sq','ne','nepalisht');
INSERT INTO "languageNames" VALUES(2661,'sq','nl','holandisht');
INSERT INTO "languageNames" VALUES(2662,'sq','nn','norvegjishte nynorsk');
INSERT INTO "languageNames" VALUES(2663,'sq','no','norvegjisht');
INSERT INTO "languageNames" VALUES(2664,'sq','nog','nogajisht');
INSERT INTO "languageNames" VALUES(2665,'sq','oc','oksitanisht');
INSERT INTO "languageNames" VALUES(2666,'sq','os','osetisht');
INSERT INTO "languageNames" VALUES(2667,'sq','pa','punxhabisht');
INSERT INTO "languageNames" VALUES(2668,'sq','pl','polonisht');
INSERT INTO "languageNames" VALUES(2669,'sq','pt','portugalisht');
INSERT INTO "languageNames" VALUES(2670,'sq','rm','retoromanisht');
INSERT INTO "languageNames" VALUES(2671,'sq','rn','rundisht');
INSERT INTO "languageNames" VALUES(2672,'sq','ro','rumanisht');
INSERT INTO "languageNames" VALUES(2673,'sq','ru','rusisht');
INSERT INTO "languageNames" VALUES(2674,'sq','rup','vllahisht');
INSERT INTO "languageNames" VALUES(2675,'sq','sa','sanskritisht');
INSERT INTO "languageNames" VALUES(2676,'sq','sah','sakaisht');
INSERT INTO "languageNames" VALUES(2677,'sq','sc','sardenjisht');
INSERT INTO "languageNames" VALUES(2678,'sq','scn','siçilianisht');
INSERT INTO "languageNames" VALUES(2679,'sq','sco','skotisht');
INSERT INTO "languageNames" VALUES(2680,'sq','sd','sindisht');
INSERT INTO "languageNames" VALUES(2681,'sq','se','samishte veriore');
INSERT INTO "languageNames" VALUES(2682,'sq','sh','serbo-kroatisht');
INSERT INTO "languageNames" VALUES(2683,'sq','si','sinhalisht');
INSERT INTO "languageNames" VALUES(2684,'sq','sk','sllovakisht');
INSERT INTO "languageNames" VALUES(2685,'sq','sl','sllovenisht');
INSERT INTO "languageNames" VALUES(2686,'sq','sma','samishte jugore');
INSERT INTO "languageNames" VALUES(2687,'sq','smj','samishte lule');
INSERT INTO "languageNames" VALUES(2688,'sq','smn','samishte inari');
INSERT INTO "languageNames" VALUES(2689,'sq','sq','shqip');
INSERT INTO "languageNames" VALUES(2690,'sq','sr','serbisht');
INSERT INTO "languageNames" VALUES(2691,'sq','srn','srananisht (sranantongoisht)');
INSERT INTO "languageNames" VALUES(2692,'sq','ss','suatisht');
INSERT INTO "languageNames" VALUES(2693,'sq','sv','suedisht');
INSERT INTO "languageNames" VALUES(2694,'sq','sw','suahilisht');
INSERT INTO "languageNames" VALUES(2695,'sq','ta','tamilisht');
INSERT INTO "languageNames" VALUES(2696,'sq','te','teluguisht');
INSERT INTO "languageNames" VALUES(2697,'sq','tet','tetumisht');
INSERT INTO "languageNames" VALUES(2698,'sq','tg','taxhikisht');
INSERT INTO "languageNames" VALUES(2699,'sq','th','tajlandisht');
INSERT INTO "languageNames" VALUES(2700,'sq','tk','turkmenisht');
INSERT INTO "languageNames" VALUES(2701,'sq','tr','turqisht');
INSERT INTO "languageNames" VALUES(2702,'sq','tt','tatarisht');
INSERT INTO "languageNames" VALUES(2703,'sq','tyv','tuvinianisht');
INSERT INTO "languageNames" VALUES(2704,'sq','udm','udmurtisht');
INSERT INTO "languageNames" VALUES(2705,'sq','ug','ujgurisht');
INSERT INTO "languageNames" VALUES(2706,'sq','uk','ukrainisht');
INSERT INTO "languageNames" VALUES(2707,'sq','ur','urduisht');
INSERT INTO "languageNames" VALUES(2708,'sq','uz','uzbekisht');
INSERT INTO "languageNames" VALUES(2709,'sq','vi','vietnamisht');
INSERT INTO "languageNames" VALUES(2710,'sq','wal','ulajtaisht');
INSERT INTO "languageNames" VALUES(2711,'sq','xh','xhosaisht');
INSERT INTO "languageNames" VALUES(2712,'sq','yi','jidisht');
INSERT INTO "languageNames" VALUES(2713,'sq','yo','jorubaisht');
INSERT INTO "languageNames" VALUES(2714,'sq','zh','kinezisht');
INSERT INTO "languageNames" VALUES(2715,'sq','zu','zuluisht');
INSERT INTO "languageNames" VALUES(2716,'be','af','афрыкаанс');
INSERT INTO "languageNames" VALUES(2717,'be','alt','паўднёваалтайская');
INSERT INTO "languageNames" VALUES(2718,'be','an','арагонская');
INSERT INTO "languageNames" VALUES(2719,'be','ar','арабская');
INSERT INTO "languageNames" VALUES(2720,'be','as','асамская');
INSERT INTO "languageNames" VALUES(2721,'be','ast','астурыйская');
INSERT INTO "languageNames" VALUES(2722,'be','av','аварская');
INSERT INTO "languageNames" VALUES(2724,'be','az','азербайджанская');
INSERT INTO "languageNames" VALUES(2725,'be','ba','башкірская');
INSERT INTO "languageNames" VALUES(2726,'be','be','беларуская');
INSERT INTO "languageNames" VALUES(2727,'be','bg','балгарская');
INSERT INTO "languageNames" VALUES(2728,'be','bi','біслама');
INSERT INTO "languageNames" VALUES(2729,'be','bn','бенгальская');
INSERT INTO "languageNames" VALUES(2730,'be','br','брэтонская');
INSERT INTO "languageNames" VALUES(2731,'be','bs','баснійская');
INSERT INTO "languageNames" VALUES(2732,'be','bua','бурацкая');
INSERT INTO "languageNames" VALUES(2733,'be','ca','каталанская');
INSERT INTO "languageNames" VALUES(2734,'be','ceb','себуана');
INSERT INTO "languageNames" VALUES(2735,'be','chm','мары');
INSERT INTO "languageNames" VALUES(2736,'be','ckb','цэнтральнакурдская');
INSERT INTO "languageNames" VALUES(2737,'be','co','карсіканская');
INSERT INTO "languageNames" VALUES(2738,'be','cs','чэшская');
INSERT INTO "languageNames" VALUES(2739,'be','cu','царкоўнаславянская');
INSERT INTO "languageNames" VALUES(2740,'be','cv','чувашская');
INSERT INTO "languageNames" VALUES(2741,'be','cy','валійская');
INSERT INTO "languageNames" VALUES(2742,'be','da','дацкая');
INSERT INTO "languageNames" VALUES(2743,'be','dar','даргінская');
INSERT INTO "languageNames" VALUES(2744,'be','de','нямецкая');
INSERT INTO "languageNames" VALUES(2745,'be','dsb','ніжнялужыцкая');
INSERT INTO "languageNames" VALUES(2746,'be','el','грэчаская');
INSERT INTO "languageNames" VALUES(2747,'be','en','англійская');
INSERT INTO "languageNames" VALUES(2748,'be','eo','эсперанта');
INSERT INTO "languageNames" VALUES(2749,'be','es','іспанская');
INSERT INTO "languageNames" VALUES(2750,'be','et','эстонская');
INSERT INTO "languageNames" VALUES(2751,'be','eu','баскская');
INSERT INTO "languageNames" VALUES(2752,'be','fa','фарсі');
INSERT INTO "languageNames" VALUES(2753,'be','fi','фінская');
INSERT INTO "languageNames" VALUES(2754,'be','fo','фарэрская');
INSERT INTO "languageNames" VALUES(2755,'be','fr','французская');
INSERT INTO "languageNames" VALUES(2756,'be','fy','заходняя фрызская');
INSERT INTO "languageNames" VALUES(2757,'be','ga','ірландская');
INSERT INTO "languageNames" VALUES(2758,'be','gag','гагаузская');
INSERT INTO "languageNames" VALUES(2759,'be','gd','шатландская гэльская');
INSERT INTO "languageNames" VALUES(2760,'be','gl','галісійская');
INSERT INTO "languageNames" VALUES(2761,'be','gn','гуарані');
INSERT INTO "languageNames" VALUES(2762,'be','gu','гуджараці');
INSERT INTO "languageNames" VALUES(2763,'be','gv','мэнская');
INSERT INTO "languageNames" VALUES(2764,'be','ha','хауса');
INSERT INTO "languageNames" VALUES(2765,'be','haw','гавайская');
INSERT INTO "languageNames" VALUES(2766,'be','he','іўрыт');
INSERT INTO "languageNames" VALUES(2767,'be','hi','хіндзі');
INSERT INTO "languageNames" VALUES(2768,'be','hr','харвацкая');
INSERT INTO "languageNames" VALUES(2769,'be','hsb','верхнялужыцкая');
INSERT INTO "languageNames" VALUES(2770,'be','ht','гаіцянская крэольская');
INSERT INTO "languageNames" VALUES(2771,'be','hu','венгерская');
INSERT INTO "languageNames" VALUES(2772,'be','hy','армянская');
INSERT INTO "languageNames" VALUES(2773,'be','ia','інтэрлінгва');
INSERT INTO "languageNames" VALUES(2774,'be','id','інданезійская');
INSERT INTO "languageNames" VALUES(2775,'be','ig','ігба');
INSERT INTO "languageNames" VALUES(2776,'be','is','ісландская');
INSERT INTO "languageNames" VALUES(2777,'be','it','італьянская');
INSERT INTO "languageNames" VALUES(2778,'be','ka','грузінская');
INSERT INTO "languageNames" VALUES(2779,'be','kk','казахская');
INSERT INTO "languageNames" VALUES(2780,'be','ko','карэйская');
INSERT INTO "languageNames" VALUES(2781,'be','krc','карачай-балкарская');
INSERT INTO "languageNames" VALUES(2782,'be','krl','карэльская');
INSERT INTO "languageNames" VALUES(2783,'be','ks','кашмірская');
INSERT INTO "languageNames" VALUES(2784,'be','kum','кумыцкая');
INSERT INTO "languageNames" VALUES(2785,'be','kv','комі');
INSERT INTO "languageNames" VALUES(2786,'be','ky','кіргізская');
INSERT INTO "languageNames" VALUES(2787,'be','la','лацінская');
INSERT INTO "languageNames" VALUES(2788,'be','lb','люксембургская');
INSERT INTO "languageNames" VALUES(2789,'be','lg','ганда');
INSERT INTO "languageNames" VALUES(2790,'be','ln','лінгала');
INSERT INTO "languageNames" VALUES(2791,'be','lo','лаоская');
INSERT INTO "languageNames" VALUES(2792,'be','lt','літоўская');
INSERT INTO "languageNames" VALUES(2793,'be','lv','латышская');
INSERT INTO "languageNames" VALUES(2794,'be','mdf','макшанская');
INSERT INTO "languageNames" VALUES(2795,'be','mfe','марысьен');
INSERT INTO "languageNames" VALUES(2796,'be','mk','македонская');
INSERT INTO "languageNames" VALUES(2797,'be','ml','малаялам');
INSERT INTO "languageNames" VALUES(2798,'be','mr','маратхі');
INSERT INTO "languageNames" VALUES(2799,'be','ms','малайская');
INSERT INTO "languageNames" VALUES(2800,'be','mt','мальтыйская');
INSERT INTO "languageNames" VALUES(2801,'be','myv','эрзянская');
INSERT INTO "languageNames" VALUES(2802,'be','nap','неапалітанская');
INSERT INTO "languageNames" VALUES(2803,'be','nb','нарвежская (букмол)');
INSERT INTO "languageNames" VALUES(2804,'be','ne','непальская');
INSERT INTO "languageNames" VALUES(2805,'be','nl','нідэрландская');
INSERT INTO "languageNames" VALUES(2806,'be','nn','нарвежская (нюношк)');
INSERT INTO "languageNames" VALUES(2807,'be','no','нарвежская');
INSERT INTO "languageNames" VALUES(2808,'be','nog','нагайская');
INSERT INTO "languageNames" VALUES(2809,'be','oc','аксітанская');
INSERT INTO "languageNames" VALUES(2810,'be','os','асецінская');
INSERT INTO "languageNames" VALUES(2811,'be','pa','панджабі');
INSERT INTO "languageNames" VALUES(2812,'be','pl','польская');
INSERT INTO "languageNames" VALUES(2813,'be','pt','партугальская');
INSERT INTO "languageNames" VALUES(2814,'be','rm','рэтараманская');
INSERT INTO "languageNames" VALUES(2815,'be','rn','рундзі');
INSERT INTO "languageNames" VALUES(2816,'be','ro','румынская');
INSERT INTO "languageNames" VALUES(2817,'be','ru','руская');
INSERT INTO "languageNames" VALUES(2818,'be','rup','арумунская');
INSERT INTO "languageNames" VALUES(2819,'be','sa','санскрыт');
INSERT INTO "languageNames" VALUES(2820,'be','sah','якуцкая');
INSERT INTO "languageNames" VALUES(2821,'be','sc','сардзінская');
INSERT INTO "languageNames" VALUES(2822,'be','scn','сіцылійская');
INSERT INTO "languageNames" VALUES(2823,'be','sco','шатландская');
INSERT INTO "languageNames" VALUES(2824,'be','sd','сіндхі');
INSERT INTO "languageNames" VALUES(2825,'be','se','паўночнасаамская');
INSERT INTO "languageNames" VALUES(2826,'be','sh','сербскахарвацкая');
INSERT INTO "languageNames" VALUES(2827,'be','si','сінгальская');
INSERT INTO "languageNames" VALUES(2828,'be','sk','славацкая');
INSERT INTO "languageNames" VALUES(2829,'be','sl','славенская');
INSERT INTO "languageNames" VALUES(2830,'be','sma','паўднёвасаамская');
INSERT INTO "languageNames" VALUES(2831,'be','smj','луле-саамская');
INSERT INTO "languageNames" VALUES(2832,'be','smn','інары-саамская');
INSERT INTO "languageNames" VALUES(2833,'be','sq','албанская');
INSERT INTO "languageNames" VALUES(2834,'be','sr','сербская');
INSERT INTO "languageNames" VALUES(2835,'be','srn','сранан-тонга');
INSERT INTO "languageNames" VALUES(2836,'be','ss','суаці');
INSERT INTO "languageNames" VALUES(2837,'be','sv','шведская');
INSERT INTO "languageNames" VALUES(2838,'be','sw','суахілі');
INSERT INTO "languageNames" VALUES(2839,'be','ta','тамільская');
INSERT INTO "languageNames" VALUES(2840,'be','te','тэлугу');
INSERT INTO "languageNames" VALUES(2841,'be','tet','тэтум');
INSERT INTO "languageNames" VALUES(2842,'be','tg','таджыкская');
INSERT INTO "languageNames" VALUES(2843,'be','th','тайская');
INSERT INTO "languageNames" VALUES(2844,'be','tk','туркменская');
INSERT INTO "languageNames" VALUES(2845,'be','tr','турэцкая');
INSERT INTO "languageNames" VALUES(2846,'be','tt','татарская');
INSERT INTO "languageNames" VALUES(2847,'be','tyv','тувінская');
INSERT INTO "languageNames" VALUES(2848,'be','udm','удмурцкая');
INSERT INTO "languageNames" VALUES(2849,'be','ug','уйгурская');
INSERT INTO "languageNames" VALUES(2850,'be','uk','украінская');
INSERT INTO "languageNames" VALUES(2851,'be','ur','урду');
INSERT INTO "languageNames" VALUES(2852,'be','uz','узбекская');
INSERT INTO "languageNames" VALUES(2853,'be','vi','в’етнамская');
INSERT INTO "languageNames" VALUES(2854,'be','wal','волайта');
INSERT INTO "languageNames" VALUES(2855,'be','xh','коса');
INSERT INTO "languageNames" VALUES(2856,'be','yi','ідыш');
INSERT INTO "languageNames" VALUES(2857,'be','yo','ёруба');
INSERT INTO "languageNames" VALUES(2858,'be','zh','кітайская');
INSERT INTO "languageNames" VALUES(2859,'be','zu','зулу');
INSERT INTO "languageNames" VALUES(2860,'ka','af','აფრიკაანსი');
INSERT INTO "languageNames" VALUES(2861,'ka','alt','სამხრეთ ალთაური');
INSERT INTO "languageNames" VALUES(2862,'ka','an','არაგონული');
INSERT INTO "languageNames" VALUES(2863,'ka','ar','არაბული');
INSERT INTO "languageNames" VALUES(2864,'ka','as','ასამური');
INSERT INTO "languageNames" VALUES(2865,'ka','ast','ასტურიული');
INSERT INTO "languageNames" VALUES(2866,'ka','av','ხუნძური');
INSERT INTO "languageNames" VALUES(2868,'ka','az','აზერბაიჯანული');
INSERT INTO "languageNames" VALUES(2869,'ka','ba','ბაშკირული');
INSERT INTO "languageNames" VALUES(2870,'ka','be','ბელორუსული');
INSERT INTO "languageNames" VALUES(2871,'ka','bg','ბულგარული');
INSERT INTO "languageNames" VALUES(2872,'ka','bi','ბისლამა');
INSERT INTO "languageNames" VALUES(2873,'ka','bn','ბენგალური');
INSERT INTO "languageNames" VALUES(2874,'ka','br','ბრეტონული');
INSERT INTO "languageNames" VALUES(2875,'ka','bs','ბოსნიური');
INSERT INTO "languageNames" VALUES(2876,'ka','bua','ბურიატული');
INSERT INTO "languageNames" VALUES(2877,'ka','ca','კატალანური');
INSERT INTO "languageNames" VALUES(2878,'ka','ceb','სებუანო');
INSERT INTO "languageNames" VALUES(2879,'ka','chm','მარიული');
INSERT INTO "languageNames" VALUES(2880,'ka','ckb','ცენტრალური ქურთული');
INSERT INTO "languageNames" VALUES(2881,'ka','co','კორსიკული');
INSERT INTO "languageNames" VALUES(2882,'ka','crh','ყირიმულ-თურქული');
INSERT INTO "languageNames" VALUES(2883,'ka','cs','ჩეხური');
INSERT INTO "languageNames" VALUES(2884,'ka','csb','კაშუბური');
INSERT INTO "languageNames" VALUES(2885,'ka','cu','საეკლესიო სლავური');
INSERT INTO "languageNames" VALUES(2886,'ka','cv','ჩუვაშური');
INSERT INTO "languageNames" VALUES(2887,'ka','cy','უელსური');
INSERT INTO "languageNames" VALUES(2888,'ka','da','დანიური');
INSERT INTO "languageNames" VALUES(2889,'ka','dar','დარგუული');
INSERT INTO "languageNames" VALUES(2890,'ka','de','გერმანული');
INSERT INTO "languageNames" VALUES(2891,'ka','dsb','ქვემოსორბული');
INSERT INTO "languageNames" VALUES(2892,'ka','el','ბერძნული');
INSERT INTO "languageNames" VALUES(2893,'ka','en','ინგლისური');
INSERT INTO "languageNames" VALUES(2894,'ka','eo','ესპერანტო');
INSERT INTO "languageNames" VALUES(2895,'ka','es','ესპანური');
INSERT INTO "languageNames" VALUES(2896,'ka','et','ესტონური');
INSERT INTO "languageNames" VALUES(2897,'ka','eu','ბასკური');
INSERT INTO "languageNames" VALUES(2898,'ka','fa','სპარსული');
INSERT INTO "languageNames" VALUES(2899,'ka','fi','ფინური');
INSERT INTO "languageNames" VALUES(2900,'ka','fo','ფარერული');
INSERT INTO "languageNames" VALUES(2901,'ka','fr','ფრანგული');
INSERT INTO "languageNames" VALUES(2902,'ka','fy','დასავლეთფრიზიული');
INSERT INTO "languageNames" VALUES(2903,'ka','ga','ირლანდიური');
INSERT INTO "languageNames" VALUES(2904,'ka','gag','გაგაუზური');
INSERT INTO "languageNames" VALUES(2905,'ka','gd','შოტლანდიური გელური');
INSERT INTO "languageNames" VALUES(2906,'ka','gl','გალისიური');
INSERT INTO "languageNames" VALUES(2907,'ka','gn','გუარანი');
INSERT INTO "languageNames" VALUES(2908,'ka','gu','გუჯარათი');
INSERT INTO "languageNames" VALUES(2909,'ka','gv','მენური');
INSERT INTO "languageNames" VALUES(2910,'ka','ha','ჰაუსა');
INSERT INTO "languageNames" VALUES(2911,'ka','haw','ჰავაიური');
INSERT INTO "languageNames" VALUES(2912,'ka','he','ებრაული');
INSERT INTO "languageNames" VALUES(2913,'ka','hi','ჰინდი');
INSERT INTO "languageNames" VALUES(2914,'ka','hr','ხორვატული');
INSERT INTO "languageNames" VALUES(2915,'ka','hsb','ზემოსორბული');
INSERT INTO "languageNames" VALUES(2916,'ka','ht','ჰაიტიური კრეოლი');
INSERT INTO "languageNames" VALUES(2917,'ka','hu','უნგრული');
INSERT INTO "languageNames" VALUES(2918,'ka','hy','სომხური');
INSERT INTO "languageNames" VALUES(2919,'ka','ia','ინტერლინგუალური');
INSERT INTO "languageNames" VALUES(2920,'ka','id','ინდონეზიური');
INSERT INTO "languageNames" VALUES(2921,'ka','ig','იგბო');
INSERT INTO "languageNames" VALUES(2922,'ka','is','ისლანდიური');
INSERT INTO "languageNames" VALUES(2923,'ka','it','იტალიური');
INSERT INTO "languageNames" VALUES(2924,'ka','ka','ქართული');
INSERT INTO "languageNames" VALUES(2925,'ka','kaa','ყარაყალფახური');
INSERT INTO "languageNames" VALUES(2926,'ka','kk','ყაზახური');
INSERT INTO "languageNames" VALUES(2927,'ka','ko','კორეული');
INSERT INTO "languageNames" VALUES(2928,'ka','krc','ყარაჩაულ-ბალყარული');
INSERT INTO "languageNames" VALUES(2929,'ka','krl','კარელიური');
INSERT INTO "languageNames" VALUES(2930,'ka','ks','ქაშმირული');
INSERT INTO "languageNames" VALUES(2931,'ka','kum','ყუმუხური');
INSERT INTO "languageNames" VALUES(2932,'ka','kv','კომი');
INSERT INTO "languageNames" VALUES(2933,'ka','ky','ყირგიზული');
INSERT INTO "languageNames" VALUES(2934,'ka','la','ლათინური');
INSERT INTO "languageNames" VALUES(2935,'ka','lb','ლუქსემბურგული');
INSERT INTO "languageNames" VALUES(2936,'ka','lg','განდა');
INSERT INTO "languageNames" VALUES(2937,'ka','ln','ლინგალა');
INSERT INTO "languageNames" VALUES(2938,'ka','lo','ლაოსური');
INSERT INTO "languageNames" VALUES(2939,'ka','lt','ლიტვური');
INSERT INTO "languageNames" VALUES(2940,'ka','lv','ლატვიური');
INSERT INTO "languageNames" VALUES(2941,'ka','mdf','მოქშა');
INSERT INTO "languageNames" VALUES(2942,'ka','mfe','მორისიენი');
INSERT INTO "languageNames" VALUES(2943,'ka','mk','მაკედონური');
INSERT INTO "languageNames" VALUES(2944,'ka','ml','მალაიალამური');
INSERT INTO "languageNames" VALUES(2945,'ka','mr','მარათჰი');
INSERT INTO "languageNames" VALUES(2946,'ka','ms','მალაიური');
INSERT INTO "languageNames" VALUES(2947,'ka','mt','მალტური');
INSERT INTO "languageNames" VALUES(2948,'ka','myv','ერზია');
INSERT INTO "languageNames" VALUES(2949,'ka','nap','ნეაპოლიტანური');
INSERT INTO "languageNames" VALUES(2950,'ka','nb','ნორვეგიული ბუკმოლი');
INSERT INTO "languageNames" VALUES(2951,'ka','ne','ნეპალური');
INSERT INTO "languageNames" VALUES(2952,'ka','nl','ნიდერლანდური');
INSERT INTO "languageNames" VALUES(2953,'ka','nn','ნორვეგიული ნიუნორსკი');
INSERT INTO "languageNames" VALUES(2954,'ka','no','ნორვეგიული');
INSERT INTO "languageNames" VALUES(2955,'ka','nog','ნოღაური');
INSERT INTO "languageNames" VALUES(2956,'ka','oc','ოქსიტანური');
INSERT INTO "languageNames" VALUES(2957,'ka','os','ოსური');
INSERT INTO "languageNames" VALUES(2958,'ka','pa','პენჯაბური');
INSERT INTO "languageNames" VALUES(2959,'ka','pl','პოლონური');
INSERT INTO "languageNames" VALUES(2960,'ka','pt','პორტუგალიური');
INSERT INTO "languageNames" VALUES(2961,'ka','rm','რეტორომანული');
INSERT INTO "languageNames" VALUES(2962,'ka','rn','რუნდი');
INSERT INTO "languageNames" VALUES(2963,'ka','ro','რუმინული');
INSERT INTO "languageNames" VALUES(2964,'ka','ru','რუსული');
INSERT INTO "languageNames" VALUES(2965,'ka','rup','არომანული');
INSERT INTO "languageNames" VALUES(2966,'ka','sa','სანსკრიტი');
INSERT INTO "languageNames" VALUES(2967,'ka','sah','იაკუტური');
INSERT INTO "languageNames" VALUES(2968,'ka','sc','სარდინიული');
INSERT INTO "languageNames" VALUES(2969,'ka','scn','სიცილიური');
INSERT INTO "languageNames" VALUES(2970,'ka','sco','შოტლანდიური');
INSERT INTO "languageNames" VALUES(2971,'ka','sd','სინდჰური');
INSERT INTO "languageNames" VALUES(2972,'ka','se','ჩრდილოეთ საამური');
INSERT INTO "languageNames" VALUES(2973,'ka','sh','სერბულ-ხორვატული');
INSERT INTO "languageNames" VALUES(2974,'ka','si','სინჰალური');
INSERT INTO "languageNames" VALUES(2975,'ka','sk','სლოვაკური');
INSERT INTO "languageNames" VALUES(2976,'ka','sl','სლოვენური');
INSERT INTO "languageNames" VALUES(2977,'ka','sma','სამხრეთსამური');
INSERT INTO "languageNames" VALUES(2978,'ka','smj','ლულე-საამური');
INSERT INTO "languageNames" VALUES(2979,'ka','smn','ინარი-საამური');
INSERT INTO "languageNames" VALUES(2980,'ka','sq','ალბანური');
INSERT INTO "languageNames" VALUES(2981,'ka','sr','სერბული');
INSERT INTO "languageNames" VALUES(2982,'ka','srn','სრანან ტონგო');
INSERT INTO "languageNames" VALUES(2983,'ka','ss','სუატი');
INSERT INTO "languageNames" VALUES(2984,'ka','sv','შვედური');
INSERT INTO "languageNames" VALUES(2985,'ka','sw','სუაჰილი');
INSERT INTO "languageNames" VALUES(2986,'ka','ta','ტამილური');
INSERT INTO "languageNames" VALUES(2987,'ka','te','ტელუგუ');
INSERT INTO "languageNames" VALUES(2988,'ka','tet','ტეტუმი');
INSERT INTO "languageNames" VALUES(2989,'ka','tg','ტაჯიკური');
INSERT INTO "languageNames" VALUES(2990,'ka','th','ტაი');
INSERT INTO "languageNames" VALUES(2991,'ka','tk','თურქმენული');
INSERT INTO "languageNames" VALUES(2992,'ka','tr','თურქული');
INSERT INTO "languageNames" VALUES(2993,'ka','tt','თათრული');
INSERT INTO "languageNames" VALUES(2994,'ka','tyv','ტუვა');
INSERT INTO "languageNames" VALUES(2995,'ka','udm','უდმურტული');
INSERT INTO "languageNames" VALUES(2996,'ka','ug','უიღურული');
INSERT INTO "languageNames" VALUES(2997,'ka','uk','უკრაინული');
INSERT INTO "languageNames" VALUES(2998,'ka','ur','ურდუ');
INSERT INTO "languageNames" VALUES(2999,'ka','uz','უზბეკური');
INSERT INTO "languageNames" VALUES(3000,'ka','vi','ვიეტნამური');
INSERT INTO "languageNames" VALUES(3001,'ka','wal','ველაითა');
INSERT INTO "languageNames" VALUES(3002,'ka','xh','ქჰოსა');
INSERT INTO "languageNames" VALUES(3003,'ka','yi','იდიში');
INSERT INTO "languageNames" VALUES(3004,'ka','yo','იორუბა');
INSERT INTO "languageNames" VALUES(3005,'ka','zh','ჩინური');
INSERT INTO "languageNames" VALUES(3006,'ka','zu','ზულუ');
INSERT INTO "languageNames" VALUES(3007,'gd','af','Afraganais');
INSERT INTO "languageNames" VALUES(3008,'gd','alt','Altais Dheasach');
INSERT INTO "languageNames" VALUES(3009,'gd','an','Aragonais');
INSERT INTO "languageNames" VALUES(3010,'gd','ar','Arabais');
INSERT INTO "languageNames" VALUES(3011,'gd','as','Asamais');
INSERT INTO "languageNames" VALUES(3012,'gd','ast','Astùrais');
INSERT INTO "languageNames" VALUES(3013,'gd','av','Avarais');
INSERT INTO "languageNames" VALUES(3015,'gd','az','Azeri');
INSERT INTO "languageNames" VALUES(3016,'gd','ba','Bashkir');
INSERT INTO "languageNames" VALUES(3017,'gd','be','Bealaruisis');
INSERT INTO "languageNames" VALUES(3018,'gd','bg','Bulgarais');
INSERT INTO "languageNames" VALUES(3019,'gd','bi','Bislama');
INSERT INTO "languageNames" VALUES(3020,'gd','bn','Bangla');
INSERT INTO "languageNames" VALUES(3021,'gd','br','Breatnais');
INSERT INTO "languageNames" VALUES(3022,'gd','bs','Bosnais');
INSERT INTO "languageNames" VALUES(3023,'gd','bua','Buriat');
INSERT INTO "languageNames" VALUES(3024,'gd','byv','Medumba');
INSERT INTO "languageNames" VALUES(3025,'gd','ca','Catalanais');
INSERT INTO "languageNames" VALUES(3026,'gd','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(3027,'gd','chm','Mari');
INSERT INTO "languageNames" VALUES(3028,'gd','ckb','Cùrdais Mheadhanach');
INSERT INTO "languageNames" VALUES(3029,'gd','co','Corsais');
INSERT INTO "languageNames" VALUES(3030,'gd','crh','Turcais Chriomach');
INSERT INTO "languageNames" VALUES(3031,'gd','cs','Seicis');
INSERT INTO "languageNames" VALUES(3032,'gd','csb','Caisiubais');
INSERT INTO "languageNames" VALUES(3033,'gd','cu','Slàbhais na h-Eaglaise');
INSERT INTO "languageNames" VALUES(3034,'gd','cv','Chuvash');
INSERT INTO "languageNames" VALUES(3035,'gd','cy','Cuimris');
INSERT INTO "languageNames" VALUES(3036,'gd','da','Danmhairgis');
INSERT INTO "languageNames" VALUES(3037,'gd','dar','Dargwa');
INSERT INTO "languageNames" VALUES(3038,'gd','de','Gearmailtis');
INSERT INTO "languageNames" VALUES(3039,'gd','dsb','Sòrbais Ìochdarach');
INSERT INTO "languageNames" VALUES(3040,'gd','el','Greugais');
INSERT INTO "languageNames" VALUES(3041,'gd','en','Beurla');
INSERT INTO "languageNames" VALUES(3042,'gd','eo','Esperanto');
INSERT INTO "languageNames" VALUES(3043,'gd','es','Spàinntis');
INSERT INTO "languageNames" VALUES(3044,'gd','et','Eastoinis');
INSERT INTO "languageNames" VALUES(3045,'gd','eu','Basgais');
INSERT INTO "languageNames" VALUES(3046,'gd','fa','Peirsis');
INSERT INTO "languageNames" VALUES(3047,'gd','fi','Fionnlannais');
INSERT INTO "languageNames" VALUES(3048,'gd','fo','Fàrothais');
INSERT INTO "languageNames" VALUES(3049,'gd','fr','Fraingis');
INSERT INTO "languageNames" VALUES(3050,'gd','fy','Frìoslannais Shiarach');
INSERT INTO "languageNames" VALUES(3051,'gd','ga','Gaeilge');
INSERT INTO "languageNames" VALUES(3052,'gd','gag','Gagauz');
INSERT INTO "languageNames" VALUES(3053,'gd','gd','Gàidhlig');
INSERT INTO "languageNames" VALUES(3054,'gd','gl','Gailìsis');
INSERT INTO "languageNames" VALUES(3055,'gd','glk','Gilaki');
INSERT INTO "languageNames" VALUES(3056,'gd','gn','Guaraní');
INSERT INTO "languageNames" VALUES(3057,'gd','gu','Gujarati');
INSERT INTO "languageNames" VALUES(3058,'gd','guc','Wayuu');
INSERT INTO "languageNames" VALUES(3059,'gd','gv','Gaelg');
INSERT INTO "languageNames" VALUES(3060,'gd','ha','Hausa');
INSERT INTO "languageNames" VALUES(3061,'gd','haw','Cànan Hawai’i');
INSERT INTO "languageNames" VALUES(3062,'gd','he','Eabhra');
INSERT INTO "languageNames" VALUES(3063,'gd','hi','Hindis');
INSERT INTO "languageNames" VALUES(3064,'gd','hr','Cròthaisis');
INSERT INTO "languageNames" VALUES(3065,'gd','hsb','Sòrbais Uachdarach');
INSERT INTO "languageNames" VALUES(3066,'gd','ht','Crìtheol Haidhti');
INSERT INTO "languageNames" VALUES(3067,'gd','hu','Ungairis');
INSERT INTO "languageNames" VALUES(3068,'gd','hy','Airmeinis');
INSERT INTO "languageNames" VALUES(3069,'gd','ia','Interlingua');
INSERT INTO "languageNames" VALUES(3070,'gd','id','Innd-Innsis');
INSERT INTO "languageNames" VALUES(3071,'gd','ig','Igbo');
INSERT INTO "languageNames" VALUES(3072,'gd','is','Innis Tìlis');
INSERT INTO "languageNames" VALUES(3073,'gd','it','Eadailtis');
INSERT INTO "languageNames" VALUES(3074,'gd','ka','Cairtbheilis');
INSERT INTO "languageNames" VALUES(3075,'gd','kaa','Kara-Kalpak');
INSERT INTO "languageNames" VALUES(3076,'gd','kk','Casachais');
INSERT INTO "languageNames" VALUES(3077,'gd','ko','Coirèanais');
INSERT INTO "languageNames" VALUES(3078,'gd','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(3079,'gd','krl','Cairealais');
INSERT INTO "languageNames" VALUES(3080,'gd','ks','Caismiris');
INSERT INTO "languageNames" VALUES(3081,'gd','kum','Kumyk');
INSERT INTO "languageNames" VALUES(3082,'gd','kv','Komi');
INSERT INTO "languageNames" VALUES(3083,'gd','ky','Cìorgasais');
INSERT INTO "languageNames" VALUES(3084,'gd','la','Laideann');
INSERT INTO "languageNames" VALUES(3085,'gd','lb','Lugsamburgais');
INSERT INTO "languageNames" VALUES(3086,'gd','lg','Ganda');
INSERT INTO "languageNames" VALUES(3087,'gd','ln','Lingala');
INSERT INTO "languageNames" VALUES(3088,'gd','lo','Làtho');
INSERT INTO "languageNames" VALUES(3089,'gd','lt','Liotuainis');
INSERT INTO "languageNames" VALUES(3090,'gd','lv','Laitbheis');
INSERT INTO "languageNames" VALUES(3091,'gd','mdf','Moksha');
INSERT INTO "languageNames" VALUES(3092,'gd','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(3093,'gd','mk','Masadonais');
INSERT INTO "languageNames" VALUES(3094,'gd','ml','Malayalam');
INSERT INTO "languageNames" VALUES(3095,'gd','mr','Marathi');
INSERT INTO "languageNames" VALUES(3096,'gd','mrj','Mari Shiarach');
INSERT INTO "languageNames" VALUES(3097,'gd','ms','Malaidhis');
INSERT INTO "languageNames" VALUES(3098,'gd','mt','Maltais');
INSERT INTO "languageNames" VALUES(3099,'gd','myv','Erzya');
INSERT INTO "languageNames" VALUES(3100,'gd','nap','Eadailtis Napoli');
INSERT INTO "languageNames" VALUES(3101,'gd','nb','Bokmål na Nirribhidh');
INSERT INTO "languageNames" VALUES(3102,'gd','ne','Neapàlais');
INSERT INTO "languageNames" VALUES(3103,'gd','nl','Duitsis');
INSERT INTO "languageNames" VALUES(3104,'gd','nn','Nynorsk na Nirribhidh');
INSERT INTO "languageNames" VALUES(3105,'gd','no','Nirribhis');
INSERT INTO "languageNames" VALUES(3106,'gd','nog','Nogai');
INSERT INTO "languageNames" VALUES(3107,'gd','oc','Ogsatanais');
INSERT INTO "languageNames" VALUES(3108,'gd','os','Ossetic');
INSERT INTO "languageNames" VALUES(3109,'gd','ota','Turcais Otomanach');
INSERT INTO "languageNames" VALUES(3110,'gd','pa','Panjabi');
INSERT INTO "languageNames" VALUES(3111,'gd','pl','Pòlainnis');
INSERT INTO "languageNames" VALUES(3112,'gd','pt','Portagailis');
INSERT INTO "languageNames" VALUES(3113,'gd','rm','Rumains');
INSERT INTO "languageNames" VALUES(3114,'gd','rn','Kirundi');
INSERT INTO "languageNames" VALUES(3115,'gd','ro','Romàinis');
INSERT INTO "languageNames" VALUES(3116,'gd','ru','Ruisis');
INSERT INTO "languageNames" VALUES(3117,'gd','rup','Aromanais');
INSERT INTO "languageNames" VALUES(3118,'gd','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(3119,'gd','sah','Sakha');
INSERT INTO "languageNames" VALUES(3120,'gd','sc','Sàrdais');
INSERT INTO "languageNames" VALUES(3121,'gd','scn','Sisilis');
INSERT INTO "languageNames" VALUES(3122,'gd','sco','Albais');
INSERT INTO "languageNames" VALUES(3123,'gd','sd','Sindhi');
INSERT INTO "languageNames" VALUES(3124,'gd','se','Sàmais Thuathach');
INSERT INTO "languageNames" VALUES(3125,'gd','sh','Sèirb-Chròthaisis');
INSERT INTO "languageNames" VALUES(3126,'gd','si','Sinhala');
INSERT INTO "languageNames" VALUES(3127,'gd','sk','Slòbhacais');
INSERT INTO "languageNames" VALUES(3128,'gd','sl','Slòbhainis');
INSERT INTO "languageNames" VALUES(3129,'gd','sma','Sàmais Dheasach');
INSERT INTO "languageNames" VALUES(3130,'gd','smj','Sàmais Lule');
INSERT INTO "languageNames" VALUES(3131,'gd','smn','Sàmais Inari');
INSERT INTO "languageNames" VALUES(3132,'gd','sq','Albàinis');
INSERT INTO "languageNames" VALUES(3133,'gd','sr','Sèirbis');
INSERT INTO "languageNames" VALUES(3134,'gd','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(3135,'gd','ss','Swati');
INSERT INTO "languageNames" VALUES(3136,'gd','sv','Suainis');
INSERT INTO "languageNames" VALUES(3137,'gd','sw','Kiswahili');
INSERT INTO "languageNames" VALUES(3138,'gd','ta','Taimilis');
INSERT INTO "languageNames" VALUES(3139,'gd','te','Telugu');
INSERT INTO "languageNames" VALUES(3140,'gd','tet','Tetum');
INSERT INTO "languageNames" VALUES(3141,'gd','tg','Taidigis');
INSERT INTO "languageNames" VALUES(3142,'gd','th','Cànan nan Tàidh');
INSERT INTO "languageNames" VALUES(3143,'gd','tk','Turcmanais');
INSERT INTO "languageNames" VALUES(3144,'gd','tl','Tagalog');
INSERT INTO "languageNames" VALUES(3145,'gd','tr','Turcais');
INSERT INTO "languageNames" VALUES(3146,'gd','tt','Tatarais');
INSERT INTO "languageNames" VALUES(3147,'gd','tyv','Cànan Tuva');
INSERT INTO "languageNames" VALUES(3148,'gd','udm','Udmurt');
INSERT INTO "languageNames" VALUES(3149,'gd','ug','Ùigiurais');
INSERT INTO "languageNames" VALUES(3150,'gd','uk','Ucràinis');
INSERT INTO "languageNames" VALUES(3151,'gd','ur','Ùrdu');
INSERT INTO "languageNames" VALUES(3152,'gd','uz','Usbagais');
INSERT INTO "languageNames" VALUES(3153,'gd','vi','Bhiet-Namais');
INSERT INTO "languageNames" VALUES(3154,'gd','vro','Võro');
INSERT INTO "languageNames" VALUES(3155,'gd','wal','Wolaytta');
INSERT INTO "languageNames" VALUES(3156,'gd','xh','Xhosa');
INSERT INTO "languageNames" VALUES(3157,'gd','yi','Iùdhais');
INSERT INTO "languageNames" VALUES(3158,'gd','yo','Yoruba');
INSERT INTO "languageNames" VALUES(3159,'gd','zh','Sìnis');
INSERT INTO "languageNames" VALUES(3160,'gd','zu','Zulu');
INSERT INTO "languageNames" VALUES(3161,'ar','af','الأفريقانية');
INSERT INTO "languageNames" VALUES(3162,'ar','alt','الألطائية الجنوبية');
INSERT INTO "languageNames" VALUES(3163,'ar','an','الأراغونية');
INSERT INTO "languageNames" VALUES(3164,'ar','ar','العربية');
INSERT INTO "languageNames" VALUES(3165,'ar','as','الأسامية');
INSERT INTO "languageNames" VALUES(3166,'ar','ast','الأسترية');
INSERT INTO "languageNames" VALUES(3167,'ar','av','الأوارية');
INSERT INTO "languageNames" VALUES(3169,'ar','az','الأذرية');
INSERT INTO "languageNames" VALUES(3170,'ar','ba','الباشكيرية');
INSERT INTO "languageNames" VALUES(3171,'ar','be','البيلاروسية');
INSERT INTO "languageNames" VALUES(3172,'ar','bg','البلغارية');
INSERT INTO "languageNames" VALUES(3173,'ar','bi','البيسلامية');
INSERT INTO "languageNames" VALUES(3174,'ar','bn','البنغالية');
INSERT INTO "languageNames" VALUES(3175,'ar','br','البريتونية');
INSERT INTO "languageNames" VALUES(3176,'ar','bs','البوسنية');
INSERT INTO "languageNames" VALUES(3177,'ar','bua','البرياتية');
INSERT INTO "languageNames" VALUES(3178,'ar','byv','لغة الميدومبا');
INSERT INTO "languageNames" VALUES(3179,'ar','ca','الكتالانية');
INSERT INTO "languageNames" VALUES(3180,'ar','ceb','السيبونية');
INSERT INTO "languageNames" VALUES(3181,'ar','chm','الماري');
INSERT INTO "languageNames" VALUES(3182,'ar','ckb','السورانية الكردية');
INSERT INTO "languageNames" VALUES(3183,'ar','co','الكورسيكية');
INSERT INTO "languageNames" VALUES(3184,'ar','crh','لغة تتار القرم');
INSERT INTO "languageNames" VALUES(3185,'ar','cs','التشيكية');
INSERT INTO "languageNames" VALUES(3186,'ar','csb','الكاشبايان');
INSERT INTO "languageNames" VALUES(3187,'ar','cu','سلافية كنسية');
INSERT INTO "languageNames" VALUES(3188,'ar','cv','التشوفاشي');
INSERT INTO "languageNames" VALUES(3189,'ar','cy','الويلزية');
INSERT INTO "languageNames" VALUES(3190,'ar','da','الدانمركية');
INSERT INTO "languageNames" VALUES(3191,'ar','dar','الدارجوا');
INSERT INTO "languageNames" VALUES(3192,'ar','de','الألمانية');
INSERT INTO "languageNames" VALUES(3193,'ar','dsb','صوربيا السفلى');
INSERT INTO "languageNames" VALUES(3194,'ar','el','اليونانية');
INSERT INTO "languageNames" VALUES(3195,'ar','en','الإنجليزية');
INSERT INTO "languageNames" VALUES(3196,'ar','eo','الإسبرانتو');
INSERT INTO "languageNames" VALUES(3197,'ar','es','الإسبانية');
INSERT INTO "languageNames" VALUES(3198,'ar','et','الإستونية');
INSERT INTO "languageNames" VALUES(3199,'ar','eu','الباسكية');
INSERT INTO "languageNames" VALUES(3200,'ar','fa','الفارسية');
INSERT INTO "languageNames" VALUES(3201,'ar','fi','الفنلندية');
INSERT INTO "languageNames" VALUES(3202,'ar','fo','الفاروية');
INSERT INTO "languageNames" VALUES(3203,'ar','fr','الفرنسية');
INSERT INTO "languageNames" VALUES(3204,'ar','fy','الفريزيان');
INSERT INTO "languageNames" VALUES(3205,'ar','ga','الأيرلندية');
INSERT INTO "languageNames" VALUES(3206,'ar','gag','الغاغوز');
INSERT INTO "languageNames" VALUES(3207,'ar','gd','الغيلية الأسكتلندية');
INSERT INTO "languageNames" VALUES(3208,'ar','gl','الجاليكية');
INSERT INTO "languageNames" VALUES(3209,'ar','gn','الغوارانية');
INSERT INTO "languageNames" VALUES(3210,'ar','gu','الغوجاراتية');
INSERT INTO "languageNames" VALUES(3211,'ar','gv','المنكية');
INSERT INTO "languageNames" VALUES(3212,'ar','ha','الهوسا');
INSERT INTO "languageNames" VALUES(3213,'ar','haw','لغة أهل الهاواي');
INSERT INTO "languageNames" VALUES(3214,'ar','he','العبرية');
INSERT INTO "languageNames" VALUES(3215,'ar','hi','الهندية');
INSERT INTO "languageNames" VALUES(3216,'ar','hr','الكرواتية');
INSERT INTO "languageNames" VALUES(3217,'ar','hsb','الصوربية العليا');
INSERT INTO "languageNames" VALUES(3218,'ar','ht','الكريولية الهايتية');
INSERT INTO "languageNames" VALUES(3219,'ar','hu','الهنغارية');
INSERT INTO "languageNames" VALUES(3220,'ar','hy','الأرمنية');
INSERT INTO "languageNames" VALUES(3221,'ar','ia','اللّغة الوسيطة');
INSERT INTO "languageNames" VALUES(3222,'ar','id','الإندونيسية');
INSERT INTO "languageNames" VALUES(3223,'ar','ig','الإيجبو');
INSERT INTO "languageNames" VALUES(3224,'ar','is','الأيسلندية');
INSERT INTO "languageNames" VALUES(3225,'ar','it','الإيطالية');
INSERT INTO "languageNames" VALUES(3226,'ar','ka','الجورجية');
INSERT INTO "languageNames" VALUES(3227,'ar','kaa','الكارا-كالباك');
INSERT INTO "languageNames" VALUES(3228,'ar','kk','الكازاخستانية');
INSERT INTO "languageNames" VALUES(3229,'ar','ko','الكورية');
INSERT INTO "languageNames" VALUES(3230,'ar','krc','الكاراتشاي-بالكار');
INSERT INTO "languageNames" VALUES(3231,'ar','krl','الكاريلية');
INSERT INTO "languageNames" VALUES(3232,'ar','ks','الكشميرية');
INSERT INTO "languageNames" VALUES(3233,'ar','kum','القموقية');
INSERT INTO "languageNames" VALUES(3234,'ar','kv','الكومي');
INSERT INTO "languageNames" VALUES(3235,'ar','ky','القيرغيزية');
INSERT INTO "languageNames" VALUES(3236,'ar','la','اللاتينية');
INSERT INTO "languageNames" VALUES(3237,'ar','lb','اللكسمبورغية');
INSERT INTO "languageNames" VALUES(3238,'ar','lg','الغاندا');
INSERT INTO "languageNames" VALUES(3239,'ar','ln','اللينجالا');
INSERT INTO "languageNames" VALUES(3240,'ar','lo','اللاوية');
INSERT INTO "languageNames" VALUES(3241,'ar','lt','الليتوانية');
INSERT INTO "languageNames" VALUES(3242,'ar','lv','اللاتفية');
INSERT INTO "languageNames" VALUES(3243,'ar','mdf','الموكشا');
INSERT INTO "languageNames" VALUES(3244,'ar','mfe','المورسيانية');
INSERT INTO "languageNames" VALUES(3245,'ar','mk','المقدونية');
INSERT INTO "languageNames" VALUES(3246,'ar','ml','المالايالامية');
INSERT INTO "languageNames" VALUES(3247,'ar','mr','الماراثية');
INSERT INTO "languageNames" VALUES(3248,'ar','ms','الماليزية');
INSERT INTO "languageNames" VALUES(3249,'ar','mt','المالطية');
INSERT INTO "languageNames" VALUES(3250,'ar','myv','الأرزية');
INSERT INTO "languageNames" VALUES(3251,'ar','nap','النابولية');
INSERT INTO "languageNames" VALUES(3252,'ar','nb','بوكمول النرويجية');
INSERT INTO "languageNames" VALUES(3253,'ar','ne','النيبالية');
INSERT INTO "languageNames" VALUES(3254,'ar','nl','الهولندية');
INSERT INTO "languageNames" VALUES(3255,'ar','nn','النرويجية نينورسك');
INSERT INTO "languageNames" VALUES(3256,'ar','no','النرويجية');
INSERT INTO "languageNames" VALUES(3257,'ar','nog','النوجاي');
INSERT INTO "languageNames" VALUES(3258,'ar','oc','الأوكيتانية');
INSERT INTO "languageNames" VALUES(3259,'ar','os','الأوسيتيك');
INSERT INTO "languageNames" VALUES(3260,'ar','ota','التركية العثمانية');
INSERT INTO "languageNames" VALUES(3261,'ar','pa','البنجابية');
INSERT INTO "languageNames" VALUES(3262,'ar','pl','البولندية');
INSERT INTO "languageNames" VALUES(3263,'ar','pt','البرتغالية');
INSERT INTO "languageNames" VALUES(3264,'ar','rm','الرومانشية');
INSERT INTO "languageNames" VALUES(3265,'ar','rn','الرندي');
INSERT INTO "languageNames" VALUES(3266,'ar','ro','الرومانية');
INSERT INTO "languageNames" VALUES(3267,'ar','ru','الروسية');
INSERT INTO "languageNames" VALUES(3268,'ar','rup','الأرومانيان');
INSERT INTO "languageNames" VALUES(3269,'ar','sa','السنسكريتية');
INSERT INTO "languageNames" VALUES(3270,'ar','sah','الساخية');
INSERT INTO "languageNames" VALUES(3271,'ar','sc','السردينية');
INSERT INTO "languageNames" VALUES(3272,'ar','scn','الصقلية');
INSERT INTO "languageNames" VALUES(3273,'ar','sco','الأسكتلندية');
INSERT INTO "languageNames" VALUES(3274,'ar','sd','السندية');
INSERT INTO "languageNames" VALUES(3275,'ar','se','سامي الشمالية');
INSERT INTO "languageNames" VALUES(3276,'ar','sh','صربية-كرواتية');
INSERT INTO "languageNames" VALUES(3277,'ar','si','السنهالية');
INSERT INTO "languageNames" VALUES(3278,'ar','sk','السلوفاكية');
INSERT INTO "languageNames" VALUES(3279,'ar','sl','السلوفانية');
INSERT INTO "languageNames" VALUES(3280,'ar','sma','السامي الجنوبي');
INSERT INTO "languageNames" VALUES(3281,'ar','smj','اللول سامي');
INSERT INTO "languageNames" VALUES(3282,'ar','smn','الإيناري سامي');
INSERT INTO "languageNames" VALUES(3283,'ar','sq','الألبانية');
INSERT INTO "languageNames" VALUES(3284,'ar','sr','الصربية');
INSERT INTO "languageNames" VALUES(3285,'ar','srn','السرانان تونجو');
INSERT INTO "languageNames" VALUES(3286,'ar','ss','السواتي');
INSERT INTO "languageNames" VALUES(3287,'ar','sv','السويدية');
INSERT INTO "languageNames" VALUES(3288,'ar','sw','السواحلية');
INSERT INTO "languageNames" VALUES(3289,'ar','ta','التاميلية');
INSERT INTO "languageNames" VALUES(3290,'ar','te','التيلوغوية');
INSERT INTO "languageNames" VALUES(3291,'ar','tet','التيتم');
INSERT INTO "languageNames" VALUES(3292,'ar','tg','الطاجيكية');
INSERT INTO "languageNames" VALUES(3293,'ar','th','التايلاندية');
INSERT INTO "languageNames" VALUES(3294,'ar','tk','التركمانية');
INSERT INTO "languageNames" VALUES(3295,'ar','tl','التاغالوغية');
INSERT INTO "languageNames" VALUES(3296,'ar','tr','التركية');
INSERT INTO "languageNames" VALUES(3297,'ar','tt','التترية');
INSERT INTO "languageNames" VALUES(3298,'ar','tyv','التوفية');
INSERT INTO "languageNames" VALUES(3299,'ar','udm','الأدمرت');
INSERT INTO "languageNames" VALUES(3301,'ar','ug','الأيغورية');
INSERT INTO "languageNames" VALUES(3302,'ar','uk','الأوكرانية');
INSERT INTO "languageNames" VALUES(3303,'ar','ur','الأوردية');
INSERT INTO "languageNames" VALUES(3304,'ar','uz','الأوزبكية');
INSERT INTO "languageNames" VALUES(3305,'ar','vi','الفيتنامية');
INSERT INTO "languageNames" VALUES(3306,'ar','wal','الولاياتا');
INSERT INTO "languageNames" VALUES(3307,'ar','xh','الخوسا');
INSERT INTO "languageNames" VALUES(3308,'ar','yi','اليديشية');
INSERT INTO "languageNames" VALUES(3309,'ar','yo','اليوروبا');
INSERT INTO "languageNames" VALUES(3310,'ar','zh','الصينية');
INSERT INTO "languageNames" VALUES(3311,'ar','zu','الزولو');
INSERT INTO "languageNames" VALUES(3312,'sl','af','afrikanščina');
INSERT INTO "languageNames" VALUES(3313,'sl','alt','južna altajščina');
INSERT INTO "languageNames" VALUES(3314,'sl','an','aragonščina');
INSERT INTO "languageNames" VALUES(3315,'sl','ar','arabščina');
INSERT INTO "languageNames" VALUES(3316,'sl','as','asamščina');
INSERT INTO "languageNames" VALUES(3317,'sl','ast','asturijščina');
INSERT INTO "languageNames" VALUES(3318,'sl','av','avarščina');
INSERT INTO "languageNames" VALUES(3320,'sl','az','azerščina');
INSERT INTO "languageNames" VALUES(3321,'sl','ba','baškirščina');
INSERT INTO "languageNames" VALUES(3322,'sl','be','beloruščina');
INSERT INTO "languageNames" VALUES(3323,'sl','bg','bolgarščina');
INSERT INTO "languageNames" VALUES(3324,'sl','bi','bislamščina');
INSERT INTO "languageNames" VALUES(3325,'sl','bn','bengalščina');
INSERT INTO "languageNames" VALUES(3326,'sl','br','bretonščina');
INSERT INTO "languageNames" VALUES(3327,'sl','bs','bosanščina');
INSERT INTO "languageNames" VALUES(3328,'sl','bua','burjatščina');
INSERT INTO "languageNames" VALUES(3329,'sl','ca','katalonščina');
INSERT INTO "languageNames" VALUES(3330,'sl','ceb','sebuanščina');
INSERT INTO "languageNames" VALUES(3331,'sl','chm','marijščina');
INSERT INTO "languageNames" VALUES(3332,'sl','ckb','soranska kurdščina');
INSERT INTO "languageNames" VALUES(3333,'sl','co','korziščina');
INSERT INTO "languageNames" VALUES(3334,'sl','crh','krimska tatarščina');
INSERT INTO "languageNames" VALUES(3335,'sl','cs','češčina');
INSERT INTO "languageNames" VALUES(3336,'sl','csb','kašubščina');
INSERT INTO "languageNames" VALUES(3337,'sl','cu','stara cerkvena slovanščina');
INSERT INTO "languageNames" VALUES(3338,'sl','cv','čuvaščina');
INSERT INTO "languageNames" VALUES(3339,'sl','cy','valižanščina');
INSERT INTO "languageNames" VALUES(3340,'sl','da','danščina');
INSERT INTO "languageNames" VALUES(3341,'sl','dar','darginščina');
INSERT INTO "languageNames" VALUES(3342,'sl','de','nemščina');
INSERT INTO "languageNames" VALUES(3343,'sl','dsb','dolnja lužiška srbščina');
INSERT INTO "languageNames" VALUES(3344,'sl','el','grščina');
INSERT INTO "languageNames" VALUES(3345,'sl','en','angleščina');
INSERT INTO "languageNames" VALUES(3346,'sl','eo','esperanto');
INSERT INTO "languageNames" VALUES(3347,'sl','es','španščina');
INSERT INTO "languageNames" VALUES(3348,'sl','et','estonščina');
INSERT INTO "languageNames" VALUES(3349,'sl','eu','baskovščina');
INSERT INTO "languageNames" VALUES(3350,'sl','fa','perzijščina');
INSERT INTO "languageNames" VALUES(3351,'sl','fi','finščina');
INSERT INTO "languageNames" VALUES(3352,'sl','fo','ferščina');
INSERT INTO "languageNames" VALUES(3353,'sl','fr','francoščina');
INSERT INTO "languageNames" VALUES(3354,'sl','fy','zahodna frizijščina');
INSERT INTO "languageNames" VALUES(3355,'sl','ga','irščina');
INSERT INTO "languageNames" VALUES(3356,'sl','gag','gagavščina');
INSERT INTO "languageNames" VALUES(3357,'sl','gd','škotska gelščina');
INSERT INTO "languageNames" VALUES(3358,'sl','gl','galicijščina');
INSERT INTO "languageNames" VALUES(3359,'sl','gn','gvaranijščina');
INSERT INTO "languageNames" VALUES(3360,'sl','gu','gudžaratščina');
INSERT INTO "languageNames" VALUES(3361,'sl','gv','manščina');
INSERT INTO "languageNames" VALUES(3362,'sl','ha','havščina');
INSERT INTO "languageNames" VALUES(3363,'sl','haw','havajščina');
INSERT INTO "languageNames" VALUES(3364,'sl','he','hebrejščina');
INSERT INTO "languageNames" VALUES(3365,'sl','hi','hindujščina');
INSERT INTO "languageNames" VALUES(3366,'sl','hr','hrvaščina');
INSERT INTO "languageNames" VALUES(3367,'sl','hsb','gornja lužiška srbščina');
INSERT INTO "languageNames" VALUES(3368,'sl','ht','haitijska kreolščina');
INSERT INTO "languageNames" VALUES(3369,'sl','hu','madžarščina');
INSERT INTO "languageNames" VALUES(3370,'sl','hy','armenščina');
INSERT INTO "languageNames" VALUES(3371,'sl','ia','interlingva');
INSERT INTO "languageNames" VALUES(3372,'sl','id','indonezijščina');
INSERT INTO "languageNames" VALUES(3373,'sl','ig','igboščina');
INSERT INTO "languageNames" VALUES(3374,'sl','is','islandščina');
INSERT INTO "languageNames" VALUES(3375,'sl','it','italijanščina');
INSERT INTO "languageNames" VALUES(3376,'sl','ka','gruzijščina');
INSERT INTO "languageNames" VALUES(3377,'sl','kaa','karakalpaščina');
INSERT INTO "languageNames" VALUES(3378,'sl','kk','kazaščina');
INSERT INTO "languageNames" VALUES(3379,'sl','ko','korejščina');
INSERT INTO "languageNames" VALUES(3380,'sl','krc','karačaj-balkarščina');
INSERT INTO "languageNames" VALUES(3381,'sl','krl','karelščina');
INSERT INTO "languageNames" VALUES(3382,'sl','ks','kašmirščina');
INSERT INTO "languageNames" VALUES(3383,'sl','kum','kumiščina');
INSERT INTO "languageNames" VALUES(3384,'sl','kv','komijščina');
INSERT INTO "languageNames" VALUES(3385,'sl','ky','kirgiščina');
INSERT INTO "languageNames" VALUES(3386,'sl','la','latinščina');
INSERT INTO "languageNames" VALUES(3387,'sl','lb','luksemburščina');
INSERT INTO "languageNames" VALUES(3388,'sl','lg','ganda');
INSERT INTO "languageNames" VALUES(3389,'sl','ln','lingala');
INSERT INTO "languageNames" VALUES(3390,'sl','lo','laoščina');
INSERT INTO "languageNames" VALUES(3391,'sl','lt','litovščina');
INSERT INTO "languageNames" VALUES(3392,'sl','lv','latvijščina');
INSERT INTO "languageNames" VALUES(3393,'sl','mdf','mokšavščina');
INSERT INTO "languageNames" VALUES(3394,'sl','mfe','morisjenščina');
INSERT INTO "languageNames" VALUES(3395,'sl','mk','makedonščina');
INSERT INTO "languageNames" VALUES(3396,'sl','ml','malajalamščina');
INSERT INTO "languageNames" VALUES(3397,'sl','mr','maratščina');
INSERT INTO "languageNames" VALUES(3398,'sl','ms','malajščina');
INSERT INTO "languageNames" VALUES(3399,'sl','mt','malteščina');
INSERT INTO "languageNames" VALUES(3400,'sl','myv','erzjanščina');
INSERT INTO "languageNames" VALUES(3401,'sl','nap','napolitanščina');
INSERT INTO "languageNames" VALUES(3402,'sl','nb','knjižna norveščina');
INSERT INTO "languageNames" VALUES(3403,'sl','ne','nepalščina');
INSERT INTO "languageNames" VALUES(3404,'sl','nl','nizozemščina');
INSERT INTO "languageNames" VALUES(3405,'sl','nn','novonorveščina');
INSERT INTO "languageNames" VALUES(3406,'sl','no','norveščina');
INSERT INTO "languageNames" VALUES(3407,'sl','nog','nogajščina');
INSERT INTO "languageNames" VALUES(3408,'sl','oc','okcitanščina');
INSERT INTO "languageNames" VALUES(3409,'sl','os','osetinščina');
INSERT INTO "languageNames" VALUES(3410,'sl','ota','otomanska turščina');
INSERT INTO "languageNames" VALUES(3411,'sl','pa','pandžabščina');
INSERT INTO "languageNames" VALUES(3412,'sl','pl','poljščina');
INSERT INTO "languageNames" VALUES(3413,'sl','pt','portugalščina');
INSERT INTO "languageNames" VALUES(3414,'sl','rm','retoromanščina');
INSERT INTO "languageNames" VALUES(3415,'sl','rn','rundščina');
INSERT INTO "languageNames" VALUES(3416,'sl','ro','romunščina');
INSERT INTO "languageNames" VALUES(3417,'sl','ru','ruščina');
INSERT INTO "languageNames" VALUES(3418,'sl','rup','aromunščina');
INSERT INTO "languageNames" VALUES(3419,'sl','sa','sanskrt');
INSERT INTO "languageNames" VALUES(3420,'sl','sah','jakutščina');
INSERT INTO "languageNames" VALUES(3421,'sl','sc','sardinščina');
INSERT INTO "languageNames" VALUES(3422,'sl','scn','sicilijanščina');
INSERT INTO "languageNames" VALUES(3423,'sl','sco','škotščina');
INSERT INTO "languageNames" VALUES(3424,'sl','sd','sindščina');
INSERT INTO "languageNames" VALUES(3425,'sl','se','severna samijščina');
INSERT INTO "languageNames" VALUES(3426,'sl','sh','srbohrvaščina');
INSERT INTO "languageNames" VALUES(3427,'sl','si','sinhalščina');
INSERT INTO "languageNames" VALUES(3428,'sl','sk','slovaščina');
INSERT INTO "languageNames" VALUES(3429,'sl','sl','slovenščina');
INSERT INTO "languageNames" VALUES(3430,'sl','sma','južna samijščina');
INSERT INTO "languageNames" VALUES(3431,'sl','smj','luleška samijščina');
INSERT INTO "languageNames" VALUES(3432,'sl','smn','inarska samijščina');
INSERT INTO "languageNames" VALUES(3433,'sl','sq','albanščina');
INSERT INTO "languageNames" VALUES(3434,'sl','sr','srbščina');
INSERT INTO "languageNames" VALUES(3435,'sl','srn','surinamska kreolščina');
INSERT INTO "languageNames" VALUES(3436,'sl','ss','svazijščina');
INSERT INTO "languageNames" VALUES(3437,'sl','sv','švedščina');
INSERT INTO "languageNames" VALUES(3438,'sl','sw','svahili');
INSERT INTO "languageNames" VALUES(3439,'sl','ta','tamilščina');
INSERT INTO "languageNames" VALUES(3440,'sl','te','telugijščina');
INSERT INTO "languageNames" VALUES(3441,'sl','tet','tetumščina');
INSERT INTO "languageNames" VALUES(3442,'sl','tg','tadžiščina');
INSERT INTO "languageNames" VALUES(3443,'sl','th','tajščina');
INSERT INTO "languageNames" VALUES(3444,'sl','tk','turkmenščina');
INSERT INTO "languageNames" VALUES(3445,'sl','tl','tagalogščina');
INSERT INTO "languageNames" VALUES(3446,'sl','tr','turščina');
INSERT INTO "languageNames" VALUES(3447,'sl','tt','tatarščina');
INSERT INTO "languageNames" VALUES(3448,'sl','tyv','tuvinščina');
INSERT INTO "languageNames" VALUES(3449,'sl','udm','udmurtščina');
INSERT INTO "languageNames" VALUES(3450,'sl','ug','ujgurščina');
INSERT INTO "languageNames" VALUES(3451,'sl','uk','ukrajinščina');
INSERT INTO "languageNames" VALUES(3452,'sl','ur','urdujščina');
INSERT INTO "languageNames" VALUES(3453,'sl','uz','uzbeščina');
INSERT INTO "languageNames" VALUES(3454,'sl','vi','vietnamščina');
INSERT INTO "languageNames" VALUES(3455,'sl','wal','valamščina');
INSERT INTO "languageNames" VALUES(3456,'sl','xh','koščina');
INSERT INTO "languageNames" VALUES(3457,'sl','yi','jidiš');
INSERT INTO "languageNames" VALUES(3458,'sl','yo','jorubščina');
INSERT INTO "languageNames" VALUES(3459,'sl','zh','kitajščina');
INSERT INTO "languageNames" VALUES(3460,'sl','zu','zulujščina');
INSERT INTO "languageNames" VALUES(3461,'hsb','af','afrikaanšćina');
INSERT INTO "languageNames" VALUES(3462,'hsb','an','aragonšćina');
INSERT INTO "languageNames" VALUES(3463,'hsb','ar','arabšćina');
INSERT INTO "languageNames" VALUES(3464,'hsb','as','asamšćina');
INSERT INTO "languageNames" VALUES(3465,'hsb','ast','asturšćina');
INSERT INTO "languageNames" VALUES(3466,'hsb','av','awaršćina');
INSERT INTO "languageNames" VALUES(3467,'hsb','az','azerbajdźanšćina');
INSERT INTO "languageNames" VALUES(3468,'hsb','ba','baškiršćina');
INSERT INTO "languageNames" VALUES(3469,'hsb','be','běłorušćina');
INSERT INTO "languageNames" VALUES(3470,'hsb','bg','bołharšćina');
INSERT INTO "languageNames" VALUES(3471,'hsb','bi','bislamšćina');
INSERT INTO "languageNames" VALUES(3472,'hsb','bn','bengalšćina');
INSERT INTO "languageNames" VALUES(3473,'hsb','br','bretonšćina');
INSERT INTO "languageNames" VALUES(3474,'hsb','bs','bosnišćina');
INSERT INTO "languageNames" VALUES(3475,'hsb','ca','katalanšćina');
INSERT INTO "languageNames" VALUES(3476,'hsb','ckb','sorani');
INSERT INTO "languageNames" VALUES(3477,'hsb','co','korsišćina');
INSERT INTO "languageNames" VALUES(3478,'hsb','cs','čěšćina');
INSERT INTO "languageNames" VALUES(3479,'hsb','cy','walizišćina');
INSERT INTO "languageNames" VALUES(3480,'hsb','da','danšćina');
INSERT INTO "languageNames" VALUES(3481,'hsb','de','němčina');
INSERT INTO "languageNames" VALUES(3482,'hsb','dsb','delnjoserbšćina');
INSERT INTO "languageNames" VALUES(3483,'hsb','el','grjekšćina');
INSERT INTO "languageNames" VALUES(3484,'hsb','en','jendźelšćina');
INSERT INTO "languageNames" VALUES(3485,'hsb','eo','esperanto');
INSERT INTO "languageNames" VALUES(3486,'hsb','es','španišćina');
INSERT INTO "languageNames" VALUES(3487,'hsb','et','estišćina');
INSERT INTO "languageNames" VALUES(3488,'hsb','eu','baskišćina');
INSERT INTO "languageNames" VALUES(3489,'hsb','fa','persišćina');
INSERT INTO "languageNames" VALUES(3490,'hsb','fi','finšćina');
INSERT INTO "languageNames" VALUES(3491,'hsb','fo','färöšćina');
INSERT INTO "languageNames" VALUES(3492,'hsb','fr','francošćina');
INSERT INTO "languageNames" VALUES(3493,'hsb','fy','frizišćina');
INSERT INTO "languageNames" VALUES(3494,'hsb','ga','iršćina');
INSERT INTO "languageNames" VALUES(3495,'hsb','gag','gagauzišćina');
INSERT INTO "languageNames" VALUES(3496,'hsb','gd','šotiska gelšćina');
INSERT INTO "languageNames" VALUES(3497,'hsb','gl','galicišćina');
INSERT INTO "languageNames" VALUES(3498,'hsb','gn','guarani');
INSERT INTO "languageNames" VALUES(3499,'hsb','gu','gujarati');
INSERT INTO "languageNames" VALUES(3500,'hsb','gv','manšćina');
INSERT INTO "languageNames" VALUES(3501,'hsb','ha','hausa');
INSERT INTO "languageNames" VALUES(3502,'hsb','haw','hawaiišćina');
INSERT INTO "languageNames" VALUES(3503,'hsb','he','hebrejšćina');
INSERT INTO "languageNames" VALUES(3504,'hsb','hi','hindišćina');
INSERT INTO "languageNames" VALUES(3505,'hsb','hr','chorwatšćina');
INSERT INTO "languageNames" VALUES(3506,'hsb','hsb','hornjoserbšćina');
INSERT INTO "languageNames" VALUES(3507,'hsb','ht','haitišćina');
INSERT INTO "languageNames" VALUES(3508,'hsb','hu','madźaršćina');
INSERT INTO "languageNames" VALUES(3509,'hsb','hy','armenšćina');
INSERT INTO "languageNames" VALUES(3510,'hsb','ia','interlingua');
INSERT INTO "languageNames" VALUES(3511,'hsb','id','indonešćina');
INSERT INTO "languageNames" VALUES(3512,'hsb','ig','igbo');
INSERT INTO "languageNames" VALUES(3513,'hsb','is','islandšćina');
INSERT INTO "languageNames" VALUES(3514,'hsb','it','italšćina');
INSERT INTO "languageNames" VALUES(3515,'hsb','ka','georgišćina');
INSERT INTO "languageNames" VALUES(3516,'hsb','kk','kazachšćina');
INSERT INTO "languageNames" VALUES(3517,'hsb','ko','korejšćina');
INSERT INTO "languageNames" VALUES(3518,'hsb','ks','kašmiršćina');
INSERT INTO "languageNames" VALUES(3519,'hsb','ky','kirgišćina');
INSERT INTO "languageNames" VALUES(3520,'hsb','la','łaćonšćina');
INSERT INTO "languageNames" VALUES(3521,'hsb','lb','luxemburgšćina');
INSERT INTO "languageNames" VALUES(3522,'hsb','lg','gandšćina');
INSERT INTO "languageNames" VALUES(3523,'hsb','ln','lingala');
INSERT INTO "languageNames" VALUES(3524,'hsb','lo','laošćina');
INSERT INTO "languageNames" VALUES(3525,'hsb','lt','litawšćina');
INSERT INTO "languageNames" VALUES(3526,'hsb','lv','letišćina');
INSERT INTO "languageNames" VALUES(3527,'hsb','mfe','mauriciska kreolšćina');
INSERT INTO "languageNames" VALUES(3528,'hsb','mk','makedonšćina');
INSERT INTO "languageNames" VALUES(3529,'hsb','ml','malajamšćina');
INSERT INTO "languageNames" VALUES(3530,'hsb','mr','maratišćina');
INSERT INTO "languageNames" VALUES(3531,'hsb','ms','malajšćina');
INSERT INTO "languageNames" VALUES(3532,'hsb','mt','maltašćina');
INSERT INTO "languageNames" VALUES(3533,'hsb','nb','norwegšćina (bokmål)');
INSERT INTO "languageNames" VALUES(3534,'hsb','ne','nepalšćina');
INSERT INTO "languageNames" VALUES(3535,'hsb','nl','nižozemšćina');
INSERT INTO "languageNames" VALUES(3536,'hsb','nn','norwegšćina (nynorsk)');
INSERT INTO "languageNames" VALUES(3537,'hsb','no','norwegšćina');
INSERT INTO "languageNames" VALUES(3538,'hsb','oc','okcitanšćina');
INSERT INTO "languageNames" VALUES(3539,'hsb','pa','pandźabšćina');
INSERT INTO "languageNames" VALUES(3540,'hsb','pl','pólšćina');
INSERT INTO "languageNames" VALUES(3541,'hsb','pt','portugalšćina');
INSERT INTO "languageNames" VALUES(3542,'hsb','rm','retoromanšćina');
INSERT INTO "languageNames" VALUES(3543,'hsb','rn','kirundišćina');
INSERT INTO "languageNames" VALUES(3544,'hsb','ro','rumunšćina');
INSERT INTO "languageNames" VALUES(3545,'hsb','ru','rušćina');
INSERT INTO "languageNames" VALUES(3546,'hsb','sa','sanskrit');
INSERT INTO "languageNames" VALUES(3547,'hsb','sc','sardinšćina');
INSERT INTO "languageNames" VALUES(3548,'hsb','scn','sicilšćina');
INSERT INTO "languageNames" VALUES(3549,'hsb','sd','sindhišćina');
INSERT INTO "languageNames" VALUES(3550,'hsb','se','sewjerosamišćina');
INSERT INTO "languageNames" VALUES(3551,'hsb','sh','serbochorwatšćina');
INSERT INTO "languageNames" VALUES(3552,'hsb','si','singhalšćina');
INSERT INTO "languageNames" VALUES(3553,'hsb','sk','słowakšćina');
INSERT INTO "languageNames" VALUES(3554,'hsb','sl','słowjenšćina');
INSERT INTO "languageNames" VALUES(3555,'hsb','sma','južnosamišćina');
INSERT INTO "languageNames" VALUES(3556,'hsb','smj','lule-samišćina');
INSERT INTO "languageNames" VALUES(3557,'hsb','smn','inari-samišćina');
INSERT INTO "languageNames" VALUES(3558,'hsb','sq','albanšćina');
INSERT INTO "languageNames" VALUES(3559,'hsb','sr','serbišćina');
INSERT INTO "languageNames" VALUES(3560,'hsb','ss','siswati');
INSERT INTO "languageNames" VALUES(3561,'hsb','sv','šwedšćina');
INSERT INTO "languageNames" VALUES(3562,'hsb','sw','suahelšćina');
INSERT INTO "languageNames" VALUES(3563,'hsb','ta','tamilšćina');
INSERT INTO "languageNames" VALUES(3564,'hsb','te','telugu');
INSERT INTO "languageNames" VALUES(3565,'hsb','tg','tadźikšćina');
INSERT INTO "languageNames" VALUES(3566,'hsb','th','thailandšćina');
INSERT INTO "languageNames" VALUES(3567,'hsb','tk','turkmenšćina');
INSERT INTO "languageNames" VALUES(3568,'hsb','tl','tagalog');
INSERT INTO "languageNames" VALUES(3569,'hsb','tr','turkowšćina');
INSERT INTO "languageNames" VALUES(3570,'hsb','tt','tataršćina');
INSERT INTO "languageNames" VALUES(3571,'hsb','ug','ujguršćina');
INSERT INTO "languageNames" VALUES(3572,'hsb','uk','ukrainšćina');
INSERT INTO "languageNames" VALUES(3573,'hsb','ur','urdušćina');
INSERT INTO "languageNames" VALUES(3574,'hsb','uz','uzbekšćina');
INSERT INTO "languageNames" VALUES(3575,'hsb','vi','vietnamšćina');
INSERT INTO "languageNames" VALUES(3576,'hsb','xh','xhosa');
INSERT INTO "languageNames" VALUES(3577,'hsb','yi','jidišćina');
INSERT INTO "languageNames" VALUES(3578,'hsb','yo','jorubašćina');
INSERT INTO "languageNames" VALUES(3579,'hsb','zh','chinšćina');
INSERT INTO "languageNames" VALUES(3580,'hsb','zu','zulušćina');
INSERT INTO "languageNames" VALUES(3581,'nl','af','Afrikaans');
INSERT INTO "languageNames" VALUES(3582,'nl','alt','Zuid-Altaïsch');
INSERT INTO "languageNames" VALUES(3583,'nl','an','Aragonees');
INSERT INTO "languageNames" VALUES(3584,'nl','ar','Arabisch');
INSERT INTO "languageNames" VALUES(3585,'nl','as','Assamees');
INSERT INTO "languageNames" VALUES(3586,'nl','ast','Asturisch');
INSERT INTO "languageNames" VALUES(3587,'nl','av','Avarisch');
INSERT INTO "languageNames" VALUES(3589,'nl','az','Azeri');
INSERT INTO "languageNames" VALUES(3590,'nl','ba','Basjkiers');
INSERT INTO "languageNames" VALUES(3591,'nl','be','Wit-Russisch');
INSERT INTO "languageNames" VALUES(3592,'nl','bg','Bulgaars');
INSERT INTO "languageNames" VALUES(3593,'nl','bi','Bislama');
INSERT INTO "languageNames" VALUES(3594,'nl','bn','Bengaals');
INSERT INTO "languageNames" VALUES(3595,'nl','br','Bretons');
INSERT INTO "languageNames" VALUES(3596,'nl','bs','Bosnisch');
INSERT INTO "languageNames" VALUES(3597,'nl','bua','Boerjatisch');
INSERT INTO "languageNames" VALUES(3598,'nl','byv','Medumba');
INSERT INTO "languageNames" VALUES(3599,'nl','ca','Catalaans');
INSERT INTO "languageNames" VALUES(3600,'nl','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(3601,'nl','chm','Mari');
INSERT INTO "languageNames" VALUES(3602,'nl','ckb','Soranî');
INSERT INTO "languageNames" VALUES(3603,'nl','co','Corsicaans');
INSERT INTO "languageNames" VALUES(3604,'nl','crh','Krim-Tataars');
INSERT INTO "languageNames" VALUES(3605,'nl','cs','Tsjechisch');
INSERT INTO "languageNames" VALUES(3606,'nl','csb','Kasjoebisch');
INSERT INTO "languageNames" VALUES(3607,'nl','cu','Kerkslavisch');
INSERT INTO "languageNames" VALUES(3608,'nl','cv','Tsjoevasjisch');
INSERT INTO "languageNames" VALUES(3609,'nl','cy','Welsh');
INSERT INTO "languageNames" VALUES(3610,'nl','da','Deens');
INSERT INTO "languageNames" VALUES(3611,'nl','dar','Dargwa');
INSERT INTO "languageNames" VALUES(3612,'nl','de','Duits');
INSERT INTO "languageNames" VALUES(3613,'nl','dsb','Nedersorbisch');
INSERT INTO "languageNames" VALUES(3614,'nl','el','Grieks');
INSERT INTO "languageNames" VALUES(3615,'nl','en','Engels');
INSERT INTO "languageNames" VALUES(3616,'nl','eo','Esperanto');
INSERT INTO "languageNames" VALUES(3617,'nl','es','Spaans');
INSERT INTO "languageNames" VALUES(3618,'nl','et','Estisch');
INSERT INTO "languageNames" VALUES(3619,'nl','eu','Baskisch');
INSERT INTO "languageNames" VALUES(3620,'nl','fa','Perzisch');
INSERT INTO "languageNames" VALUES(3621,'nl','fi','Fins');
INSERT INTO "languageNames" VALUES(3622,'nl','fo','Faeröers');
INSERT INTO "languageNames" VALUES(3623,'nl','fr','Frans');
INSERT INTO "languageNames" VALUES(3624,'nl','fy','Fries');
INSERT INTO "languageNames" VALUES(3625,'nl','ga','Iers');
INSERT INTO "languageNames" VALUES(3626,'nl','gag','Gagaoezisch');
INSERT INTO "languageNames" VALUES(3627,'nl','gd','Schots-Gaelisch');
INSERT INTO "languageNames" VALUES(3628,'nl','gl','Galicisch');
INSERT INTO "languageNames" VALUES(3629,'nl','glk','Gilaki');
INSERT INTO "languageNames" VALUES(3630,'nl','gn','Guaraní');
INSERT INTO "languageNames" VALUES(3631,'nl','gu','Gujarati');
INSERT INTO "languageNames" VALUES(3632,'nl','guc','Wayuu');
INSERT INTO "languageNames" VALUES(3633,'nl','gv','Manx');
INSERT INTO "languageNames" VALUES(3634,'nl','ha','Hausa');
INSERT INTO "languageNames" VALUES(3635,'nl','haw','Hawaïaans');
INSERT INTO "languageNames" VALUES(3636,'nl','he','Hebreeuws');
INSERT INTO "languageNames" VALUES(3637,'nl','hi','Hindi');
INSERT INTO "languageNames" VALUES(3638,'nl','hr','Kroatisch');
INSERT INTO "languageNames" VALUES(3639,'nl','hsb','Oppersorbisch');
INSERT INTO "languageNames" VALUES(3640,'nl','ht','Haïtiaans Creools');
INSERT INTO "languageNames" VALUES(3641,'nl','hu','Hongaars');
INSERT INTO "languageNames" VALUES(3642,'nl','hy','Armeens');
INSERT INTO "languageNames" VALUES(3643,'nl','ia','Interlingua');
INSERT INTO "languageNames" VALUES(3644,'nl','id','Indonesisch');
INSERT INTO "languageNames" VALUES(3645,'nl','ig','Igbo');
INSERT INTO "languageNames" VALUES(3646,'nl','is','IJslands');
INSERT INTO "languageNames" VALUES(3647,'nl','it','Italiaans');
INSERT INTO "languageNames" VALUES(3648,'nl','ka','Georgisch');
INSERT INTO "languageNames" VALUES(3649,'nl','kaa','Karakalpaks');
INSERT INTO "languageNames" VALUES(3650,'nl','kk','Kazachs');
INSERT INTO "languageNames" VALUES(3651,'nl','ko','Koreaans');
INSERT INTO "languageNames" VALUES(3652,'nl','krc','Karatsjaj-Balkarisch');
INSERT INTO "languageNames" VALUES(3653,'nl','krl','Karelisch');
INSERT INTO "languageNames" VALUES(3654,'nl','ks','Kasjmiri');
INSERT INTO "languageNames" VALUES(3655,'nl','kum','Koemuks');
INSERT INTO "languageNames" VALUES(3656,'nl','kv','Komi');
INSERT INTO "languageNames" VALUES(3657,'nl','ky','Kirgizisch');
INSERT INTO "languageNames" VALUES(3658,'nl','la','Latijn');
INSERT INTO "languageNames" VALUES(3659,'nl','lb','Luxemburgs');
INSERT INTO "languageNames" VALUES(3660,'nl','lg','Luganda');
INSERT INTO "languageNames" VALUES(3661,'nl','liv','Lijfs');
INSERT INTO "languageNames" VALUES(3662,'nl','ln','Lingala');
INSERT INTO "languageNames" VALUES(3663,'nl','lo','Laotiaans');
INSERT INTO "languageNames" VALUES(3664,'nl','lt','Litouws');
INSERT INTO "languageNames" VALUES(3665,'nl','lv','Lets');
INSERT INTO "languageNames" VALUES(3666,'nl','mdf','Moksja');
INSERT INTO "languageNames" VALUES(3667,'nl','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(3668,'nl','mk','Macedonisch');
INSERT INTO "languageNames" VALUES(3669,'nl','ml','Malayalam');
INSERT INTO "languageNames" VALUES(3670,'nl','mr','Marathi');
INSERT INTO "languageNames" VALUES(3671,'nl','mrj','West-Mari');
INSERT INTO "languageNames" VALUES(3672,'nl','ms','Maleis');
INSERT INTO "languageNames" VALUES(3673,'nl','mt','Maltees');
INSERT INTO "languageNames" VALUES(3674,'nl','myv','Erzja');
INSERT INTO "languageNames" VALUES(3675,'nl','nap','Napolitaans');
INSERT INTO "languageNames" VALUES(3676,'nl','nb','Noors - Bokmål');
INSERT INTO "languageNames" VALUES(3677,'nl','ne','Nepalees');
INSERT INTO "languageNames" VALUES(3678,'nl','nl','Nederlands');
INSERT INTO "languageNames" VALUES(3679,'nl','nn','Noors - Nynorsk');
INSERT INTO "languageNames" VALUES(3680,'nl','no','Noors');
INSERT INTO "languageNames" VALUES(3681,'nl','nog','Nogai');
INSERT INTO "languageNames" VALUES(3682,'nl','oc','Occitaans');
INSERT INTO "languageNames" VALUES(3683,'nl','os','Ossetisch');
INSERT INTO "languageNames" VALUES(3684,'nl','ota','Ottomaans-Turks');
INSERT INTO "languageNames" VALUES(3685,'nl','pa','Punjabi');
INSERT INTO "languageNames" VALUES(3686,'nl','pl','Pools');
INSERT INTO "languageNames" VALUES(3687,'nl','pt','Portugees');
INSERT INTO "languageNames" VALUES(3688,'nl','rm','Reto-Romaans');
INSERT INTO "languageNames" VALUES(3689,'nl','rn','Kirundi');
INSERT INTO "languageNames" VALUES(3690,'nl','ro','Roemeens');
INSERT INTO "languageNames" VALUES(3691,'nl','ru','Russisch');
INSERT INTO "languageNames" VALUES(3692,'nl','rup','Aroemeens');
INSERT INTO "languageNames" VALUES(3693,'nl','sa','Sanskriet');
INSERT INTO "languageNames" VALUES(3694,'nl','sah','Jakoets');
INSERT INTO "languageNames" VALUES(3695,'nl','sc','Sardijns');
INSERT INTO "languageNames" VALUES(3696,'nl','scn','Siciliaans');
INSERT INTO "languageNames" VALUES(3697,'nl','sco','Schots');
INSERT INTO "languageNames" VALUES(3698,'nl','sd','Sindhi');
INSERT INTO "languageNames" VALUES(3699,'nl','se','Noord-Samisch');
INSERT INTO "languageNames" VALUES(3700,'nl','sh','Servo-Kroatisch');
INSERT INTO "languageNames" VALUES(3701,'nl','si','Singalees');
INSERT INTO "languageNames" VALUES(3702,'nl','sk','Slowaaks');
INSERT INTO "languageNames" VALUES(3703,'nl','sl','Sloveens');
INSERT INTO "languageNames" VALUES(3704,'nl','sma','Zuid-Samisch');
INSERT INTO "languageNames" VALUES(3705,'nl','smj','Lule-Samisch');
INSERT INTO "languageNames" VALUES(3706,'nl','smn','Inari-Samisch');
INSERT INTO "languageNames" VALUES(3707,'nl','sq','Albanees');
INSERT INTO "languageNames" VALUES(3708,'nl','sr','Servisch');
INSERT INTO "languageNames" VALUES(3709,'nl','srn','Sranantongo');
INSERT INTO "languageNames" VALUES(3710,'nl','ss','Swazi');
INSERT INTO "languageNames" VALUES(3711,'nl','sv','Zweeds');
INSERT INTO "languageNames" VALUES(3712,'nl','sw','Swahili');
INSERT INTO "languageNames" VALUES(3713,'nl','ta','Tamil');
INSERT INTO "languageNames" VALUES(3714,'nl','te','Telugu');
INSERT INTO "languageNames" VALUES(3715,'nl','tet','Tetun');
INSERT INTO "languageNames" VALUES(3716,'nl','tg','Tadzjieks');
INSERT INTO "languageNames" VALUES(3717,'nl','th','Thai');
INSERT INTO "languageNames" VALUES(3718,'nl','tk','Turkmeens');
INSERT INTO "languageNames" VALUES(3719,'nl','tl','Tagalog');
INSERT INTO "languageNames" VALUES(3720,'nl','tr','Turks');
INSERT INTO "languageNames" VALUES(3721,'nl','tt','Tataars');
INSERT INTO "languageNames" VALUES(3722,'nl','tyv','Toevaans');
INSERT INTO "languageNames" VALUES(3723,'nl','udm','Oedmoerts');
INSERT INTO "languageNames" VALUES(3724,'nl','ug','Oeigoers');
INSERT INTO "languageNames" VALUES(3725,'nl','uk','Oekraïens');
INSERT INTO "languageNames" VALUES(3726,'nl','ur','Urdu');
INSERT INTO "languageNames" VALUES(3727,'nl','uz','Oezbeeks');
INSERT INTO "languageNames" VALUES(3728,'nl','vi','Vietnamees');
INSERT INTO "languageNames" VALUES(3729,'nl','vro','Võro');
INSERT INTO "languageNames" VALUES(3730,'nl','wal','Wolaytta');
INSERT INTO "languageNames" VALUES(3731,'nl','xh','Xhosa');
INSERT INTO "languageNames" VALUES(3732,'nl','yi','Jiddisch');
INSERT INTO "languageNames" VALUES(3733,'nl','yo','Yoruba');
INSERT INTO "languageNames" VALUES(3734,'nl','zh','Chinees');
INSERT INTO "languageNames" VALUES(3735,'nl','zu','Zoeloe');
INSERT INTO "languageNames" VALUES(3736,'rm','af','afrikaans');
INSERT INTO "languageNames" VALUES(3737,'rm','alt','altaic dal sid');
INSERT INTO "languageNames" VALUES(3738,'rm','an','aragonais');
INSERT INTO "languageNames" VALUES(3739,'rm','ar','arab');
INSERT INTO "languageNames" VALUES(3740,'rm','as','assami');
INSERT INTO "languageNames" VALUES(3741,'rm','ast','asturian');
INSERT INTO "languageNames" VALUES(3742,'rm','av','avaric');
INSERT INTO "languageNames" VALUES(3743,'rm','az','aserbeidschanic');
INSERT INTO "languageNames" VALUES(3744,'rm','ba','baschkir');
INSERT INTO "languageNames" VALUES(3745,'rm','be','bieloruss');
INSERT INTO "languageNames" VALUES(3746,'rm','bg','bulgar');
INSERT INTO "languageNames" VALUES(3747,'rm','bi','bislama');
INSERT INTO "languageNames" VALUES(3748,'rm','bn','bengal');
INSERT INTO "languageNames" VALUES(3749,'rm','br','breton');
INSERT INTO "languageNames" VALUES(3750,'rm','bs','bosniac');
INSERT INTO "languageNames" VALUES(3751,'rm','bua','buriat');
INSERT INTO "languageNames" VALUES(3752,'rm','ca','catalan');
INSERT INTO "languageNames" VALUES(3753,'rm','ceb','cebuano');
INSERT INTO "languageNames" VALUES(3754,'rm','chm','mari');
INSERT INTO "languageNames" VALUES(3755,'rm','co','cors');
INSERT INTO "languageNames" VALUES(3756,'rm','crh','tirc crimean');
INSERT INTO "languageNames" VALUES(3757,'rm','cs','tschec');
INSERT INTO "languageNames" VALUES(3758,'rm','csb','kaschubic');
INSERT INTO "languageNames" VALUES(3759,'rm','cu','slav da baselgia');
INSERT INTO "languageNames" VALUES(3760,'rm','cv','tschuvasch');
INSERT INTO "languageNames" VALUES(3761,'rm','cy','kimric');
INSERT INTO "languageNames" VALUES(3762,'rm','da','danais');
INSERT INTO "languageNames" VALUES(3763,'rm','dar','dargwa');
INSERT INTO "languageNames" VALUES(3764,'rm','de','tudestg');
INSERT INTO "languageNames" VALUES(3765,'rm','dsb','bass sorb');
INSERT INTO "languageNames" VALUES(3766,'rm','el','grec');
INSERT INTO "languageNames" VALUES(3767,'rm','en','englais');
INSERT INTO "languageNames" VALUES(3768,'rm','eo','esperanto');
INSERT INTO "languageNames" VALUES(3769,'rm','es','spagnol');
INSERT INTO "languageNames" VALUES(3770,'rm','et','eston');
INSERT INTO "languageNames" VALUES(3771,'rm','eu','basc');
INSERT INTO "languageNames" VALUES(3772,'rm','fa','persian');
INSERT INTO "languageNames" VALUES(3773,'rm','fi','finlandais');
INSERT INTO "languageNames" VALUES(3774,'rm','fo','ferrais');
INSERT INTO "languageNames" VALUES(3775,'rm','fr','franzos');
INSERT INTO "languageNames" VALUES(3776,'rm','fy','fris');
INSERT INTO "languageNames" VALUES(3777,'rm','ga','irlandais');
INSERT INTO "languageNames" VALUES(3778,'rm','gd','gaelic scot');
INSERT INTO "languageNames" VALUES(3779,'rm','gl','galician');
INSERT INTO "languageNames" VALUES(3780,'rm','gn','guarani');
INSERT INTO "languageNames" VALUES(3781,'rm','gu','gujarati');
INSERT INTO "languageNames" VALUES(3782,'rm','gv','manx');
INSERT INTO "languageNames" VALUES(3783,'rm','ha','haussa');
INSERT INTO "languageNames" VALUES(3784,'rm','haw','hawaian');
INSERT INTO "languageNames" VALUES(3785,'rm','he','ebraic');
INSERT INTO "languageNames" VALUES(3786,'rm','hi','hindi');
INSERT INTO "languageNames" VALUES(3787,'rm','hr','croat');
INSERT INTO "languageNames" VALUES(3788,'rm','hsb','aut sorb');
INSERT INTO "languageNames" VALUES(3789,'rm','ht','haitian');
INSERT INTO "languageNames" VALUES(3790,'rm','hu','ungarais');
INSERT INTO "languageNames" VALUES(3791,'rm','hy','armen');
INSERT INTO "languageNames" VALUES(3792,'rm','ia','interlingua');
INSERT INTO "languageNames" VALUES(3793,'rm','id','indonais');
INSERT INTO "languageNames" VALUES(3794,'rm','ig','igbo');
INSERT INTO "languageNames" VALUES(3795,'rm','is','islandais');
INSERT INTO "languageNames" VALUES(3796,'rm','it','talian');
INSERT INTO "languageNames" VALUES(3797,'rm','ka','georgian');
INSERT INTO "languageNames" VALUES(3798,'rm','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(3799,'rm','kk','casac');
INSERT INTO "languageNames" VALUES(3800,'rm','ko','corean');
INSERT INTO "languageNames" VALUES(3801,'rm','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(3802,'rm','krl','carelian');
INSERT INTO "languageNames" VALUES(3803,'rm','ks','kashmiri');
INSERT INTO "languageNames" VALUES(3804,'rm','kum','kumuk');
INSERT INTO "languageNames" VALUES(3805,'rm','kv','komi');
INSERT INTO "languageNames" VALUES(3806,'rm','ky','kirghis');
INSERT INTO "languageNames" VALUES(3807,'rm','la','latin');
INSERT INTO "languageNames" VALUES(3808,'rm','lb','luxemburgais');
INSERT INTO "languageNames" VALUES(3809,'rm','lg','ganda');
INSERT INTO "languageNames" VALUES(3810,'rm','ln','lingala');
INSERT INTO "languageNames" VALUES(3811,'rm','lo','laot');
INSERT INTO "languageNames" VALUES(3812,'rm','lt','lituan');
INSERT INTO "languageNames" VALUES(3813,'rm','lv','letton');
INSERT INTO "languageNames" VALUES(3814,'rm','mdf','moksha');
INSERT INTO "languageNames" VALUES(3815,'rm','mk','macedon');
INSERT INTO "languageNames" VALUES(3816,'rm','ml','malayalam');
INSERT INTO "languageNames" VALUES(3817,'rm','mr','marathi');
INSERT INTO "languageNames" VALUES(3818,'rm','ms','malaic');
INSERT INTO "languageNames" VALUES(3819,'rm','mt','maltais');
INSERT INTO "languageNames" VALUES(3820,'rm','myv','erzya');
INSERT INTO "languageNames" VALUES(3821,'rm','nap','neapolitan');
INSERT INTO "languageNames" VALUES(3822,'rm','nb','norvegais bokmål');
INSERT INTO "languageNames" VALUES(3823,'rm','ne','nepalais');
INSERT INTO "languageNames" VALUES(3824,'rm','nl','ollandais');
INSERT INTO "languageNames" VALUES(3825,'rm','nn','norvegiais nynorsk');
INSERT INTO "languageNames" VALUES(3826,'rm','no','norvegiais');
INSERT INTO "languageNames" VALUES(3827,'rm','nog','nogai');
INSERT INTO "languageNames" VALUES(3828,'rm','oc','occitan');
INSERT INTO "languageNames" VALUES(3829,'rm','os','ossetic');
INSERT INTO "languageNames" VALUES(3830,'rm','ota','tirc ottoman');
INSERT INTO "languageNames" VALUES(3831,'rm','pa','punjabi');
INSERT INTO "languageNames" VALUES(3832,'rm','pl','polac');
INSERT INTO "languageNames" VALUES(3833,'rm','pt','portugais');
INSERT INTO "languageNames" VALUES(3834,'rm','rm','rumantsch');
INSERT INTO "languageNames" VALUES(3835,'rm','rn','rundi');
INSERT INTO "languageNames" VALUES(3836,'rm','ro','rumen');
INSERT INTO "languageNames" VALUES(3837,'rm','ru','russ');
INSERT INTO "languageNames" VALUES(3838,'rm','rup','aromunic');
INSERT INTO "languageNames" VALUES(3839,'rm','sa','sanscrit');
INSERT INTO "languageNames" VALUES(3840,'rm','sah','jakut');
INSERT INTO "languageNames" VALUES(3841,'rm','sc','sard');
INSERT INTO "languageNames" VALUES(3842,'rm','scn','sicilian');
INSERT INTO "languageNames" VALUES(3843,'rm','sco','scot');
INSERT INTO "languageNames" VALUES(3844,'rm','sd','sindhi');
INSERT INTO "languageNames" VALUES(3845,'rm','se','sami dal nord');
INSERT INTO "languageNames" VALUES(3846,'rm','sh','serbo-croat');
INSERT INTO "languageNames" VALUES(3847,'rm','si','singalais');
INSERT INTO "languageNames" VALUES(3848,'rm','sk','slovac');
INSERT INTO "languageNames" VALUES(3849,'rm','sl','sloven');
INSERT INTO "languageNames" VALUES(3850,'rm','sma','sami dal sid');
INSERT INTO "languageNames" VALUES(3851,'rm','smj','sami lule');
INSERT INTO "languageNames" VALUES(3852,'rm','smn','sami inari');
INSERT INTO "languageNames" VALUES(3853,'rm','sq','albanais');
INSERT INTO "languageNames" VALUES(3854,'rm','sr','serb');
INSERT INTO "languageNames" VALUES(3855,'rm','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(3856,'rm','ss','swazi');
INSERT INTO "languageNames" VALUES(3857,'rm','sv','svedais');
INSERT INTO "languageNames" VALUES(3858,'rm','sw','suahili');
INSERT INTO "languageNames" VALUES(3859,'rm','ta','tamil');
INSERT INTO "languageNames" VALUES(3860,'rm','te','telugu');
INSERT INTO "languageNames" VALUES(3861,'rm','tet','tetum');
INSERT INTO "languageNames" VALUES(3862,'rm','tg','tadjik');
INSERT INTO "languageNames" VALUES(3863,'rm','th','tailandais');
INSERT INTO "languageNames" VALUES(3864,'rm','tk','turkmen');
INSERT INTO "languageNames" VALUES(3865,'rm','tl','tagalog');
INSERT INTO "languageNames" VALUES(3866,'rm','tr','tirc');
INSERT INTO "languageNames" VALUES(3867,'rm','tt','tatar');
INSERT INTO "languageNames" VALUES(3868,'rm','tyv','tuvinian');
INSERT INTO "languageNames" VALUES(3869,'rm','udm','udmurt');
INSERT INTO "languageNames" VALUES(3870,'rm','ug','uiguric');
INSERT INTO "languageNames" VALUES(3871,'rm','uk','ucranais');
INSERT INTO "languageNames" VALUES(3872,'rm','ur','urdu');
INSERT INTO "languageNames" VALUES(3873,'rm','uz','usbec');
INSERT INTO "languageNames" VALUES(3874,'rm','vi','vietnamais');
INSERT INTO "languageNames" VALUES(3875,'rm','wal','walamo');
INSERT INTO "languageNames" VALUES(3876,'rm','xh','xhosa');
INSERT INTO "languageNames" VALUES(3877,'rm','yi','jiddic');
INSERT INTO "languageNames" VALUES(3878,'rm','yo','yoruba');
INSERT INTO "languageNames" VALUES(3879,'rm','zh','chinais');
INSERT INTO "languageNames" VALUES(3880,'rm','zu','zulu');
INSERT INTO "languageNames" VALUES(3881,'yo','af','Èdè Afrikani');
INSERT INTO "languageNames" VALUES(3882,'yo','ar','Èdè Arabiki');
INSERT INTO "languageNames" VALUES(3883,'yo','as','Ti Assam');
INSERT INTO "languageNames" VALUES(3884,'yo','az','Èdè Azerbaijani');
INSERT INTO "languageNames" VALUES(3885,'yo','be','Èdè Belarusi');
INSERT INTO "languageNames" VALUES(3886,'yo','bg','Èdè Bugaria');
INSERT INTO "languageNames" VALUES(3887,'yo','bn','Èdè Bengali');
INSERT INTO "languageNames" VALUES(3888,'yo','br','Èdè Bretoni');
INSERT INTO "languageNames" VALUES(3889,'yo','bs','Èdè Bosnia');
INSERT INTO "languageNames" VALUES(3890,'yo','ca','Èdè Catala');
INSERT INTO "languageNames" VALUES(3891,'yo','cs','Èdè seeki');
INSERT INTO "languageNames" VALUES(3892,'yo','cy','Èdè Welshi');
INSERT INTO "languageNames" VALUES(3893,'yo','da','Èdè Ilẹ̀ Denmark');
INSERT INTO "languageNames" VALUES(3894,'yo','de','Èdè Ilẹ̀ Gemani');
INSERT INTO "languageNames" VALUES(3895,'yo','el','Èdè Giriki');
INSERT INTO "languageNames" VALUES(3896,'yo','en','Èdè Gẹ̀ẹ́sì');
INSERT INTO "languageNames" VALUES(3897,'yo','eo','Èdè Esperanto');
INSERT INTO "languageNames" VALUES(3898,'yo','es','Èdè Sipanisi');
INSERT INTO "languageNames" VALUES(3899,'yo','et','Èdè Estonia');
INSERT INTO "languageNames" VALUES(3900,'yo','eu','Èdè Baski');
INSERT INTO "languageNames" VALUES(3901,'yo','fa','Èdè Pasia');
INSERT INTO "languageNames" VALUES(3902,'yo','fi','Èdè Finisi');
INSERT INTO "languageNames" VALUES(3903,'yo','fo','Èdè Faroesi');
INSERT INTO "languageNames" VALUES(3904,'yo','fr','Èdè Faransé');
INSERT INTO "languageNames" VALUES(3905,'yo','fy','Èdè Frisia');
INSERT INTO "languageNames" VALUES(3906,'yo','ga','Èdè Ireland');
INSERT INTO "languageNames" VALUES(3907,'yo','gd','Èdè Gaelik ti Ilu Scotland');
INSERT INTO "languageNames" VALUES(3908,'yo','gl','Èdè Galicia');
INSERT INTO "languageNames" VALUES(3909,'yo','gn','Èdè Guarani');
INSERT INTO "languageNames" VALUES(3910,'yo','gu','Èdè Gujarati');
INSERT INTO "languageNames" VALUES(3911,'yo','ha','Èdè Hausa');
INSERT INTO "languageNames" VALUES(3912,'yo','he','Èdè Heberu');
INSERT INTO "languageNames" VALUES(3913,'yo','hi','Èdè Hindi');
INSERT INTO "languageNames" VALUES(3914,'yo','hr','Èdè Kroatia');
INSERT INTO "languageNames" VALUES(3915,'yo','hu','Èdè Hungaria');
INSERT INTO "languageNames" VALUES(3916,'yo','hy','Èdè Ile Armenia');
INSERT INTO "languageNames" VALUES(3917,'yo','ia','Èdè pipo');
INSERT INTO "languageNames" VALUES(3918,'yo','id','Èdè Indonasia');
INSERT INTO "languageNames" VALUES(3919,'yo','ig','Èdè Ibo');
INSERT INTO "languageNames" VALUES(3920,'yo','is','Èdè Icelandic');
INSERT INTO "languageNames" VALUES(3921,'yo','it','Èdè Italiani');
INSERT INTO "languageNames" VALUES(3922,'yo','ka','Èdè Georgia');
INSERT INTO "languageNames" VALUES(3923,'yo','ko','Èdè Koria');
INSERT INTO "languageNames" VALUES(3924,'yo','la','Èdè Latini');
INSERT INTO "languageNames" VALUES(3925,'yo','lt','Èdè Lithuania');
INSERT INTO "languageNames" VALUES(3926,'yo','lv','Èdè Latvianu');
INSERT INTO "languageNames" VALUES(3927,'yo','mk','Èdè Macedonia');
INSERT INTO "languageNames" VALUES(3928,'yo','mr','Èdè marathi');
INSERT INTO "languageNames" VALUES(3929,'yo','ms','Èdè Malaya');
INSERT INTO "languageNames" VALUES(3930,'yo','mt','Èdè Malta');
INSERT INTO "languageNames" VALUES(3931,'yo','ne','Èdè Nepali');
INSERT INTO "languageNames" VALUES(3932,'yo','nl','Èdè Duki');
INSERT INTO "languageNames" VALUES(3933,'yo','no','Èdè Norway');
INSERT INTO "languageNames" VALUES(3934,'yo','oc','Èdè Occitani');
INSERT INTO "languageNames" VALUES(3935,'yo','pa','Èdè Punjabi');
INSERT INTO "languageNames" VALUES(3936,'yo','pl','Èdè Ilẹ̀ Polandi');
INSERT INTO "languageNames" VALUES(3937,'yo','pt','Èdè Pọtugi');
INSERT INTO "languageNames" VALUES(3938,'yo','ro','Èdè Romania');
INSERT INTO "languageNames" VALUES(3939,'yo','ru','Èdè ̣Rọọsia');
INSERT INTO "languageNames" VALUES(3940,'yo','sa','Èdè awon ara Indo');
INSERT INTO "languageNames" VALUES(3941,'yo','sd','Èdè Sindhi');
INSERT INTO "languageNames" VALUES(3942,'yo','sh','Èdè Serbo-Croatiani');
INSERT INTO "languageNames" VALUES(3943,'yo','si','Èdè Sinhalese');
INSERT INTO "languageNames" VALUES(3944,'yo','sk','Èdè Slovaki');
INSERT INTO "languageNames" VALUES(3945,'yo','sl','Èdè Slovenia');
INSERT INTO "languageNames" VALUES(3946,'yo','sq','Èdè Albania');
INSERT INTO "languageNames" VALUES(3947,'yo','sr','Èdè Serbia');
INSERT INTO "languageNames" VALUES(3948,'yo','sv','Èdè Suwidiisi');
INSERT INTO "languageNames" VALUES(3949,'yo','sw','Èdè Swahili');
INSERT INTO "languageNames" VALUES(3950,'yo','ta','Èdè Tamili');
INSERT INTO "languageNames" VALUES(3951,'yo','te','Èdè Telugu');
INSERT INTO "languageNames" VALUES(3952,'yo','th','Èdè Tai');
INSERT INTO "languageNames" VALUES(3953,'yo','tk','Èdè Turkmen');
INSERT INTO "languageNames" VALUES(3954,'yo','tr','Èdè Tọọkisi');
INSERT INTO "languageNames" VALUES(3955,'yo','uk','Èdè Ukania');
INSERT INTO "languageNames" VALUES(3956,'yo','ur','Èdè Udu');
INSERT INTO "languageNames" VALUES(3957,'yo','uz','Èdè Uzbek');
INSERT INTO "languageNames" VALUES(3958,'yo','vi','Èdè Jetinamu');
INSERT INTO "languageNames" VALUES(3959,'yo','xh','Èdè Xhosa');
INSERT INTO "languageNames" VALUES(3960,'yo','yi','Èdè Yiddishi');
INSERT INTO "languageNames" VALUES(3961,'yo','yo','Èdè Yorùbá');
INSERT INTO "languageNames" VALUES(3962,'yo','zh','Èdè Mandari');
INSERT INTO "languageNames" VALUES(3963,'yo','zu','Èdè Ṣulu');
INSERT INTO "languageNames" VALUES(3964,'lo','af','ອາຟຣິການ');
INSERT INTO "languageNames" VALUES(3965,'lo','alt','ອານໄຕໃຕ້');
INSERT INTO "languageNames" VALUES(3966,'lo','an','ອາຣາໂກເນັດ');
INSERT INTO "languageNames" VALUES(3967,'lo','ar','ອາຣັບ');
INSERT INTO "languageNames" VALUES(3968,'lo','as','ອັສຊາມີສ');
INSERT INTO "languageNames" VALUES(3969,'lo','ast','ອັສຕູຮຽນ');
INSERT INTO "languageNames" VALUES(3970,'lo','av','ອາວາຣິກ');
INSERT INTO "languageNames" VALUES(3972,'lo','az','ອາ​ເຊີ​ຣີ');
INSERT INTO "languageNames" VALUES(3973,'lo','ba','ບາຣກີ');
INSERT INTO "languageNames" VALUES(3974,'lo','be','ເບລາຣັສຊຽນ');
INSERT INTO "languageNames" VALUES(3975,'lo','bg','ບັງກາຣຽນ');
INSERT INTO "languageNames" VALUES(3976,'lo','bi','ບິສລະມາ');
INSERT INTO "languageNames" VALUES(3977,'lo','bn','ເບັງກາລີ');
INSERT INTO "languageNames" VALUES(3978,'lo','br','ເບຣຕັນ');
INSERT INTO "languageNames" VALUES(3979,'lo','bs','ບອສນຽນ');
INSERT INTO "languageNames" VALUES(3980,'lo','bua','ບູຣຽດ');
INSERT INTO "languageNames" VALUES(3981,'lo','byv','ເມດູມບາ');
INSERT INTO "languageNames" VALUES(3982,'lo','ca','ຄາຕາລານ');
INSERT INTO "languageNames" VALUES(3983,'lo','ceb','ຊີບູໂນ');
INSERT INTO "languageNames" VALUES(3984,'lo','chm','ມາຣິ');
INSERT INTO "languageNames" VALUES(3985,'lo','ckb','ໂຊຣານິ ເຄີດິຊ');
INSERT INTO "languageNames" VALUES(3986,'lo','co','ຄໍຊິກາ');
INSERT INTO "languageNames" VALUES(3987,'lo','crh','ຄຣີເມນເຕີຄິຊ');
INSERT INTO "languageNames" VALUES(3988,'lo','cs','ເຊກ');
INSERT INTO "languageNames" VALUES(3989,'lo','csb','ກາຊູບຽນ');
INSERT INTO "languageNames" VALUES(3990,'lo','cu','ໂບດສລາວິກ');
INSERT INTO "languageNames" VALUES(3991,'lo','cv','ຊູວາຊ');
INSERT INTO "languageNames" VALUES(3992,'lo','cy','ເວວ');
INSERT INTO "languageNames" VALUES(3993,'lo','da','ແດນິຊ');
INSERT INTO "languageNames" VALUES(3994,'lo','dar','ດາກວາ');
INSERT INTO "languageNames" VALUES(3995,'lo','de','ເຢຍລະມັນ');
INSERT INTO "languageNames" VALUES(3996,'lo','dsb','ຊໍບຽນຕໍ່ກວ່າ');
INSERT INTO "languageNames" VALUES(3997,'lo','el','ກຣີກ');
INSERT INTO "languageNames" VALUES(3998,'lo','en','ອັງກິດ');
INSERT INTO "languageNames" VALUES(3999,'lo','eo','ເອສປາຍ');
INSERT INTO "languageNames" VALUES(4000,'lo','es','ສະແປນນິຊ');
INSERT INTO "languageNames" VALUES(4001,'lo','et','ເອສໂຕນຽນ');
INSERT INTO "languageNames" VALUES(4002,'lo','eu','ບັສກີ');
INSERT INTO "languageNames" VALUES(4003,'lo','fa','ເປີຊຽນ');
INSERT INTO "languageNames" VALUES(4004,'lo','fi','ຟິນນິຊ');
INSERT INTO "languageNames" VALUES(4005,'lo','fo','ຟາໂຣສ');
INSERT INTO "languageNames" VALUES(4006,'lo','fr','ຝຣັ່ງ');
INSERT INTO "languageNames" VALUES(4007,'lo','fy','ຟຣິຊຽນ ຕາເວັນຕົກ');
INSERT INTO "languageNames" VALUES(4008,'lo','ga','ໄອຣິສ');
INSERT INTO "languageNames" VALUES(4009,'lo','gag','ກາກາອຸຊ');
INSERT INTO "languageNames" VALUES(4010,'lo','gd','ສະກັອດເກລິກ');
INSERT INTO "languageNames" VALUES(4011,'lo','gl','ກາລິຊຽນ');
INSERT INTO "languageNames" VALUES(4012,'lo','gn','ກົວຣານີ');
INSERT INTO "languageNames" VALUES(4013,'lo','gu','ກູຈາຣາຕິ');
INSERT INTO "languageNames" VALUES(4014,'lo','gv','ແມງຊ໌');
INSERT INTO "languageNames" VALUES(4015,'lo','ha','ເຮົາຊາ');
INSERT INTO "languageNames" VALUES(4016,'lo','haw','ຮາໄວອຽນ');
INSERT INTO "languageNames" VALUES(4017,'lo','he','ຮີບຣິວ');
INSERT INTO "languageNames" VALUES(4018,'lo','hi','ຮິນດິ');
INSERT INTO "languageNames" VALUES(4019,'lo','hr','ໂຄຣເອທຽນ');
INSERT INTO "languageNames" VALUES(4020,'lo','hsb','ຊໍບຽນ ທາງຕອນເໜືອ');
INSERT INTO "languageNames" VALUES(4021,'lo','ht','ໄຮຕຽນ');
INSERT INTO "languageNames" VALUES(4022,'lo','hu','ຮັງກາຣຽນ');
INSERT INTO "languageNames" VALUES(4023,'lo','hy','ອາເມນຽນ');
INSERT INTO "languageNames" VALUES(4024,'lo','ia','ອິນເຕີລິງລົວ');
INSERT INTO "languageNames" VALUES(4025,'lo','id','ອິນໂດເນຊຽນ');
INSERT INTO "languageNames" VALUES(4026,'lo','ig','ອິກໂບ');
INSERT INTO "languageNames" VALUES(4027,'lo','is','ໄອສແລນດິກ');
INSERT INTO "languageNames" VALUES(4028,'lo','it','ອິຕາລຽນ');
INSERT INTO "languageNames" VALUES(4029,'lo','ka','ຈໍຈຽນ');
INSERT INTO "languageNames" VALUES(4030,'lo','kaa','ກາຣາ-ການປາກ');
INSERT INTO "languageNames" VALUES(4031,'lo','kk','ຄາຊັກ');
INSERT INTO "languageNames" VALUES(4032,'lo','ko','ເກົາຫລີ');
INSERT INTO "languageNames" VALUES(4033,'lo','krc','ກາຣາໄຊ-ບານກາ');
INSERT INTO "languageNames" VALUES(4034,'lo','krl','ກາເຣລຽນ');
INSERT INTO "languageNames" VALUES(4035,'lo','ks','ຄາສເມຍຣິ');
INSERT INTO "languageNames" VALUES(4036,'lo','kum','ຄູມີກ');
INSERT INTO "languageNames" VALUES(4037,'lo','kv','ໂຄມິ');
INSERT INTO "languageNames" VALUES(4038,'lo','ky','ເກຍກີສ');
INSERT INTO "languageNames" VALUES(4039,'lo','la','ລາຕິນ');
INSERT INTO "languageNames" VALUES(4040,'lo','lb','ລັກເຊມບວກກິຊ');
INSERT INTO "languageNames" VALUES(4041,'lo','lg','ແກນດາ');
INSERT INTO "languageNames" VALUES(4042,'lo','ln','ລິງກາລາ');
INSERT INTO "languageNames" VALUES(4043,'lo','lo','ລາວ');
INSERT INTO "languageNames" VALUES(4044,'lo','lt','ລິທົວນຽນ');
INSERT INTO "languageNames" VALUES(4045,'lo','lv','ລັດວຽນ');
INSERT INTO "languageNames" VALUES(4046,'lo','mdf','ມອກຊາ');
INSERT INTO "languageNames" VALUES(4047,'lo','mfe','ມໍຣິສເຢນ');
INSERT INTO "languageNames" VALUES(4048,'lo','mk','ແມຊິໂດນຽນ');
INSERT INTO "languageNames" VALUES(4049,'lo','ml','ມາເລອາລຳ');
INSERT INTO "languageNames" VALUES(4050,'lo','mr','ມາຣາທີ');
INSERT INTO "languageNames" VALUES(4051,'lo','ms','ມາເລ');
INSERT INTO "languageNames" VALUES(4052,'lo','mt','ມອລທີສ');
INSERT INTO "languageNames" VALUES(4053,'lo','myv','ເອີຍາ');
INSERT INTO "languageNames" VALUES(4054,'lo','nap','ນາໂປລີ');
INSERT INTO "languageNames" VALUES(4055,'lo','nb','ນໍເວຈຽນ ບັອກມອລ');
INSERT INTO "languageNames" VALUES(4056,'lo','ne','ເນປາລີ');
INSERT INTO "languageNames" VALUES(4057,'lo','nl','ດັຊ');
INSERT INTO "languageNames" VALUES(4058,'lo','nn','ນໍເວຈຽນ ນີນອກ');
INSERT INTO "languageNames" VALUES(4059,'lo','no','ນໍເວຍ');
INSERT INTO "languageNames" VALUES(4060,'lo','nog','ນໍໄກ');
INSERT INTO "languageNames" VALUES(4061,'lo','oc','ອັອກຊີຕານ');
INSERT INTO "languageNames" VALUES(4062,'lo','os','ອອດເຊຕິກ');
INSERT INTO "languageNames" VALUES(4063,'lo','ota','ຕູກີອອດໂຕມັນ');
INSERT INTO "languageNames" VALUES(4064,'lo','pa','ປັນຈາບີ');
INSERT INTO "languageNames" VALUES(4065,'lo','pl','ໂປລິຊ');
INSERT INTO "languageNames" VALUES(4066,'lo','pt','ປອກຕຸຍກິສ');
INSERT INTO "languageNames" VALUES(4067,'lo','rm','ໂຣແມນຊ໌');
INSERT INTO "languageNames" VALUES(4068,'lo','rn','ຣຸນດິ');
INSERT INTO "languageNames" VALUES(4069,'lo','ro','ໂຣແມນຽນ');
INSERT INTO "languageNames" VALUES(4070,'lo','ru','ລັດເຊຍ');
INSERT INTO "languageNames" VALUES(4071,'lo','rup','ອາໂຣມານຽນ');
INSERT INTO "languageNames" VALUES(4072,'lo','sa','ສັນສະກຣິດ');
INSERT INTO "languageNames" VALUES(4073,'lo','sah','ຊາກາ');
INSERT INTO "languageNames" VALUES(4074,'lo','sc','ສາດີນຽນ');
INSERT INTO "languageNames" VALUES(4075,'lo','scn','ຊີຊິລີນ');
INSERT INTO "languageNames" VALUES(4076,'lo','sco','ສກອດ');
INSERT INTO "languageNames" VALUES(4077,'lo','sd','ສິນທິ');
INSERT INTO "languageNames" VALUES(4078,'lo','se','ຊາມິເໜືອ');
INSERT INTO "languageNames" VALUES(4079,'lo','sh','ເຊີໂບ-ໂກເຊຍ');
INSERT INTO "languageNames" VALUES(4080,'lo','si','ສິນຫາລາ');
INSERT INTO "languageNames" VALUES(4081,'lo','sk','ສະໂລແວັກ');
INSERT INTO "languageNames" VALUES(4082,'lo','sl','ສະໂລເວນຽນ');
INSERT INTO "languageNames" VALUES(4083,'lo','sma','ຊາມິໃຕ້');
INSERT INTO "languageNames" VALUES(4084,'lo','smj','ລຸນຊາມິ');
INSERT INTO "languageNames" VALUES(4085,'lo','smn','ອີນາຣິຊາມິ');
INSERT INTO "languageNames" VALUES(4086,'lo','sq','ອານບານຽນ');
INSERT INTO "languageNames" VALUES(4087,'lo','sr','ເຊີບຽນ');
INSERT INTO "languageNames" VALUES(4088,'lo','srn','ສຣານນານຕອນໂກ');
INSERT INTO "languageNames" VALUES(4089,'lo','ss','ຊຣາຕິ');
INSERT INTO "languageNames" VALUES(4090,'lo','sv','ສະວີດິຊ');
INSERT INTO "languageNames" VALUES(4091,'lo','sw','ຊວາຮີລິ');
INSERT INTO "languageNames" VALUES(4092,'lo','ta','ທາມິລ');
INSERT INTO "languageNames" VALUES(4093,'lo','te','ເຕລູກູ');
INSERT INTO "languageNames" VALUES(4094,'lo','tet','ເຕຕູມ');
INSERT INTO "languageNames" VALUES(4095,'lo','tg','ທາຈິກ');
INSERT INTO "languageNames" VALUES(4096,'lo','th','ໄທ');
INSERT INTO "languageNames" VALUES(4097,'lo','tk','ເທີກເມັນ');
INSERT INTO "languageNames" VALUES(4098,'lo','tl','ຕາກາລອກ');
INSERT INTO "languageNames" VALUES(4099,'lo','tr','ເທີຄິຊ');
INSERT INTO "languageNames" VALUES(4100,'lo','tt','ທາທາ');
INSERT INTO "languageNames" VALUES(4101,'lo','tyv','ຕູວີນຽນ');
INSERT INTO "languageNames" VALUES(4102,'lo','udm','ອຸດມັດ');
INSERT INTO "languageNames" VALUES(4103,'lo','ug','ອຸຍເຄີ');
INSERT INTO "languageNames" VALUES(4104,'lo','uk','ຢູເຄຣນຽນ');
INSERT INTO "languageNames" VALUES(4105,'lo','ur','ອູຣດູ');
INSERT INTO "languageNames" VALUES(4106,'lo','uz','ອຸສເບກ');
INSERT INTO "languageNames" VALUES(4107,'lo','vi','ຫວຽດນາມ');
INSERT INTO "languageNames" VALUES(4108,'lo','wal','ວາລາໂມ');
INSERT INTO "languageNames" VALUES(4109,'lo','xh','ໂຮຊາ');
INSERT INTO "languageNames" VALUES(4110,'lo','yi','ຢິວ');
INSERT INTO "languageNames" VALUES(4111,'lo','yo','ໂຢຣູບາ');
INSERT INTO "languageNames" VALUES(4112,'lo','zh','ຈີນ');
INSERT INTO "languageNames" VALUES(4113,'lo','zu','ຊູລູ');
INSERT INTO "languageNames" VALUES(4114,'lg','ar','Luwarabu');
INSERT INTO "languageNames" VALUES(4115,'lg','be','Lubelarusi');
INSERT INTO "languageNames" VALUES(4116,'lg','bg','Lubulugariya');
INSERT INTO "languageNames" VALUES(4117,'lg','bn','Lubengali');
INSERT INTO "languageNames" VALUES(4118,'lg','cs','Luceeke');
INSERT INTO "languageNames" VALUES(4119,'lg','de','Ludaaki');
INSERT INTO "languageNames" VALUES(4120,'lg','el','Lugereeki/Luyonaani');
INSERT INTO "languageNames" VALUES(4121,'lg','en','Lungereza');
INSERT INTO "languageNames" VALUES(4122,'lg','es','Lusipanya');
INSERT INTO "languageNames" VALUES(4123,'lg','fa','Luperusi');
INSERT INTO "languageNames" VALUES(4124,'lg','fr','Lufalansa');
INSERT INTO "languageNames" VALUES(4125,'lg','ha','Luhawuza');
INSERT INTO "languageNames" VALUES(4126,'lg','hi','Luhindu');
INSERT INTO "languageNames" VALUES(4127,'lg','hu','Luhangare');
INSERT INTO "languageNames" VALUES(4128,'lg','id','Luyindonezya');
INSERT INTO "languageNames" VALUES(4129,'lg','ig','Luyibo');
INSERT INTO "languageNames" VALUES(4130,'lg','it','Luyitale');
INSERT INTO "languageNames" VALUES(4131,'lg','ko','Lukoreya');
INSERT INTO "languageNames" VALUES(4132,'lg','lg','Luganda');
INSERT INTO "languageNames" VALUES(4133,'lg','ms','Lumalayi');
INSERT INTO "languageNames" VALUES(4134,'lg','ne','Lunepali');
INSERT INTO "languageNames" VALUES(4135,'lg','nl','Luholandi');
INSERT INTO "languageNames" VALUES(4136,'lg','pa','Lupunjabi');
INSERT INTO "languageNames" VALUES(4137,'lg','pl','Lupolandi');
INSERT INTO "languageNames" VALUES(4138,'lg','pt','Lupotugiizi');
INSERT INTO "languageNames" VALUES(4139,'lg','ro','Lulomaniya');
INSERT INTO "languageNames" VALUES(4140,'lg','ru','Lulasa');
INSERT INTO "languageNames" VALUES(4141,'lg','sv','Luswideni');
INSERT INTO "languageNames" VALUES(4142,'lg','ta','Lutamiiru');
INSERT INTO "languageNames" VALUES(4143,'lg','th','Luttaayi');
INSERT INTO "languageNames" VALUES(4144,'lg','tr','Lutake');
INSERT INTO "languageNames" VALUES(4145,'lg','uk','Luyukurayine');
INSERT INTO "languageNames" VALUES(4146,'lg','ur','Lu-urudu');
INSERT INTO "languageNames" VALUES(4147,'lg','vi','Luvyetinaamu');
INSERT INTO "languageNames" VALUES(4148,'lg','yo','Luyoruba');
INSERT INTO "languageNames" VALUES(4149,'lg','zh','Lucayina');
INSERT INTO "languageNames" VALUES(4150,'lg','zu','Luzzulu');
INSERT INTO "languageNames" VALUES(4151,'tt','af','африкаанс');
INSERT INTO "languageNames" VALUES(4152,'tt','ar','гарәп');
INSERT INTO "languageNames" VALUES(4153,'tt','as','ассам');
INSERT INTO "languageNames" VALUES(4154,'tt','az','әзәрбайҗан');
INSERT INTO "languageNames" VALUES(4155,'tt','ba','башкорт');
INSERT INTO "languageNames" VALUES(4156,'tt','be','белорус');
INSERT INTO "languageNames" VALUES(4157,'tt','bg','болгар');
INSERT INTO "languageNames" VALUES(4158,'tt','bn','бенгали');
INSERT INTO "languageNames" VALUES(4159,'tt','br','бретон');
INSERT INTO "languageNames" VALUES(4160,'tt','bs','босния');
INSERT INTO "languageNames" VALUES(4161,'tt','ca','каталан');
INSERT INTO "languageNames" VALUES(4162,'tt','ceb','себуано');
INSERT INTO "languageNames" VALUES(4163,'tt','chm','мари');
INSERT INTO "languageNames" VALUES(4164,'tt','ckb','үзәк көрд');
INSERT INTO "languageNames" VALUES(4165,'tt','co','корсика');
INSERT INTO "languageNames" VALUES(4166,'tt','cs','чех');
INSERT INTO "languageNames" VALUES(4167,'tt','cy','уэльс');
INSERT INTO "languageNames" VALUES(4168,'tt','da','дания');
INSERT INTO "languageNames" VALUES(4169,'tt','de','алман');
INSERT INTO "languageNames" VALUES(4170,'tt','dsb','түбән сорб');
INSERT INTO "languageNames" VALUES(4171,'tt','el','грек');
INSERT INTO "languageNames" VALUES(4172,'tt','en','инглиз');
INSERT INTO "languageNames" VALUES(4173,'tt','eo','эсперанто');
INSERT INTO "languageNames" VALUES(4174,'tt','es','испан');
INSERT INTO "languageNames" VALUES(4175,'tt','et','эстон');
INSERT INTO "languageNames" VALUES(4176,'tt','eu','баск');
INSERT INTO "languageNames" VALUES(4177,'tt','fa','фарсы');
INSERT INTO "languageNames" VALUES(4178,'tt','fi','фин');
INSERT INTO "languageNames" VALUES(4179,'tt','fo','фарер');
INSERT INTO "languageNames" VALUES(4180,'tt','fr','француз');
INSERT INTO "languageNames" VALUES(4181,'tt','ga','ирланд');
INSERT INTO "languageNames" VALUES(4182,'tt','gd','шотланд гэль');
INSERT INTO "languageNames" VALUES(4183,'tt','gl','галисия');
INSERT INTO "languageNames" VALUES(4184,'tt','gn','гуарани');
INSERT INTO "languageNames" VALUES(4185,'tt','gu','гуҗарати');
INSERT INTO "languageNames" VALUES(4186,'tt','ha','хауса');
INSERT INTO "languageNames" VALUES(4187,'tt','haw','гавайи');
INSERT INTO "languageNames" VALUES(4188,'tt','he','яһүд');
INSERT INTO "languageNames" VALUES(4189,'tt','hi','һинд');
INSERT INTO "languageNames" VALUES(4190,'tt','hr','хорват');
INSERT INTO "languageNames" VALUES(4191,'tt','hsb','югары сорб');
INSERT INTO "languageNames" VALUES(4192,'tt','ht','гаити креол');
INSERT INTO "languageNames" VALUES(4193,'tt','hu','венгр');
INSERT INTO "languageNames" VALUES(4194,'tt','hy','әрмән');
INSERT INTO "languageNames" VALUES(4195,'tt','id','индонезия');
INSERT INTO "languageNames" VALUES(4196,'tt','ig','игбо');
INSERT INTO "languageNames" VALUES(4197,'tt','is','исланд');
INSERT INTO "languageNames" VALUES(4198,'tt','it','итальян');
INSERT INTO "languageNames" VALUES(4199,'tt','ka','грузин');
INSERT INTO "languageNames" VALUES(4200,'tt','kk','казакъ');
INSERT INTO "languageNames" VALUES(4201,'tt','ko','корея');
INSERT INTO "languageNames" VALUES(4202,'tt','ks','кашмири');
INSERT INTO "languageNames" VALUES(4203,'tt','ky','кыргыз');
INSERT INTO "languageNames" VALUES(4204,'tt','la','латин');
INSERT INTO "languageNames" VALUES(4205,'tt','lb','люксембург');
INSERT INTO "languageNames" VALUES(4206,'tt','lo','лаос');
INSERT INTO "languageNames" VALUES(4207,'tt','lt','литва');
INSERT INTO "languageNames" VALUES(4208,'tt','lv','латыш');
INSERT INTO "languageNames" VALUES(4209,'tt','mk','македон');
INSERT INTO "languageNames" VALUES(4210,'tt','ml','малаялам');
INSERT INTO "languageNames" VALUES(4211,'tt','mr','маратхи');
INSERT INTO "languageNames" VALUES(4212,'tt','ms','малай');
INSERT INTO "languageNames" VALUES(4213,'tt','mt','мальта');
INSERT INTO "languageNames" VALUES(4214,'tt','ne','непали');
INSERT INTO "languageNames" VALUES(4215,'tt','nl','голланд');
INSERT INTO "languageNames" VALUES(4216,'tt','oc','окситан');
INSERT INTO "languageNames" VALUES(4217,'tt','pa','пәнҗаби');
INSERT INTO "languageNames" VALUES(4218,'tt','pl','поляк');
INSERT INTO "languageNames" VALUES(4219,'tt','pt','португал');
INSERT INTO "languageNames" VALUES(4220,'tt','rm','ретороман');
INSERT INTO "languageNames" VALUES(4221,'tt','ro','румын');
INSERT INTO "languageNames" VALUES(4222,'tt','ru','рус');
INSERT INTO "languageNames" VALUES(4223,'tt','sa','санскрит');
INSERT INTO "languageNames" VALUES(4224,'tt','sah','саха');
INSERT INTO "languageNames" VALUES(4225,'tt','sd','синдһи');
INSERT INTO "languageNames" VALUES(4226,'tt','se','төньяк саам');
INSERT INTO "languageNames" VALUES(4227,'tt','si','сингал');
INSERT INTO "languageNames" VALUES(4228,'tt','sk','словак');
INSERT INTO "languageNames" VALUES(4229,'tt','sl','словен');
INSERT INTO "languageNames" VALUES(4230,'tt','sma','көньяк саам');
INSERT INTO "languageNames" VALUES(4231,'tt','smj','луле-саам');
INSERT INTO "languageNames" VALUES(4232,'tt','smn','инари-саам');
INSERT INTO "languageNames" VALUES(4233,'tt','sq','албан');
INSERT INTO "languageNames" VALUES(4234,'tt','sr','серб');
INSERT INTO "languageNames" VALUES(4235,'tt','sv','швед');
INSERT INTO "languageNames" VALUES(4236,'tt','ta','тамил');
INSERT INTO "languageNames" VALUES(4237,'tt','te','телугу');
INSERT INTO "languageNames" VALUES(4238,'tt','tg','таҗик');
INSERT INTO "languageNames" VALUES(4239,'tt','th','тай');
INSERT INTO "languageNames" VALUES(4240,'tt','tk','төрекмән');
INSERT INTO "languageNames" VALUES(4241,'tt','tr','төрек');
INSERT INTO "languageNames" VALUES(4242,'tt','tt','татар');
INSERT INTO "languageNames" VALUES(4243,'tt','ug','уйгыр');
INSERT INTO "languageNames" VALUES(4244,'tt','uk','украин');
INSERT INTO "languageNames" VALUES(4245,'tt','ur','урду');
INSERT INTO "languageNames" VALUES(4246,'tt','uz','үзбәк');
INSERT INTO "languageNames" VALUES(4247,'tt','vi','вьетнам');
INSERT INTO "languageNames" VALUES(4248,'tt','yi','идиш');
INSERT INTO "languageNames" VALUES(4249,'tt','yo','йоруба');
INSERT INTO "languageNames" VALUES(4250,'tt','zh','кытай (тәрҗемә киңәше: аерым алганда, мандарин кытайчасы)');
INSERT INTO "languageNames" VALUES(4251,'si','af','අෆ්රිකාන්ස්');
INSERT INTO "languageNames" VALUES(4252,'si','alt','සතර්න් අල්ටය්');
INSERT INTO "languageNames" VALUES(4253,'si','an','ඇරගොනීස්');
INSERT INTO "languageNames" VALUES(4254,'si','ar','අරාබි');
INSERT INTO "languageNames" VALUES(4255,'si','as','ඇසෑම්');
INSERT INTO "languageNames" VALUES(4256,'si','ast','ඇස්ටියුරියන්');
INSERT INTO "languageNames" VALUES(4257,'si','av','ඇවරික්');
INSERT INTO "languageNames" VALUES(4259,'si','az','අසීරී');
INSERT INTO "languageNames" VALUES(4260,'si','ba','බාෂ්කිර්');
INSERT INTO "languageNames" VALUES(4261,'si','be','බෙලරුසියානු');
INSERT INTO "languageNames" VALUES(4262,'si','bg','බල්ගේරියානු');
INSERT INTO "languageNames" VALUES(4263,'si','bi','බිස්ලමා');
INSERT INTO "languageNames" VALUES(4264,'si','bn','බෙංගාලි');
INSERT INTO "languageNames" VALUES(4265,'si','br','බ්‍රේටොන්');
INSERT INTO "languageNames" VALUES(4266,'si','bs','බොස්නියානු');
INSERT INTO "languageNames" VALUES(4267,'si','ca','කැටලන්');
INSERT INTO "languageNames" VALUES(4268,'si','ceb','සෙබුඅනො');
INSERT INTO "languageNames" VALUES(4269,'si','chm','මරි');
INSERT INTO "languageNames" VALUES(4270,'si','ckb','සොරානි කුර්දිෂ්');
INSERT INTO "languageNames" VALUES(4271,'si','co','කෝසිකානු');
INSERT INTO "languageNames" VALUES(4272,'si','cs','චෙක්');
INSERT INTO "languageNames" VALUES(4273,'si','cu','චර්ච් ස්ලැවික්');
INSERT INTO "languageNames" VALUES(4274,'si','cv','චවේෂ්');
INSERT INTO "languageNames" VALUES(4275,'si','cy','වෙල්ෂ්');
INSERT INTO "languageNames" VALUES(4276,'si','da','ඩැනිශ්');
INSERT INTO "languageNames" VALUES(4277,'si','dar','ඩාර්ග්වා');
INSERT INTO "languageNames" VALUES(4278,'si','de','ජර්මන්');
INSERT INTO "languageNames" VALUES(4279,'si','dsb','පහළ සෝබියානු');
INSERT INTO "languageNames" VALUES(4280,'si','el','ග්‍රීක');
INSERT INTO "languageNames" VALUES(4281,'si','en','ඉංග්‍රීසි');
INSERT INTO "languageNames" VALUES(4282,'si','eo','එස්පැරන්ටෝ');
INSERT INTO "languageNames" VALUES(4283,'si','es','ස්පාඤ්ඤ');
INSERT INTO "languageNames" VALUES(4284,'si','et','එස්තෝනියානු');
INSERT INTO "languageNames" VALUES(4285,'si','eu','බාස්ක්');
INSERT INTO "languageNames" VALUES(4286,'si','fa','පර්සියානු');
INSERT INTO "languageNames" VALUES(4287,'si','fi','ෆින්ලන්ත');
INSERT INTO "languageNames" VALUES(4288,'si','fo','ෆාරෝස්');
INSERT INTO "languageNames" VALUES(4289,'si','fr','ප්‍රංශ');
INSERT INTO "languageNames" VALUES(4290,'si','fy','බටහිර ෆ්‍රිසියානු');
INSERT INTO "languageNames" VALUES(4291,'si','ga','අයර්ලන්ත');
INSERT INTO "languageNames" VALUES(4292,'si','gag','ගගාස්');
INSERT INTO "languageNames" VALUES(4293,'si','gd','ස්කොට්ටිශ් ගෙලික්');
INSERT INTO "languageNames" VALUES(4294,'si','gl','ගැලීසියානු');
INSERT INTO "languageNames" VALUES(4295,'si','gn','ගුවාරනි');
INSERT INTO "languageNames" VALUES(4296,'si','gu','ගුජරාටි');
INSERT INTO "languageNames" VALUES(4297,'si','gv','මැන්ක්ස්');
INSERT INTO "languageNames" VALUES(4298,'si','ha','හෝසා');
INSERT INTO "languageNames" VALUES(4299,'si','haw','හවායි');
INSERT INTO "languageNames" VALUES(4300,'si','he','හීබෲ');
INSERT INTO "languageNames" VALUES(4301,'si','hi','හින්දි');
INSERT INTO "languageNames" VALUES(4302,'si','hr','කෝඒෂියානු');
INSERT INTO "languageNames" VALUES(4303,'si','hsb','ඉහළ සෝබියානු');
INSERT INTO "languageNames" VALUES(4304,'si','ht','හයිටි');
INSERT INTO "languageNames" VALUES(4305,'si','hu','හන්ගේරියානු');
INSERT INTO "languageNames" VALUES(4306,'si','hy','ආර්මේනියානු');
INSERT INTO "languageNames" VALUES(4307,'si','ia','ඉන්ටලින්ගුආ');
INSERT INTO "languageNames" VALUES(4308,'si','id','ඉන්දුනීසියානු');
INSERT INTO "languageNames" VALUES(4309,'si','ig','ඉග්බෝ');
INSERT INTO "languageNames" VALUES(4310,'si','is','අයිස්ලන්ත');
INSERT INTO "languageNames" VALUES(4311,'si','it','ඉතාලි');
INSERT INTO "languageNames" VALUES(4312,'si','ka','ජෝර්ජියානු');
INSERT INTO "languageNames" VALUES(4313,'si','kk','කසාඛ්');
INSERT INTO "languageNames" VALUES(4314,'si','ko','කොරියානු');
INSERT INTO "languageNames" VALUES(4315,'si','krc','කරන්චි-බාකර්');
INSERT INTO "languageNames" VALUES(4316,'si','krl','කැරෙලියන්');
INSERT INTO "languageNames" VALUES(4317,'si','ks','කාෂ්මීර්');
INSERT INTO "languageNames" VALUES(4318,'si','kum','කුමික්');
INSERT INTO "languageNames" VALUES(4319,'si','kv','කොමි');
INSERT INTO "languageNames" VALUES(4320,'si','ky','කිර්ගිස්');
INSERT INTO "languageNames" VALUES(4321,'si','la','ලතින්');
INSERT INTO "languageNames" VALUES(4322,'si','lb','ලක්සැම්බර්ග්');
INSERT INTO "languageNames" VALUES(4323,'si','lg','ගන්ඩා');
INSERT INTO "languageNames" VALUES(4324,'si','ln','ලින්ගලා');
INSERT INTO "languageNames" VALUES(4325,'si','lo','ලාඕ');
INSERT INTO "languageNames" VALUES(4326,'si','lt','ලිතුවේනියානු');
INSERT INTO "languageNames" VALUES(4327,'si','lv','ලැට්වියානු');
INSERT INTO "languageNames" VALUES(4328,'si','mdf','මොක්ශා');
INSERT INTO "languageNames" VALUES(4329,'si','mfe','මොරිස්යෙම්');
INSERT INTO "languageNames" VALUES(4330,'si','mk','මැසිඩෝනියානු');
INSERT INTO "languageNames" VALUES(4331,'si','ml','මලයාලම්');
INSERT INTO "languageNames" VALUES(4332,'si','mr','මරාති');
INSERT INTO "languageNames" VALUES(4333,'si','ms','මැලේ');
INSERT INTO "languageNames" VALUES(4334,'si','mt','මොල්ටිස්');
INSERT INTO "languageNames" VALUES(4335,'si','myv','එර්ස්යා');
INSERT INTO "languageNames" VALUES(4336,'si','nap','නියාපොලිටන්');
INSERT INTO "languageNames" VALUES(4337,'si','nb','නෝර්වීජියානු බොක්මල්');
INSERT INTO "languageNames" VALUES(4338,'si','ne','නේපාල');
INSERT INTO "languageNames" VALUES(4339,'si','nl','ලන්දේසි');
INSERT INTO "languageNames" VALUES(4340,'si','nn','නෝර්වීජියානු නයිනෝර්ස්ක්');
INSERT INTO "languageNames" VALUES(4341,'si','nog','නොගායි');
INSERT INTO "languageNames" VALUES(4342,'si','oc','ඔසිටාන්');
INSERT INTO "languageNames" VALUES(4343,'si','os','ඔසිටෙක්');
INSERT INTO "languageNames" VALUES(4344,'si','pa','පන්ජාබි');
INSERT INTO "languageNames" VALUES(4345,'si','pl','පෝලන්ත');
INSERT INTO "languageNames" VALUES(4346,'si','pt','පෘතුගීසි');
INSERT INTO "languageNames" VALUES(4347,'si','rm','රොමෑන්ශ්');
INSERT INTO "languageNames" VALUES(4348,'si','rn','රුන්ඩි');
INSERT INTO "languageNames" VALUES(4349,'si','ro','රොමේනියානු');
INSERT INTO "languageNames" VALUES(4350,'si','ru','රුසියානු');
INSERT INTO "languageNames" VALUES(4351,'si','rup','ඇරොමානියානු');
INSERT INTO "languageNames" VALUES(4352,'si','sa','සංස්කෘත');
INSERT INTO "languageNames" VALUES(4353,'si','sah','සඛා');
INSERT INTO "languageNames" VALUES(4354,'si','sc','සාර්ඩිනිඅන්');
INSERT INTO "languageNames" VALUES(4355,'si','scn','සිසිලියන්');
INSERT INTO "languageNames" VALUES(4356,'si','sco','ස්කොට්ස්');
INSERT INTO "languageNames" VALUES(4357,'si','sd','සින්ධි');
INSERT INTO "languageNames" VALUES(4358,'si','se','උතුරු සාමි');
INSERT INTO "languageNames" VALUES(4359,'si','si','සිංහල');
INSERT INTO "languageNames" VALUES(4360,'si','sk','ස්ලෝවැක්');
INSERT INTO "languageNames" VALUES(4361,'si','sl','ස්ලෝවේනියානු');
INSERT INTO "languageNames" VALUES(4362,'si','sma','දකුණු සාමි');
INSERT INTO "languageNames" VALUES(4363,'si','smj','ලුලේ සාමි');
INSERT INTO "languageNames" VALUES(4364,'si','smn','ඉනාරි සාමි');
INSERT INTO "languageNames" VALUES(4365,'si','sq','ඇල්බේනියානු');
INSERT INTO "languageNames" VALUES(4366,'si','sr','සර්බියානු');
INSERT INTO "languageNames" VALUES(4367,'si','srn','ස්‍රන් ටොන්ගො');
INSERT INTO "languageNames" VALUES(4368,'si','ss','ස්වති');
INSERT INTO "languageNames" VALUES(4369,'si','sv','ස්වීඩන්');
INSERT INTO "languageNames" VALUES(4370,'si','sw','ස්වාහිලි');
INSERT INTO "languageNames" VALUES(4371,'si','ta','දෙමළ');
INSERT INTO "languageNames" VALUES(4372,'si','te','තෙළිඟු');
INSERT INTO "languageNames" VALUES(4373,'si','tet','ටේටම්');
INSERT INTO "languageNames" VALUES(4374,'si','tg','ටජික්');
INSERT INTO "languageNames" VALUES(4375,'si','th','තායි');
INSERT INTO "languageNames" VALUES(4376,'si','tk','ටර්ක්මෙන්');
INSERT INTO "languageNames" VALUES(4377,'si','tr','තුර්කි');
INSERT INTO "languageNames" VALUES(4378,'si','tt','ටාටර්');
INSERT INTO "languageNames" VALUES(4379,'si','tyv','ටුවිනියන්');
INSERT INTO "languageNames" VALUES(4380,'si','udm','අඩ්මර්ට්');
INSERT INTO "languageNames" VALUES(4381,'si','ug','උයිගර්');
INSERT INTO "languageNames" VALUES(4382,'si','uk','යුක්රේනියානු');
INSERT INTO "languageNames" VALUES(4383,'si','ur','උර්දු');
INSERT INTO "languageNames" VALUES(4384,'si','uz','උස්බෙක්');
INSERT INTO "languageNames" VALUES(4385,'si','vi','වියට්නාම්');
INSERT INTO "languageNames" VALUES(4386,'si','wal','වොලෙට්ට');
INSERT INTO "languageNames" VALUES(4387,'si','xh','ශෝසා');
INSERT INTO "languageNames" VALUES(4388,'si','yi','යිඩිශ්');
INSERT INTO "languageNames" VALUES(4389,'si','yo','යොරූබා');
INSERT INTO "languageNames" VALUES(4390,'si','zh','චීන');
INSERT INTO "languageNames" VALUES(4391,'si','zu','සුලු');
INSERT INTO "languageNames" VALUES(4392,'sr','af','африканс');
INSERT INTO "languageNames" VALUES(4393,'sr','alt','јужноалтајски');
INSERT INTO "languageNames" VALUES(4394,'sr','an','арагонски');
INSERT INTO "languageNames" VALUES(4395,'sr','ar','арапски');
INSERT INTO "languageNames" VALUES(4396,'sr','as','асамски');
INSERT INTO "languageNames" VALUES(4397,'sr','ast','астуријски');
INSERT INTO "languageNames" VALUES(4398,'sr','av','аварски');
INSERT INTO "languageNames" VALUES(4400,'sr','az','азерски');
INSERT INTO "languageNames" VALUES(4401,'sr','ba','башкирски');
INSERT INTO "languageNames" VALUES(4402,'sr','be','белоруски');
INSERT INTO "languageNames" VALUES(4403,'sr','bg','бугарски');
INSERT INTO "languageNames" VALUES(4404,'sr','bi','бислама');
INSERT INTO "languageNames" VALUES(4405,'sr','bn','бенгалски');
INSERT INTO "languageNames" VALUES(4406,'sr','br','бретонски');
INSERT INTO "languageNames" VALUES(4407,'sr','bs','босански');
INSERT INTO "languageNames" VALUES(4408,'sr','bua','бурјатски');
INSERT INTO "languageNames" VALUES(4409,'sr','ca','каталонски');
INSERT INTO "languageNames" VALUES(4410,'sr','ceb','себуански');
INSERT INTO "languageNames" VALUES(4411,'sr','chm','мари');
INSERT INTO "languageNames" VALUES(4412,'sr','ckb','централни курдски');
INSERT INTO "languageNames" VALUES(4413,'sr','co','корзикански');
INSERT INTO "languageNames" VALUES(4414,'sr','crh','кримскотатарски');
INSERT INTO "languageNames" VALUES(4415,'sr','cs','чешки');
INSERT INTO "languageNames" VALUES(4416,'sr','csb','кашупски');
INSERT INTO "languageNames" VALUES(4417,'sr','cu','црквенословенски');
INSERT INTO "languageNames" VALUES(4418,'sr','cv','чувашки');
INSERT INTO "languageNames" VALUES(4419,'sr','cy','велшки');
INSERT INTO "languageNames" VALUES(4420,'sr','da','дански');
INSERT INTO "languageNames" VALUES(4421,'sr','dar','даргински');
INSERT INTO "languageNames" VALUES(4422,'sr','de','немачки');
INSERT INTO "languageNames" VALUES(4423,'sr','dsb','доњи лужичкосрпски');
INSERT INTO "languageNames" VALUES(4424,'sr','el','грчки');
INSERT INTO "languageNames" VALUES(4425,'sr','en','енглески');
INSERT INTO "languageNames" VALUES(4426,'sr','eo','есперанто');
INSERT INTO "languageNames" VALUES(4427,'sr','es','шпански');
INSERT INTO "languageNames" VALUES(4428,'sr','et','естонски');
INSERT INTO "languageNames" VALUES(4429,'sr','eu','баскијски');
INSERT INTO "languageNames" VALUES(4430,'sr','fa','персијски');
INSERT INTO "languageNames" VALUES(4431,'sr','fi','фински');
INSERT INTO "languageNames" VALUES(4432,'sr','fo','фарски');
INSERT INTO "languageNames" VALUES(4433,'sr','fr','француски');
INSERT INTO "languageNames" VALUES(4434,'sr','fy','западни фризијски');
INSERT INTO "languageNames" VALUES(4435,'sr','ga','ирски');
INSERT INTO "languageNames" VALUES(4436,'sr','gag','гагауз');
INSERT INTO "languageNames" VALUES(4437,'sr','gd','шкотски гелски');
INSERT INTO "languageNames" VALUES(4438,'sr','gl','галицијски');
INSERT INTO "languageNames" VALUES(4439,'sr','gn','гварани');
INSERT INTO "languageNames" VALUES(4440,'sr','gu','гуџарати');
INSERT INTO "languageNames" VALUES(4441,'sr','gv','манкс');
INSERT INTO "languageNames" VALUES(4442,'sr','ha','хауса');
INSERT INTO "languageNames" VALUES(4443,'sr','haw','хавајски');
INSERT INTO "languageNames" VALUES(4444,'sr','he','хебрејски');
INSERT INTO "languageNames" VALUES(4445,'sr','hi','хинди');
INSERT INTO "languageNames" VALUES(4446,'sr','hr','хрватски');
INSERT INTO "languageNames" VALUES(4447,'sr','hsb','горњи лужичкосрпски');
INSERT INTO "languageNames" VALUES(4448,'sr','ht','хаићански');
INSERT INTO "languageNames" VALUES(4449,'sr','hu','мађарски');
INSERT INTO "languageNames" VALUES(4450,'sr','hy','јерменски');
INSERT INTO "languageNames" VALUES(4451,'sr','ia','интерлингва');
INSERT INTO "languageNames" VALUES(4452,'sr','id','индонежански');
INSERT INTO "languageNames" VALUES(4453,'sr','ig','игбо');
INSERT INTO "languageNames" VALUES(4454,'sr','is','исландски');
INSERT INTO "languageNames" VALUES(4455,'sr','it','италијански');
INSERT INTO "languageNames" VALUES(4456,'sr','ka','грузијски');
INSERT INTO "languageNames" VALUES(4457,'sr','kaa','кара-калпашки');
INSERT INTO "languageNames" VALUES(4458,'sr','kk','казашки');
INSERT INTO "languageNames" VALUES(4459,'sr','ko','корејски');
INSERT INTO "languageNames" VALUES(4460,'sr','krc','карачајско-балкарски');
INSERT INTO "languageNames" VALUES(4461,'sr','krl','карелски');
INSERT INTO "languageNames" VALUES(4462,'sr','ks','кашмирски');
INSERT INTO "languageNames" VALUES(4463,'sr','kum','кумички');
INSERT INTO "languageNames" VALUES(4464,'sr','kv','коми');
INSERT INTO "languageNames" VALUES(4465,'sr','ky','киргиски');
INSERT INTO "languageNames" VALUES(4466,'sr','la','латински');
INSERT INTO "languageNames" VALUES(4467,'sr','lb','луксембуршки');
INSERT INTO "languageNames" VALUES(4468,'sr','lg','ганда');
INSERT INTO "languageNames" VALUES(4469,'sr','ln','лингала');
INSERT INTO "languageNames" VALUES(4470,'sr','lo','лаоски');
INSERT INTO "languageNames" VALUES(4471,'sr','lt','литвански');
INSERT INTO "languageNames" VALUES(4472,'sr','lv','летонски');
INSERT INTO "languageNames" VALUES(4473,'sr','mdf','мокша');
INSERT INTO "languageNames" VALUES(4474,'sr','mfe','морисјен');
INSERT INTO "languageNames" VALUES(4475,'sr','mk','македонски');
INSERT INTO "languageNames" VALUES(4476,'sr','ml','малајалам');
INSERT INTO "languageNames" VALUES(4477,'sr','mr','марати');
INSERT INTO "languageNames" VALUES(4478,'sr','ms','малајски');
INSERT INTO "languageNames" VALUES(4479,'sr','mt','малтешки');
INSERT INTO "languageNames" VALUES(4480,'sr','myv','ерзја');
INSERT INTO "languageNames" VALUES(4481,'sr','nap','напуљски');
INSERT INTO "languageNames" VALUES(4482,'sr','nb','норвешки букмол');
INSERT INTO "languageNames" VALUES(4483,'sr','ne','непалски');
INSERT INTO "languageNames" VALUES(4484,'sr','nl','холандски');
INSERT INTO "languageNames" VALUES(4485,'sr','nn','норвешки нинорск');
INSERT INTO "languageNames" VALUES(4486,'sr','no','норвешки');
INSERT INTO "languageNames" VALUES(4487,'sr','nog','ногајски');
INSERT INTO "languageNames" VALUES(4488,'sr','oc','окситански');
INSERT INTO "languageNames" VALUES(4489,'sr','os','осетински');
INSERT INTO "languageNames" VALUES(4490,'sr','ota','османски турски');
INSERT INTO "languageNames" VALUES(4491,'sr','pa','пенџапски');
INSERT INTO "languageNames" VALUES(4492,'sr','pl','пољски');
INSERT INTO "languageNames" VALUES(4493,'sr','pt','португалски');
INSERT INTO "languageNames" VALUES(4494,'sr','rm','романш');
INSERT INTO "languageNames" VALUES(4495,'sr','rn','кирунди');
INSERT INTO "languageNames" VALUES(4496,'sr','ro','румунски');
INSERT INTO "languageNames" VALUES(4497,'sr','ru','руски');
INSERT INTO "languageNames" VALUES(4498,'sr','rup','цинцарски');
INSERT INTO "languageNames" VALUES(4499,'sr','sa','санскрит');
INSERT INTO "languageNames" VALUES(4500,'sr','sah','саха');
INSERT INTO "languageNames" VALUES(4501,'sr','sc','сардински');
INSERT INTO "languageNames" VALUES(4502,'sr','scn','сицилијански');
INSERT INTO "languageNames" VALUES(4503,'sr','sco','шкотски');
INSERT INTO "languageNames" VALUES(4504,'sr','sd','синди');
INSERT INTO "languageNames" VALUES(4505,'sr','se','северни сами');
INSERT INTO "languageNames" VALUES(4506,'sr','sh','српскохрватски');
INSERT INTO "languageNames" VALUES(4507,'sr','si','синхалешки');
INSERT INTO "languageNames" VALUES(4508,'sr','sk','словачки');
INSERT INTO "languageNames" VALUES(4509,'sr','sl','словеначки');
INSERT INTO "languageNames" VALUES(4510,'sr','sma','јужни сами');
INSERT INTO "languageNames" VALUES(4511,'sr','smj','луле сами');
INSERT INTO "languageNames" VALUES(4512,'sr','smn','инари сами');
INSERT INTO "languageNames" VALUES(4513,'sr','sq','албански');
INSERT INTO "languageNames" VALUES(4514,'sr','sr','српски');
INSERT INTO "languageNames" VALUES(4515,'sr','srn','сранан тонго');
INSERT INTO "languageNames" VALUES(4516,'sr','ss','свази');
INSERT INTO "languageNames" VALUES(4517,'sr','sv','шведски');
INSERT INTO "languageNames" VALUES(4518,'sr','sw','свахили');
INSERT INTO "languageNames" VALUES(4519,'sr','ta','тамилски');
INSERT INTO "languageNames" VALUES(4520,'sr','te','телугу');
INSERT INTO "languageNames" VALUES(4521,'sr','tet','тетум');
INSERT INTO "languageNames" VALUES(4522,'sr','tg','таџички');
INSERT INTO "languageNames" VALUES(4523,'sr','th','тајски');
INSERT INTO "languageNames" VALUES(4524,'sr','tk','туркменски');
INSERT INTO "languageNames" VALUES(4525,'sr','tl','тагалог');
INSERT INTO "languageNames" VALUES(4526,'sr','tr','турски');
INSERT INTO "languageNames" VALUES(4527,'sr','tt','татарски');
INSERT INTO "languageNames" VALUES(4528,'sr','tyv','тувински');
INSERT INTO "languageNames" VALUES(4529,'sr','udm','удмуртски');
INSERT INTO "languageNames" VALUES(4530,'sr','ug','ујгурски');
INSERT INTO "languageNames" VALUES(4531,'sr','uk','украјински');
INSERT INTO "languageNames" VALUES(4532,'sr','ur','урду');
INSERT INTO "languageNames" VALUES(4533,'sr','uz','узбечки');
INSERT INTO "languageNames" VALUES(4534,'sr','vi','вијетнамски');
INSERT INTO "languageNames" VALUES(4535,'sr','wal','волајта');
INSERT INTO "languageNames" VALUES(4536,'sr','xh','коса');
INSERT INTO "languageNames" VALUES(4537,'sr','yi','јидиш');
INSERT INTO "languageNames" VALUES(4538,'sr','yo','јоруба');
INSERT INTO "languageNames" VALUES(4539,'sr','zh','кинески');
INSERT INTO "languageNames" VALUES(4540,'sr','zu','зулу');
INSERT INTO "languageNames" VALUES(4541,'ca','af','afrikaans');
INSERT INTO "languageNames" VALUES(4542,'ca','alt','altaic meridional');
INSERT INTO "languageNames" VALUES(4543,'ca','an','aragonès');
INSERT INTO "languageNames" VALUES(4544,'ca','ar','àrab');
INSERT INTO "languageNames" VALUES(4545,'ca','as','assamès');
INSERT INTO "languageNames" VALUES(4546,'ca','ast','asturià');
INSERT INTO "languageNames" VALUES(4547,'ca','av','àvar');
INSERT INTO "languageNames" VALUES(4549,'ca','az','àzeri');
INSERT INTO "languageNames" VALUES(4550,'ca','ba','baixkir');
INSERT INTO "languageNames" VALUES(4551,'ca','be','bielorús');
INSERT INTO "languageNames" VALUES(4552,'ca','bg','búlgar');
INSERT INTO "languageNames" VALUES(4553,'ca','bi','bislama');
INSERT INTO "languageNames" VALUES(4554,'ca','bn','bengalí');
INSERT INTO "languageNames" VALUES(4555,'ca','br','bretó');
INSERT INTO "languageNames" VALUES(4556,'ca','bs','bosnià');
INSERT INTO "languageNames" VALUES(4557,'ca','bua','buriat');
INSERT INTO "languageNames" VALUES(4558,'ca','byv','medumba');
INSERT INTO "languageNames" VALUES(4559,'ca','ca','català');
INSERT INTO "languageNames" VALUES(4560,'ca','ceb','cebuano');
INSERT INTO "languageNames" VALUES(4561,'ca','chm','mari');
INSERT INTO "languageNames" VALUES(4562,'ca','ckb','kurd central');
INSERT INTO "languageNames" VALUES(4563,'ca','co','cors');
INSERT INTO "languageNames" VALUES(4564,'ca','crh','tàtar de Crimea');
INSERT INTO "languageNames" VALUES(4565,'ca','cs','txec');
INSERT INTO "languageNames" VALUES(4566,'ca','csb','caixubi');
INSERT INTO "languageNames" VALUES(4567,'ca','cu','eslau eclesiàstic');
INSERT INTO "languageNames" VALUES(4568,'ca','cv','txuvaix');
INSERT INTO "languageNames" VALUES(4569,'ca','cy','gal·lès');
INSERT INTO "languageNames" VALUES(4570,'ca','da','danès');
INSERT INTO "languageNames" VALUES(4571,'ca','dar','darguà');
INSERT INTO "languageNames" VALUES(4572,'ca','de','alemany');
INSERT INTO "languageNames" VALUES(4573,'ca','dsb','baix sòrab');
INSERT INTO "languageNames" VALUES(4574,'ca','el','grec');
INSERT INTO "languageNames" VALUES(4575,'ca','en','anglès');
INSERT INTO "languageNames" VALUES(4576,'ca','eo','esperanto');
INSERT INTO "languageNames" VALUES(4577,'ca','es','espanyol');
INSERT INTO "languageNames" VALUES(4578,'ca','et','estonià');
INSERT INTO "languageNames" VALUES(4579,'ca','eu','basc');
INSERT INTO "languageNames" VALUES(4580,'ca','fa','persa');
INSERT INTO "languageNames" VALUES(4581,'ca','fi','finès');
INSERT INTO "languageNames" VALUES(4582,'ca','fo','feroès');
INSERT INTO "languageNames" VALUES(4583,'ca','fr','francès');
INSERT INTO "languageNames" VALUES(4584,'ca','fy','frisó occidental');
INSERT INTO "languageNames" VALUES(4585,'ca','ga','irlandès');
INSERT INTO "languageNames" VALUES(4586,'ca','gag','gagaús');
INSERT INTO "languageNames" VALUES(4587,'ca','gd','gaèlic escocès');
INSERT INTO "languageNames" VALUES(4588,'ca','gl','gallec');
INSERT INTO "languageNames" VALUES(4589,'ca','glk','gilaki');
INSERT INTO "languageNames" VALUES(4590,'ca','gn','guaraní');
INSERT INTO "languageNames" VALUES(4591,'ca','gu','gujarati');
INSERT INTO "languageNames" VALUES(4592,'ca','guc','wayú');
INSERT INTO "languageNames" VALUES(4593,'ca','gv','manx');
INSERT INTO "languageNames" VALUES(4594,'ca','ha','haussa');
INSERT INTO "languageNames" VALUES(4595,'ca','haw','hawaià');
INSERT INTO "languageNames" VALUES(4596,'ca','he','hebreu');
INSERT INTO "languageNames" VALUES(4597,'ca','hi','hindi');
INSERT INTO "languageNames" VALUES(4598,'ca','hr','croat');
INSERT INTO "languageNames" VALUES(4599,'ca','hsb','alt sòrab');
INSERT INTO "languageNames" VALUES(4600,'ca','ht','crioll d’Haití');
INSERT INTO "languageNames" VALUES(4601,'ca','hu','hongarès');
INSERT INTO "languageNames" VALUES(4602,'ca','hy','armeni');
INSERT INTO "languageNames" VALUES(4603,'ca','ia','interlingua');
INSERT INTO "languageNames" VALUES(4604,'ca','id','indonesi');
INSERT INTO "languageNames" VALUES(4605,'ca','ig','igbo');
INSERT INTO "languageNames" VALUES(4606,'ca','is','islandès');
INSERT INTO "languageNames" VALUES(4607,'ca','it','italià');
INSERT INTO "languageNames" VALUES(4608,'ca','ka','georgià');
INSERT INTO "languageNames" VALUES(4609,'ca','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(4610,'ca','kk','kazakh');
INSERT INTO "languageNames" VALUES(4611,'ca','ko','coreà');
INSERT INTO "languageNames" VALUES(4612,'ca','krc','karatxai-balkar');
INSERT INTO "languageNames" VALUES(4613,'ca','krl','carelià');
INSERT INTO "languageNames" VALUES(4614,'ca','ks','caixmiri');
INSERT INTO "languageNames" VALUES(4615,'ca','kum','kúmik');
INSERT INTO "languageNames" VALUES(4616,'ca','kv','komi');
INSERT INTO "languageNames" VALUES(4617,'ca','ky','kirguís');
INSERT INTO "languageNames" VALUES(4618,'ca','la','llatí');
INSERT INTO "languageNames" VALUES(4619,'ca','lb','luxemburguès');
INSERT INTO "languageNames" VALUES(4620,'ca','lg','ganda');
INSERT INTO "languageNames" VALUES(4621,'ca','ln','lingala');
INSERT INTO "languageNames" VALUES(4622,'ca','lo','laosià');
INSERT INTO "languageNames" VALUES(4623,'ca','lt','lituà');
INSERT INTO "languageNames" VALUES(4624,'ca','lv','letó');
INSERT INTO "languageNames" VALUES(4625,'ca','mdf','mordovià moksa');
INSERT INTO "languageNames" VALUES(4626,'ca','mfe','mauricià');
INSERT INTO "languageNames" VALUES(4627,'ca','mk','macedoni');
INSERT INTO "languageNames" VALUES(4628,'ca','ml','malaialam');
INSERT INTO "languageNames" VALUES(4629,'ca','mr','marathi');
INSERT INTO "languageNames" VALUES(4630,'ca','mrj','mari occidental');
INSERT INTO "languageNames" VALUES(4631,'ca','ms','malai');
INSERT INTO "languageNames" VALUES(4632,'ca','mt','maltès');
INSERT INTO "languageNames" VALUES(4633,'ca','myv','mordovià erza');
INSERT INTO "languageNames" VALUES(4634,'ca','nap','napolità');
INSERT INTO "languageNames" VALUES(4635,'ca','nb','noruec bokmål');
INSERT INTO "languageNames" VALUES(4636,'ca','ne','nepalès');
INSERT INTO "languageNames" VALUES(4637,'ca','nl','neerlandès');
INSERT INTO "languageNames" VALUES(4638,'ca','nn','noruec nynorsk');
INSERT INTO "languageNames" VALUES(4639,'ca','no','noruec');
INSERT INTO "languageNames" VALUES(4640,'ca','nog','nogai');
INSERT INTO "languageNames" VALUES(4641,'ca','oc','occità');
INSERT INTO "languageNames" VALUES(4642,'ca','os','osseta');
INSERT INTO "languageNames" VALUES(4643,'ca','ota','turc otomà');
INSERT INTO "languageNames" VALUES(4644,'ca','pa','panjabi');
INSERT INTO "languageNames" VALUES(4645,'ca','pl','polonès');
INSERT INTO "languageNames" VALUES(4646,'ca','pt','portuguès');
INSERT INTO "languageNames" VALUES(4647,'ca','rm','retoromànic');
INSERT INTO "languageNames" VALUES(4648,'ca','rn','rundi');
INSERT INTO "languageNames" VALUES(4649,'ca','ro','romanès');
INSERT INTO "languageNames" VALUES(4650,'ca','ru','rus');
INSERT INTO "languageNames" VALUES(4651,'ca','rup','aromanès');
INSERT INTO "languageNames" VALUES(4652,'ca','sa','sànscrit');
INSERT INTO "languageNames" VALUES(4653,'ca','sah','iacut');
INSERT INTO "languageNames" VALUES(4654,'ca','sc','sard');
INSERT INTO "languageNames" VALUES(4655,'ca','scn','sicilià');
INSERT INTO "languageNames" VALUES(4656,'ca','sco','escocès');
INSERT INTO "languageNames" VALUES(4657,'ca','sd','sindi');
INSERT INTO "languageNames" VALUES(4658,'ca','se','sami septentrional');
INSERT INTO "languageNames" VALUES(4659,'ca','sh','serbocroat');
INSERT INTO "languageNames" VALUES(4660,'ca','si','singalès');
INSERT INTO "languageNames" VALUES(4661,'ca','sk','eslovac');
INSERT INTO "languageNames" VALUES(4662,'ca','sl','eslovè');
INSERT INTO "languageNames" VALUES(4663,'ca','sma','sami meridional');
INSERT INTO "languageNames" VALUES(4664,'ca','smj','sami lule');
INSERT INTO "languageNames" VALUES(4665,'ca','smn','sami d’Inari');
INSERT INTO "languageNames" VALUES(4666,'ca','sq','albanès');
INSERT INTO "languageNames" VALUES(4667,'ca','sr','serbi');
INSERT INTO "languageNames" VALUES(4668,'ca','srn','sranan');
INSERT INTO "languageNames" VALUES(4669,'ca','ss','swazi');
INSERT INTO "languageNames" VALUES(4670,'ca','sv','suec');
INSERT INTO "languageNames" VALUES(4671,'ca','sw','suahili');
INSERT INTO "languageNames" VALUES(4672,'ca','ta','tàmil');
INSERT INTO "languageNames" VALUES(4673,'ca','te','telugu');
INSERT INTO "languageNames" VALUES(4674,'ca','tet','tètum');
INSERT INTO "languageNames" VALUES(4675,'ca','tg','tadjik');
INSERT INTO "languageNames" VALUES(4676,'ca','th','tai');
INSERT INTO "languageNames" VALUES(4677,'ca','tk','turcman');
INSERT INTO "languageNames" VALUES(4678,'ca','tl','tagal');
INSERT INTO "languageNames" VALUES(4679,'ca','tr','turc');
INSERT INTO "languageNames" VALUES(4680,'ca','tt','tàtar');
INSERT INTO "languageNames" VALUES(4681,'ca','tyv','tuvinià');
INSERT INTO "languageNames" VALUES(4682,'ca','udm','udmurt');
INSERT INTO "languageNames" VALUES(4683,'ca','ug','uigur');
INSERT INTO "languageNames" VALUES(4684,'ca','uk','ucraïnès');
INSERT INTO "languageNames" VALUES(4685,'ca','ur','urdú');
INSERT INTO "languageNames" VALUES(4686,'ca','uz','uzbek');
INSERT INTO "languageNames" VALUES(4687,'ca','vi','vietnamita');
INSERT INTO "languageNames" VALUES(4688,'ca','wal','ameto');
INSERT INTO "languageNames" VALUES(4689,'ca','xh','xosa');
INSERT INTO "languageNames" VALUES(4690,'ca','yi','jiddisch');
INSERT INTO "languageNames" VALUES(4691,'ca','yo','ioruba');
INSERT INTO "languageNames" VALUES(4692,'ca','zh','xinès');
INSERT INTO "languageNames" VALUES(4693,'ca','zu','zulu');
INSERT INTO "languageNames" VALUES(4694,'sah','af','Аппырыкааныстыы');
INSERT INTO "languageNames" VALUES(4695,'sah','ar','Араабтыы');
INSERT INTO "languageNames" VALUES(4696,'sah','ast','Астуурдуу');
INSERT INTO "languageNames" VALUES(4697,'sah','av','Аваардыы');
INSERT INTO "languageNames" VALUES(4698,'sah','az','Адьырбайдьаанныы');
INSERT INTO "languageNames" VALUES(4699,'sah','be','Бөлөрүүстүү');
INSERT INTO "languageNames" VALUES(4700,'sah','bg','Булҕаардыы');
INSERT INTO "languageNames" VALUES(4701,'sah','bn','Бенгаллыы');
INSERT INTO "languageNames" VALUES(4702,'sah','bs','Босныйалыы');
INSERT INTO "languageNames" VALUES(4703,'sah','ca','Каталаанныы');
INSERT INTO "languageNames" VALUES(4704,'sah','ckb','Киин куурдуу');
INSERT INTO "languageNames" VALUES(4705,'sah','cs','Чиэхтии');
INSERT INTO "languageNames" VALUES(4706,'sah','da','Даатскайдыы');
INSERT INTO "languageNames" VALUES(4707,'sah','de','Ниэмэстии');
INSERT INTO "languageNames" VALUES(4708,'sah','el','Гириэктии');
INSERT INTO "languageNames" VALUES(4709,'sah','en','Ааҥыллыы');
INSERT INTO "languageNames" VALUES(4710,'sah','es','Ыспаанныы');
INSERT INTO "languageNames" VALUES(4711,'sah','et','Эстиэнийэлии');
INSERT INTO "languageNames" VALUES(4712,'sah','fa','Пиэристии');
INSERT INTO "languageNames" VALUES(4713,'sah','fi','Пииннии');
INSERT INTO "languageNames" VALUES(4714,'sah','fr','Боронсуустуу');
INSERT INTO "languageNames" VALUES(4715,'sah','hu','Бэҥгиэрдии');
INSERT INTO "languageNames" VALUES(4716,'sah','hy','Эрмээннии');
INSERT INTO "languageNames" VALUES(4717,'sah','it','Ытаалыйалыы');
INSERT INTO "languageNames" VALUES(4718,'sah','ka','Курусууннуу');
INSERT INTO "languageNames" VALUES(4719,'sah','kk','Хаһаахтыы');
INSERT INTO "languageNames" VALUES(4720,'sah','ko','Кэриэйдии');
INSERT INTO "languageNames" VALUES(4721,'sah','ky','Кыргыстыы');
INSERT INTO "languageNames" VALUES(4722,'sah','la','Латыынныы');
INSERT INTO "languageNames" VALUES(4723,'sah','ms','Малаайдыы');
INSERT INTO "languageNames" VALUES(4724,'sah','ne','Ньыпааллыы');
INSERT INTO "languageNames" VALUES(4725,'sah','nog','Нагаайдыы');
INSERT INTO "languageNames" VALUES(4726,'sah','pa','Пандьаабтыы');
INSERT INTO "languageNames" VALUES(4727,'sah','pt','Португааллыы');
INSERT INTO "languageNames" VALUES(4728,'sah','ro','Румыынныы');
INSERT INTO "languageNames" VALUES(4729,'sah','ru','Нууччалыы');
INSERT INTO "languageNames" VALUES(4730,'sah','sah','саха тыла');
INSERT INTO "languageNames" VALUES(4731,'sah','sk','Словаактыы');
INSERT INTO "languageNames" VALUES(4732,'sah','sq','Албаанныы');
INSERT INTO "languageNames" VALUES(4733,'sah','ta','Тамыллыы');
INSERT INTO "languageNames" VALUES(4734,'sah','te','Төлүгүлүү');
INSERT INTO "languageNames" VALUES(4735,'sah','tg','Тадьыыктыы');
INSERT INTO "languageNames" VALUES(4736,'sah','tt','Татаардыы');
INSERT INTO "languageNames" VALUES(4737,'sah','ug','Уйгуурдуу');
INSERT INTO "languageNames" VALUES(4738,'sah','uk','Украйыыньыстыы');
INSERT INTO "languageNames" VALUES(4739,'sah','uz','Үзбиэктии');
INSERT INTO "languageNames" VALUES(4740,'sah','zh','Кытайдыы');
INSERT INTO "languageNames" VALUES(4741,'sah','zu','Зуулулуу');
INSERT INTO "languageNames" VALUES(4742,'ga','af','Afracáinis');
INSERT INTO "languageNames" VALUES(4743,'ga','alt','alt');
INSERT INTO "languageNames" VALUES(4744,'ga','an','Aragóinis');
INSERT INTO "languageNames" VALUES(4745,'ga','ar','Araibis');
INSERT INTO "languageNames" VALUES(4746,'ga','as','Asaimis');
INSERT INTO "languageNames" VALUES(4747,'ga','ast','Astúiris');
INSERT INTO "languageNames" VALUES(4748,'ga','av','Aváiris');
INSERT INTO "languageNames" VALUES(4750,'ga','az','Asairis');
INSERT INTO "languageNames" VALUES(4751,'ga','ba','Baiscíris');
INSERT INTO "languageNames" VALUES(4752,'ga','be','Bealarúisis');
INSERT INTO "languageNames" VALUES(4753,'ga','bg','Bulgáiris');
INSERT INTO "languageNames" VALUES(4754,'ga','bi','Bioslaimis');
INSERT INTO "languageNames" VALUES(4755,'ga','bn','Beangáilis');
INSERT INTO "languageNames" VALUES(4756,'ga','br','Briotáinis');
INSERT INTO "languageNames" VALUES(4757,'ga','bs','Boisnis');
INSERT INTO "languageNames" VALUES(4758,'ga','bua','Buiriáitis');
INSERT INTO "languageNames" VALUES(4759,'ga','ca','Catalóinis');
INSERT INTO "languageNames" VALUES(4760,'ga','ceb','Seabúáinis');
INSERT INTO "languageNames" VALUES(4761,'ga','chm','Mairis');
INSERT INTO "languageNames" VALUES(4762,'ga','ckb','Coirdis Lárnach');
INSERT INTO "languageNames" VALUES(4763,'ga','co','Corsaicis');
INSERT INTO "languageNames" VALUES(4764,'ga','cs','Seicis');
INSERT INTO "languageNames" VALUES(4765,'ga','csb','Caisiúibis');
INSERT INTO "languageNames" VALUES(4766,'ga','cu','Slavais na hEaglaise');
INSERT INTO "languageNames" VALUES(4767,'ga','cv','Suvaisis');
INSERT INTO "languageNames" VALUES(4768,'ga','cy','Breatnais');
INSERT INTO "languageNames" VALUES(4769,'ga','da','Danmhairgis');
INSERT INTO "languageNames" VALUES(4770,'ga','dar','dar');
INSERT INTO "languageNames" VALUES(4771,'ga','de','Gearmáinis');
INSERT INTO "languageNames" VALUES(4772,'ga','dsb','Sorbais Íochtarach');
INSERT INTO "languageNames" VALUES(4773,'ga','el','Gréigis');
INSERT INTO "languageNames" VALUES(4774,'ga','en','Béarla');
INSERT INTO "languageNames" VALUES(4775,'ga','eo','Esperanto');
INSERT INTO "languageNames" VALUES(4776,'ga','es','Spáinnis');
INSERT INTO "languageNames" VALUES(4777,'ga','et','Eastóinis');
INSERT INTO "languageNames" VALUES(4778,'ga','eu','Bascais');
INSERT INTO "languageNames" VALUES(4779,'ga','fa','Peirsis');
INSERT INTO "languageNames" VALUES(4780,'ga','fi','Fionlainnis');
INSERT INTO "languageNames" VALUES(4781,'ga','fo','Faróis');
INSERT INTO "languageNames" VALUES(4782,'ga','fr','Fraincis');
INSERT INTO "languageNames" VALUES(4783,'ga','fy','Freaslainnis Iartharach');
INSERT INTO "languageNames" VALUES(4784,'ga','ga','Gaeilge');
INSERT INTO "languageNames" VALUES(4785,'ga','gd','Gaeilge na hAlban');
INSERT INTO "languageNames" VALUES(4786,'ga','gl','Gailísis');
INSERT INTO "languageNames" VALUES(4787,'ga','gn','Guaráinis');
INSERT INTO "languageNames" VALUES(4788,'ga','gu','Gúisearáitis');
INSERT INTO "languageNames" VALUES(4789,'ga','guc','Uaúis');
INSERT INTO "languageNames" VALUES(4790,'ga','gv','Manainnis');
INSERT INTO "languageNames" VALUES(4791,'ga','ha','Hásais');
INSERT INTO "languageNames" VALUES(4792,'ga','haw','Haváis');
INSERT INTO "languageNames" VALUES(4793,'ga','he','Eabhrais');
INSERT INTO "languageNames" VALUES(4794,'ga','hi','Hiondúis');
INSERT INTO "languageNames" VALUES(4795,'ga','hr','Cróitis');
INSERT INTO "languageNames" VALUES(4796,'ga','hsb','Sorbais Uachtarach');
INSERT INTO "languageNames" VALUES(4797,'ga','ht','Criól Háítíoch');
INSERT INTO "languageNames" VALUES(4798,'ga','hu','Ungáiris');
INSERT INTO "languageNames" VALUES(4799,'ga','hy','Airméinis');
INSERT INTO "languageNames" VALUES(4800,'ga','ia','Interlingua');
INSERT INTO "languageNames" VALUES(4801,'ga','id','Indinéisis');
INSERT INTO "languageNames" VALUES(4802,'ga','ig','Íogbóis');
INSERT INTO "languageNames" VALUES(4803,'ga','is','Íoslainnis');
INSERT INTO "languageNames" VALUES(4804,'ga','it','Iodáilis');
INSERT INTO "languageNames" VALUES(4805,'ga','ka','Seoirsis');
INSERT INTO "languageNames" VALUES(4806,'ga','kaa','Cara-Chalpáis');
INSERT INTO "languageNames" VALUES(4807,'ga','kk','Casaicis');
INSERT INTO "languageNames" VALUES(4808,'ga','ko','Cóiréis');
INSERT INTO "languageNames" VALUES(4809,'ga','krc','krc');
INSERT INTO "languageNames" VALUES(4810,'ga','krl','Cairéilis');
INSERT INTO "languageNames" VALUES(4811,'ga','ks','Caismíris');
INSERT INTO "languageNames" VALUES(4812,'ga','kum','kum');
INSERT INTO "languageNames" VALUES(4813,'ga','kv','Coimis');
INSERT INTO "languageNames" VALUES(4814,'ga','ky','Cirgisis');
INSERT INTO "languageNames" VALUES(4815,'ga','la','Laidin');
INSERT INTO "languageNames" VALUES(4816,'ga','lb','Lucsambuirgis');
INSERT INTO "languageNames" VALUES(4817,'ga','lg','Lugandais');
INSERT INTO "languageNames" VALUES(4818,'ga','liv','Liovóinis');
INSERT INTO "languageNames" VALUES(4819,'ga','ln','Liongáilis');
INSERT INTO "languageNames" VALUES(4820,'ga','lo','Laoisis');
INSERT INTO "languageNames" VALUES(4821,'ga','lt','Liotuáinis');
INSERT INTO "languageNames" VALUES(4822,'ga','lv','Laitvis');
INSERT INTO "languageNames" VALUES(4823,'ga','mdf','mdf');
INSERT INTO "languageNames" VALUES(4824,'ga','mfe','mfe');
INSERT INTO "languageNames" VALUES(4825,'ga','mk','Macadóinis');
INSERT INTO "languageNames" VALUES(4826,'ga','ml','Mailéalaimis');
INSERT INTO "languageNames" VALUES(4827,'ga','mr','Maraitis');
INSERT INTO "languageNames" VALUES(4828,'ga','mrj','Mairis Iartharach');
INSERT INTO "languageNames" VALUES(4829,'ga','ms','Malaeis');
INSERT INTO "languageNames" VALUES(4830,'ga','mt','Máltais');
INSERT INTO "languageNames" VALUES(4831,'ga','myv','myv');
INSERT INTO "languageNames" VALUES(4832,'ga','nap','Napóilis');
INSERT INTO "languageNames" VALUES(4833,'ga','nb','Ioruais Bokmål');
INSERT INTO "languageNames" VALUES(4834,'ga','ne','Neipeailis');
INSERT INTO "languageNames" VALUES(4835,'ga','nl','Ollainnis');
INSERT INTO "languageNames" VALUES(4836,'ga','nn','Nua-Ioruais');
INSERT INTO "languageNames" VALUES(4837,'ga','no','Ioruais');
INSERT INTO "languageNames" VALUES(4838,'ga','nog','nog');
INSERT INTO "languageNames" VALUES(4839,'ga','oc','Ocsatáinis');
INSERT INTO "languageNames" VALUES(4840,'ga','os','Oiséitis');
INSERT INTO "languageNames" VALUES(4841,'ga','pa','Puinseáibis');
INSERT INTO "languageNames" VALUES(4842,'ga','pl','Polainnis');
INSERT INTO "languageNames" VALUES(4843,'ga','pt','Portaingéilis');
INSERT INTO "languageNames" VALUES(4844,'ga','rm','Rómainis');
INSERT INTO "languageNames" VALUES(4845,'ga','rn','Rúindis');
INSERT INTO "languageNames" VALUES(4846,'ga','ro','Rómáinis');
INSERT INTO "languageNames" VALUES(4847,'ga','ru','Rúisis');
INSERT INTO "languageNames" VALUES(4848,'ga','rup','Arómáinis');
INSERT INTO "languageNames" VALUES(4849,'ga','sa','Sanscrait');
INSERT INTO "languageNames" VALUES(4850,'ga','sah','Sachais');
INSERT INTO "languageNames" VALUES(4851,'ga','sc','Sairdínis');
INSERT INTO "languageNames" VALUES(4852,'ga','scn','Sicilis');
INSERT INTO "languageNames" VALUES(4853,'ga','sco','Albainis');
INSERT INTO "languageNames" VALUES(4854,'ga','sd','Sindis');
INSERT INTO "languageNames" VALUES(4855,'ga','se','Sáimis Thuaidh');
INSERT INTO "languageNames" VALUES(4856,'ga','sh','Seirbea-Chróitis');
INSERT INTO "languageNames" VALUES(4857,'ga','si','Siolóinis');
INSERT INTO "languageNames" VALUES(4858,'ga','sk','Slóvaicis');
INSERT INTO "languageNames" VALUES(4859,'ga','sl','Slóivéinis');
INSERT INTO "languageNames" VALUES(4860,'ga','sma','Sáimis Theas');
INSERT INTO "languageNames" VALUES(4861,'ga','smj','Sáimis Lule');
INSERT INTO "languageNames" VALUES(4862,'ga','smn','Sáimis Inari');
INSERT INTO "languageNames" VALUES(4863,'ga','sq','Albáinis');
INSERT INTO "languageNames" VALUES(4864,'ga','sr','Seirbis');
INSERT INTO "languageNames" VALUES(4865,'ga','srn','srn');
INSERT INTO "languageNames" VALUES(4866,'ga','ss','Suaisis');
INSERT INTO "languageNames" VALUES(4867,'ga','sv','Sualainnis');
INSERT INTO "languageNames" VALUES(4868,'ga','sw','Svahaílis');
INSERT INTO "languageNames" VALUES(4869,'ga','ta','Tamailis');
INSERT INTO "languageNames" VALUES(4870,'ga','te','Teileagúis');
INSERT INTO "languageNames" VALUES(4871,'ga','tet','tet');
INSERT INTO "languageNames" VALUES(4872,'ga','tg','Táidsícis');
INSERT INTO "languageNames" VALUES(4873,'ga','th','Téalainnis');
INSERT INTO "languageNames" VALUES(4874,'ga','tk','Tuircméinis');
INSERT INTO "languageNames" VALUES(4875,'ga','tl','Tagálaigis');
INSERT INTO "languageNames" VALUES(4876,'ga','tr','Tuircis');
INSERT INTO "languageNames" VALUES(4877,'ga','tt','Tatairis');
INSERT INTO "languageNames" VALUES(4878,'ga','tyv','tyv');
INSERT INTO "languageNames" VALUES(4879,'ga','udm','Udmairtis');
INSERT INTO "languageNames" VALUES(4880,'ga','ug','Uigiúiris');
INSERT INTO "languageNames" VALUES(4881,'ga','uk','Úcráinis');
INSERT INTO "languageNames" VALUES(4882,'ga','ur','Urdúis');
INSERT INTO "languageNames" VALUES(4883,'ga','uz','Úisbéiceastáinis');
INSERT INTO "languageNames" VALUES(4884,'ga','vi','Vítneaimis');
INSERT INTO "languageNames" VALUES(4885,'ga','wal','wal');
INSERT INTO "languageNames" VALUES(4886,'ga','xh','Cóisis');
INSERT INTO "languageNames" VALUES(4887,'ga','yi','Giúdais');
INSERT INTO "languageNames" VALUES(4888,'ga','yo','Iarúibis');
INSERT INTO "languageNames" VALUES(4889,'ga','zh','Sínis');
INSERT INTO "languageNames" VALUES(4890,'ga','zu','Súlúis');
INSERT INTO "languageNames" VALUES(4891,'smn','af','afrikaans');
INSERT INTO "languageNames" VALUES(4892,'smn','alt','maadâaltaikielâ');
INSERT INTO "languageNames" VALUES(4893,'smn','an','aragoniakielâ');
INSERT INTO "languageNames" VALUES(4894,'smn','ar','arabiakielâ');
INSERT INTO "languageNames" VALUES(4895,'smn','as','assamkielâ');
INSERT INTO "languageNames" VALUES(4896,'smn','ast','asturiakielâ');
INSERT INTO "languageNames" VALUES(4897,'smn','av','avarkielâ');
INSERT INTO "languageNames" VALUES(4898,'smn','az','azerbaidžankielâ');
INSERT INTO "languageNames" VALUES(4899,'smn','ba','baškirkielâ');
INSERT INTO "languageNames" VALUES(4900,'smn','be','vielgisruošâkielâ');
INSERT INTO "languageNames" VALUES(4901,'smn','bg','bulgariakielâ');
INSERT INTO "languageNames" VALUES(4902,'smn','bi','bislama');
INSERT INTO "languageNames" VALUES(4903,'smn','bn','banglakielâ');
INSERT INTO "languageNames" VALUES(4904,'smn','br','bretonkielâ');
INSERT INTO "languageNames" VALUES(4905,'smn','bs','bosniakielâ');
INSERT INTO "languageNames" VALUES(4906,'smn','ca','katalankielâ');
INSERT INTO "languageNames" VALUES(4907,'smn','ceb','cebuanokielâ');
INSERT INTO "languageNames" VALUES(4908,'smn','chm','marikielâ');
INSERT INTO "languageNames" VALUES(4909,'smn','ckb','sorani kurdikielâ');
INSERT INTO "languageNames" VALUES(4910,'smn','co','korsikakielâ');
INSERT INTO "languageNames" VALUES(4911,'smn','cs','tšeekikielâ');
INSERT INTO "languageNames" VALUES(4912,'smn','cu','kirkkoslaavi');
INSERT INTO "languageNames" VALUES(4913,'smn','cv','tšuvaskielâ');
INSERT INTO "languageNames" VALUES(4914,'smn','cy','kymrikielâ');
INSERT INTO "languageNames" VALUES(4915,'smn','da','tanskakielâ');
INSERT INTO "languageNames" VALUES(4916,'smn','dar','dargikielâ');
INSERT INTO "languageNames" VALUES(4917,'smn','de','saksakielâ');
INSERT INTO "languageNames" VALUES(4918,'smn','dsb','vyelisorbi');
INSERT INTO "languageNames" VALUES(4919,'smn','el','kreikakielâ');
INSERT INTO "languageNames" VALUES(4920,'smn','en','eŋgâlâskielâ');
INSERT INTO "languageNames" VALUES(4921,'smn','eo','esperantokielâ');
INSERT INTO "languageNames" VALUES(4922,'smn','es','espanjakielâ');
INSERT INTO "languageNames" VALUES(4923,'smn','et','eestikielâ');
INSERT INTO "languageNames" VALUES(4924,'smn','eu','baskikielâ');
INSERT INTO "languageNames" VALUES(4925,'smn','fa','persiakielâ');
INSERT INTO "languageNames" VALUES(4926,'smn','fi','suomâkielâ');
INSERT INTO "languageNames" VALUES(4927,'smn','fo','fäärikielâ');
INSERT INTO "languageNames" VALUES(4928,'smn','fr','ranskakielâ');
INSERT INTO "languageNames" VALUES(4929,'smn','fy','viestârfriisi');
INSERT INTO "languageNames" VALUES(4930,'smn','ga','iirikielâ');
INSERT INTO "languageNames" VALUES(4931,'smn','gd','skottilâš gaelikielâ');
INSERT INTO "languageNames" VALUES(4932,'smn','gl','galiciakielâ');
INSERT INTO "languageNames" VALUES(4933,'smn','gn','guaranikielâ');
INSERT INTO "languageNames" VALUES(4934,'smn','gu','gudžaratikielâ');
INSERT INTO "languageNames" VALUES(4935,'smn','gv','manks');
INSERT INTO "languageNames" VALUES(4936,'smn','ha','hausakielâ');
INSERT INTO "languageNames" VALUES(4937,'smn','haw','hawaijikielâ');
INSERT INTO "languageNames" VALUES(4938,'smn','he','hepreakielâ');
INSERT INTO "languageNames" VALUES(4939,'smn','hi','hindikielâ');
INSERT INTO "languageNames" VALUES(4940,'smn','hr','kroatiakielâ');
INSERT INTO "languageNames" VALUES(4941,'smn','hsb','pajesorbi');
INSERT INTO "languageNames" VALUES(4942,'smn','ht','Haiti kreoli');
INSERT INTO "languageNames" VALUES(4943,'smn','hu','uŋgarkielâ');
INSERT INTO "languageNames" VALUES(4944,'smn','hy','armeniakielâ');
INSERT INTO "languageNames" VALUES(4945,'smn','ia','interlingua');
INSERT INTO "languageNames" VALUES(4946,'smn','id','indonesiakielâ');
INSERT INTO "languageNames" VALUES(4947,'smn','ig','igbokielâ');
INSERT INTO "languageNames" VALUES(4948,'smn','is','islandkielâ');
INSERT INTO "languageNames" VALUES(4949,'smn','it','italiakielâ');
INSERT INTO "languageNames" VALUES(4950,'smn','ka','georgiakielâ');
INSERT INTO "languageNames" VALUES(4951,'smn','kk','kazakkielâ');
INSERT INTO "languageNames" VALUES(4952,'smn','ko','koreakielâ');
INSERT INTO "languageNames" VALUES(4953,'smn','krc','karachai-balkarkielâ');
INSERT INTO "languageNames" VALUES(4954,'smn','krl','kärjilkielâ');
INSERT INTO "languageNames" VALUES(4955,'smn','ks','kashmirkielâ');
INSERT INTO "languageNames" VALUES(4956,'smn','kum','kumykkielâ');
INSERT INTO "languageNames" VALUES(4957,'smn','kv','komikielâ');
INSERT INTO "languageNames" VALUES(4958,'smn','ky','kirgiskielâ');
INSERT INTO "languageNames" VALUES(4959,'smn','la','läättinkielâ');
INSERT INTO "languageNames" VALUES(4960,'smn','lb','luxemburgkielâ');
INSERT INTO "languageNames" VALUES(4961,'smn','lg','luganda');
INSERT INTO "languageNames" VALUES(4962,'smn','ln','lingala');
INSERT INTO "languageNames" VALUES(4963,'smn','lo','laokielâ');
INSERT INTO "languageNames" VALUES(4964,'smn','lt','liettuakielâ');
INSERT INTO "languageNames" VALUES(4965,'smn','lv','latviakielâ');
INSERT INTO "languageNames" VALUES(4966,'smn','mdf','mokšakielâ');
INSERT INTO "languageNames" VALUES(4967,'smn','mfe','morisyen');
INSERT INTO "languageNames" VALUES(4968,'smn','mk','makedoniakielâ');
INSERT INTO "languageNames" VALUES(4969,'smn','ml','malajam');
INSERT INTO "languageNames" VALUES(4970,'smn','mr','marathikielâ');
INSERT INTO "languageNames" VALUES(4971,'smn','mrj','viestârmari');
INSERT INTO "languageNames" VALUES(4972,'smn','ms','malaiji');
INSERT INTO "languageNames" VALUES(4973,'smn','mt','maltakielâ');
INSERT INTO "languageNames" VALUES(4974,'smn','myv','ersäkielâ');
INSERT INTO "languageNames" VALUES(4975,'smn','nap','napolikielâ');
INSERT INTO "languageNames" VALUES(4976,'smn','nb','tárukielâ bokmål');
INSERT INTO "languageNames" VALUES(4977,'smn','ne','nepalkielâ');
INSERT INTO "languageNames" VALUES(4978,'smn','nl','hollandkielâ');
INSERT INTO "languageNames" VALUES(4979,'smn','nn','tárukielâ nynorsk');
INSERT INTO "languageNames" VALUES(4980,'smn','no','tárukielâ');
INSERT INTO "languageNames" VALUES(4981,'smn','nog','nogaikielâ');
INSERT INTO "languageNames" VALUES(4982,'smn','oc','oksitan');
INSERT INTO "languageNames" VALUES(4983,'smn','os','ossetkielâ');
INSERT INTO "languageNames" VALUES(4984,'smn','pa','pandžabi');
INSERT INTO "languageNames" VALUES(4985,'smn','pl','puolakielâ');
INSERT INTO "languageNames" VALUES(4986,'smn','pt','portugalkielâ');
INSERT INTO "languageNames" VALUES(4987,'smn','rm','retoroomaankielâ');
INSERT INTO "languageNames" VALUES(4988,'smn','rn','rundi');
INSERT INTO "languageNames" VALUES(4989,'smn','ro','romaniakielâ');
INSERT INTO "languageNames" VALUES(4990,'smn','ru','ruošâkielâ');
INSERT INTO "languageNames" VALUES(4991,'smn','rup','aromaniakielâ');
INSERT INTO "languageNames" VALUES(4992,'smn','sa','sanskrit');
INSERT INTO "languageNames" VALUES(4993,'smn','sah','jakutkielâ');
INSERT INTO "languageNames" VALUES(4994,'smn','sc','sardiniakielâ');
INSERT INTO "languageNames" VALUES(4995,'smn','scn','sisiliakielâ');
INSERT INTO "languageNames" VALUES(4996,'smn','sco','skootikielâ');
INSERT INTO "languageNames" VALUES(4997,'smn','sd','sindhi');
INSERT INTO "languageNames" VALUES(4998,'smn','se','tavekielâ');
INSERT INTO "languageNames" VALUES(4999,'smn','si','sinhala');
INSERT INTO "languageNames" VALUES(5000,'smn','sk','slovakiakielâ');
INSERT INTO "languageNames" VALUES(5001,'smn','sl','sloveniakielâ');
INSERT INTO "languageNames" VALUES(5002,'smn','sma','maadâsämikielâ');
INSERT INTO "languageNames" VALUES(5003,'smn','smj','juulevsämikielâ');
INSERT INTO "languageNames" VALUES(5004,'smn','smn','anarâškielâ');
INSERT INTO "languageNames" VALUES(5005,'smn','sq','albaniakielâ');
INSERT INTO "languageNames" VALUES(5006,'smn','sr','serbiakielâ');
INSERT INTO "languageNames" VALUES(5007,'smn','srn','sranantongo');
INSERT INTO "languageNames" VALUES(5008,'smn','ss','swazikielâ');
INSERT INTO "languageNames" VALUES(5009,'smn','sv','ruotâkielâ');
INSERT INTO "languageNames" VALUES(5010,'smn','sw','swahilikielâ');
INSERT INTO "languageNames" VALUES(5011,'smn','ta','tamilkielâ');
INSERT INTO "languageNames" VALUES(5012,'smn','te','telugu');
INSERT INTO "languageNames" VALUES(5013,'smn','tet','tetum');
INSERT INTO "languageNames" VALUES(5014,'smn','tg','tadžikkielâ');
INSERT INTO "languageNames" VALUES(5015,'smn','th','thaikielâ');
INSERT INTO "languageNames" VALUES(5016,'smn','tk','turkmenkielâ');
INSERT INTO "languageNames" VALUES(5017,'smn','tr','tuurkikielâ');
INSERT INTO "languageNames" VALUES(5018,'smn','tt','tatarkielâ');
INSERT INTO "languageNames" VALUES(5019,'smn','tyv','tuvakielâ');
INSERT INTO "languageNames" VALUES(5020,'smn','udm','udmurtkielâ');
INSERT INTO "languageNames" VALUES(5021,'smn','ug','uigurkielâ');
INSERT INTO "languageNames" VALUES(5022,'smn','uk','ukrainakielâ');
INSERT INTO "languageNames" VALUES(5023,'smn','ur','urdu');
INSERT INTO "languageNames" VALUES(5024,'smn','uz','uzbekkielâ');
INSERT INTO "languageNames" VALUES(5025,'smn','vi','vietnamkielâ');
INSERT INTO "languageNames" VALUES(5026,'smn','wal','wolaitakielâ');
INSERT INTO "languageNames" VALUES(5027,'smn','xh','xhosakielâ');
INSERT INTO "languageNames" VALUES(5028,'smn','yi','jiddish');
INSERT INTO "languageNames" VALUES(5029,'smn','yo','yorubakielâ');
INSERT INTO "languageNames" VALUES(5030,'smn','zh','mandarinkiinakielâ');
INSERT INTO "languageNames" VALUES(5031,'smn','zu','zulukielâ');
INSERT INTO "languageNames" VALUES(5032,'en','af','Afrikaans');
INSERT INTO "languageNames" VALUES(5033,'en','alt','Southern Altai');
INSERT INTO "languageNames" VALUES(5034,'en','an','Aragonese');
INSERT INTO "languageNames" VALUES(5035,'en','ar','Arabic');
INSERT INTO "languageNames" VALUES(5036,'en','as','Assamese');
INSERT INTO "languageNames" VALUES(5037,'en','ast','Asturian');
INSERT INTO "languageNames" VALUES(5038,'en','av','Avaric');
INSERT INTO "languageNames" VALUES(5040,'en','az','Azeri');
INSERT INTO "languageNames" VALUES(5041,'en','ba','Bashkir');
INSERT INTO "languageNames" VALUES(5042,'en','be','Belarusian');
INSERT INTO "languageNames" VALUES(5043,'en','bg','Bulgarian');
INSERT INTO "languageNames" VALUES(5044,'en','bi','Bislama');
INSERT INTO "languageNames" VALUES(5045,'en','bn','Bangla');
INSERT INTO "languageNames" VALUES(5046,'en','br','Breton');
INSERT INTO "languageNames" VALUES(5047,'en','bs','Bosnian');
INSERT INTO "languageNames" VALUES(5048,'en','bua','Buriat');
INSERT INTO "languageNames" VALUES(5049,'en','byv','Medumba');
INSERT INTO "languageNames" VALUES(5050,'en','ca','Catalan');
INSERT INTO "languageNames" VALUES(5051,'en','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(5052,'en','chm','Mari');
INSERT INTO "languageNames" VALUES(5053,'en','ckb','Central Kurdish');
INSERT INTO "languageNames" VALUES(5054,'en','co','Corsican');
INSERT INTO "languageNames" VALUES(5055,'en','crh','Crimean Turkish');
INSERT INTO "languageNames" VALUES(5056,'en','cs','Czech');
INSERT INTO "languageNames" VALUES(5057,'en','csb','Kashubian');
INSERT INTO "languageNames" VALUES(5058,'en','cu','Church Slavic');
INSERT INTO "languageNames" VALUES(5059,'en','cv','Chuvash');
INSERT INTO "languageNames" VALUES(5060,'en','cy','Welsh');
INSERT INTO "languageNames" VALUES(5061,'en','da','Danish');
INSERT INTO "languageNames" VALUES(5062,'en','dar','Dargwa');
INSERT INTO "languageNames" VALUES(5063,'en','de','German');
INSERT INTO "languageNames" VALUES(5064,'en','dsb','Lower Sorbian');
INSERT INTO "languageNames" VALUES(5065,'en','el','Greek');
INSERT INTO "languageNames" VALUES(5066,'en','en','English');
INSERT INTO "languageNames" VALUES(5067,'en','eo','Esperanto');
INSERT INTO "languageNames" VALUES(5068,'en','es','Spanish');
INSERT INTO "languageNames" VALUES(5069,'en','et','Estonian');
INSERT INTO "languageNames" VALUES(5070,'en','eu','Basque');
INSERT INTO "languageNames" VALUES(5071,'en','fa','Persian');
INSERT INTO "languageNames" VALUES(5072,'en','fi','Finnish');
INSERT INTO "languageNames" VALUES(5073,'en','fo','Faroese');
INSERT INTO "languageNames" VALUES(5074,'en','fr','French');
INSERT INTO "languageNames" VALUES(5075,'en','fy','Western Frisian');
INSERT INTO "languageNames" VALUES(5076,'en','ga','Irish');
INSERT INTO "languageNames" VALUES(5077,'en','gag','Gagauz');
INSERT INTO "languageNames" VALUES(5078,'en','gd','Scottish Gaelic');
INSERT INTO "languageNames" VALUES(5079,'en','gl','Galician');
INSERT INTO "languageNames" VALUES(5080,'en','glk','Gilaki');
INSERT INTO "languageNames" VALUES(5081,'en','gn','Guarani');
INSERT INTO "languageNames" VALUES(5082,'en','gu','Gujarati');
INSERT INTO "languageNames" VALUES(5083,'en','guc','Wayuu');
INSERT INTO "languageNames" VALUES(5084,'en','gv','Manx');
INSERT INTO "languageNames" VALUES(5085,'en','ha','Hausa');
INSERT INTO "languageNames" VALUES(5086,'en','haw','Hawaiian');
INSERT INTO "languageNames" VALUES(5087,'en','he','Hebrew');
INSERT INTO "languageNames" VALUES(5088,'en','hi','Hindi');
INSERT INTO "languageNames" VALUES(5089,'en','hr','Croatian');
INSERT INTO "languageNames" VALUES(5090,'en','hsb','Upper Sorbian');
INSERT INTO "languageNames" VALUES(5091,'en','ht','Haitian Creole');
INSERT INTO "languageNames" VALUES(5092,'en','hu','Hungarian');
INSERT INTO "languageNames" VALUES(5093,'en','hy','Armenian');
INSERT INTO "languageNames" VALUES(5094,'en','ia','Interlingua');
INSERT INTO "languageNames" VALUES(5095,'en','id','Indonesian');
INSERT INTO "languageNames" VALUES(5096,'en','ig','Igbo');
INSERT INTO "languageNames" VALUES(5097,'en','is','Icelandic');
INSERT INTO "languageNames" VALUES(5098,'en','it','Italian');
INSERT INTO "languageNames" VALUES(5099,'en','ka','Georgian');
INSERT INTO "languageNames" VALUES(5100,'en','kaa','Kara-Kalpak');
INSERT INTO "languageNames" VALUES(5101,'en','kk','Kazakh');
INSERT INTO "languageNames" VALUES(5102,'en','ko','Korean');
INSERT INTO "languageNames" VALUES(5103,'en','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(5104,'en','krl','Karelian');
INSERT INTO "languageNames" VALUES(5105,'en','ks','Kashmiri');
INSERT INTO "languageNames" VALUES(5106,'en','kum','Kumyk');
INSERT INTO "languageNames" VALUES(5107,'en','kv','Komi');
INSERT INTO "languageNames" VALUES(5109,'en','ky','Kirghiz');
INSERT INTO "languageNames" VALUES(5110,'en','la','Latin');
INSERT INTO "languageNames" VALUES(5111,'en','lb','Luxembourgish');
INSERT INTO "languageNames" VALUES(5112,'en','lg','Ganda');
INSERT INTO "languageNames" VALUES(5113,'en','liv','Livonian');
INSERT INTO "languageNames" VALUES(5114,'en','ln','Lingala');
INSERT INTO "languageNames" VALUES(5115,'en','lo','Lao');
INSERT INTO "languageNames" VALUES(5116,'en','lt','Lithuanian');
INSERT INTO "languageNames" VALUES(5117,'en','lv','Latvian');
INSERT INTO "languageNames" VALUES(5118,'en','mdf','Moksha');
INSERT INTO "languageNames" VALUES(5119,'en','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(5120,'en','mk','Macedonian');
INSERT INTO "languageNames" VALUES(5121,'en','ml','Malayalam');
INSERT INTO "languageNames" VALUES(5122,'en','mr','Marathi');
INSERT INTO "languageNames" VALUES(5123,'en','mrj','Western Mari');
INSERT INTO "languageNames" VALUES(5124,'en','ms','Malay');
INSERT INTO "languageNames" VALUES(5125,'en','mt','Maltese');
INSERT INTO "languageNames" VALUES(5126,'en','myv','Erzya');
INSERT INTO "languageNames" VALUES(5127,'en','nap','Neapolitan');
INSERT INTO "languageNames" VALUES(5128,'en','nb','Norwegian Bokmål');
INSERT INTO "languageNames" VALUES(5129,'en','ne','Nepali');
INSERT INTO "languageNames" VALUES(5130,'en','nl','Dutch');
INSERT INTO "languageNames" VALUES(5131,'en','nn','Norwegian Nynorsk');
INSERT INTO "languageNames" VALUES(5132,'en','no','Norwegian');
INSERT INTO "languageNames" VALUES(5133,'en','nog','Nogai');
INSERT INTO "languageNames" VALUES(5134,'en','oc','Occitan');
INSERT INTO "languageNames" VALUES(5135,'en','os','Ossetic');
INSERT INTO "languageNames" VALUES(5136,'en','ota','Ottoman Turkish');
INSERT INTO "languageNames" VALUES(5137,'en','pa','Punjabi');
INSERT INTO "languageNames" VALUES(5138,'en','pl','Polish');
INSERT INTO "languageNames" VALUES(5139,'en','pt','Portuguese');
INSERT INTO "languageNames" VALUES(5140,'en','rm','Romansh');
INSERT INTO "languageNames" VALUES(5141,'en','rn','Rundi');
INSERT INTO "languageNames" VALUES(5142,'en','ro','Romanian');
INSERT INTO "languageNames" VALUES(5143,'en','ru','Russian');
INSERT INTO "languageNames" VALUES(5144,'en','rup','Aromanian');
INSERT INTO "languageNames" VALUES(5145,'en','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(5146,'en','sah','Sakha');
INSERT INTO "languageNames" VALUES(5147,'en','sc','Sardinian');
INSERT INTO "languageNames" VALUES(5148,'en','scn','Sicilian');
INSERT INTO "languageNames" VALUES(5149,'en','sco','Scots');
INSERT INTO "languageNames" VALUES(5150,'en','sd','Sindhi');
INSERT INTO "languageNames" VALUES(5151,'en','se','Northern Sami');
INSERT INTO "languageNames" VALUES(5152,'en','sh','Serbo-Croatian');
INSERT INTO "languageNames" VALUES(5153,'en','si','Sinhala');
INSERT INTO "languageNames" VALUES(5154,'en','sk','Slovak');
INSERT INTO "languageNames" VALUES(5155,'en','sl','Slovenian');
INSERT INTO "languageNames" VALUES(5156,'en','sma','Southern Sami');
INSERT INTO "languageNames" VALUES(5157,'en','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(5158,'en','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(5159,'en','sq','Albanian');
INSERT INTO "languageNames" VALUES(5160,'en','sr','Serbian');
INSERT INTO "languageNames" VALUES(5161,'en','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(5162,'en','ss','Swati');
INSERT INTO "languageNames" VALUES(5163,'en','sv','Swedish');
INSERT INTO "languageNames" VALUES(5164,'en','sw','Swahili');
INSERT INTO "languageNames" VALUES(5165,'en','ta','Tamil');
INSERT INTO "languageNames" VALUES(5166,'en','te','Telugu');
INSERT INTO "languageNames" VALUES(5167,'en','tet','Tetum');
INSERT INTO "languageNames" VALUES(5168,'en','tg','Tajik');
INSERT INTO "languageNames" VALUES(5169,'en','th','Thai');
INSERT INTO "languageNames" VALUES(5170,'en','tk','Turkmen');
INSERT INTO "languageNames" VALUES(5171,'en','tl','Tagalog');
INSERT INTO "languageNames" VALUES(5172,'en','tr','Turkish');
INSERT INTO "languageNames" VALUES(5173,'en','tt','Tatar');
INSERT INTO "languageNames" VALUES(5174,'en','tyv','Tuvinian');
INSERT INTO "languageNames" VALUES(5175,'en','udm','Udmurt');
INSERT INTO "languageNames" VALUES(5177,'en','ug','Uighur');
INSERT INTO "languageNames" VALUES(5178,'en','uk','Ukrainian');
INSERT INTO "languageNames" VALUES(5179,'en','ur','Urdu');
INSERT INTO "languageNames" VALUES(5180,'en','uz','Uzbek');
INSERT INTO "languageNames" VALUES(5181,'en','vi','Vietnamese');
INSERT INTO "languageNames" VALUES(5182,'en','vro','Võro');
INSERT INTO "languageNames" VALUES(5183,'en','wal','Wolaytta');
INSERT INTO "languageNames" VALUES(5184,'en','xh','Xhosa');
INSERT INTO "languageNames" VALUES(5185,'en','yi','Yiddish');
INSERT INTO "languageNames" VALUES(5186,'en','yo','Yoruba');
INSERT INTO "languageNames" VALUES(5188,'en','zh','Mandarin Chinese');
INSERT INTO "languageNames" VALUES(5189,'en','zu','Zulu');
INSERT INTO "languageNames" VALUES(5190,'fi','af','afrikaans');
INSERT INTO "languageNames" VALUES(5191,'fi','alt','altai');
INSERT INTO "languageNames" VALUES(5192,'fi','an','aragonia');
INSERT INTO "languageNames" VALUES(5193,'fi','ar','arabia');
INSERT INTO "languageNames" VALUES(5194,'fi','as','assami');
INSERT INTO "languageNames" VALUES(5195,'fi','ast','asturia');
INSERT INTO "languageNames" VALUES(5196,'fi','av','avaari');
INSERT INTO "languageNames" VALUES(5198,'fi','az','azeri');
INSERT INTO "languageNames" VALUES(5199,'fi','ba','baškiiri');
INSERT INTO "languageNames" VALUES(5200,'fi','be','valkovenäjä');
INSERT INTO "languageNames" VALUES(5201,'fi','bg','bulgaria');
INSERT INTO "languageNames" VALUES(5202,'fi','bi','bislama');
INSERT INTO "languageNames" VALUES(5203,'fi','bn','bengali');
INSERT INTO "languageNames" VALUES(5204,'fi','br','bretoni');
INSERT INTO "languageNames" VALUES(5205,'fi','bs','bosnia');
INSERT INTO "languageNames" VALUES(5206,'fi','bua','burjaatti');
INSERT INTO "languageNames" VALUES(5207,'fi','byv','medumba');
INSERT INTO "languageNames" VALUES(5208,'fi','ca','katalaani');
INSERT INTO "languageNames" VALUES(5209,'fi','ceb','cebuano');
INSERT INTO "languageNames" VALUES(5210,'fi','chm','mari');
INSERT INTO "languageNames" VALUES(5211,'fi','ckb','sorani');
INSERT INTO "languageNames" VALUES(5212,'fi','co','korsika');
INSERT INTO "languageNames" VALUES(5214,'fi','crh','kriminturkki');
INSERT INTO "languageNames" VALUES(5215,'fi','cs','tšekki');
INSERT INTO "languageNames" VALUES(5216,'fi','csb','kašubi');
INSERT INTO "languageNames" VALUES(5217,'fi','cu','kirkkoslaavi');
INSERT INTO "languageNames" VALUES(5218,'fi','cv','tšuvassi');
INSERT INTO "languageNames" VALUES(5219,'fi','cy','kymri');
INSERT INTO "languageNames" VALUES(5220,'fi','da','tanska');
INSERT INTO "languageNames" VALUES(5221,'fi','dar','dargi');
INSERT INTO "languageNames" VALUES(5222,'fi','de','saksa');
INSERT INTO "languageNames" VALUES(5223,'fi','dsb','alasorbi');
INSERT INTO "languageNames" VALUES(5224,'fi','el','kreikka');
INSERT INTO "languageNames" VALUES(5225,'fi','en','englanti');
INSERT INTO "languageNames" VALUES(5226,'fi','eo','esperanto');
INSERT INTO "languageNames" VALUES(5227,'fi','es','espanja');
INSERT INTO "languageNames" VALUES(5228,'fi','et','viro');
INSERT INTO "languageNames" VALUES(5229,'fi','eu','baski');
INSERT INTO "languageNames" VALUES(5231,'fi','fa','persia');
INSERT INTO "languageNames" VALUES(5232,'fi','fi','suomi');
INSERT INTO "languageNames" VALUES(5233,'fi','fo','fääri');
INSERT INTO "languageNames" VALUES(5234,'fi','fr','ranska');
INSERT INTO "languageNames" VALUES(5235,'fi','fy','länsifriisi');
INSERT INTO "languageNames" VALUES(5236,'fi','ga','iiri');
INSERT INTO "languageNames" VALUES(5237,'fi','gag','gagauzi');
INSERT INTO "languageNames" VALUES(5238,'fi','gd','gaeli');
INSERT INTO "languageNames" VALUES(5239,'fi','gl','galicia');
INSERT INTO "languageNames" VALUES(5240,'fi','glk','gilaki');
INSERT INTO "languageNames" VALUES(5241,'fi','gn','guarani');
INSERT INTO "languageNames" VALUES(5242,'fi','gu','gudžarati');
INSERT INTO "languageNames" VALUES(5243,'fi','guc','wayuu');
INSERT INTO "languageNames" VALUES(5244,'fi','gv','manksi');
INSERT INTO "languageNames" VALUES(5245,'fi','ha','hausa');
INSERT INTO "languageNames" VALUES(5246,'fi','haw','havaiji');
INSERT INTO "languageNames" VALUES(5247,'fi','he','heprea');
INSERT INTO "languageNames" VALUES(5248,'fi','hi','hindi');
INSERT INTO "languageNames" VALUES(5249,'fi','hr','kroatia');
INSERT INTO "languageNames" VALUES(5250,'fi','hsb','yläsorbi');
INSERT INTO "languageNames" VALUES(5251,'fi','ht','haiti');
INSERT INTO "languageNames" VALUES(5252,'fi','hu','unkari');
INSERT INTO "languageNames" VALUES(5253,'fi','hy','armenia');
INSERT INTO "languageNames" VALUES(5254,'fi','ia','interlingua');
INSERT INTO "languageNames" VALUES(5255,'fi','id','indonesia');
INSERT INTO "languageNames" VALUES(5256,'fi','ig','igbo');
INSERT INTO "languageNames" VALUES(5257,'fi','is','islanti');
INSERT INTO "languageNames" VALUES(5258,'fi','it','italia');
INSERT INTO "languageNames" VALUES(5259,'fi','ka','georgia');
INSERT INTO "languageNames" VALUES(5260,'fi','kaa','karakalpakki');
INSERT INTO "languageNames" VALUES(5261,'fi','kk','kazakki');
INSERT INTO "languageNames" VALUES(5262,'fi','ko','korea');
INSERT INTO "languageNames" VALUES(5263,'fi','krc','karatšai-balkaari');
INSERT INTO "languageNames" VALUES(5264,'fi','krl','karjala');
INSERT INTO "languageNames" VALUES(5265,'fi','ks','kašmiri');
INSERT INTO "languageNames" VALUES(5266,'fi','kum','kumykki');
INSERT INTO "languageNames" VALUES(5267,'fi','kv','komi');
INSERT INTO "languageNames" VALUES(5268,'fi','ky','kirgiisi');
INSERT INTO "languageNames" VALUES(5269,'fi','la','latina');
INSERT INTO "languageNames" VALUES(5270,'fi','lb','luxemburg');
INSERT INTO "languageNames" VALUES(5271,'fi','lg','ganda');
INSERT INTO "languageNames" VALUES(5272,'fi','liv','liivi');
INSERT INTO "languageNames" VALUES(5273,'fi','ln','lingala');
INSERT INTO "languageNames" VALUES(5274,'fi','lo','lao');
INSERT INTO "languageNames" VALUES(5275,'fi','lt','liettua');
INSERT INTO "languageNames" VALUES(5276,'fi','lv','latvia');
INSERT INTO "languageNames" VALUES(5277,'fi','mdf','mokša');
INSERT INTO "languageNames" VALUES(5278,'fi','mfe','morisyen');
INSERT INTO "languageNames" VALUES(5279,'fi','mk','makedonia');
INSERT INTO "languageNames" VALUES(5280,'fi','ml','malajalam');
INSERT INTO "languageNames" VALUES(5281,'fi','mr','marathi');
INSERT INTO "languageNames" VALUES(5282,'fi','mrj','vuorimari');
INSERT INTO "languageNames" VALUES(5283,'fi','ms','malaiji');
INSERT INTO "languageNames" VALUES(5284,'fi','mt','malta');
INSERT INTO "languageNames" VALUES(5285,'fi','myv','ersä');
INSERT INTO "languageNames" VALUES(5286,'fi','nap','napoli');
INSERT INTO "languageNames" VALUES(5287,'fi','nb','norjan bokmål');
INSERT INTO "languageNames" VALUES(5288,'fi','ne','nepali');
INSERT INTO "languageNames" VALUES(5289,'fi','nl','hollanti');
INSERT INTO "languageNames" VALUES(5290,'fi','nn','norjan nynorsk');
INSERT INTO "languageNames" VALUES(5291,'fi','no','norja');
INSERT INTO "languageNames" VALUES(5292,'fi','nog','nogai');
INSERT INTO "languageNames" VALUES(5293,'fi','oc','oksitaani');
INSERT INTO "languageNames" VALUES(5294,'fi','os','osseetti');
INSERT INTO "languageNames" VALUES(5295,'fi','ota','osmani');
INSERT INTO "languageNames" VALUES(5296,'fi','pa','pandžabi');
INSERT INTO "languageNames" VALUES(5297,'fi','pl','puola');
INSERT INTO "languageNames" VALUES(5298,'fi','pt','portugali');
INSERT INTO "languageNames" VALUES(5299,'fi','rm','retoromaani');
INSERT INTO "languageNames" VALUES(5300,'fi','rn','rundi');
INSERT INTO "languageNames" VALUES(5301,'fi','ro','romania');
INSERT INTO "languageNames" VALUES(5302,'fi','ru','venäjä');
INSERT INTO "languageNames" VALUES(5303,'fi','rup','aromania');
INSERT INTO "languageNames" VALUES(5304,'fi','sa','sanskrit');
INSERT INTO "languageNames" VALUES(5305,'fi','sah','jakuutti');
INSERT INTO "languageNames" VALUES(5306,'fi','sc','sardi');
INSERT INTO "languageNames" VALUES(5307,'fi','scn','sisilia');
INSERT INTO "languageNames" VALUES(5308,'fi','sco','skotti');
INSERT INTO "languageNames" VALUES(5309,'fi','sd','sindhi');
INSERT INTO "languageNames" VALUES(5310,'fi','se','pohjoissaame');
INSERT INTO "languageNames" VALUES(5311,'fi','sh','serbokroaatti');
INSERT INTO "languageNames" VALUES(5312,'fi','si','sinhala');
INSERT INTO "languageNames" VALUES(5313,'fi','sk','slovakki');
INSERT INTO "languageNames" VALUES(5314,'fi','sl','sloveeni');
INSERT INTO "languageNames" VALUES(5315,'fi','sma','eteläsaame');
INSERT INTO "languageNames" VALUES(5316,'fi','smj','luulajansaame');
INSERT INTO "languageNames" VALUES(5317,'fi','smn','inarinsaame');
INSERT INTO "languageNames" VALUES(5318,'fi','sq','albania');
INSERT INTO "languageNames" VALUES(5319,'fi','sr','serbia');
INSERT INTO "languageNames" VALUES(5320,'fi','srn','sranan');
INSERT INTO "languageNames" VALUES(5321,'fi','ss','swazi');
INSERT INTO "languageNames" VALUES(5322,'fi','sv','ruotsi');
INSERT INTO "languageNames" VALUES(5323,'fi','sw','swahili');
INSERT INTO "languageNames" VALUES(5324,'fi','ta','tamili');
INSERT INTO "languageNames" VALUES(5325,'fi','te','telugu');
INSERT INTO "languageNames" VALUES(5326,'fi','tet','tetum');
INSERT INTO "languageNames" VALUES(5327,'fi','tg','tadžikki');
INSERT INTO "languageNames" VALUES(5328,'fi','th','thai');
INSERT INTO "languageNames" VALUES(5329,'fi','tk','turkmeeni');
INSERT INTO "languageNames" VALUES(5330,'fi','tl','tagalog');
INSERT INTO "languageNames" VALUES(5331,'fi','tr','turkki');
INSERT INTO "languageNames" VALUES(5332,'fi','tt','tataari');
INSERT INTO "languageNames" VALUES(5333,'fi','tyv','tuva');
INSERT INTO "languageNames" VALUES(5334,'fi','udm','udmurtti');
INSERT INTO "languageNames" VALUES(5335,'fi','ug','uiguuri');
INSERT INTO "languageNames" VALUES(5336,'fi','uk','ukraina');
INSERT INTO "languageNames" VALUES(5337,'fi','ur','urdu');
INSERT INTO "languageNames" VALUES(5338,'fi','uz','uzbekki');
INSERT INTO "languageNames" VALUES(5339,'fi','vi','vietnam');
INSERT INTO "languageNames" VALUES(5340,'fi','vro','võro');
INSERT INTO "languageNames" VALUES(5341,'fi','wal','wolaitta');
INSERT INTO "languageNames" VALUES(5342,'fi','xh','xhosa');
INSERT INTO "languageNames" VALUES(5343,'fi','yi','jiddiš');
INSERT INTO "languageNames" VALUES(5344,'fi','yo','joruba');
INSERT INTO "languageNames" VALUES(5345,'fi','zh','kiina');
INSERT INTO "languageNames" VALUES(5346,'fi','zu','zulu');
INSERT INTO "languageNames" VALUES(5347,'mk','af','африканс');
INSERT INTO "languageNames" VALUES(5348,'mk','alt','јужноалтајски');
INSERT INTO "languageNames" VALUES(5349,'mk','an','арагонски');
INSERT INTO "languageNames" VALUES(5350,'mk','ar','арапски');
INSERT INTO "languageNames" VALUES(5351,'mk','as','асамски');
INSERT INTO "languageNames" VALUES(5352,'mk','ast','астурски');
INSERT INTO "languageNames" VALUES(5353,'mk','av','аварски');
INSERT INTO "languageNames" VALUES(5355,'mk','az','азерски');
INSERT INTO "languageNames" VALUES(5356,'mk','ba','башкирски');
INSERT INTO "languageNames" VALUES(5357,'mk','be','белоруски');
INSERT INTO "languageNames" VALUES(5358,'mk','bg','бугарски');
INSERT INTO "languageNames" VALUES(5359,'mk','bi','бислама');
INSERT INTO "languageNames" VALUES(5360,'mk','bn','бенгалски');
INSERT INTO "languageNames" VALUES(5361,'mk','br','бретонски');
INSERT INTO "languageNames" VALUES(5362,'mk','bs','босански');
INSERT INTO "languageNames" VALUES(5363,'mk','bua','бурјатски');
INSERT INTO "languageNames" VALUES(5364,'mk','byv','медумба');
INSERT INTO "languageNames" VALUES(5365,'mk','ca','каталонски');
INSERT INTO "languageNames" VALUES(5366,'mk','ceb','себуански');
INSERT INTO "languageNames" VALUES(5367,'mk','chm','мариски');
INSERT INTO "languageNames" VALUES(5368,'mk','ckb','централнокурдски');
INSERT INTO "languageNames" VALUES(5369,'mk','co','корзикански');
INSERT INTO "languageNames" VALUES(5370,'mk','crh','кримскотурски');
INSERT INTO "languageNames" VALUES(5371,'mk','cs','чешки');
INSERT INTO "languageNames" VALUES(5372,'mk','csb','кашупски');
INSERT INTO "languageNames" VALUES(5373,'mk','cu','црковнословенски');
INSERT INTO "languageNames" VALUES(5374,'mk','cv','чувашки');
INSERT INTO "languageNames" VALUES(5375,'mk','cy','велшки');
INSERT INTO "languageNames" VALUES(5376,'mk','da','дански');
INSERT INTO "languageNames" VALUES(5377,'mk','dar','даргва');
INSERT INTO "languageNames" VALUES(5378,'mk','de','германски');
INSERT INTO "languageNames" VALUES(5379,'mk','dsb','долнолужички');
INSERT INTO "languageNames" VALUES(5380,'mk','el','грчки');
INSERT INTO "languageNames" VALUES(5381,'mk','en','англиски');
INSERT INTO "languageNames" VALUES(5382,'mk','eo','есперанто');
INSERT INTO "languageNames" VALUES(5383,'mk','es','шпански');
INSERT INTO "languageNames" VALUES(5384,'mk','et','естонски');
INSERT INTO "languageNames" VALUES(5385,'mk','eu','баскиски');
INSERT INTO "languageNames" VALUES(5386,'mk','fa','персиски');
INSERT INTO "languageNames" VALUES(5387,'mk','fi','фински');
INSERT INTO "languageNames" VALUES(5388,'mk','fo','фарски');
INSERT INTO "languageNames" VALUES(5389,'mk','fr','француски');
INSERT INTO "languageNames" VALUES(5390,'mk','fy','западнофризиски');
INSERT INTO "languageNames" VALUES(5391,'mk','ga','ирски');
INSERT INTO "languageNames" VALUES(5392,'mk','gag','гагауски');
INSERT INTO "languageNames" VALUES(5393,'mk','gd','шкотски гелски');
INSERT INTO "languageNames" VALUES(5394,'mk','gl','галициски');
INSERT INTO "languageNames" VALUES(5395,'mk','glk','гилански');
INSERT INTO "languageNames" VALUES(5396,'mk','gn','гварански');
INSERT INTO "languageNames" VALUES(5397,'mk','gu','гуџарати');
INSERT INTO "languageNames" VALUES(5398,'mk','guc','гвахиро');
INSERT INTO "languageNames" VALUES(5399,'mk','gv','манкс');
INSERT INTO "languageNames" VALUES(5400,'mk','ha','хауса');
INSERT INTO "languageNames" VALUES(5401,'mk','haw','хавајски');
INSERT INTO "languageNames" VALUES(5402,'mk','he','хебрејски');
INSERT INTO "languageNames" VALUES(5403,'mk','hi','хинди');
INSERT INTO "languageNames" VALUES(5404,'mk','hr','хрватски');
INSERT INTO "languageNames" VALUES(5405,'mk','hsb','горнолужички');
INSERT INTO "languageNames" VALUES(5406,'mk','ht','хаитски');
INSERT INTO "languageNames" VALUES(5407,'mk','hu','унгарски');
INSERT INTO "languageNames" VALUES(5408,'mk','hy','ерменски');
INSERT INTO "languageNames" VALUES(5409,'mk','ia','интерлингва');
INSERT INTO "languageNames" VALUES(5410,'mk','id','индонезиски');
INSERT INTO "languageNames" VALUES(5411,'mk','ig','игбо');
INSERT INTO "languageNames" VALUES(5412,'mk','is','исландски');
INSERT INTO "languageNames" VALUES(5413,'mk','it','италијански');
INSERT INTO "languageNames" VALUES(5414,'mk','ka','грузиски');
INSERT INTO "languageNames" VALUES(5415,'mk','kaa','каракалпачки');
INSERT INTO "languageNames" VALUES(5416,'mk','kk','казашки');
INSERT INTO "languageNames" VALUES(5417,'mk','ko','корејски');
INSERT INTO "languageNames" VALUES(5418,'mk','krc','карачаевско-балкарски');
INSERT INTO "languageNames" VALUES(5419,'mk','krl','карелски');
INSERT INTO "languageNames" VALUES(5420,'mk','ks','кашмирски');
INSERT INTO "languageNames" VALUES(5421,'mk','kum','кумички');
INSERT INTO "languageNames" VALUES(5422,'mk','kv','коми');
INSERT INTO "languageNames" VALUES(5423,'mk','ky','киргиски');
INSERT INTO "languageNames" VALUES(5424,'mk','la','латински');
INSERT INTO "languageNames" VALUES(5425,'mk','lb','луксембуршки');
INSERT INTO "languageNames" VALUES(5426,'mk','lg','ганда');
INSERT INTO "languageNames" VALUES(5427,'mk','liv','ливонски');
INSERT INTO "languageNames" VALUES(5428,'mk','ln','лингала');
INSERT INTO "languageNames" VALUES(5429,'mk','lo','лаошки');
INSERT INTO "languageNames" VALUES(5430,'mk','lt','литвански');
INSERT INTO "languageNames" VALUES(5431,'mk','lv','латвиски');
INSERT INTO "languageNames" VALUES(5432,'mk','mdf','мокшански');
INSERT INTO "languageNames" VALUES(5433,'mk','mfe','морисјен');
INSERT INTO "languageNames" VALUES(5434,'mk','mk','македонски');
INSERT INTO "languageNames" VALUES(5435,'mk','ml','малајамски');
INSERT INTO "languageNames" VALUES(5436,'mk','mr','марати');
INSERT INTO "languageNames" VALUES(5437,'mk','mrj','западномариски');
INSERT INTO "languageNames" VALUES(5438,'mk','ms','малајски');
INSERT INTO "languageNames" VALUES(5439,'mk','mt','малтешки');
INSERT INTO "languageNames" VALUES(5440,'mk','myv','ерзјански');
INSERT INTO "languageNames" VALUES(5441,'mk','nap','неаполски');
INSERT INTO "languageNames" VALUES(5442,'mk','nb','норвешки букмол');
INSERT INTO "languageNames" VALUES(5443,'mk','ne','непалски');
INSERT INTO "languageNames" VALUES(5444,'mk','nl','холандски');
INSERT INTO "languageNames" VALUES(5445,'mk','nn','норвешки нинорск');
INSERT INTO "languageNames" VALUES(5446,'mk','no','норвешки');
INSERT INTO "languageNames" VALUES(5447,'mk','nog','ногајски');
INSERT INTO "languageNames" VALUES(5448,'mk','oc','окситански');
INSERT INTO "languageNames" VALUES(5449,'mk','os','осетски');
INSERT INTO "languageNames" VALUES(5450,'mk','ota','отомански турски');
INSERT INTO "languageNames" VALUES(5451,'mk','pa','пенџапски');
INSERT INTO "languageNames" VALUES(5452,'mk','pl','полски');
INSERT INTO "languageNames" VALUES(5453,'mk','pt','португалски');
INSERT INTO "languageNames" VALUES(5454,'mk','rm','реторомански');
INSERT INTO "languageNames" VALUES(5455,'mk','rn','рунди');
INSERT INTO "languageNames" VALUES(5456,'mk','ro','романски');
INSERT INTO "languageNames" VALUES(5457,'mk','ru','руски');
INSERT INTO "languageNames" VALUES(5458,'mk','rup','влашки');
INSERT INTO "languageNames" VALUES(5459,'mk','sa','санскрит');
INSERT INTO "languageNames" VALUES(5460,'mk','sah','јакутски');
INSERT INTO "languageNames" VALUES(5461,'mk','sc','сардински');
INSERT INTO "languageNames" VALUES(5462,'mk','scn','сицилијански');
INSERT INTO "languageNames" VALUES(5463,'mk','sco','шкотски германски');
INSERT INTO "languageNames" VALUES(5464,'mk','sd','синди');
INSERT INTO "languageNames" VALUES(5465,'mk','se','северен сами');
INSERT INTO "languageNames" VALUES(5466,'mk','sh','српскохрватски');
INSERT INTO "languageNames" VALUES(5467,'mk','si','синхалски');
INSERT INTO "languageNames" VALUES(5468,'mk','sk','словачки');
INSERT INTO "languageNames" VALUES(5469,'mk','sl','словенечки');
INSERT INTO "languageNames" VALUES(5470,'mk','sma','јужен сами');
INSERT INTO "languageNames" VALUES(5471,'mk','smj','луле сами');
INSERT INTO "languageNames" VALUES(5472,'mk','smn','инари сами');
INSERT INTO "languageNames" VALUES(5473,'mk','sq','албански');
INSERT INTO "languageNames" VALUES(5474,'mk','sr','српски');
INSERT INTO "languageNames" VALUES(5475,'mk','srn','срански тонго');
INSERT INTO "languageNames" VALUES(5476,'mk','ss','свати');
INSERT INTO "languageNames" VALUES(5477,'mk','sv','шведски');
INSERT INTO "languageNames" VALUES(5478,'mk','sw','свахили');
INSERT INTO "languageNames" VALUES(5479,'mk','ta','тамилски');
INSERT INTO "languageNames" VALUES(5480,'mk','te','телугу');
INSERT INTO "languageNames" VALUES(5481,'mk','tet','тетум');
INSERT INTO "languageNames" VALUES(5482,'mk','tg','таџикистански');
INSERT INTO "languageNames" VALUES(5483,'mk','th','тајландски');
INSERT INTO "languageNames" VALUES(5484,'mk','tk','туркменски');
INSERT INTO "languageNames" VALUES(5485,'mk','tl','тагалог');
INSERT INTO "languageNames" VALUES(5486,'mk','tr','турски');
INSERT INTO "languageNames" VALUES(5487,'mk','tt','татарски');
INSERT INTO "languageNames" VALUES(5488,'mk','tyv','тувански');
INSERT INTO "languageNames" VALUES(5489,'mk','udm','удмуртски');
INSERT INTO "languageNames" VALUES(5490,'mk','ug','ујгурски');
INSERT INTO "languageNames" VALUES(5491,'mk','uk','украински');
INSERT INTO "languageNames" VALUES(5492,'mk','ur','урду');
INSERT INTO "languageNames" VALUES(5493,'mk','uz','узбечки');
INSERT INTO "languageNames" VALUES(5494,'mk','vi','виетнамски');
INSERT INTO "languageNames" VALUES(5495,'mk','vro','виру');
INSERT INTO "languageNames" VALUES(5496,'mk','wal','воламо');
INSERT INTO "languageNames" VALUES(5497,'mk','xh','коса');
INSERT INTO "languageNames" VALUES(5498,'mk','yi','јидиш');
INSERT INTO "languageNames" VALUES(5499,'mk','yo','јорупски');
INSERT INTO "languageNames" VALUES(5500,'mk','zh','кинески');
INSERT INTO "languageNames" VALUES(5501,'mk','zu','зулу');
INSERT INTO "languageNames" VALUES(5502,'sk','af','afrikánčina');
INSERT INTO "languageNames" VALUES(5503,'sk','alt','južná altajčina');
INSERT INTO "languageNames" VALUES(5504,'sk','an','aragónčina');
INSERT INTO "languageNames" VALUES(5505,'sk','ar','arabčina');
INSERT INTO "languageNames" VALUES(5506,'sk','as','ásamčina');
INSERT INTO "languageNames" VALUES(5507,'sk','ast','astúrčina');
INSERT INTO "languageNames" VALUES(5508,'sk','av','avarčina');
INSERT INTO "languageNames" VALUES(5510,'sk','az','azerbajdžančina');
INSERT INTO "languageNames" VALUES(5511,'sk','ba','baškirčina');
INSERT INTO "languageNames" VALUES(5512,'sk','be','bieloruština');
INSERT INTO "languageNames" VALUES(5513,'sk','bg','bulharčina');
INSERT INTO "languageNames" VALUES(5514,'sk','bi','bislama');
INSERT INTO "languageNames" VALUES(5515,'sk','bn','bengálčina');
INSERT INTO "languageNames" VALUES(5516,'sk','br','bretónčina');
INSERT INTO "languageNames" VALUES(5517,'sk','bs','bosniačtina');
INSERT INTO "languageNames" VALUES(5518,'sk','bua','buriatčina');
INSERT INTO "languageNames" VALUES(5519,'sk','byv','medumba');
INSERT INTO "languageNames" VALUES(5520,'sk','ca','katalánčina');
INSERT INTO "languageNames" VALUES(5521,'sk','ceb','cebuánčina');
INSERT INTO "languageNames" VALUES(5522,'sk','chm','marijčina');
INSERT INTO "languageNames" VALUES(5523,'sk','ckb','kurdčina (sorání)');
INSERT INTO "languageNames" VALUES(5524,'sk','co','korzičtina');
INSERT INTO "languageNames" VALUES(5525,'sk','crh','krymská tatárčina');
INSERT INTO "languageNames" VALUES(5526,'sk','cs','čeština');
INSERT INTO "languageNames" VALUES(5527,'sk','csb','kašubčina');
INSERT INTO "languageNames" VALUES(5528,'sk','cu','cirkevná slovančina');
INSERT INTO "languageNames" VALUES(5529,'sk','cv','čuvaština');
INSERT INTO "languageNames" VALUES(5530,'sk','cy','waleština');
INSERT INTO "languageNames" VALUES(5531,'sk','da','dánčina');
INSERT INTO "languageNames" VALUES(5532,'sk','dar','darginčina');
INSERT INTO "languageNames" VALUES(5533,'sk','de','nemčina');
INSERT INTO "languageNames" VALUES(5534,'sk','dsb','dolnolužická srbčina');
INSERT INTO "languageNames" VALUES(5535,'sk','el','gréčtina');
INSERT INTO "languageNames" VALUES(5536,'sk','en','angličtina');
INSERT INTO "languageNames" VALUES(5537,'sk','eo','esperanto');
INSERT INTO "languageNames" VALUES(5538,'sk','es','španielčina');
INSERT INTO "languageNames" VALUES(5539,'sk','et','estónčina');
INSERT INTO "languageNames" VALUES(5540,'sk','eu','baskičtina');
INSERT INTO "languageNames" VALUES(5541,'sk','fa','perzština');
INSERT INTO "languageNames" VALUES(5542,'sk','fi','fínčina');
INSERT INTO "languageNames" VALUES(5543,'sk','fo','faerčina');
INSERT INTO "languageNames" VALUES(5544,'sk','fr','francúzština');
INSERT INTO "languageNames" VALUES(5545,'sk','fy','západná frízština');
INSERT INTO "languageNames" VALUES(5546,'sk','ga','írčina');
INSERT INTO "languageNames" VALUES(5547,'sk','gag','gagauzština');
INSERT INTO "languageNames" VALUES(5548,'sk','gd','škótska gaelčina');
INSERT INTO "languageNames" VALUES(5549,'sk','gl','galícijčina');
INSERT INTO "languageNames" VALUES(5550,'sk','gn','guaraníjčina');
INSERT INTO "languageNames" VALUES(5551,'sk','gu','gudžarátčina');
INSERT INTO "languageNames" VALUES(5552,'sk','gv','mančina');
INSERT INTO "languageNames" VALUES(5553,'sk','ha','hauština');
INSERT INTO "languageNames" VALUES(5554,'sk','haw','havajčina');
INSERT INTO "languageNames" VALUES(5555,'sk','he','hebrejčina');
INSERT INTO "languageNames" VALUES(5556,'sk','hi','hindčina');
INSERT INTO "languageNames" VALUES(5557,'sk','hr','chorvátčina');
INSERT INTO "languageNames" VALUES(5558,'sk','hsb','hornolužická srbčina');
INSERT INTO "languageNames" VALUES(5559,'sk','ht','haitská kreolčina');
INSERT INTO "languageNames" VALUES(5560,'sk','hu','maďarčina');
INSERT INTO "languageNames" VALUES(5561,'sk','hy','arménčina');
INSERT INTO "languageNames" VALUES(5562,'sk','ia','interlingua');
INSERT INTO "languageNames" VALUES(5563,'sk','id','indonézština');
INSERT INTO "languageNames" VALUES(5564,'sk','ig','igboština');
INSERT INTO "languageNames" VALUES(5565,'sk','is','islandčina');
INSERT INTO "languageNames" VALUES(5566,'sk','it','taliančina');
INSERT INTO "languageNames" VALUES(5567,'sk','ka','gruzínčina');
INSERT INTO "languageNames" VALUES(5568,'sk','kaa','karakalpačtina');
INSERT INTO "languageNames" VALUES(5569,'sk','kk','kazaština');
INSERT INTO "languageNames" VALUES(5570,'sk','ko','kórejčina');
INSERT INTO "languageNames" VALUES(5571,'sk','krc','karačajevsko-balkarčina');
INSERT INTO "languageNames" VALUES(5572,'sk','krl','karelčina');
INSERT INTO "languageNames" VALUES(5573,'sk','ks','kašmírčina');
INSERT INTO "languageNames" VALUES(5574,'sk','kum','kumyčtina');
INSERT INTO "languageNames" VALUES(5575,'sk','kv','komijčina');
INSERT INTO "languageNames" VALUES(5576,'sk','ky','kirgizština');
INSERT INTO "languageNames" VALUES(5577,'sk','la','latinčina');
INSERT INTO "languageNames" VALUES(5578,'sk','lb','luxemburčina');
INSERT INTO "languageNames" VALUES(5579,'sk','lg','gandčina');
INSERT INTO "languageNames" VALUES(5580,'sk','ln','lingalčina');
INSERT INTO "languageNames" VALUES(5581,'sk','lo','laoština');
INSERT INTO "languageNames" VALUES(5582,'sk','lt','litovčina');
INSERT INTO "languageNames" VALUES(5583,'sk','lv','lotyština');
INSERT INTO "languageNames" VALUES(5584,'sk','mdf','mokšiančina');
INSERT INTO "languageNames" VALUES(5585,'sk','mfe','maurícijská kreolčina');
INSERT INTO "languageNames" VALUES(5586,'sk','mk','macedónčina');
INSERT INTO "languageNames" VALUES(5587,'sk','ml','malajálamčina');
INSERT INTO "languageNames" VALUES(5588,'sk','mr','maráthčina');
INSERT INTO "languageNames" VALUES(5589,'sk','ms','malajčina');
INSERT INTO "languageNames" VALUES(5590,'sk','mt','maltčina');
INSERT INTO "languageNames" VALUES(5591,'sk','myv','erzjančina');
INSERT INTO "languageNames" VALUES(5592,'sk','nap','neapolčina');
INSERT INTO "languageNames" VALUES(5593,'sk','nb','nórčina (bokmal)');
INSERT INTO "languageNames" VALUES(5594,'sk','ne','nepálčina');
INSERT INTO "languageNames" VALUES(5595,'sk','nl','holandčina');
INSERT INTO "languageNames" VALUES(5596,'sk','nn','nórčina (nynorsk)');
INSERT INTO "languageNames" VALUES(5597,'sk','no','nórčina');
INSERT INTO "languageNames" VALUES(5598,'sk','nog','nogajčina');
INSERT INTO "languageNames" VALUES(5599,'sk','oc','okcitánčina');
INSERT INTO "languageNames" VALUES(5600,'sk','os','osetčina');
INSERT INTO "languageNames" VALUES(5601,'sk','ota','osmanská turečtina');
INSERT INTO "languageNames" VALUES(5602,'sk','pa','pandžábčina');
INSERT INTO "languageNames" VALUES(5603,'sk','pl','poľština');
INSERT INTO "languageNames" VALUES(5604,'sk','pt','portugalčina');
INSERT INTO "languageNames" VALUES(5605,'sk','rm','rétorománčina');
INSERT INTO "languageNames" VALUES(5606,'sk','rn','rundčina');
INSERT INTO "languageNames" VALUES(5607,'sk','ro','rumunčina');
INSERT INTO "languageNames" VALUES(5608,'sk','ru','ruština');
INSERT INTO "languageNames" VALUES(5609,'sk','rup','arumunčina');
INSERT INTO "languageNames" VALUES(5610,'sk','sa','sanskrit');
INSERT INTO "languageNames" VALUES(5611,'sk','sah','jakutčina');
INSERT INTO "languageNames" VALUES(5612,'sk','sc','sardínčina');
INSERT INTO "languageNames" VALUES(5613,'sk','scn','sicílčina');
INSERT INTO "languageNames" VALUES(5614,'sk','sco','škótčina');
INSERT INTO "languageNames" VALUES(5615,'sk','sd','sindhčina');
INSERT INTO "languageNames" VALUES(5616,'sk','se','severná saamčina');
INSERT INTO "languageNames" VALUES(5617,'sk','sh','srbochorvátčina');
INSERT INTO "languageNames" VALUES(5618,'sk','si','sinhalčina');
INSERT INTO "languageNames" VALUES(5619,'sk','sk','slovenčina');
INSERT INTO "languageNames" VALUES(5620,'sk','sl','slovinčina');
INSERT INTO "languageNames" VALUES(5621,'sk','sma','južná saamčina');
INSERT INTO "languageNames" VALUES(5622,'sk','smj','lulská saamčina');
INSERT INTO "languageNames" VALUES(5623,'sk','smn','inarijská saamčina');
INSERT INTO "languageNames" VALUES(5624,'sk','sq','albánčina');
INSERT INTO "languageNames" VALUES(5625,'sk','sr','srbčina');
INSERT INTO "languageNames" VALUES(5626,'sk','srn','surinamčina');
INSERT INTO "languageNames" VALUES(5627,'sk','ss','svazijčina');
INSERT INTO "languageNames" VALUES(5628,'sk','sv','švédčina');
INSERT INTO "languageNames" VALUES(5629,'sk','sw','swahilčina');
INSERT INTO "languageNames" VALUES(5630,'sk','ta','tamilčina');
INSERT INTO "languageNames" VALUES(5631,'sk','te','telugčina');
INSERT INTO "languageNames" VALUES(5632,'sk','tet','tetumčina');
INSERT INTO "languageNames" VALUES(5633,'sk','tg','tadžičtina');
INSERT INTO "languageNames" VALUES(5634,'sk','th','thajčina');
INSERT INTO "languageNames" VALUES(5635,'sk','tk','turkménčina');
INSERT INTO "languageNames" VALUES(5636,'sk','tl','tagalčina');
INSERT INTO "languageNames" VALUES(5637,'sk','tr','turečtina');
INSERT INTO "languageNames" VALUES(5638,'sk','tt','tatárčina');
INSERT INTO "languageNames" VALUES(5639,'sk','tyv','tuviančina');
INSERT INTO "languageNames" VALUES(5640,'sk','udm','udmurtčina');
INSERT INTO "languageNames" VALUES(5641,'sk','ug','ujgurčina');
INSERT INTO "languageNames" VALUES(5642,'sk','uk','ukrajinčina');
INSERT INTO "languageNames" VALUES(5643,'sk','ur','urdčina');
INSERT INTO "languageNames" VALUES(5644,'sk','uz','uzbečtina');
INSERT INTO "languageNames" VALUES(5645,'sk','vi','vietnamčina');
INSERT INTO "languageNames" VALUES(5646,'sk','wal','walamčina');
INSERT INTO "languageNames" VALUES(5647,'sk','xh','xhoština');
INSERT INTO "languageNames" VALUES(5648,'sk','yi','jidiš');
INSERT INTO "languageNames" VALUES(5649,'sk','yo','jorubčina');
INSERT INTO "languageNames" VALUES(5650,'sk','zh','čínština');
INSERT INTO "languageNames" VALUES(5651,'sk','zu','zuluština');
INSERT INTO "languageNames" VALUES(5652,'it','af','afrikaans');
INSERT INTO "languageNames" VALUES(5653,'it','alt','altai meridionale');
INSERT INTO "languageNames" VALUES(5654,'it','an','aragonese');
INSERT INTO "languageNames" VALUES(5655,'it','ar','arabo');
INSERT INTO "languageNames" VALUES(5656,'it','as','assamese');
INSERT INTO "languageNames" VALUES(5657,'it','ast','asturiano');
INSERT INTO "languageNames" VALUES(5658,'it','av','avaro');
INSERT INTO "languageNames" VALUES(5660,'it','az','azero');
INSERT INTO "languageNames" VALUES(5661,'it','ba','baschiro');
INSERT INTO "languageNames" VALUES(5662,'it','be','bielorusso');
INSERT INTO "languageNames" VALUES(5663,'it','bg','bulgaro');
INSERT INTO "languageNames" VALUES(5664,'it','bi','bislama');
INSERT INTO "languageNames" VALUES(5665,'it','bn','bengalese');
INSERT INTO "languageNames" VALUES(5666,'it','br','bretone');
INSERT INTO "languageNames" VALUES(5667,'it','bs','bosniaco');
INSERT INTO "languageNames" VALUES(5668,'it','bua','buriat');
INSERT INTO "languageNames" VALUES(5669,'it','byv','medumba');
INSERT INTO "languageNames" VALUES(5670,'it','ca','catalano');
INSERT INTO "languageNames" VALUES(5671,'it','ceb','cebuano');
INSERT INTO "languageNames" VALUES(5672,'it','chm','mari');
INSERT INTO "languageNames" VALUES(5673,'it','ckb','curdo sorani');
INSERT INTO "languageNames" VALUES(5674,'it','co','corso');
INSERT INTO "languageNames" VALUES(5675,'it','crh','turco crimeo');
INSERT INTO "languageNames" VALUES(5676,'it','cs','ceco');
INSERT INTO "languageNames" VALUES(5677,'it','csb','kashubian');
INSERT INTO "languageNames" VALUES(5678,'it','cu','slavo della Chiesa');
INSERT INTO "languageNames" VALUES(5679,'it','cv','ciuvascio');
INSERT INTO "languageNames" VALUES(5680,'it','cy','gallese');
INSERT INTO "languageNames" VALUES(5681,'it','da','danese');
INSERT INTO "languageNames" VALUES(5682,'it','dar','dargwa');
INSERT INTO "languageNames" VALUES(5683,'it','de','tedesco');
INSERT INTO "languageNames" VALUES(5684,'it','dsb','basso sorabo');
INSERT INTO "languageNames" VALUES(5685,'it','el','greco');
INSERT INTO "languageNames" VALUES(5686,'it','en','inglese');
INSERT INTO "languageNames" VALUES(5687,'it','eo','esperanto');
INSERT INTO "languageNames" VALUES(5688,'it','es','spagnolo');
INSERT INTO "languageNames" VALUES(5689,'it','et','estone');
INSERT INTO "languageNames" VALUES(5690,'it','eu','basco');
INSERT INTO "languageNames" VALUES(5691,'it','fa','persiano');
INSERT INTO "languageNames" VALUES(5692,'it','fi','finlandese');
INSERT INTO "languageNames" VALUES(5693,'it','fo','faroese');
INSERT INTO "languageNames" VALUES(5694,'it','fr','francese');
INSERT INTO "languageNames" VALUES(5695,'it','fy','frisone occidentale');
INSERT INTO "languageNames" VALUES(5696,'it','ga','irlandese');
INSERT INTO "languageNames" VALUES(5697,'it','gag','gagauzo');
INSERT INTO "languageNames" VALUES(5698,'it','gd','gaelico scozzese');
INSERT INTO "languageNames" VALUES(5699,'it','gl','galiziano');
INSERT INTO "languageNames" VALUES(5700,'it','glk','gilaki');
INSERT INTO "languageNames" VALUES(5701,'it','gn','guaraní');
INSERT INTO "languageNames" VALUES(5702,'it','gu','gujarati');
INSERT INTO "languageNames" VALUES(5703,'it','guc','wayuu');
INSERT INTO "languageNames" VALUES(5704,'it','gv','mannese');
INSERT INTO "languageNames" VALUES(5705,'it','ha','hausa');
INSERT INTO "languageNames" VALUES(5706,'it','haw','hawaiano');
INSERT INTO "languageNames" VALUES(5707,'it','he','ebraico');
INSERT INTO "languageNames" VALUES(5708,'it','hi','hindi');
INSERT INTO "languageNames" VALUES(5709,'it','hr','croato');
INSERT INTO "languageNames" VALUES(5710,'it','hsb','alto sorabo');
INSERT INTO "languageNames" VALUES(5711,'it','ht','haitiano');
INSERT INTO "languageNames" VALUES(5712,'it','hu','ungherese');
INSERT INTO "languageNames" VALUES(5713,'it','hy','armeno');
INSERT INTO "languageNames" VALUES(5714,'it','ia','interlingua');
INSERT INTO "languageNames" VALUES(5715,'it','id','indonesiano');
INSERT INTO "languageNames" VALUES(5716,'it','ig','igbo');
INSERT INTO "languageNames" VALUES(5717,'it','is','islandese');
INSERT INTO "languageNames" VALUES(5718,'it','it','italiano');
INSERT INTO "languageNames" VALUES(5719,'it','ka','georgiano');
INSERT INTO "languageNames" VALUES(5720,'it','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(5721,'it','kk','kazako');
INSERT INTO "languageNames" VALUES(5722,'it','ko','coreano');
INSERT INTO "languageNames" VALUES(5723,'it','krc','karachay-Balkar');
INSERT INTO "languageNames" VALUES(5724,'it','krl','careliano');
INSERT INTO "languageNames" VALUES(5725,'it','ks','kashmiri');
INSERT INTO "languageNames" VALUES(5726,'it','kum','kumyk');
INSERT INTO "languageNames" VALUES(5727,'it','kv','komi');
INSERT INTO "languageNames" VALUES(5728,'it','ky','chirghiso');
INSERT INTO "languageNames" VALUES(5729,'it','la','latino');
INSERT INTO "languageNames" VALUES(5730,'it','lb','lussemburghese');
INSERT INTO "languageNames" VALUES(5731,'it','lg','ganda');
INSERT INTO "languageNames" VALUES(5732,'it','liv','livone');
INSERT INTO "languageNames" VALUES(5733,'it','ln','lingala');
INSERT INTO "languageNames" VALUES(5734,'it','lo','lao');
INSERT INTO "languageNames" VALUES(5735,'it','lt','lituano');
INSERT INTO "languageNames" VALUES(5736,'it','lv','lettone');
INSERT INTO "languageNames" VALUES(5737,'it','mdf','moksha');
INSERT INTO "languageNames" VALUES(5738,'it','mfe','creolo mauriziano');
INSERT INTO "languageNames" VALUES(5739,'it','mk','macedone');
INSERT INTO "languageNames" VALUES(5740,'it','ml','malayalam');
INSERT INTO "languageNames" VALUES(5741,'it','mr','marathi');
INSERT INTO "languageNames" VALUES(5742,'it','mrj','mari occidentale');
INSERT INTO "languageNames" VALUES(5743,'it','ms','malese');
INSERT INTO "languageNames" VALUES(5744,'it','mt','maltese');
INSERT INTO "languageNames" VALUES(5745,'it','myv','erzya');
INSERT INTO "languageNames" VALUES(5746,'it','nap','napoletano');
INSERT INTO "languageNames" VALUES(5747,'it','nb','norvegese bokmål');
INSERT INTO "languageNames" VALUES(5748,'it','ne','nepalese');
INSERT INTO "languageNames" VALUES(5749,'it','nl','olandese');
INSERT INTO "languageNames" VALUES(5750,'it','nn','norvegese nynorsk');
INSERT INTO "languageNames" VALUES(5751,'it','no','norvegese');
INSERT INTO "languageNames" VALUES(5752,'it','nog','nogai');
INSERT INTO "languageNames" VALUES(5753,'it','oc','occitano');
INSERT INTO "languageNames" VALUES(5754,'it','os','ossetico');
INSERT INTO "languageNames" VALUES(5755,'it','ota','turco ottomano');
INSERT INTO "languageNames" VALUES(5756,'it','pa','punjabi');
INSERT INTO "languageNames" VALUES(5757,'it','pl','polacco');
INSERT INTO "languageNames" VALUES(5758,'it','pt','portoghese');
INSERT INTO "languageNames" VALUES(5759,'it','rm','romancio');
INSERT INTO "languageNames" VALUES(5760,'it','rn','rundi');
INSERT INTO "languageNames" VALUES(5761,'it','ro','rumeno');
INSERT INTO "languageNames" VALUES(5762,'it','ru','russo');
INSERT INTO "languageNames" VALUES(5763,'it','rup','arumeno');
INSERT INTO "languageNames" VALUES(5764,'it','sa','sanscrito');
INSERT INTO "languageNames" VALUES(5765,'it','sah','yakut');
INSERT INTO "languageNames" VALUES(5766,'it','sc','sardo');
INSERT INTO "languageNames" VALUES(5767,'it','scn','siciliano');
INSERT INTO "languageNames" VALUES(5768,'it','sco','scozzese');
INSERT INTO "languageNames" VALUES(5769,'it','sd','sindhi');
INSERT INTO "languageNames" VALUES(5770,'it','se','sami del nord');
INSERT INTO "languageNames" VALUES(5771,'it','sh','serbo-croato');
INSERT INTO "languageNames" VALUES(5772,'it','si','singalese');
INSERT INTO "languageNames" VALUES(5773,'it','sk','slovacco');
INSERT INTO "languageNames" VALUES(5774,'it','sl','sloveno');
INSERT INTO "languageNames" VALUES(5775,'it','sma','sami del sud');
INSERT INTO "languageNames" VALUES(5776,'it','smj','sami di Lule');
INSERT INTO "languageNames" VALUES(5777,'it','smn','sami di Inari');
INSERT INTO "languageNames" VALUES(5778,'it','sq','albanese');
INSERT INTO "languageNames" VALUES(5779,'it','sr','serbo');
INSERT INTO "languageNames" VALUES(5780,'it','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(5781,'it','ss','swati');
INSERT INTO "languageNames" VALUES(5782,'it','sv','svedese');
INSERT INTO "languageNames" VALUES(5783,'it','sw','swahili');
INSERT INTO "languageNames" VALUES(5784,'it','ta','tamil');
INSERT INTO "languageNames" VALUES(5785,'it','te','telugu');
INSERT INTO "languageNames" VALUES(5786,'it','tet','tetum');
INSERT INTO "languageNames" VALUES(5787,'it','tg','tagico');
INSERT INTO "languageNames" VALUES(5788,'it','th','thai');
INSERT INTO "languageNames" VALUES(5789,'it','tk','turcomanno');
INSERT INTO "languageNames" VALUES(5790,'it','tl','tagalog');
INSERT INTO "languageNames" VALUES(5791,'it','tr','turco');
INSERT INTO "languageNames" VALUES(5792,'it','tt','tataro');
INSERT INTO "languageNames" VALUES(5793,'it','tyv','tuvinian');
INSERT INTO "languageNames" VALUES(5794,'it','udm','udmurt');
INSERT INTO "languageNames" VALUES(5795,'it','ug','uiguro');
INSERT INTO "languageNames" VALUES(5796,'it','uk','ucraino');
INSERT INTO "languageNames" VALUES(5797,'it','ur','urdu');
INSERT INTO "languageNames" VALUES(5798,'it','uz','uzbeco');
INSERT INTO "languageNames" VALUES(5799,'it','vi','vietnamita');
INSERT INTO "languageNames" VALUES(5800,'it','vro','võro');
INSERT INTO "languageNames" VALUES(5801,'it','wal','walamo');
INSERT INTO "languageNames" VALUES(5802,'it','xh','xhosa');
INSERT INTO "languageNames" VALUES(5803,'it','yi','yiddish');
INSERT INTO "languageNames" VALUES(5804,'it','yo','yoruba');
INSERT INTO "languageNames" VALUES(5805,'it','zh','cinese');
INSERT INTO "languageNames" VALUES(5806,'it','zu','zulu');
INSERT INTO "languageNames" VALUES(5807,'et','af','afrikaani');
INSERT INTO "languageNames" VALUES(5808,'et','alt','altai');
INSERT INTO "languageNames" VALUES(5809,'et','an','aragoni');
INSERT INTO "languageNames" VALUES(5810,'et','ar','araabia');
INSERT INTO "languageNames" VALUES(5811,'et','as','assami');
INSERT INTO "languageNames" VALUES(5812,'et','ast','astuuria');
INSERT INTO "languageNames" VALUES(5813,'et','av','avaari');
INSERT INTO "languageNames" VALUES(5815,'et','az','aseri');
INSERT INTO "languageNames" VALUES(5816,'et','ba','baškiiri');
INSERT INTO "languageNames" VALUES(5817,'et','be','valgevene');
INSERT INTO "languageNames" VALUES(5818,'et','bg','bulgaaria');
INSERT INTO "languageNames" VALUES(5819,'et','bi','bislama');
INSERT INTO "languageNames" VALUES(5820,'et','bn','bengali');
INSERT INTO "languageNames" VALUES(5821,'et','br','bretooni');
INSERT INTO "languageNames" VALUES(5822,'et','bs','bosnia');
INSERT INTO "languageNames" VALUES(5823,'et','bua','burjaadi');
INSERT INTO "languageNames" VALUES(5824,'et','byv','medumba');
INSERT INTO "languageNames" VALUES(5825,'et','ca','katalaani');
INSERT INTO "languageNames" VALUES(5826,'et','ceb','sebu');
INSERT INTO "languageNames" VALUES(5827,'et','chm','mari');
INSERT INTO "languageNames" VALUES(5828,'et','ckb','sorani');
INSERT INTO "languageNames" VALUES(5829,'et','co','korsika');
INSERT INTO "languageNames" VALUES(5830,'et','crh','krimmitatari');
INSERT INTO "languageNames" VALUES(5831,'et','cs','tšehhi');
INSERT INTO "languageNames" VALUES(5832,'et','csb','kašuubi');
INSERT INTO "languageNames" VALUES(5833,'et','cu','kirikuslaavi');
INSERT INTO "languageNames" VALUES(5834,'et','cv','tšuvaši');
INSERT INTO "languageNames" VALUES(5835,'et','cy','kõmri');
INSERT INTO "languageNames" VALUES(5836,'et','da','taani');
INSERT INTO "languageNames" VALUES(5837,'et','dar','dargi');
INSERT INTO "languageNames" VALUES(5838,'et','de','saksa');
INSERT INTO "languageNames" VALUES(5839,'et','dsb','alamsorbi');
INSERT INTO "languageNames" VALUES(5840,'et','el','kreeka');
INSERT INTO "languageNames" VALUES(5841,'et','en','inglise');
INSERT INTO "languageNames" VALUES(5842,'et','eo','esperanto');
INSERT INTO "languageNames" VALUES(5843,'et','es','hispaania');
INSERT INTO "languageNames" VALUES(5844,'et','et','eesti');
INSERT INTO "languageNames" VALUES(5845,'et','eu','baski');
INSERT INTO "languageNames" VALUES(5846,'et','fa','pärsia');
INSERT INTO "languageNames" VALUES(5847,'et','fi','soome');
INSERT INTO "languageNames" VALUES(5848,'et','fo','fääri');
INSERT INTO "languageNames" VALUES(5849,'et','fr','prantsuse');
INSERT INTO "languageNames" VALUES(5850,'et','fy','läänefriisi');
INSERT INTO "languageNames" VALUES(5851,'et','ga','iiri');
INSERT INTO "languageNames" VALUES(5852,'et','gag','gagauusi');
INSERT INTO "languageNames" VALUES(5853,'et','gd','gaeli');
INSERT INTO "languageNames" VALUES(5854,'et','gl','galeegi');
INSERT INTO "languageNames" VALUES(5855,'et','glk','gilaki');
INSERT INTO "languageNames" VALUES(5856,'et','gn','guaranii');
INSERT INTO "languageNames" VALUES(5857,'et','gu','gudžarati');
INSERT INTO "languageNames" VALUES(5858,'et','guc','vajuu');
INSERT INTO "languageNames" VALUES(5859,'et','gv','mänksi');
INSERT INTO "languageNames" VALUES(5860,'et','ha','hausa');
INSERT INTO "languageNames" VALUES(5861,'et','haw','havai');
INSERT INTO "languageNames" VALUES(5862,'et','he','heebrea');
INSERT INTO "languageNames" VALUES(5863,'et','hi','hindi');
INSERT INTO "languageNames" VALUES(5864,'et','hr','horvaadi');
INSERT INTO "languageNames" VALUES(5865,'et','hsb','ülemsorbi');
INSERT INTO "languageNames" VALUES(5866,'et','ht','haiti');
INSERT INTO "languageNames" VALUES(5867,'et','hu','ungari');
INSERT INTO "languageNames" VALUES(5868,'et','hy','armeenia');
INSERT INTO "languageNames" VALUES(5869,'et','ia','interlingua');
INSERT INTO "languageNames" VALUES(5870,'et','id','indoneesia');
INSERT INTO "languageNames" VALUES(5871,'et','ig','ibo');
INSERT INTO "languageNames" VALUES(5872,'et','is','islandi');
INSERT INTO "languageNames" VALUES(5873,'et','it','itaalia');
INSERT INTO "languageNames" VALUES(5874,'et','ka','gruusia');
INSERT INTO "languageNames" VALUES(5875,'et','kaa','karakalpaki');
INSERT INTO "languageNames" VALUES(5876,'et','kk','kasahhi');
INSERT INTO "languageNames" VALUES(5877,'et','ko','korea');
INSERT INTO "languageNames" VALUES(5878,'et','krc','karatšai-balkaari');
INSERT INTO "languageNames" VALUES(5879,'et','krl','karjala');
INSERT INTO "languageNames" VALUES(5880,'et','ks','kašmiiri');
INSERT INTO "languageNames" VALUES(5881,'et','kum','kumõki');
INSERT INTO "languageNames" VALUES(5882,'et','kv','komi');
INSERT INTO "languageNames" VALUES(5883,'et','ky','kirgiisi');
INSERT INTO "languageNames" VALUES(5884,'et','la','ladina');
INSERT INTO "languageNames" VALUES(5885,'et','lb','letseburgi');
INSERT INTO "languageNames" VALUES(5886,'et','lg','ganda');
INSERT INTO "languageNames" VALUES(5887,'et','liv','liivi');
INSERT INTO "languageNames" VALUES(5888,'et','ln','lingala');
INSERT INTO "languageNames" VALUES(5889,'et','lo','lao');
INSERT INTO "languageNames" VALUES(5890,'et','lt','leedu');
INSERT INTO "languageNames" VALUES(5891,'et','lv','läti');
INSERT INTO "languageNames" VALUES(5892,'et','mdf','mokša');
INSERT INTO "languageNames" VALUES(5893,'et','mfe','Mauritiuse kreoolkeel');
INSERT INTO "languageNames" VALUES(5894,'et','mk','makedoonia');
INSERT INTO "languageNames" VALUES(5895,'et','ml','malajalami');
INSERT INTO "languageNames" VALUES(5896,'et','mr','marathi');
INSERT INTO "languageNames" VALUES(5897,'et','mrj','mäemari');
INSERT INTO "languageNames" VALUES(5898,'et','ms','malai');
INSERT INTO "languageNames" VALUES(5899,'et','mt','malta');
INSERT INTO "languageNames" VALUES(5900,'et','myv','ersa');
INSERT INTO "languageNames" VALUES(5901,'et','nap','napoli');
INSERT INTO "languageNames" VALUES(5902,'et','nb','norra bokmål');
INSERT INTO "languageNames" VALUES(5903,'et','ne','nepali');
INSERT INTO "languageNames" VALUES(5904,'et','nl','hollandi');
INSERT INTO "languageNames" VALUES(5905,'et','nn','uusnorra');
INSERT INTO "languageNames" VALUES(5906,'et','no','norra');
INSERT INTO "languageNames" VALUES(5907,'et','nog','nogai');
INSERT INTO "languageNames" VALUES(5908,'et','oc','oksitaani');
INSERT INTO "languageNames" VALUES(5909,'et','os','osseedi');
INSERT INTO "languageNames" VALUES(5910,'et','ota','osmanitürgi');
INSERT INTO "languageNames" VALUES(5911,'et','pa','pandžabi');
INSERT INTO "languageNames" VALUES(5912,'et','pl','poola');
INSERT INTO "languageNames" VALUES(5913,'et','pt','portugali');
INSERT INTO "languageNames" VALUES(5914,'et','rm','romanši');
INSERT INTO "languageNames" VALUES(5915,'et','rn','rundi');
INSERT INTO "languageNames" VALUES(5916,'et','ro','rumeenia');
INSERT INTO "languageNames" VALUES(5917,'et','ru','vene');
INSERT INTO "languageNames" VALUES(5918,'et','rup','aromuuni');
INSERT INTO "languageNames" VALUES(5919,'et','sa','sanskriti');
INSERT INTO "languageNames" VALUES(5920,'et','sah','jakuudi');
INSERT INTO "languageNames" VALUES(5921,'et','sc','sardi');
INSERT INTO "languageNames" VALUES(5922,'et','scn','sitsiilia');
INSERT INTO "languageNames" VALUES(5923,'et','sco','šoti');
INSERT INTO "languageNames" VALUES(5924,'et','sd','sindhi');
INSERT INTO "languageNames" VALUES(5925,'et','se','põhjasaami');
INSERT INTO "languageNames" VALUES(5926,'et','sh','serbia-horvaadi');
INSERT INTO "languageNames" VALUES(5927,'et','si','singali');
INSERT INTO "languageNames" VALUES(5928,'et','sk','slovaki');
INSERT INTO "languageNames" VALUES(5929,'et','sl','sloveeni');
INSERT INTO "languageNames" VALUES(5930,'et','sma','lõunasaami');
INSERT INTO "languageNames" VALUES(5931,'et','smj','Lule saami');
INSERT INTO "languageNames" VALUES(5932,'et','smn','Inari saami');
INSERT INTO "languageNames" VALUES(5933,'et','sq','albaania');
INSERT INTO "languageNames" VALUES(5934,'et','sr','serbia');
INSERT INTO "languageNames" VALUES(5935,'et','srn','sranani');
INSERT INTO "languageNames" VALUES(5936,'et','ss','svaasi');
INSERT INTO "languageNames" VALUES(5937,'et','sv','rootsi');
INSERT INTO "languageNames" VALUES(5938,'et','sw','suahiili');
INSERT INTO "languageNames" VALUES(5939,'et','ta','tamili');
INSERT INTO "languageNames" VALUES(5940,'et','te','telugu');
INSERT INTO "languageNames" VALUES(5941,'et','tet','tetumi');
INSERT INTO "languageNames" VALUES(5942,'et','tg','tadžiki');
INSERT INTO "languageNames" VALUES(5943,'et','th','tai');
INSERT INTO "languageNames" VALUES(5944,'et','tk','türkmeeni');
INSERT INTO "languageNames" VALUES(5945,'et','tl','tagalogi');
INSERT INTO "languageNames" VALUES(5946,'et','tr','türgi');
INSERT INTO "languageNames" VALUES(5947,'et','tt','tatari');
INSERT INTO "languageNames" VALUES(5948,'et','tyv','tõva');
INSERT INTO "languageNames" VALUES(5949,'et','udm','udmurdi');
INSERT INTO "languageNames" VALUES(5950,'et','ug','uiguuri');
INSERT INTO "languageNames" VALUES(5951,'et','uk','ukraina');
INSERT INTO "languageNames" VALUES(5952,'et','ur','urdu');
INSERT INTO "languageNames" VALUES(5953,'et','uz','usbeki');
INSERT INTO "languageNames" VALUES(5954,'et','vi','vietnami');
INSERT INTO "languageNames" VALUES(5955,'et','vro','võru');
INSERT INTO "languageNames" VALUES(5956,'et','wal','volaita');
INSERT INTO "languageNames" VALUES(5957,'et','xh','koosa');
INSERT INTO "languageNames" VALUES(5958,'et','yi','jidiši');
INSERT INTO "languageNames" VALUES(5959,'et','yo','joruba');
INSERT INTO "languageNames" VALUES(5960,'et','zh','hiina');
INSERT INTO "languageNames" VALUES(5961,'et','zu','suulu');
INSERT INTO "languageNames" VALUES(5962,'th','af','แอฟริกานส์');
INSERT INTO "languageNames" VALUES(5963,'th','alt','อัลไตใต้');
INSERT INTO "languageNames" VALUES(5964,'th','an','อารากอน');
INSERT INTO "languageNames" VALUES(5965,'th','ar','อาหรับ');
INSERT INTO "languageNames" VALUES(5966,'th','as','อัสสัม');
INSERT INTO "languageNames" VALUES(5967,'th','ast','อัสตูเรียส');
INSERT INTO "languageNames" VALUES(5968,'th','av','อาวาร์');
INSERT INTO "languageNames" VALUES(5970,'th','az','อะเซอรี');
INSERT INTO "languageNames" VALUES(5971,'th','ba','บัชคีร์');
INSERT INTO "languageNames" VALUES(5972,'th','be','เบลารุส');
INSERT INTO "languageNames" VALUES(5973,'th','bg','บัลแกเรีย');
INSERT INTO "languageNames" VALUES(5974,'th','bi','บิสลามา');
INSERT INTO "languageNames" VALUES(5975,'th','bn','เบงกาลี');
INSERT INTO "languageNames" VALUES(5976,'th','br','เบรตัน');
INSERT INTO "languageNames" VALUES(5977,'th','bs','บอสเนีย');
INSERT INTO "languageNames" VALUES(5978,'th','bua','บูเรียต');
INSERT INTO "languageNames" VALUES(5979,'th','byv','เมดุมบา');
INSERT INTO "languageNames" VALUES(5980,'th','ca','กาตาลัง');
INSERT INTO "languageNames" VALUES(5981,'th','ceb','เซบู');
INSERT INTO "languageNames" VALUES(5982,'th','chm','มารี');
INSERT INTO "languageNames" VALUES(5983,'th','ckb','เคิร์ดโซรานี');
INSERT INTO "languageNames" VALUES(5984,'th','co','คอร์ซิกา');
INSERT INTO "languageNames" VALUES(5985,'th','crh','ตุรกีไครเมีย');
INSERT INTO "languageNames" VALUES(5986,'th','cs','เช็ก');
INSERT INTO "languageNames" VALUES(5987,'th','csb','คาซูเบียน');
INSERT INTO "languageNames" VALUES(5988,'th','cu','เชอร์ชสลาวิก');
INSERT INTO "languageNames" VALUES(5989,'th','cv','ชูวัช');
INSERT INTO "languageNames" VALUES(5990,'th','cy','เวลส์');
INSERT INTO "languageNames" VALUES(5991,'th','da','เดนมาร์ก');
INSERT INTO "languageNames" VALUES(5992,'th','dar','ดาร์กิน');
INSERT INTO "languageNames" VALUES(5993,'th','de','เยอรมัน');
INSERT INTO "languageNames" VALUES(5994,'th','dsb','ซอร์บส์ตอนล่าง');
INSERT INTO "languageNames" VALUES(5995,'th','el','กรีก');
INSERT INTO "languageNames" VALUES(5996,'th','en','อังกฤษ');
INSERT INTO "languageNames" VALUES(5997,'th','eo','เอสเปรันโต');
INSERT INTO "languageNames" VALUES(5998,'th','es','สเปน');
INSERT INTO "languageNames" VALUES(5999,'th','et','เอสโตเนีย');
INSERT INTO "languageNames" VALUES(6000,'th','eu','บาสก์');
INSERT INTO "languageNames" VALUES(6001,'th','fa','เปอร์เซีย');
INSERT INTO "languageNames" VALUES(6002,'th','fi','ฟินแลนด์');
INSERT INTO "languageNames" VALUES(6003,'th','fo','แฟโร');
INSERT INTO "languageNames" VALUES(6004,'th','fr','ฝรั่งเศส');
INSERT INTO "languageNames" VALUES(6005,'th','fy','ฟริเซียนตะวันตก');
INSERT INTO "languageNames" VALUES(6006,'th','ga','ไอริช');
INSERT INTO "languageNames" VALUES(6007,'th','gag','กากาอุซ');
INSERT INTO "languageNames" VALUES(6008,'th','gd','เกลิกสกอต');
INSERT INTO "languageNames" VALUES(6009,'th','gl','กาลิเซีย');
INSERT INTO "languageNames" VALUES(6010,'th','glk','กิลากี');
INSERT INTO "languageNames" VALUES(6011,'th','gn','กัวรานี');
INSERT INTO "languageNames" VALUES(6012,'th','gu','คุชราต');
INSERT INTO "languageNames" VALUES(6013,'th','guc','วายู');
INSERT INTO "languageNames" VALUES(6014,'th','gv','มานซ์');
INSERT INTO "languageNames" VALUES(6015,'th','ha','เฮาซา');
INSERT INTO "languageNames" VALUES(6016,'th','haw','ฮาวาย');
INSERT INTO "languageNames" VALUES(6017,'th','he','ฮิบรู');
INSERT INTO "languageNames" VALUES(6018,'th','hi','ฮินดี');
INSERT INTO "languageNames" VALUES(6019,'th','hr','โครเอเชีย');
INSERT INTO "languageNames" VALUES(6020,'th','hsb','ซอร์เบียตอนบน');
INSERT INTO "languageNames" VALUES(6021,'th','ht','เฮติครีโอล');
INSERT INTO "languageNames" VALUES(6022,'th','hu','ฮังการี');
INSERT INTO "languageNames" VALUES(6023,'th','hy','อาร์เมเนีย');
INSERT INTO "languageNames" VALUES(6024,'th','ia','อินเตอร์ลิงกัว');
INSERT INTO "languageNames" VALUES(6025,'th','id','อินโดนีเซีย');
INSERT INTO "languageNames" VALUES(6026,'th','ig','อิกโบ');
INSERT INTO "languageNames" VALUES(6027,'th','is','ไอซ์แลนด์');
INSERT INTO "languageNames" VALUES(6028,'th','it','อิตาลี');
INSERT INTO "languageNames" VALUES(6029,'th','ka','จอร์เจีย');
INSERT INTO "languageNames" VALUES(6030,'th','kaa','การา-กาลพาก');
INSERT INTO "languageNames" VALUES(6031,'th','kk','คาซัค');
INSERT INTO "languageNames" VALUES(6032,'th','ko','เกาหลี');
INSERT INTO "languageNames" VALUES(6033,'th','krc','คาราไช-บัลคาร์');
INSERT INTO "languageNames" VALUES(6034,'th','krl','แกรเลียน');
INSERT INTO "languageNames" VALUES(6035,'th','ks','กัศมีร์');
INSERT INTO "languageNames" VALUES(6036,'th','kum','คูมืยค์');
INSERT INTO "languageNames" VALUES(6037,'th','kv','โกมิ');
INSERT INTO "languageNames" VALUES(6038,'th','ky','คีร์กีซ');
INSERT INTO "languageNames" VALUES(6039,'th','la','ละติน');
INSERT INTO "languageNames" VALUES(6040,'th','lb','ลักเซมเบิร์ก');
INSERT INTO "languageNames" VALUES(6041,'th','lg','ยูกันดา');
INSERT INTO "languageNames" VALUES(6042,'th','liv','ลิโวเนีย');
INSERT INTO "languageNames" VALUES(6043,'th','ln','ลิงกาลา');
INSERT INTO "languageNames" VALUES(6044,'th','lo','ลาว');
INSERT INTO "languageNames" VALUES(6045,'th','lt','ลิทัวเนีย');
INSERT INTO "languageNames" VALUES(6046,'th','lv','ลัตเวีย');
INSERT INTO "languageNames" VALUES(6047,'th','mdf','มอคชา');
INSERT INTO "languageNames" VALUES(6048,'th','mfe','มอริสเยน');
INSERT INTO "languageNames" VALUES(6049,'th','mk','มาซิโดเนีย');
INSERT INTO "languageNames" VALUES(6050,'th','ml','มาลายาลัม');
INSERT INTO "languageNames" VALUES(6051,'th','mr','มราฐี');
INSERT INTO "languageNames" VALUES(6052,'th','mrj','มารีตะวันตก');
INSERT INTO "languageNames" VALUES(6053,'th','ms','มาเลย์');
INSERT INTO "languageNames" VALUES(6054,'th','mt','มอลตา');
INSERT INTO "languageNames" VALUES(6055,'th','myv','เอียร์ซยา');
INSERT INTO "languageNames" VALUES(6056,'th','nap','นาโปลี');
INSERT INTO "languageNames" VALUES(6057,'th','nb','นอร์เวย์บุคมอล');
INSERT INTO "languageNames" VALUES(6058,'th','ne','เนปาล');
INSERT INTO "languageNames" VALUES(6059,'th','nl','ดัตช์');
INSERT INTO "languageNames" VALUES(6060,'th','nn','นอร์เวย์นีนอสก์');
INSERT INTO "languageNames" VALUES(6061,'th','no','นอร์เวย์');
INSERT INTO "languageNames" VALUES(6062,'th','nog','โนไก');
INSERT INTO "languageNames" VALUES(6063,'th','oc','อ็อกซิตัน');
INSERT INTO "languageNames" VALUES(6064,'th','os','ออสเซเตีย');
INSERT INTO "languageNames" VALUES(6065,'th','ota','ตุรกีออตโตมัน');
INSERT INTO "languageNames" VALUES(6066,'th','pa','ปัญจาบ');
INSERT INTO "languageNames" VALUES(6067,'th','pl','โปแลนด์');
INSERT INTO "languageNames" VALUES(6068,'th','pt','โปรตุเกส');
INSERT INTO "languageNames" VALUES(6069,'th','rm','โรแมนซ์');
INSERT INTO "languageNames" VALUES(6070,'th','rn','บุรุนดี');
INSERT INTO "languageNames" VALUES(6071,'th','ro','โรมาเนีย');
INSERT INTO "languageNames" VALUES(6072,'th','ru','รัสเซีย');
INSERT INTO "languageNames" VALUES(6073,'th','rup','อาโรมาเนียน');
INSERT INTO "languageNames" VALUES(6074,'th','sa','สันสกฤต');
INSERT INTO "languageNames" VALUES(6075,'th','sah','ซาคา');
INSERT INTO "languageNames" VALUES(6076,'th','sc','ซาร์เดญา');
INSERT INTO "languageNames" VALUES(6077,'th','scn','ซิซิลี');
INSERT INTO "languageNames" VALUES(6078,'th','sco','สกอตส์');
INSERT INTO "languageNames" VALUES(6079,'th','sd','สินธิ');
INSERT INTO "languageNames" VALUES(6080,'th','se','ซามิเหนือ');
INSERT INTO "languageNames" VALUES(6081,'th','sh','เซอร์โบ-โครเอเชีย');
INSERT INTO "languageNames" VALUES(6082,'th','si','สิงหล');
INSERT INTO "languageNames" VALUES(6083,'th','sk','สโลวัก');
INSERT INTO "languageNames" VALUES(6084,'th','sl','สโลวีเนีย');
INSERT INTO "languageNames" VALUES(6085,'th','sma','ซามิใต้');
INSERT INTO "languageNames" VALUES(6086,'th','smj','ซามิลูเล');
INSERT INTO "languageNames" VALUES(6087,'th','smn','ซามิอีนารี');
INSERT INTO "languageNames" VALUES(6088,'th','sq','แอลเบเนีย');
INSERT INTO "languageNames" VALUES(6089,'th','sr','เซอร์เบีย');
INSERT INTO "languageNames" VALUES(6090,'th','srn','ซูรินาเม');
INSERT INTO "languageNames" VALUES(6091,'th','ss','สวาติ');
INSERT INTO "languageNames" VALUES(6092,'th','sv','สวีเดน');
INSERT INTO "languageNames" VALUES(6093,'th','sw','สวาฮีลี');
INSERT INTO "languageNames" VALUES(6094,'th','ta','ทมิฬ');
INSERT INTO "languageNames" VALUES(6095,'th','te','เตลูกู');
INSERT INTO "languageNames" VALUES(6096,'th','tet','เตตุม');
INSERT INTO "languageNames" VALUES(6097,'th','tg','ทาจิก');
INSERT INTO "languageNames" VALUES(6098,'th','th','ไทย');
INSERT INTO "languageNames" VALUES(6099,'th','tk','เติร์กเมน');
INSERT INTO "languageNames" VALUES(6100,'th','tl','ตากาล็อก');
INSERT INTO "languageNames" VALUES(6101,'th','tr','ตุรกี');
INSERT INTO "languageNames" VALUES(6102,'th','tt','ตาตาร์');
INSERT INTO "languageNames" VALUES(6103,'th','tyv','ตูวา');
INSERT INTO "languageNames" VALUES(6104,'th','udm','อุดมูร์ต');
INSERT INTO "languageNames" VALUES(6105,'th','ug','อุยกูร์');
INSERT INTO "languageNames" VALUES(6106,'th','uk','ยูเครน');
INSERT INTO "languageNames" VALUES(6107,'th','ur','อูรดู');
INSERT INTO "languageNames" VALUES(6108,'th','uz','อุซเบก');
INSERT INTO "languageNames" VALUES(6109,'th','vi','เวียดนาม');
INSERT INTO "languageNames" VALUES(6110,'th','vro','โวโร');
INSERT INTO "languageNames" VALUES(6111,'th','wal','วาลาโม');
INSERT INTO "languageNames" VALUES(6112,'th','xh','คะห์โอซา');
INSERT INTO "languageNames" VALUES(6113,'th','yi','ยิดดิช');
INSERT INTO "languageNames" VALUES(6114,'th','yo','โยรูบา');
INSERT INTO "languageNames" VALUES(6115,'th','zh','จีน');
INSERT INTO "languageNames" VALUES(6116,'th','zu','ซูลู');
INSERT INTO "languageNames" VALUES(6117,'cy','af','Affricâneg');
INSERT INTO "languageNames" VALUES(6118,'cy','alt','Altäeg Deheuol');
INSERT INTO "languageNames" VALUES(6119,'cy','an','Aragoneg');
INSERT INTO "languageNames" VALUES(6120,'cy','ar','Arabeg');
INSERT INTO "languageNames" VALUES(6121,'cy','as','Asameg');
INSERT INTO "languageNames" VALUES(6122,'cy','ast','Astwrianeg');
INSERT INTO "languageNames" VALUES(6123,'cy','av','Afareg');
INSERT INTO "languageNames" VALUES(6125,'cy','az','Aseri');
INSERT INTO "languageNames" VALUES(6126,'cy','ba','Bashcorteg');
INSERT INTO "languageNames" VALUES(6127,'cy','be','Belarwseg');
INSERT INTO "languageNames" VALUES(6128,'cy','bg','Bwlgareg');
INSERT INTO "languageNames" VALUES(6129,'cy','bi','Bislama');
INSERT INTO "languageNames" VALUES(6130,'cy','bn','Bengaleg');
INSERT INTO "languageNames" VALUES(6131,'cy','br','Llydaweg');
INSERT INTO "languageNames" VALUES(6132,'cy','bs','Bosnieg');
INSERT INTO "languageNames" VALUES(6133,'cy','bua','Bwriateg');
INSERT INTO "languageNames" VALUES(6134,'cy','ca','Catalaneg');
INSERT INTO "languageNames" VALUES(6135,'cy','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(6136,'cy','chm','Marieg');
INSERT INTO "languageNames" VALUES(6137,'cy','ckb','Cwrdeg Sorani');
INSERT INTO "languageNames" VALUES(6138,'cy','co','Corseg');
INSERT INTO "languageNames" VALUES(6139,'cy','crh','Tyrceg y Crimea');
INSERT INTO "languageNames" VALUES(6140,'cy','cs','Tsieceg');
INSERT INTO "languageNames" VALUES(6141,'cy','cu','Hen Slafoneg');
INSERT INTO "languageNames" VALUES(6142,'cy','cv','Tshwfasheg');
INSERT INTO "languageNames" VALUES(6143,'cy','cy','Cymraeg');
INSERT INTO "languageNames" VALUES(6144,'cy','da','Daneg');
INSERT INTO "languageNames" VALUES(6145,'cy','dar','Dargwa');
INSERT INTO "languageNames" VALUES(6146,'cy','de','Almaeneg');
INSERT INTO "languageNames" VALUES(6147,'cy','dsb','Sorbeg Isaf');
INSERT INTO "languageNames" VALUES(6148,'cy','el','Groeg');
INSERT INTO "languageNames" VALUES(6149,'cy','en','Saesneg');
INSERT INTO "languageNames" VALUES(6150,'cy','eo','Esperanto');
INSERT INTO "languageNames" VALUES(6151,'cy','es','Sbaeneg');
INSERT INTO "languageNames" VALUES(6152,'cy','et','Estoneg');
INSERT INTO "languageNames" VALUES(6153,'cy','eu','Basgeg');
INSERT INTO "languageNames" VALUES(6154,'cy','fa','Perseg');
INSERT INTO "languageNames" VALUES(6155,'cy','fi','Ffinneg');
INSERT INTO "languageNames" VALUES(6156,'cy','fo','Ffaröeg');
INSERT INTO "languageNames" VALUES(6157,'cy','fr','Ffrangeg');
INSERT INTO "languageNames" VALUES(6158,'cy','fy','Ffriseg y Gorllewin');
INSERT INTO "languageNames" VALUES(6159,'cy','ga','Gwyddeleg');
INSERT INTO "languageNames" VALUES(6160,'cy','gag','Gagauz');
INSERT INTO "languageNames" VALUES(6161,'cy','gd','Gaeleg yr Alban');
INSERT INTO "languageNames" VALUES(6162,'cy','gl','Galisieg');
INSERT INTO "languageNames" VALUES(6163,'cy','gn','Guaraní');
INSERT INTO "languageNames" VALUES(6164,'cy','gu','Gwjarati');
INSERT INTO "languageNames" VALUES(6165,'cy','gv','Manaweg');
INSERT INTO "languageNames" VALUES(6166,'cy','ha','Hawsa');
INSERT INTO "languageNames" VALUES(6167,'cy','haw','Hawäieg');
INSERT INTO "languageNames" VALUES(6168,'cy','he','Hebraeg');
INSERT INTO "languageNames" VALUES(6169,'cy','hi','Hindi');
INSERT INTO "languageNames" VALUES(6170,'cy','hr','Croateg');
INSERT INTO "languageNames" VALUES(6171,'cy','hsb','Sorbeg Uchaf');
INSERT INTO "languageNames" VALUES(6172,'cy','ht','Creol Haiti');
INSERT INTO "languageNames" VALUES(6173,'cy','hu','Hwngareg');
INSERT INTO "languageNames" VALUES(6174,'cy','hy','Armeneg');
INSERT INTO "languageNames" VALUES(6175,'cy','ia','Interlingua');
INSERT INTO "languageNames" VALUES(6176,'cy','id','Indoneseg');
INSERT INTO "languageNames" VALUES(6177,'cy','ig','Igbo');
INSERT INTO "languageNames" VALUES(6178,'cy','is','Islandeg');
INSERT INTO "languageNames" VALUES(6179,'cy','it','Eidaleg');
INSERT INTO "languageNames" VALUES(6180,'cy','ka','Georgeg');
INSERT INTO "languageNames" VALUES(6181,'cy','kaa','Cara-Calpaceg');
INSERT INTO "languageNames" VALUES(6182,'cy','kk','Casacheg');
INSERT INTO "languageNames" VALUES(6183,'cy','ko','Coreeg');
INSERT INTO "languageNames" VALUES(6184,'cy','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(6185,'cy','krl','Careleg');
INSERT INTO "languageNames" VALUES(6186,'cy','ks','Cashmireg');
INSERT INTO "languageNames" VALUES(6187,'cy','kum','Cwmiceg');
INSERT INTO "languageNames" VALUES(6188,'cy','kv','Comi');
INSERT INTO "languageNames" VALUES(6189,'cy','ky','Cirgiseg');
INSERT INTO "languageNames" VALUES(6190,'cy','la','Lladin');
INSERT INTO "languageNames" VALUES(6191,'cy','lb','Lwcsembwrgeg');
INSERT INTO "languageNames" VALUES(6192,'cy','lg','Ganda');
INSERT INTO "languageNames" VALUES(6193,'cy','ln','Lingala');
INSERT INTO "languageNames" VALUES(6194,'cy','lo','Laoeg');
INSERT INTO "languageNames" VALUES(6195,'cy','lt','Lithwaneg');
INSERT INTO "languageNames" VALUES(6196,'cy','lv','Latfieg');
INSERT INTO "languageNames" VALUES(6197,'cy','mdf','Mocsia');
INSERT INTO "languageNames" VALUES(6198,'cy','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(6199,'cy','mk','Macedoneg');
INSERT INTO "languageNames" VALUES(6200,'cy','ml','Malayalam');
INSERT INTO "languageNames" VALUES(6201,'cy','mr','Marathi');
INSERT INTO "languageNames" VALUES(6202,'cy','mrj','Mari Gorllewinol');
INSERT INTO "languageNames" VALUES(6203,'cy','ms','Maleieg');
INSERT INTO "languageNames" VALUES(6204,'cy','mt','Malteg');
INSERT INTO "languageNames" VALUES(6205,'cy','myv','Erzya');
INSERT INTO "languageNames" VALUES(6206,'cy','nap','Naplieg');
INSERT INTO "languageNames" VALUES(6207,'cy','nb','Norwyeg Bokmål');
INSERT INTO "languageNames" VALUES(6208,'cy','ne','Nepaleg');
INSERT INTO "languageNames" VALUES(6209,'cy','nl','Iseldireg');
INSERT INTO "languageNames" VALUES(6210,'cy','nn','Norwyeg Nynorsk');
INSERT INTO "languageNames" VALUES(6211,'cy','no','Norwyeg');
INSERT INTO "languageNames" VALUES(6212,'cy','nog','Nogai');
INSERT INTO "languageNames" VALUES(6213,'cy','oc','Ocsitaneg');
INSERT INTO "languageNames" VALUES(6214,'cy','os','Oseteg');
INSERT INTO "languageNames" VALUES(6215,'cy','ota','Tyrceg Otoman');
INSERT INTO "languageNames" VALUES(6216,'cy','pa','Pwnjabeg');
INSERT INTO "languageNames" VALUES(6217,'cy','pl','Pwyleg');
INSERT INTO "languageNames" VALUES(6218,'cy','pt','Portiwgeeg');
INSERT INTO "languageNames" VALUES(6219,'cy','rm','Románsh');
INSERT INTO "languageNames" VALUES(6220,'cy','rn','Rwndi');
INSERT INTO "languageNames" VALUES(6221,'cy','ro','Rwmaneg');
INSERT INTO "languageNames" VALUES(6222,'cy','ru','Rwseg');
INSERT INTO "languageNames" VALUES(6223,'cy','rup','Aromaneg');
INSERT INTO "languageNames" VALUES(6224,'cy','sa','Sansgrit');
INSERT INTO "languageNames" VALUES(6225,'cy','sah','Sakha');
INSERT INTO "languageNames" VALUES(6226,'cy','sc','Sardeg');
INSERT INTO "languageNames" VALUES(6227,'cy','scn','Sisileg');
INSERT INTO "languageNames" VALUES(6228,'cy','sco','Sgoteg');
INSERT INTO "languageNames" VALUES(6229,'cy','sd','Sindhi');
INSERT INTO "languageNames" VALUES(6230,'cy','se','Sami Gogleddol');
INSERT INTO "languageNames" VALUES(6231,'cy','sh','Serbo-Croateg');
INSERT INTO "languageNames" VALUES(6232,'cy','si','Sinhaleg');
INSERT INTO "languageNames" VALUES(6233,'cy','sk','Slofaceg');
INSERT INTO "languageNames" VALUES(6234,'cy','sl','Slofeneg');
INSERT INTO "languageNames" VALUES(6235,'cy','sma','Sami Deheuol');
INSERT INTO "languageNames" VALUES(6236,'cy','smj','Sami Lwle');
INSERT INTO "languageNames" VALUES(6237,'cy','smn','Sami Inari');
INSERT INTO "languageNames" VALUES(6238,'cy','sq','Albaneg');
INSERT INTO "languageNames" VALUES(6239,'cy','sr','Serbeg');
INSERT INTO "languageNames" VALUES(6240,'cy','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(6241,'cy','ss','Swati');
INSERT INTO "languageNames" VALUES(6242,'cy','sv','Swedeg');
INSERT INTO "languageNames" VALUES(6243,'cy','sw','Swahili');
INSERT INTO "languageNames" VALUES(6244,'cy','ta','Tamileg');
INSERT INTO "languageNames" VALUES(6245,'cy','te','Telugu');
INSERT INTO "languageNames" VALUES(6246,'cy','tet','Tetumeg');
INSERT INTO "languageNames" VALUES(6247,'cy','tg','Tajiceg');
INSERT INTO "languageNames" VALUES(6248,'cy','th','Thai');
INSERT INTO "languageNames" VALUES(6249,'cy','tk','Twrcmeneg');
INSERT INTO "languageNames" VALUES(6250,'cy','tl','Tagalog');
INSERT INTO "languageNames" VALUES(6251,'cy','tr','Tyrceg');
INSERT INTO "languageNames" VALUES(6252,'cy','tt','Tatareg');
INSERT INTO "languageNames" VALUES(6253,'cy','tyv','Twfwnieg');
INSERT INTO "languageNames" VALUES(6254,'cy','udm','Fotiaceg');
INSERT INTO "languageNames" VALUES(6255,'cy','ug','Uighur');
INSERT INTO "languageNames" VALUES(6256,'cy','uk','Wcreineg');
INSERT INTO "languageNames" VALUES(6257,'cy','ur','Wrdw');
INSERT INTO "languageNames" VALUES(6258,'cy','uz','Wsbeceg');
INSERT INTO "languageNames" VALUES(6259,'cy','vi','Fietnameg');
INSERT INTO "languageNames" VALUES(6260,'cy','wal','Walamo');
INSERT INTO "languageNames" VALUES(6261,'cy','xh','Xhosa');
INSERT INTO "languageNames" VALUES(6262,'cy','yi','Iddew-Almaeneg');
INSERT INTO "languageNames" VALUES(6263,'cy','yo','Iorwba');
INSERT INTO "languageNames" VALUES(6264,'cy','zh','Tsieineeg');
INSERT INTO "languageNames" VALUES(6265,'cy','zu','Swlw');
INSERT INTO "languageNames" VALUES(6266,'uz','af','afrikaans');
INSERT INTO "languageNames" VALUES(6267,'uz','alt','janubiy oltoy');
INSERT INTO "languageNames" VALUES(6268,'uz','an','aragon');
INSERT INTO "languageNames" VALUES(6269,'uz','ar','arab');
INSERT INTO "languageNames" VALUES(6270,'uz','as','assam');
INSERT INTO "languageNames" VALUES(6271,'uz','ast','asturiy');
INSERT INTO "languageNames" VALUES(6272,'uz','av','avar');
INSERT INTO "languageNames" VALUES(6274,'uz','az','ozar');
INSERT INTO "languageNames" VALUES(6275,'uz','ba','boshqird');
INSERT INTO "languageNames" VALUES(6276,'uz','be','belarus');
INSERT INTO "languageNames" VALUES(6277,'uz','bg','bolgar');
INSERT INTO "languageNames" VALUES(6278,'uz','bi','bislama');
INSERT INTO "languageNames" VALUES(6279,'uz','bn','bengal');
INSERT INTO "languageNames" VALUES(6280,'uz','br','breton');
INSERT INTO "languageNames" VALUES(6281,'uz','bs','bosniy');
INSERT INTO "languageNames" VALUES(6282,'uz','ca','katalan');
INSERT INTO "languageNames" VALUES(6283,'uz','ceb','sebuan');
INSERT INTO "languageNames" VALUES(6284,'uz','chm','mari');
INSERT INTO "languageNames" VALUES(6285,'uz','ckb','sorani-kurd');
INSERT INTO "languageNames" VALUES(6286,'uz','co','korsikan');
INSERT INTO "languageNames" VALUES(6287,'uz','cs','chex');
INSERT INTO "languageNames" VALUES(6288,'uz','cu','slavyan (cherkov)');
INSERT INTO "languageNames" VALUES(6289,'uz','cv','chuvash');
INSERT INTO "languageNames" VALUES(6290,'uz','cy','valliy');
INSERT INTO "languageNames" VALUES(6291,'uz','da','dan');
INSERT INTO "languageNames" VALUES(6292,'uz','dar','dargva');
INSERT INTO "languageNames" VALUES(6293,'uz','de','nemischa');
INSERT INTO "languageNames" VALUES(6294,'uz','dsb','quyi sorbcha');
INSERT INTO "languageNames" VALUES(6295,'uz','el','grek');
INSERT INTO "languageNames" VALUES(6296,'uz','en','inglizcha');
INSERT INTO "languageNames" VALUES(6297,'uz','eo','esperanto');
INSERT INTO "languageNames" VALUES(6298,'uz','es','ispancha');
INSERT INTO "languageNames" VALUES(6299,'uz','et','estoncha');
INSERT INTO "languageNames" VALUES(6300,'uz','eu','bask');
INSERT INTO "languageNames" VALUES(6301,'uz','fa','fors');
INSERT INTO "languageNames" VALUES(6302,'uz','fi','fincha');
INSERT INTO "languageNames" VALUES(6303,'uz','fo','farercha');
INSERT INTO "languageNames" VALUES(6304,'uz','fr','fransuzcha');
INSERT INTO "languageNames" VALUES(6305,'uz','fy','g‘arbiy friz');
INSERT INTO "languageNames" VALUES(6306,'uz','ga','irland');
INSERT INTO "languageNames" VALUES(6307,'uz','gag','gagauz');
INSERT INTO "languageNames" VALUES(6308,'uz','gd','shotland-gel');
INSERT INTO "languageNames" VALUES(6309,'uz','gl','galisiy');
INSERT INTO "languageNames" VALUES(6310,'uz','gn','guarani');
INSERT INTO "languageNames" VALUES(6311,'uz','gu','gujarot');
INSERT INTO "languageNames" VALUES(6312,'uz','gv','men');
INSERT INTO "languageNames" VALUES(6313,'uz','ha','xausa');
INSERT INTO "languageNames" VALUES(6314,'uz','haw','gavaycha');
INSERT INTO "languageNames" VALUES(6315,'uz','he','ivrit');
INSERT INTO "languageNames" VALUES(6316,'uz','hi','hind');
INSERT INTO "languageNames" VALUES(6317,'uz','hr','xorvat');
INSERT INTO "languageNames" VALUES(6318,'uz','hsb','yuqori sorb');
INSERT INTO "languageNames" VALUES(6319,'uz','ht','gaityan');
INSERT INTO "languageNames" VALUES(6320,'uz','hu','venger');
INSERT INTO "languageNames" VALUES(6321,'uz','hy','arman');
INSERT INTO "languageNames" VALUES(6322,'uz','ia','interlingva');
INSERT INTO "languageNames" VALUES(6323,'uz','id','indonez');
INSERT INTO "languageNames" VALUES(6324,'uz','ig','igbo');
INSERT INTO "languageNames" VALUES(6325,'uz','is','island');
INSERT INTO "languageNames" VALUES(6326,'uz','it','italyan');
INSERT INTO "languageNames" VALUES(6327,'uz','ka','gruzincha');
INSERT INTO "languageNames" VALUES(6328,'uz','kk','qozoqcha');
INSERT INTO "languageNames" VALUES(6329,'uz','ko','koreyscha');
INSERT INTO "languageNames" VALUES(6330,'uz','krc','qorachoy-bolqor');
INSERT INTO "languageNames" VALUES(6331,'uz','krl','karel');
INSERT INTO "languageNames" VALUES(6332,'uz','ks','kashmircha');
INSERT INTO "languageNames" VALUES(6333,'uz','kum','qo‘miq');
INSERT INTO "languageNames" VALUES(6334,'uz','kv','komi');
INSERT INTO "languageNames" VALUES(6335,'uz','ky','qirgʻizcha');
INSERT INTO "languageNames" VALUES(6336,'uz','la','lotincha');
INSERT INTO "languageNames" VALUES(6337,'uz','lb','lyuksemburgcha');
INSERT INTO "languageNames" VALUES(6338,'uz','lg','ganda');
INSERT INTO "languageNames" VALUES(6339,'uz','ln','lingala');
INSERT INTO "languageNames" VALUES(6340,'uz','lo','laos');
INSERT INTO "languageNames" VALUES(6341,'uz','lt','litva');
INSERT INTO "languageNames" VALUES(6342,'uz','lv','latishcha');
INSERT INTO "languageNames" VALUES(6343,'uz','mdf','moksha');
INSERT INTO "languageNames" VALUES(6344,'uz','mfe','morisyen');
INSERT INTO "languageNames" VALUES(6345,'uz','mk','makedon');
INSERT INTO "languageNames" VALUES(6346,'uz','ml','malayalam');
INSERT INTO "languageNames" VALUES(6347,'uz','mr','maratxi');
INSERT INTO "languageNames" VALUES(6348,'uz','ms','malay');
INSERT INTO "languageNames" VALUES(6349,'uz','mt','maltiy');
INSERT INTO "languageNames" VALUES(6350,'uz','myv','erzya');
INSERT INTO "languageNames" VALUES(6351,'uz','nap','neapolitan');
INSERT INTO "languageNames" VALUES(6352,'uz','nb','norveg-bokmal');
INSERT INTO "languageNames" VALUES(6353,'uz','ne','nepal');
INSERT INTO "languageNames" VALUES(6354,'uz','nl','golland');
INSERT INTO "languageNames" VALUES(6355,'uz','nn','norveg-nyunorsk');
INSERT INTO "languageNames" VALUES(6356,'uz','nog','no‘g‘ay');
INSERT INTO "languageNames" VALUES(6357,'uz','oc','oksitan');
INSERT INTO "languageNames" VALUES(6358,'uz','os','osetin');
INSERT INTO "languageNames" VALUES(6359,'uz','pa','panjobcha');
INSERT INTO "languageNames" VALUES(6360,'uz','pl','polyakcha');
INSERT INTO "languageNames" VALUES(6361,'uz','pt','portugalcha');
INSERT INTO "languageNames" VALUES(6362,'uz','rm','romansh');
INSERT INTO "languageNames" VALUES(6363,'uz','rn','rundi');
INSERT INTO "languageNames" VALUES(6364,'uz','ro','rumincha');
INSERT INTO "languageNames" VALUES(6365,'uz','ru','ruscha');
INSERT INTO "languageNames" VALUES(6366,'uz','rup','arumin');
INSERT INTO "languageNames" VALUES(6367,'uz','sa','sanskrit');
INSERT INTO "languageNames" VALUES(6368,'uz','sah','saxa');
INSERT INTO "languageNames" VALUES(6369,'uz','sc','sardin');
INSERT INTO "languageNames" VALUES(6370,'uz','scn','sitsiliya');
INSERT INTO "languageNames" VALUES(6371,'uz','sco','shotland');
INSERT INTO "languageNames" VALUES(6372,'uz','sd','sindxi');
INSERT INTO "languageNames" VALUES(6373,'uz','se','shimoliy saam');
INSERT INTO "languageNames" VALUES(6374,'uz','si','singal');
INSERT INTO "languageNames" VALUES(6375,'uz','sk','slovakcha');
INSERT INTO "languageNames" VALUES(6376,'uz','sl','slovencha');
INSERT INTO "languageNames" VALUES(6377,'uz','sma','janubiy saam');
INSERT INTO "languageNames" VALUES(6378,'uz','smj','lule-saam');
INSERT INTO "languageNames" VALUES(6379,'uz','smn','inari-saam');
INSERT INTO "languageNames" VALUES(6380,'uz','sq','alban');
INSERT INTO "languageNames" VALUES(6381,'uz','sr','serbcha');
INSERT INTO "languageNames" VALUES(6382,'uz','srn','sranan-tongo');
INSERT INTO "languageNames" VALUES(6383,'uz','ss','svati');
INSERT INTO "languageNames" VALUES(6384,'uz','sv','shved');
INSERT INTO "languageNames" VALUES(6385,'uz','sw','suaxili');
INSERT INTO "languageNames" VALUES(6386,'uz','ta','tamil');
INSERT INTO "languageNames" VALUES(6387,'uz','te','telugu');
INSERT INTO "languageNames" VALUES(6388,'uz','tet','tetum');
INSERT INTO "languageNames" VALUES(6389,'uz','tg','tojik');
INSERT INTO "languageNames" VALUES(6390,'uz','th','tay');
INSERT INTO "languageNames" VALUES(6391,'uz','tk','turkman');
INSERT INTO "languageNames" VALUES(6392,'uz','tr','turk');
INSERT INTO "languageNames" VALUES(6393,'uz','tt','tatar');
INSERT INTO "languageNames" VALUES(6394,'uz','tyv','tuva');
INSERT INTO "languageNames" VALUES(6395,'uz','udm','udmurt');
INSERT INTO "languageNames" VALUES(6396,'uz','ug','uyg‘ur');
INSERT INTO "languageNames" VALUES(6397,'uz','uk','ukrain');
INSERT INTO "languageNames" VALUES(6398,'uz','ur','urdu');
INSERT INTO "languageNames" VALUES(6399,'uz','uz','o‘zbek');
INSERT INTO "languageNames" VALUES(6400,'uz','vi','vyetnam');
INSERT INTO "languageNames" VALUES(6401,'uz','wal','volamo');
INSERT INTO "languageNames" VALUES(6402,'uz','xh','kxosa');
INSERT INTO "languageNames" VALUES(6403,'uz','yi','idish');
INSERT INTO "languageNames" VALUES(6404,'uz','yo','yoruba');
INSERT INTO "languageNames" VALUES(6405,'uz','zh','xitoy');
INSERT INTO "languageNames" VALUES(6406,'uz','zu','zulu');
INSERT INTO "languageNames" VALUES(6407,'tg','af','африкаанс');
INSERT INTO "languageNames" VALUES(6408,'tg','ar','арабӣ');
INSERT INTO "languageNames" VALUES(6409,'tg','as','ассомӣ');
INSERT INTO "languageNames" VALUES(6410,'tg','az','озарбойҷонӣ');
INSERT INTO "languageNames" VALUES(6411,'tg','ba','бошқирдӣ');
INSERT INTO "languageNames" VALUES(6412,'tg','be','белорусӣ');
INSERT INTO "languageNames" VALUES(6413,'tg','bg','булғорӣ');
INSERT INTO "languageNames" VALUES(6414,'tg','bn','бинғолӣ');
INSERT INTO "languageNames" VALUES(6415,'tg','br','бретонӣ');
INSERT INTO "languageNames" VALUES(6416,'tg','bs','босниягӣ');
INSERT INTO "languageNames" VALUES(6417,'tg','ca','каталонӣ');
INSERT INTO "languageNames" VALUES(6418,'tg','ceb','себуано');
INSERT INTO "languageNames" VALUES(6419,'tg','chm','марӣ');
INSERT INTO "languageNames" VALUES(6420,'tg','ckb','курдии марказӣ');
INSERT INTO "languageNames" VALUES(6421,'tg','co','корсиканӣ');
INSERT INTO "languageNames" VALUES(6422,'tg','cs','чехӣ');
INSERT INTO "languageNames" VALUES(6423,'tg','cy','валлӣ');
INSERT INTO "languageNames" VALUES(6424,'tg','da','даниягӣ');
INSERT INTO "languageNames" VALUES(6425,'tg','de','немисӣ');
INSERT INTO "languageNames" VALUES(6426,'tg','dsb','сербии поёнӣ');
INSERT INTO "languageNames" VALUES(6427,'tg','el','юнонӣ');
INSERT INTO "languageNames" VALUES(6428,'tg','en','англисӣ');
INSERT INTO "languageNames" VALUES(6429,'tg','eo','эсперанто');
INSERT INTO "languageNames" VALUES(6430,'tg','es','испанӣ');
INSERT INTO "languageNames" VALUES(6431,'tg','et','эстонӣ');
INSERT INTO "languageNames" VALUES(6432,'tg','eu','баскӣ');
INSERT INTO "languageNames" VALUES(6433,'tg','fa','форсӣ');
INSERT INTO "languageNames" VALUES(6434,'tg','fi','финӣ');
INSERT INTO "languageNames" VALUES(6435,'tg','fo','фарерӣ');
INSERT INTO "languageNames" VALUES(6436,'tg','fr','франсузӣ');
INSERT INTO "languageNames" VALUES(6437,'tg','fy','фризии ғарбӣ');
INSERT INTO "languageNames" VALUES(6438,'tg','ga','ирландӣ');
INSERT INTO "languageNames" VALUES(6439,'tg','gd','шотландии гэлӣ');
INSERT INTO "languageNames" VALUES(6440,'tg','gl','галисиягӣ');
INSERT INTO "languageNames" VALUES(6441,'tg','gn','гуаранӣ');
INSERT INTO "languageNames" VALUES(6442,'tg','gu','гуҷаротӣ');
INSERT INTO "languageNames" VALUES(6443,'tg','ha','ҳауса');
INSERT INTO "languageNames" VALUES(6444,'tg','haw','ҳавайӣ');
INSERT INTO "languageNames" VALUES(6445,'tg','he','ибронӣ');
INSERT INTO "languageNames" VALUES(6446,'tg','hi','ҳиндӣ');
INSERT INTO "languageNames" VALUES(6447,'tg','hr','хорватӣ');
INSERT INTO "languageNames" VALUES(6448,'tg','hsb','сербии болоӣ');
INSERT INTO "languageNames" VALUES(6449,'tg','ht','гаитии креолӣ');
INSERT INTO "languageNames" VALUES(6450,'tg','hu','маҷорӣ');
INSERT INTO "languageNames" VALUES(6451,'tg','hy','арманӣ');
INSERT INTO "languageNames" VALUES(6452,'tg','ia','Байни забонӣ');
INSERT INTO "languageNames" VALUES(6453,'tg','id','индонезӣ');
INSERT INTO "languageNames" VALUES(6454,'tg','ig','игбо');
INSERT INTO "languageNames" VALUES(6455,'tg','is','исландӣ');
INSERT INTO "languageNames" VALUES(6456,'tg','it','италиявӣ');
INSERT INTO "languageNames" VALUES(6457,'tg','ka','гурҷӣ');
INSERT INTO "languageNames" VALUES(6458,'tg','kk','қазоқӣ');
INSERT INTO "languageNames" VALUES(6459,'tg','ko','кореягӣ');
INSERT INTO "languageNames" VALUES(6460,'tg','ks','кашмирӣ');
INSERT INTO "languageNames" VALUES(6461,'tg','ky','қирғизӣ');
INSERT INTO "languageNames" VALUES(6462,'tg','la','лотинӣ');
INSERT INTO "languageNames" VALUES(6463,'tg','lb','люксембургӣ');
INSERT INTO "languageNames" VALUES(6464,'tg','lo','лаосӣ');
INSERT INTO "languageNames" VALUES(6465,'tg','lt','литвонӣ');
INSERT INTO "languageNames" VALUES(6466,'tg','lv','латишӣ');
INSERT INTO "languageNames" VALUES(6467,'tg','mk','мақдунӣ');
INSERT INTO "languageNames" VALUES(6468,'tg','ml','малаяламӣ');
INSERT INTO "languageNames" VALUES(6469,'tg','mr','маратҳӣ');
INSERT INTO "languageNames" VALUES(6470,'tg','ms','малайӣ');
INSERT INTO "languageNames" VALUES(6471,'tg','mt','малтӣ');
INSERT INTO "languageNames" VALUES(6472,'tg','ne','непалӣ');
INSERT INTO "languageNames" VALUES(6473,'tg','nl','голландӣ');
INSERT INTO "languageNames" VALUES(6474,'tg','no','норвегӣ');
INSERT INTO "languageNames" VALUES(6475,'tg','oc','окситанӣ');
INSERT INTO "languageNames" VALUES(6476,'tg','pa','панҷобӣ');
INSERT INTO "languageNames" VALUES(6477,'tg','pl','лаҳистонӣ');
INSERT INTO "languageNames" VALUES(6478,'tg','pt','португалӣ');
INSERT INTO "languageNames" VALUES(6479,'tg','rm','ретороманӣ');
INSERT INTO "languageNames" VALUES(6480,'tg','ro','руминӣ');
INSERT INTO "languageNames" VALUES(6481,'tg','ru','русӣ');
INSERT INTO "languageNames" VALUES(6482,'tg','sa','санскрит');
INSERT INTO "languageNames" VALUES(6483,'tg','sah','саха');
INSERT INTO "languageNames" VALUES(6484,'tg','sd','синдӣ');
INSERT INTO "languageNames" VALUES(6485,'tg','se','самии шимолӣ');
INSERT INTO "languageNames" VALUES(6486,'tg','si','сингалӣ');
INSERT INTO "languageNames" VALUES(6487,'tg','sk','словакӣ');
INSERT INTO "languageNames" VALUES(6488,'tg','sl','словенӣ');
INSERT INTO "languageNames" VALUES(6489,'tg','sma','самии ҷанубӣ');
INSERT INTO "languageNames" VALUES(6490,'tg','smj','луле самӣ');
INSERT INTO "languageNames" VALUES(6491,'tg','smn','инари самӣ');
INSERT INTO "languageNames" VALUES(6492,'tg','sq','албанӣ');
INSERT INTO "languageNames" VALUES(6493,'tg','sr','сербӣ');
INSERT INTO "languageNames" VALUES(6494,'tg','sv','шведӣ');
INSERT INTO "languageNames" VALUES(6495,'tg','ta','тамилӣ');
INSERT INTO "languageNames" VALUES(6496,'tg','te','телугу');
INSERT INTO "languageNames" VALUES(6497,'tg','tg','тоҷикӣ');
INSERT INTO "languageNames" VALUES(6498,'tg','th','тайӣ');
INSERT INTO "languageNames" VALUES(6499,'tg','tk','туркманӣ');
INSERT INTO "languageNames" VALUES(6500,'tg','tr','туркӣ');
INSERT INTO "languageNames" VALUES(6501,'tg','tt','тоторӣ');
INSERT INTO "languageNames" VALUES(6502,'tg','ug','ӯйғурӣ');
INSERT INTO "languageNames" VALUES(6503,'tg','uk','украинӣ');
INSERT INTO "languageNames" VALUES(6504,'tg','ur','урду');
INSERT INTO "languageNames" VALUES(6505,'tg','uz','ӯзбекӣ');
INSERT INTO "languageNames" VALUES(6506,'tg','vi','ветнамӣ');
INSERT INTO "languageNames" VALUES(6507,'tg','yi','идиш');
INSERT INTO "languageNames" VALUES(6508,'tg','yo','йоруба');
INSERT INTO "languageNames" VALUES(6509,'tg','zh','хитоӣ');
INSERT INTO "languageNames" VALUES(6510,'tg','zu','Зулу');
INSERT INTO "languageNames" VALUES(6511,'kk','af','африкаанс тілі');
INSERT INTO "languageNames" VALUES(6512,'kk','alt','оңтүстік алтай тілі');
INSERT INTO "languageNames" VALUES(6513,'kk','an','арагон тілі');
INSERT INTO "languageNames" VALUES(6514,'kk','ar','араб тілі');
INSERT INTO "languageNames" VALUES(6515,'kk','as','ассам тілі');
INSERT INTO "languageNames" VALUES(6516,'kk','ast','астурия тілі');
INSERT INTO "languageNames" VALUES(6517,'kk','av','авар тілі');
INSERT INTO "languageNames" VALUES(6519,'kk','az','әзірбайжан тілі');
INSERT INTO "languageNames" VALUES(6520,'kk','ba','башқұрт тілі');
INSERT INTO "languageNames" VALUES(6521,'kk','be','беларусь тілі');
INSERT INTO "languageNames" VALUES(6522,'kk','bg','болгар тілі');
INSERT INTO "languageNames" VALUES(6523,'kk','bi','бислама тілі');
INSERT INTO "languageNames" VALUES(6524,'kk','bn','бенгал тілі');
INSERT INTO "languageNames" VALUES(6525,'kk','br','бретон тілі');
INSERT INTO "languageNames" VALUES(6526,'kk','bs','босния тілі');
INSERT INTO "languageNames" VALUES(6527,'kk','ca','каталан тілі');
INSERT INTO "languageNames" VALUES(6528,'kk','ceb','себуано тілі');
INSERT INTO "languageNames" VALUES(6529,'kk','chm','мари тілі');
INSERT INTO "languageNames" VALUES(6530,'kk','ckb','сорани тілі');
INSERT INTO "languageNames" VALUES(6531,'kk','co','корсика тілі');
INSERT INTO "languageNames" VALUES(6532,'kk','cs','чех тілі');
INSERT INTO "languageNames" VALUES(6533,'kk','cu','шіркеулік славян тілі');
INSERT INTO "languageNames" VALUES(6534,'kk','cv','чуваш тілі');
INSERT INTO "languageNames" VALUES(6535,'kk','cy','валлий тілі');
INSERT INTO "languageNames" VALUES(6536,'kk','da','дат тілі');
INSERT INTO "languageNames" VALUES(6537,'kk','dar','даргин тілі');
INSERT INTO "languageNames" VALUES(6538,'kk','de','неміс тілі');
INSERT INTO "languageNames" VALUES(6539,'kk','dsb','төменгі лужица тілі');
INSERT INTO "languageNames" VALUES(6540,'kk','el','грек тілі');
INSERT INTO "languageNames" VALUES(6541,'kk','en','ағылшын тілі');
INSERT INTO "languageNames" VALUES(6542,'kk','eo','эсперанто тілі');
INSERT INTO "languageNames" VALUES(6543,'kk','es','испан тілі');
INSERT INTO "languageNames" VALUES(6544,'kk','et','эстон тілі');
INSERT INTO "languageNames" VALUES(6545,'kk','eu','баск тілі');
INSERT INTO "languageNames" VALUES(6546,'kk','fa','парсы тілі');
INSERT INTO "languageNames" VALUES(6547,'kk','fi','фин тілі');
INSERT INTO "languageNames" VALUES(6548,'kk','fo','фарер тілі');
INSERT INTO "languageNames" VALUES(6549,'kk','fr','француз тілі');
INSERT INTO "languageNames" VALUES(6550,'kk','fy','батыс фриз тілі');
INSERT INTO "languageNames" VALUES(6551,'kk','ga','ирланд тілі');
INSERT INTO "languageNames" VALUES(6552,'kk','gag','гагауз тілі');
INSERT INTO "languageNames" VALUES(6553,'kk','gd','шотландиялық гэль тілі');
INSERT INTO "languageNames" VALUES(6554,'kk','gl','галисия тілі');
INSERT INTO "languageNames" VALUES(6555,'kk','gn','гуарани тілі');
INSERT INTO "languageNames" VALUES(6556,'kk','gu','гуджарати тілі');
INSERT INTO "languageNames" VALUES(6557,'kk','gv','мэн тілі');
INSERT INTO "languageNames" VALUES(6558,'kk','ha','хауса тілі');
INSERT INTO "languageNames" VALUES(6559,'kk','haw','гавайи тілі');
INSERT INTO "languageNames" VALUES(6560,'kk','he','иврит тілі');
INSERT INTO "languageNames" VALUES(6561,'kk','hi','хинди тілі');
INSERT INTO "languageNames" VALUES(6562,'kk','hr','хорват тілі');
INSERT INTO "languageNames" VALUES(6563,'kk','hsb','жоғарғы лужица тілі');
INSERT INTO "languageNames" VALUES(6564,'kk','ht','гаити тілі');
INSERT INTO "languageNames" VALUES(6565,'kk','hu','венгр тілі');
INSERT INTO "languageNames" VALUES(6566,'kk','hy','армян тілі');
INSERT INTO "languageNames" VALUES(6567,'kk','ia','интерлингва тілі');
INSERT INTO "languageNames" VALUES(6568,'kk','id','индонезия тілі');
INSERT INTO "languageNames" VALUES(6569,'kk','ig','игбо тілі');
INSERT INTO "languageNames" VALUES(6570,'kk','is','исланд тілі');
INSERT INTO "languageNames" VALUES(6571,'kk','it','итальян тілі');
INSERT INTO "languageNames" VALUES(6572,'kk','ka','грузин тілі');
INSERT INTO "languageNames" VALUES(6573,'kk','kk','қазақ тілі');
INSERT INTO "languageNames" VALUES(6574,'kk','ko','корей тілі');
INSERT INTO "languageNames" VALUES(6575,'kk','krc','қарашай-балқар тілі');
INSERT INTO "languageNames" VALUES(6576,'kk','krl','карель тілі');
INSERT INTO "languageNames" VALUES(6577,'kk','ks','кашмир тілі');
INSERT INTO "languageNames" VALUES(6578,'kk','kum','құмық тілі');
INSERT INTO "languageNames" VALUES(6579,'kk','kv','коми тілі');
INSERT INTO "languageNames" VALUES(6580,'kk','ky','қырғыз тілі');
INSERT INTO "languageNames" VALUES(6581,'kk','la','латын тілі');
INSERT INTO "languageNames" VALUES(6582,'kk','lb','люксембург тілі');
INSERT INTO "languageNames" VALUES(6583,'kk','lg','ганда тілі');
INSERT INTO "languageNames" VALUES(6584,'kk','ln','лингала тілі');
INSERT INTO "languageNames" VALUES(6585,'kk','lo','лаос тілі');
INSERT INTO "languageNames" VALUES(6586,'kk','lt','литва тілі');
INSERT INTO "languageNames" VALUES(6587,'kk','lv','латыш тілі');
INSERT INTO "languageNames" VALUES(6588,'kk','mdf','мокша тілі');
INSERT INTO "languageNames" VALUES(6589,'kk','mfe','морисиен тілі');
INSERT INTO "languageNames" VALUES(6590,'kk','mk','македон тілі');
INSERT INTO "languageNames" VALUES(6591,'kk','ml','малаялам тілі');
INSERT INTO "languageNames" VALUES(6592,'kk','mr','маратхи тілі');
INSERT INTO "languageNames" VALUES(6593,'kk','ms','малай тілі');
INSERT INTO "languageNames" VALUES(6594,'kk','mt','мальта тілі');
INSERT INTO "languageNames" VALUES(6595,'kk','myv','эрзян тілі');
INSERT INTO "languageNames" VALUES(6596,'kk','nap','неаполитан тілі');
INSERT INTO "languageNames" VALUES(6597,'kk','nb','норвегиялық букмол тілі');
INSERT INTO "languageNames" VALUES(6598,'kk','ne','непал тілі');
INSERT INTO "languageNames" VALUES(6599,'kk','nl','нидерланд тілі');
INSERT INTO "languageNames" VALUES(6600,'kk','nn','норвегиялық нюнорск тілі');
INSERT INTO "languageNames" VALUES(6601,'kk','no','норвег тілі');
INSERT INTO "languageNames" VALUES(6602,'kk','nog','ноғай тілі');
INSERT INTO "languageNames" VALUES(6603,'kk','oc','окситан тілі');
INSERT INTO "languageNames" VALUES(6604,'kk','os','осетин тілі');
INSERT INTO "languageNames" VALUES(6605,'kk','pa','пенджаб тілі');
INSERT INTO "languageNames" VALUES(6606,'kk','pl','поляк тілі');
INSERT INTO "languageNames" VALUES(6607,'kk','pt','португал тілі');
INSERT INTO "languageNames" VALUES(6608,'kk','rm','романш тілі');
INSERT INTO "languageNames" VALUES(6609,'kk','rn','рунди тілі');
INSERT INTO "languageNames" VALUES(6610,'kk','ro','румын тілі');
INSERT INTO "languageNames" VALUES(6611,'kk','ru','орыс тілі');
INSERT INTO "languageNames" VALUES(6612,'kk','rup','арумын тілі');
INSERT INTO "languageNames" VALUES(6613,'kk','sa','санскрит тілі');
INSERT INTO "languageNames" VALUES(6614,'kk','sah','якут тілі');
INSERT INTO "languageNames" VALUES(6615,'kk','sc','сардин тілі');
INSERT INTO "languageNames" VALUES(6616,'kk','scn','сицилия тілі');
INSERT INTO "languageNames" VALUES(6617,'kk','sco','шотланд тілі');
INSERT INTO "languageNames" VALUES(6618,'kk','sd','синдхи тілі');
INSERT INTO "languageNames" VALUES(6619,'kk','se','солтүстік саам тілі');
INSERT INTO "languageNames" VALUES(6620,'kk','sh','серб-хорват тілі');
INSERT INTO "languageNames" VALUES(6621,'kk','si','сингал тілі');
INSERT INTO "languageNames" VALUES(6622,'kk','sk','словак тілі');
INSERT INTO "languageNames" VALUES(6623,'kk','sl','словен тілі');
INSERT INTO "languageNames" VALUES(6624,'kk','sma','оңтүстік саам тілі');
INSERT INTO "languageNames" VALUES(6625,'kk','smj','луле саам тілі');
INSERT INTO "languageNames" VALUES(6626,'kk','smn','инари саам тілі');
INSERT INTO "languageNames" VALUES(6627,'kk','sq','албан тілі');
INSERT INTO "languageNames" VALUES(6628,'kk','sr','серб тілі');
INSERT INTO "languageNames" VALUES(6629,'kk','srn','сранан тонго тілі');
INSERT INTO "languageNames" VALUES(6630,'kk','ss','свати тілі');
INSERT INTO "languageNames" VALUES(6631,'kk','sv','швед тілі');
INSERT INTO "languageNames" VALUES(6632,'kk','sw','суахили тілі');
INSERT INTO "languageNames" VALUES(6633,'kk','ta','тамил тілі');
INSERT INTO "languageNames" VALUES(6634,'kk','te','телугу тілі');
INSERT INTO "languageNames" VALUES(6635,'kk','tet','тетум тілі');
INSERT INTO "languageNames" VALUES(6636,'kk','tg','тәжік тілі');
INSERT INTO "languageNames" VALUES(6637,'kk','th','тай тілі');
INSERT INTO "languageNames" VALUES(6638,'kk','tk','түрікмен тілі');
INSERT INTO "languageNames" VALUES(6639,'kk','tr','түрік тілі');
INSERT INTO "languageNames" VALUES(6640,'kk','tt','татар тілі');
INSERT INTO "languageNames" VALUES(6641,'kk','tyv','тувин тілі');
INSERT INTO "languageNames" VALUES(6642,'kk','udm','удмурт тілі');
INSERT INTO "languageNames" VALUES(6643,'kk','ug','ұйғыр тілі');
INSERT INTO "languageNames" VALUES(6644,'kk','uk','украин тілі');
INSERT INTO "languageNames" VALUES(6645,'kk','ur','урду тілі');
INSERT INTO "languageNames" VALUES(6646,'kk','uz','өзбек тілі');
INSERT INTO "languageNames" VALUES(6647,'kk','vi','вьетнам тілі');
INSERT INTO "languageNames" VALUES(6648,'kk','wal','волайта тілі');
INSERT INTO "languageNames" VALUES(6649,'kk','xh','кхоса тілі');
INSERT INTO "languageNames" VALUES(6650,'kk','yi','идиш тілі');
INSERT INTO "languageNames" VALUES(6651,'kk','yo','йоруба тілі');
INSERT INTO "languageNames" VALUES(6652,'kk','zh','қытай тілі');
INSERT INTO "languageNames" VALUES(6653,'kk','zu','зулу тілі');
INSERT INTO "languageNames" VALUES(6654,'lb','af','Afrikaans');
INSERT INTO "languageNames" VALUES(6655,'lb','alt','Süd-Alaesch');
INSERT INTO "languageNames" VALUES(6656,'lb','an','Aragonesesch');
INSERT INTO "languageNames" VALUES(6657,'lb','ar','Arabesch');
INSERT INTO "languageNames" VALUES(6658,'lb','as','Assamesesch');
INSERT INTO "languageNames" VALUES(6659,'lb','ast','Asturianesch');
INSERT INTO "languageNames" VALUES(6660,'lb','av','Awaresch');
INSERT INTO "languageNames" VALUES(6661,'lb','az','Aserbaidschanesch');
INSERT INTO "languageNames" VALUES(6662,'lb','ba','Baschkiresch');
INSERT INTO "languageNames" VALUES(6663,'lb','be','Wäissrussesch');
INSERT INTO "languageNames" VALUES(6664,'lb','bg','Bulgaresch');
INSERT INTO "languageNames" VALUES(6665,'lb','bi','Bislama');
INSERT INTO "languageNames" VALUES(6666,'lb','bn','Bengalesch');
INSERT INTO "languageNames" VALUES(6667,'lb','br','Bretonesch');
INSERT INTO "languageNames" VALUES(6668,'lb','bs','Bosnesch');
INSERT INTO "languageNames" VALUES(6669,'lb','bua','Burjatesch');
INSERT INTO "languageNames" VALUES(6670,'lb','byv','Medumba');
INSERT INTO "languageNames" VALUES(6671,'lb','ca','Katalanesch');
INSERT INTO "languageNames" VALUES(6672,'lb','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(6673,'lb','chm','Mari');
INSERT INTO "languageNames" VALUES(6674,'lb','ckb','Sorani');
INSERT INTO "languageNames" VALUES(6675,'lb','co','Korsesch');
INSERT INTO "languageNames" VALUES(6676,'lb','crh','Krimtataresch');
INSERT INTO "languageNames" VALUES(6677,'lb','cs','Tschechesch');
INSERT INTO "languageNames" VALUES(6678,'lb','csb','Kaschubesch');
INSERT INTO "languageNames" VALUES(6679,'lb','cu','Kiercheslawesch');
INSERT INTO "languageNames" VALUES(6680,'lb','cv','Tschuwaschesch');
INSERT INTO "languageNames" VALUES(6681,'lb','cy','Walisesch');
INSERT INTO "languageNames" VALUES(6682,'lb','da','Dänesch');
INSERT INTO "languageNames" VALUES(6683,'lb','dar','Darginesch');
INSERT INTO "languageNames" VALUES(6684,'lb','de','Däitsch');
INSERT INTO "languageNames" VALUES(6685,'lb','dsb','Niddersorbesch');
INSERT INTO "languageNames" VALUES(6686,'lb','el','Griichesch');
INSERT INTO "languageNames" VALUES(6687,'lb','en','Englesch');
INSERT INTO "languageNames" VALUES(6688,'lb','eo','Esperanto');
INSERT INTO "languageNames" VALUES(6689,'lb','es','Spuenesch');
INSERT INTO "languageNames" VALUES(6690,'lb','et','Estnesch');
INSERT INTO "languageNames" VALUES(6691,'lb','eu','Baskesch');
INSERT INTO "languageNames" VALUES(6692,'lb','fa','Persesch');
INSERT INTO "languageNames" VALUES(6693,'lb','fi','Finnesch');
INSERT INTO "languageNames" VALUES(6694,'lb','fo','Färöesch');
INSERT INTO "languageNames" VALUES(6695,'lb','fr','Franséisch');
INSERT INTO "languageNames" VALUES(6696,'lb','fy','Westfriesesch');
INSERT INTO "languageNames" VALUES(6697,'lb','ga','Iresch');
INSERT INTO "languageNames" VALUES(6698,'lb','gag','Gagausesch');
INSERT INTO "languageNames" VALUES(6699,'lb','gd','Schottescht Gällesch');
INSERT INTO "languageNames" VALUES(6700,'lb','gl','Galizesch');
INSERT INTO "languageNames" VALUES(6701,'lb','glk','Gilaki');
INSERT INTO "languageNames" VALUES(6702,'lb','gn','Guarani');
INSERT INTO "languageNames" VALUES(6703,'lb','gu','Gujarati');
INSERT INTO "languageNames" VALUES(6704,'lb','guc','Wayuu');
INSERT INTO "languageNames" VALUES(6705,'lb','gv','Manx');
INSERT INTO "languageNames" VALUES(6706,'lb','ha','Hausa');
INSERT INTO "languageNames" VALUES(6707,'lb','haw','Hawaiesch');
INSERT INTO "languageNames" VALUES(6708,'lb','he','Hebräesch');
INSERT INTO "languageNames" VALUES(6709,'lb','hi','Hindi');
INSERT INTO "languageNames" VALUES(6710,'lb','hr','Kroatesch');
INSERT INTO "languageNames" VALUES(6711,'lb','hsb','Uewersorbesch');
INSERT INTO "languageNames" VALUES(6712,'lb','ht','Haitianesch');
INSERT INTO "languageNames" VALUES(6713,'lb','hu','Ungaresch');
INSERT INTO "languageNames" VALUES(6714,'lb','hy','Armenesch');
INSERT INTO "languageNames" VALUES(6715,'lb','ia','Interlingua');
INSERT INTO "languageNames" VALUES(6716,'lb','id','Indonesesch');
INSERT INTO "languageNames" VALUES(6717,'lb','ig','Igbo-Sprooch');
INSERT INTO "languageNames" VALUES(6718,'lb','is','Islännesch');
INSERT INTO "languageNames" VALUES(6719,'lb','it','Italienesch');
INSERT INTO "languageNames" VALUES(6720,'lb','ka','Georgesch');
INSERT INTO "languageNames" VALUES(6721,'lb','kaa','Karakalpakesch');
INSERT INTO "languageNames" VALUES(6722,'lb','kk','Kasachesch');
INSERT INTO "languageNames" VALUES(6723,'lb','ko','Koreanesch');
INSERT INTO "languageNames" VALUES(6724,'lb','krc','Karatschaiesch-Balkaresch');
INSERT INTO "languageNames" VALUES(6725,'lb','krl','Karelesch');
INSERT INTO "languageNames" VALUES(6726,'lb','ks','Kaschmiresch');
INSERT INTO "languageNames" VALUES(6727,'lb','kum','Kumükesch');
INSERT INTO "languageNames" VALUES(6728,'lb','kv','Komi-Sprooch');
INSERT INTO "languageNames" VALUES(6729,'lb','ky','Kirgisesch');
INSERT INTO "languageNames" VALUES(6730,'lb','la','Latäin');
INSERT INTO "languageNames" VALUES(6731,'lb','lb','Lëtzebuergesch');
INSERT INTO "languageNames" VALUES(6732,'lb','lg','Ganda-Sprooch');
INSERT INTO "languageNames" VALUES(6733,'lb','liv','Livesch');
INSERT INTO "languageNames" VALUES(6734,'lb','ln','Lingala');
INSERT INTO "languageNames" VALUES(6735,'lb','lo','Laotesch');
INSERT INTO "languageNames" VALUES(6736,'lb','lt','Litauesch');
INSERT INTO "languageNames" VALUES(6737,'lb','lv','Lettesch');
INSERT INTO "languageNames" VALUES(6738,'lb','mdf','Moksha');
INSERT INTO "languageNames" VALUES(6739,'lb','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(6740,'lb','mk','Mazedonesch');
INSERT INTO "languageNames" VALUES(6741,'lb','ml','Malayalam');
INSERT INTO "languageNames" VALUES(6742,'lb','mr','Marathi');
INSERT INTO "languageNames" VALUES(6743,'lb','mrj','West-Mari');
INSERT INTO "languageNames" VALUES(6744,'lb','ms','Malaiesch');
INSERT INTO "languageNames" VALUES(6745,'lb','mt','Maltesesch');
INSERT INTO "languageNames" VALUES(6746,'lb','myv','Ersja-Mordwinesch');
INSERT INTO "languageNames" VALUES(6747,'lb','nap','Neapolitanesch');
INSERT INTO "languageNames" VALUES(6748,'lb','nb','Norwegesch Bokmål');
INSERT INTO "languageNames" VALUES(6749,'lb','ne','Nepalesesch');
INSERT INTO "languageNames" VALUES(6750,'lb','nl','Hollännesch');
INSERT INTO "languageNames" VALUES(6751,'lb','nn','Norwegesch Nynorsk');
INSERT INTO "languageNames" VALUES(6752,'lb','no','Norwegesch');
INSERT INTO "languageNames" VALUES(6753,'lb','nog','Nogai');
INSERT INTO "languageNames" VALUES(6754,'lb','oc','Okzitanesch');
INSERT INTO "languageNames" VALUES(6755,'lb','os','Ossetesch');
INSERT INTO "languageNames" VALUES(6756,'lb','ota','Osmanesch');
INSERT INTO "languageNames" VALUES(6757,'lb','pa','Pandschabesch');
INSERT INTO "languageNames" VALUES(6758,'lb','pl','Polnesch');
INSERT INTO "languageNames" VALUES(6759,'lb','pt','Portugisesch');
INSERT INTO "languageNames" VALUES(6760,'lb','rm','Rätoromanesch');
INSERT INTO "languageNames" VALUES(6761,'lb','rn','Rundi-Sprooch');
INSERT INTO "languageNames" VALUES(6762,'lb','ro','Rumänesch');
INSERT INTO "languageNames" VALUES(6763,'lb','ru','Russesch');
INSERT INTO "languageNames" VALUES(6764,'lb','rup','Aromunesch');
INSERT INTO "languageNames" VALUES(6765,'lb','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(6766,'lb','sah','Jakutesch');
INSERT INTO "languageNames" VALUES(6767,'lb','sc','Sardesch');
INSERT INTO "languageNames" VALUES(6768,'lb','scn','Sizilianesch');
INSERT INTO "languageNames" VALUES(6769,'lb','sco','Schottesch');
INSERT INTO "languageNames" VALUES(6770,'lb','sd','Sindhi');
INSERT INTO "languageNames" VALUES(6771,'lb','se','Nordsamesch');
INSERT INTO "languageNames" VALUES(6772,'lb','sh','Serbo-Kroatesch');
INSERT INTO "languageNames" VALUES(6773,'lb','si','Singhalesesch');
INSERT INTO "languageNames" VALUES(6774,'lb','sk','Slowakesch');
INSERT INTO "languageNames" VALUES(6775,'lb','sl','Slowenesch');
INSERT INTO "languageNames" VALUES(6776,'lb','sma','Südsamesch');
INSERT INTO "languageNames" VALUES(6777,'lb','smj','Lule-Lappesch');
INSERT INTO "languageNames" VALUES(6778,'lb','smn','Inari-Lappesch');
INSERT INTO "languageNames" VALUES(6779,'lb','sq','Albanesch');
INSERT INTO "languageNames" VALUES(6780,'lb','sr','Serbesch');
INSERT INTO "languageNames" VALUES(6781,'lb','srn','Srananesch');
INSERT INTO "languageNames" VALUES(6782,'lb','ss','Swazi');
INSERT INTO "languageNames" VALUES(6783,'lb','sv','Schwedesch');
INSERT INTO "languageNames" VALUES(6784,'lb','sw','Suaheli');
INSERT INTO "languageNames" VALUES(6785,'lb','ta','Tamilesch');
INSERT INTO "languageNames" VALUES(6786,'lb','te','Telugu');
INSERT INTO "languageNames" VALUES(6787,'lb','tet','Tetum-Sprooch');
INSERT INTO "languageNames" VALUES(6788,'lb','tg','Tadschikesch');
INSERT INTO "languageNames" VALUES(6789,'lb','th','Thailännesch');
INSERT INTO "languageNames" VALUES(6790,'lb','tk','Turkmenesch');
INSERT INTO "languageNames" VALUES(6791,'lb','tl','Dagalog');
INSERT INTO "languageNames" VALUES(6792,'lb','tr','Tierkesch');
INSERT INTO "languageNames" VALUES(6793,'lb','tt','Tataresch');
INSERT INTO "languageNames" VALUES(6794,'lb','tyv','Tuwinesch');
INSERT INTO "languageNames" VALUES(6795,'lb','udm','Udmurtesch');
INSERT INTO "languageNames" VALUES(6796,'lb','ug','Uiguresch');
INSERT INTO "languageNames" VALUES(6797,'lb','uk','Ukrainesch');
INSERT INTO "languageNames" VALUES(6798,'lb','ur','Urdu');
INSERT INTO "languageNames" VALUES(6799,'lb','uz','Usbekesch');
INSERT INTO "languageNames" VALUES(6800,'lb','vi','Vietnamesesch');
INSERT INTO "languageNames" VALUES(6801,'lb','vro','Voro');
INSERT INTO "languageNames" VALUES(6802,'lb','wal','Walamo-Sprooch');
INSERT INTO "languageNames" VALUES(6803,'lb','xh','Xhosa');
INSERT INTO "languageNames" VALUES(6804,'lb','yi','Jiddesch');
INSERT INTO "languageNames" VALUES(6805,'lb','yo','Yoruba');
INSERT INTO "languageNames" VALUES(6806,'lb','zh','Chinesesch');
INSERT INTO "languageNames" VALUES(6807,'lb','zu','Zulu');
INSERT INTO "languageNames" VALUES(6808,'gu','af','આફ્રિકન્સ');
INSERT INTO "languageNames" VALUES(6809,'gu','alt','દક્ષિણ અલ્તાઇ');
INSERT INTO "languageNames" VALUES(6810,'gu','an','અર્ગોનીઝ');
INSERT INTO "languageNames" VALUES(6811,'gu','ar','અરબી');
INSERT INTO "languageNames" VALUES(6812,'gu','as','આસામી');
INSERT INTO "languageNames" VALUES(6813,'gu','ast','અસ્તુરિયન');
INSERT INTO "languageNames" VALUES(6814,'gu','av','અવેરિક');
INSERT INTO "languageNames" VALUES(6816,'gu','az','અઝેરી');
INSERT INTO "languageNames" VALUES(6817,'gu','ba','બશ્કીર');
INSERT INTO "languageNames" VALUES(6818,'gu','be','બેલારુશિયન');
INSERT INTO "languageNames" VALUES(6819,'gu','bg','બલ્ગેરિયન');
INSERT INTO "languageNames" VALUES(6820,'gu','bi','બિસ્લામા');
INSERT INTO "languageNames" VALUES(6821,'gu','bn','બાંગ્લા');
INSERT INTO "languageNames" VALUES(6822,'gu','br','બ્રેટોન');
INSERT INTO "languageNames" VALUES(6823,'gu','bs','બોસ્નિયન');
INSERT INTO "languageNames" VALUES(6824,'gu','bua','બુરિયાત');
INSERT INTO "languageNames" VALUES(6825,'gu','ca','કતલાન');
INSERT INTO "languageNames" VALUES(6826,'gu','ceb','સિબુઆનો');
INSERT INTO "languageNames" VALUES(6827,'gu','chm','મારી');
INSERT INTO "languageNames" VALUES(6828,'gu','ckb','સેન્ટ્રલ કુર્દિશ');
INSERT INTO "languageNames" VALUES(6829,'gu','co','કોર્સિકન');
INSERT INTO "languageNames" VALUES(6830,'gu','crh','ક્રિમિયન તુર્કી');
INSERT INTO "languageNames" VALUES(6831,'gu','cs','ચેક');
INSERT INTO "languageNames" VALUES(6832,'gu','csb','કાશુબિયન');
INSERT INTO "languageNames" VALUES(6833,'gu','cu','ચર્ચ સ્લાવિક');
INSERT INTO "languageNames" VALUES(6834,'gu','cv','ચૂવાશ');
INSERT INTO "languageNames" VALUES(6835,'gu','cy','વેલ્શ');
INSERT INTO "languageNames" VALUES(6836,'gu','da','ડેનિશ');
INSERT INTO "languageNames" VALUES(6837,'gu','dar','દાર્ગવા');
INSERT INTO "languageNames" VALUES(6838,'gu','de','જર્મન');
INSERT INTO "languageNames" VALUES(6839,'gu','dsb','લોઅર સોર્બિયન');
INSERT INTO "languageNames" VALUES(6840,'gu','el','ગ્રીક');
INSERT INTO "languageNames" VALUES(6841,'gu','en','અંગ્રેજી');
INSERT INTO "languageNames" VALUES(6842,'gu','eo','એસ્પેરાન્ટો');
INSERT INTO "languageNames" VALUES(6843,'gu','es','સ્પેનિશ');
INSERT INTO "languageNames" VALUES(6844,'gu','et','એસ્ટોનિયન');
INSERT INTO "languageNames" VALUES(6845,'gu','eu','બાસ્ક');
INSERT INTO "languageNames" VALUES(6846,'gu','fa','ફારસી');
INSERT INTO "languageNames" VALUES(6847,'gu','fi','ફિનિશ');
INSERT INTO "languageNames" VALUES(6848,'gu','fo','ફોરિસ્ત');
INSERT INTO "languageNames" VALUES(6849,'gu','fr','ફ્રેન્ચ');
INSERT INTO "languageNames" VALUES(6850,'gu','fy','પશ્ચિમી ફ્રિસિયન');
INSERT INTO "languageNames" VALUES(6851,'gu','ga','આઇરિશ');
INSERT INTO "languageNames" VALUES(6852,'gu','gag','ગાગાઝ');
INSERT INTO "languageNames" VALUES(6853,'gu','gd','સ્કોટીસ ગેલિક');
INSERT INTO "languageNames" VALUES(6854,'gu','gl','ગેલિશિયન');
INSERT INTO "languageNames" VALUES(6855,'gu','gn','ગુઆરાની');
INSERT INTO "languageNames" VALUES(6856,'gu','gu','ગુજરાતી');
INSERT INTO "languageNames" VALUES(6857,'gu','gv','માંક્સ');
INSERT INTO "languageNames" VALUES(6858,'gu','ha','હૌસા');
INSERT INTO "languageNames" VALUES(6859,'gu','haw','હવાઇયન');
INSERT INTO "languageNames" VALUES(6860,'gu','he','હીબ્રુ');
INSERT INTO "languageNames" VALUES(6861,'gu','hi','હિન્દી');
INSERT INTO "languageNames" VALUES(6862,'gu','hr','ક્રોએશિયન');
INSERT INTO "languageNames" VALUES(6863,'gu','hsb','અપર સોર્બિયન');
INSERT INTO "languageNames" VALUES(6864,'gu','ht','હૈતિઅન ક્રેઓલે');
INSERT INTO "languageNames" VALUES(6865,'gu','hu','હંગેરિયન');
INSERT INTO "languageNames" VALUES(6866,'gu','hy','આર્મેનિયન');
INSERT INTO "languageNames" VALUES(6867,'gu','ia','ઇંટરલિંગુઆ');
INSERT INTO "languageNames" VALUES(6868,'gu','id','ઇન્ડોનેશિયન');
INSERT INTO "languageNames" VALUES(6869,'gu','ig','ઇગ્બો');
INSERT INTO "languageNames" VALUES(6870,'gu','is','આઇસલેન્ડિક');
INSERT INTO "languageNames" VALUES(6871,'gu','it','ઇટાલિયન');
INSERT INTO "languageNames" VALUES(6872,'gu','ka','જ્યોર્જિયન');
INSERT INTO "languageNames" VALUES(6873,'gu','kaa','કારા-કલ્પક');
INSERT INTO "languageNames" VALUES(6874,'gu','kk','કઝાખ');
INSERT INTO "languageNames" VALUES(6875,'gu','ko','કોરિયન');
INSERT INTO "languageNames" VALUES(6876,'gu','krc','કરાચય-બલ્કાર');
INSERT INTO "languageNames" VALUES(6877,'gu','krl','કરેલિયન');
INSERT INTO "languageNames" VALUES(6878,'gu','ks','કાશ્મીરી');
INSERT INTO "languageNames" VALUES(6879,'gu','kum','કુમીક');
INSERT INTO "languageNames" VALUES(6880,'gu','kv','કોમી');
INSERT INTO "languageNames" VALUES(6881,'gu','ky','કિર્ગીઝ');
INSERT INTO "languageNames" VALUES(6882,'gu','la','લેટિન');
INSERT INTO "languageNames" VALUES(6883,'gu','lb','લક્ઝેમબર્ગિશ');
INSERT INTO "languageNames" VALUES(6884,'gu','lg','ગાંડા');
INSERT INTO "languageNames" VALUES(6885,'gu','ln','લિંગાલા');
INSERT INTO "languageNames" VALUES(6886,'gu','lo','લાઓ');
INSERT INTO "languageNames" VALUES(6887,'gu','lt','લિથુઆનિયન');
INSERT INTO "languageNames" VALUES(6888,'gu','lv','લાતવિયન');
INSERT INTO "languageNames" VALUES(6889,'gu','mdf','મોક્ષ');
INSERT INTO "languageNames" VALUES(6890,'gu','mfe','મોરીસ્યેન');
INSERT INTO "languageNames" VALUES(6891,'gu','mk','મેસેડોનિયન');
INSERT INTO "languageNames" VALUES(6892,'gu','ml','મલયાલમ');
INSERT INTO "languageNames" VALUES(6893,'gu','mr','મરાઠી');
INSERT INTO "languageNames" VALUES(6894,'gu','mrj','પશ્ચિમી મારી');
INSERT INTO "languageNames" VALUES(6895,'gu','ms','મલય');
INSERT INTO "languageNames" VALUES(6896,'gu','mt','માલ્ટિઝ');
INSERT INTO "languageNames" VALUES(6897,'gu','myv','એર્ઝયા');
INSERT INTO "languageNames" VALUES(6898,'gu','nap','નેપોલિટાન');
INSERT INTO "languageNames" VALUES(6899,'gu','nb','નોર્વેજિયન બોકમાલ');
INSERT INTO "languageNames" VALUES(6900,'gu','ne','નેપાળી');
INSERT INTO "languageNames" VALUES(6901,'gu','nl','ડચ');
INSERT INTO "languageNames" VALUES(6902,'gu','nn','નોર્વેજિયન નાયનૉર્સ્ક');
INSERT INTO "languageNames" VALUES(6903,'gu','no','નૉર્વેજીયન');
INSERT INTO "languageNames" VALUES(6904,'gu','nog','નોગાઇ');
INSERT INTO "languageNames" VALUES(6905,'gu','oc','ઓક્સિટન');
INSERT INTO "languageNames" VALUES(6906,'gu','os','ઓસ્સેટિક');
INSERT INTO "languageNames" VALUES(6907,'gu','ota','ઓટોમાન તુર્કિશ');
INSERT INTO "languageNames" VALUES(6908,'gu','pa','પંજાબી');
INSERT INTO "languageNames" VALUES(6909,'gu','pl','પોલીશ');
INSERT INTO "languageNames" VALUES(6910,'gu','pt','પોર્ટુગીઝ');
INSERT INTO "languageNames" VALUES(6911,'gu','rm','રોમાન્શ');
INSERT INTO "languageNames" VALUES(6912,'gu','rn','રૂન્દી');
INSERT INTO "languageNames" VALUES(6913,'gu','ro','રોમાનિયન');
INSERT INTO "languageNames" VALUES(6914,'gu','ru','રશિયન');
INSERT INTO "languageNames" VALUES(6915,'gu','rup','અરોમેનિયન');
INSERT INTO "languageNames" VALUES(6916,'gu','sa','સંસ્કૃત');
INSERT INTO "languageNames" VALUES(6917,'gu','sah','સખા');
INSERT INTO "languageNames" VALUES(6918,'gu','sc','સાર્દિનિયન');
INSERT INTO "languageNames" VALUES(6919,'gu','scn','સિસિલિયાન');
INSERT INTO "languageNames" VALUES(6920,'gu','sco','સ્કોટ્સ');
INSERT INTO "languageNames" VALUES(6921,'gu','sd','સિંધી');
INSERT INTO "languageNames" VALUES(6922,'gu','se','ઉત્તરી સામી');
INSERT INTO "languageNames" VALUES(6923,'gu','sh','સર્બો-ક્રોએશિયન');
INSERT INTO "languageNames" VALUES(6924,'gu','si','સિંહાલી');
INSERT INTO "languageNames" VALUES(6925,'gu','sk','સ્લોવૅક');
INSERT INTO "languageNames" VALUES(6926,'gu','sl','સ્લોવેનિયન');
INSERT INTO "languageNames" VALUES(6927,'gu','sma','દક્ષિણ સામી');
INSERT INTO "languageNames" VALUES(6928,'gu','smj','લુલે સામી');
INSERT INTO "languageNames" VALUES(6929,'gu','smn','ઇનારી સામી');
INSERT INTO "languageNames" VALUES(6930,'gu','sq','અલ્બેનિયન');
INSERT INTO "languageNames" VALUES(6931,'gu','sr','સર્બિયન');
INSERT INTO "languageNames" VALUES(6932,'gu','srn','સ્રાનન ટોન્ગો');
INSERT INTO "languageNames" VALUES(6933,'gu','ss','સ્વાતી');
INSERT INTO "languageNames" VALUES(6934,'gu','sv','સ્વીડિશ');
INSERT INTO "languageNames" VALUES(6935,'gu','sw','સ્વાહિલી');
INSERT INTO "languageNames" VALUES(6936,'gu','ta','તમિલ');
INSERT INTO "languageNames" VALUES(6937,'gu','te','તેલુગુ');
INSERT INTO "languageNames" VALUES(6938,'gu','tet','તેતુમ');
INSERT INTO "languageNames" VALUES(6939,'gu','tg','તાજીક');
INSERT INTO "languageNames" VALUES(6940,'gu','th','થાઈ');
INSERT INTO "languageNames" VALUES(6941,'gu','tk','તુર્કમેન');
INSERT INTO "languageNames" VALUES(6942,'gu','tl','ટાગાલોગ');
INSERT INTO "languageNames" VALUES(6943,'gu','tr','ટર્કિશ');
INSERT INTO "languageNames" VALUES(6944,'gu','tt','તતાર');
INSERT INTO "languageNames" VALUES(6945,'gu','tyv','ટુવીનિયન');
INSERT INTO "languageNames" VALUES(6946,'gu','udm','ઉદમુર્ત');
INSERT INTO "languageNames" VALUES(6947,'gu','ug','ઉઇગુર');
INSERT INTO "languageNames" VALUES(6948,'gu','uk','યુક્રેનિયન');
INSERT INTO "languageNames" VALUES(6949,'gu','ur','ઉર્દૂ');
INSERT INTO "languageNames" VALUES(6950,'gu','uz','ઉઝ્બેક');
INSERT INTO "languageNames" VALUES(6951,'gu','vi','વિયેતનામીસ');
INSERT INTO "languageNames" VALUES(6952,'gu','wal','વોલાયટ્ટા');
INSERT INTO "languageNames" VALUES(6953,'gu','xh','ખોસા');
INSERT INTO "languageNames" VALUES(6954,'gu','yi','યિદ્દિશ');
INSERT INTO "languageNames" VALUES(6955,'gu','yo','યોરૂબા');
INSERT INTO "languageNames" VALUES(6956,'gu','zh','ચાઇનીઝ');
INSERT INTO "languageNames" VALUES(6957,'gu','zu','ઝુલુ');
INSERT INTO "languageNames" VALUES(6958,'id','af','Afrikaans');
INSERT INTO "languageNames" VALUES(6959,'id','alt','Altai Selatan');
INSERT INTO "languageNames" VALUES(6960,'id','an','Aragon');
INSERT INTO "languageNames" VALUES(6961,'id','ar','Arab');
INSERT INTO "languageNames" VALUES(6962,'id','as','Assam');
INSERT INTO "languageNames" VALUES(6963,'id','ast','Asturia');
INSERT INTO "languageNames" VALUES(6964,'id','av','Avar');
INSERT INTO "languageNames" VALUES(6966,'id','az','Azeri');
INSERT INTO "languageNames" VALUES(6967,'id','ba','Bashkir');
INSERT INTO "languageNames" VALUES(6968,'id','be','Belarusia');
INSERT INTO "languageNames" VALUES(6969,'id','bg','Bulgaria');
INSERT INTO "languageNames" VALUES(6970,'id','bi','Bislama');
INSERT INTO "languageNames" VALUES(6971,'id','bn','Bengali');
INSERT INTO "languageNames" VALUES(6972,'id','br','Breton');
INSERT INTO "languageNames" VALUES(6973,'id','bs','Bosnia');
INSERT INTO "languageNames" VALUES(6974,'id','bua','Buriat');
INSERT INTO "languageNames" VALUES(6975,'id','byv','Medumba');
INSERT INTO "languageNames" VALUES(6976,'id','ca','Katalan');
INSERT INTO "languageNames" VALUES(6977,'id','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(6978,'id','chm','Mari');
INSERT INTO "languageNames" VALUES(6979,'id','ckb','Kurdi Sorani');
INSERT INTO "languageNames" VALUES(6980,'id','co','Korsika');
INSERT INTO "languageNames" VALUES(6981,'id','crh','Tatar Krimea');
INSERT INTO "languageNames" VALUES(6982,'id','cs','Cheska');
INSERT INTO "languageNames" VALUES(6983,'id','csb','Kashubia');
INSERT INTO "languageNames" VALUES(6984,'id','cu','Bahasa Gereja Slavonia');
INSERT INTO "languageNames" VALUES(6985,'id','cv','Chuvash');
INSERT INTO "languageNames" VALUES(6986,'id','cy','Welsh');
INSERT INTO "languageNames" VALUES(6987,'id','da','Dansk');
INSERT INTO "languageNames" VALUES(6988,'id','dar','Dargwa');
INSERT INTO "languageNames" VALUES(6989,'id','de','Jerman');
INSERT INTO "languageNames" VALUES(6990,'id','dsb','Sorbia Hilir');
INSERT INTO "languageNames" VALUES(6991,'id','el','Yunani');
INSERT INTO "languageNames" VALUES(6992,'id','en','Inggris');
INSERT INTO "languageNames" VALUES(6993,'id','eo','Esperanto');
INSERT INTO "languageNames" VALUES(6994,'id','es','Spanyol');
INSERT INTO "languageNames" VALUES(6995,'id','et','Esti');
INSERT INTO "languageNames" VALUES(6996,'id','eu','Basque');
INSERT INTO "languageNames" VALUES(6997,'id','fa','Persia');
INSERT INTO "languageNames" VALUES(6998,'id','fi','Suomi');
INSERT INTO "languageNames" VALUES(6999,'id','fo','Faroe');
INSERT INTO "languageNames" VALUES(7000,'id','fr','Prancis');
INSERT INTO "languageNames" VALUES(7001,'id','fy','Frisia Barat');
INSERT INTO "languageNames" VALUES(7002,'id','ga','Irlandia');
INSERT INTO "languageNames" VALUES(7003,'id','gag','Gagauz');
INSERT INTO "languageNames" VALUES(7004,'id','gd','Gaelik Skotlandia');
INSERT INTO "languageNames" VALUES(7005,'id','gl','Galisia');
INSERT INTO "languageNames" VALUES(7006,'id','glk','Gilaki');
INSERT INTO "languageNames" VALUES(7007,'id','gn','Guarani');
INSERT INTO "languageNames" VALUES(7008,'id','gu','Gujarat');
INSERT INTO "languageNames" VALUES(7009,'id','gv','Manx');
INSERT INTO "languageNames" VALUES(7010,'id','ha','Hausa');
INSERT INTO "languageNames" VALUES(7011,'id','haw','Hawaii');
INSERT INTO "languageNames" VALUES(7012,'id','he','Ibrani');
INSERT INTO "languageNames" VALUES(7013,'id','hi','Hindi');
INSERT INTO "languageNames" VALUES(7014,'id','hr','Kroasia');
INSERT INTO "languageNames" VALUES(7015,'id','hsb','Sorbia Hulu');
INSERT INTO "languageNames" VALUES(7016,'id','ht','Kreol Haiti');
INSERT INTO "languageNames" VALUES(7017,'id','hu','Hungaria');
INSERT INTO "languageNames" VALUES(7018,'id','hy','Armenia');
INSERT INTO "languageNames" VALUES(7019,'id','ia','Interlingua');
INSERT INTO "languageNames" VALUES(7020,'id','id','Indonesia');
INSERT INTO "languageNames" VALUES(7021,'id','ig','Igbo');
INSERT INTO "languageNames" VALUES(7022,'id','is','Islandia');
INSERT INTO "languageNames" VALUES(7023,'id','it','Italia');
INSERT INTO "languageNames" VALUES(7024,'id','ka','Georgia');
INSERT INTO "languageNames" VALUES(7025,'id','kaa','Kara-Kalpak');
INSERT INTO "languageNames" VALUES(7026,'id','kk','Kazakh');
INSERT INTO "languageNames" VALUES(7027,'id','ko','Korea');
INSERT INTO "languageNames" VALUES(7028,'id','krc','Karachai Balkar');
INSERT INTO "languageNames" VALUES(7029,'id','krl','Karelia');
INSERT INTO "languageNames" VALUES(7030,'id','ks','Kashmir');
INSERT INTO "languageNames" VALUES(7031,'id','kum','Kumyk');
INSERT INTO "languageNames" VALUES(7032,'id','kv','Komi');
INSERT INTO "languageNames" VALUES(7033,'id','ky','Kirgiz');
INSERT INTO "languageNames" VALUES(7034,'id','la','Latin');
INSERT INTO "languageNames" VALUES(7035,'id','lb','Luksemburg');
INSERT INTO "languageNames" VALUES(7036,'id','lg','Ganda');
INSERT INTO "languageNames" VALUES(7037,'id','ln','Lingala');
INSERT INTO "languageNames" VALUES(7038,'id','lo','Lao');
INSERT INTO "languageNames" VALUES(7039,'id','lt','Lituavi');
INSERT INTO "languageNames" VALUES(7040,'id','lv','Latvi');
INSERT INTO "languageNames" VALUES(7041,'id','mdf','Moksha');
INSERT INTO "languageNames" VALUES(7042,'id','mfe','Morisien');
INSERT INTO "languageNames" VALUES(7043,'id','mk','Makedonia');
INSERT INTO "languageNames" VALUES(7044,'id','ml','Malayalam');
INSERT INTO "languageNames" VALUES(7045,'id','mr','Marathi');
INSERT INTO "languageNames" VALUES(7046,'id','ms','Melayu');
INSERT INTO "languageNames" VALUES(7047,'id','mt','Malta');
INSERT INTO "languageNames" VALUES(7048,'id','myv','Eryza');
INSERT INTO "languageNames" VALUES(7049,'id','nap','Neapolitan');
INSERT INTO "languageNames" VALUES(7050,'id','nb','Bokmål Norwegia');
INSERT INTO "languageNames" VALUES(7051,'id','ne','Nepali');
INSERT INTO "languageNames" VALUES(7052,'id','nl','Belanda');
INSERT INTO "languageNames" VALUES(7053,'id','nn','Nynorsk Norwegia');
INSERT INTO "languageNames" VALUES(7054,'id','no','Norwegia');
INSERT INTO "languageNames" VALUES(7055,'id','nog','Nogai');
INSERT INTO "languageNames" VALUES(7056,'id','oc','Ositania');
INSERT INTO "languageNames" VALUES(7057,'id','os','Ossetia');
INSERT INTO "languageNames" VALUES(7058,'id','ota','Turki Osmani');
INSERT INTO "languageNames" VALUES(7059,'id','pa','Punjabi');
INSERT INTO "languageNames" VALUES(7060,'id','pl','Polski');
INSERT INTO "languageNames" VALUES(7061,'id','pt','Portugis');
INSERT INTO "languageNames" VALUES(7062,'id','rm','Reto-Roman');
INSERT INTO "languageNames" VALUES(7063,'id','rn','Rundi');
INSERT INTO "languageNames" VALUES(7064,'id','ro','Rumania');
INSERT INTO "languageNames" VALUES(7065,'id','ru','Rusia');
INSERT INTO "languageNames" VALUES(7066,'id','rup','Aromania');
INSERT INTO "languageNames" VALUES(7067,'id','sa','Sanskerta');
INSERT INTO "languageNames" VALUES(7068,'id','sah','Sakha');
INSERT INTO "languageNames" VALUES(7069,'id','sc','Sardinia');
INSERT INTO "languageNames" VALUES(7070,'id','scn','Sisilia');
INSERT INTO "languageNames" VALUES(7071,'id','sco','Skotlandia');
INSERT INTO "languageNames" VALUES(7072,'id','sd','Sindhi');
INSERT INTO "languageNames" VALUES(7073,'id','se','Sami Utara');
INSERT INTO "languageNames" VALUES(7074,'id','sh','Serbo-Kroasia');
INSERT INTO "languageNames" VALUES(7075,'id','si','Sinhala');
INSERT INTO "languageNames" VALUES(7076,'id','sk','Slovak');
INSERT INTO "languageNames" VALUES(7077,'id','sl','Sloven');
INSERT INTO "languageNames" VALUES(7078,'id','sma','Sami Selatan');
INSERT INTO "languageNames" VALUES(7079,'id','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(7080,'id','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(7081,'id','sq','Albania');
INSERT INTO "languageNames" VALUES(7082,'id','sr','Serbia');
INSERT INTO "languageNames" VALUES(7083,'id','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(7084,'id','ss','Swati');
INSERT INTO "languageNames" VALUES(7085,'id','sv','Swedia');
INSERT INTO "languageNames" VALUES(7086,'id','sw','Swahili');
INSERT INTO "languageNames" VALUES(7087,'id','ta','Tamil');
INSERT INTO "languageNames" VALUES(7088,'id','te','Telugu');
INSERT INTO "languageNames" VALUES(7089,'id','tet','Tetun');
INSERT INTO "languageNames" VALUES(7090,'id','tg','Tajik');
INSERT INTO "languageNames" VALUES(7091,'id','th','Thai');
INSERT INTO "languageNames" VALUES(7092,'id','tk','Turkmen');
INSERT INTO "languageNames" VALUES(7093,'id','tl','Tagalog');
INSERT INTO "languageNames" VALUES(7094,'id','tr','Turki');
INSERT INTO "languageNames" VALUES(7095,'id','tt','Tatar');
INSERT INTO "languageNames" VALUES(7096,'id','tyv','Tuvinia');
INSERT INTO "languageNames" VALUES(7097,'id','udm','Udmurt');
INSERT INTO "languageNames" VALUES(7099,'id','ug','Uighur');
INSERT INTO "languageNames" VALUES(7100,'id','uk','Ukraina');
INSERT INTO "languageNames" VALUES(7101,'id','ur','Urdu');
INSERT INTO "languageNames" VALUES(7102,'id','uz','Uzbek');
INSERT INTO "languageNames" VALUES(7103,'id','vi','Vietnam');
INSERT INTO "languageNames" VALUES(7104,'id','wal','Walamo');
INSERT INTO "languageNames" VALUES(7105,'id','xh','Xhosa');
INSERT INTO "languageNames" VALUES(7106,'id','yi','Yiddish');
INSERT INTO "languageNames" VALUES(7107,'id','yo','Yoruba');
INSERT INTO "languageNames" VALUES(7108,'id','zh','Tionghoa');
INSERT INTO "languageNames" VALUES(7109,'id','zu','Zulu');
INSERT INTO "languageNames" VALUES(7110,'zh','af','南非荷兰语');
INSERT INTO "languageNames" VALUES(7111,'zh','alt','南阿尔泰语');
INSERT INTO "languageNames" VALUES(7112,'zh','an','阿拉贡语');
INSERT INTO "languageNames" VALUES(7113,'zh','ar','阿拉伯语');
INSERT INTO "languageNames" VALUES(7114,'zh','as','阿萨姆语');
INSERT INTO "languageNames" VALUES(7115,'zh','ast','阿斯图里亚斯语');
INSERT INTO "languageNames" VALUES(7116,'zh','av','阿瓦尔语');
INSERT INTO "languageNames" VALUES(7118,'zh','az','阿塞语');
INSERT INTO "languageNames" VALUES(7119,'zh','ba','巴什基尔语');
INSERT INTO "languageNames" VALUES(7120,'zh','be','白俄罗斯语');
INSERT INTO "languageNames" VALUES(7121,'zh','bg','保加利亚语');
INSERT INTO "languageNames" VALUES(7122,'zh','bi','比斯拉马语');
INSERT INTO "languageNames" VALUES(7123,'zh','bn','孟加拉语');
INSERT INTO "languageNames" VALUES(7124,'zh','br','布列塔尼语');
INSERT INTO "languageNames" VALUES(7125,'zh','bs','波斯尼亚语');
INSERT INTO "languageNames" VALUES(7126,'zh','bua','布里亚特语');
INSERT INTO "languageNames" VALUES(7127,'zh','byv','梅敦巴语');
INSERT INTO "languageNames" VALUES(7128,'zh','ca','加泰罗尼亚语');
INSERT INTO "languageNames" VALUES(7129,'zh','ceb','宿务语');
INSERT INTO "languageNames" VALUES(7130,'zh','chm','马里语');
INSERT INTO "languageNames" VALUES(7131,'zh','ckb','中库尔德语');
INSERT INTO "languageNames" VALUES(7132,'zh','co','科西嘉语');
INSERT INTO "languageNames" VALUES(7133,'zh','crh','克里米亚土耳其语');
INSERT INTO "languageNames" VALUES(7134,'zh','cs','捷克语');
INSERT INTO "languageNames" VALUES(7135,'zh','csb','卡舒比语');
INSERT INTO "languageNames" VALUES(7136,'zh','cu','教会斯拉夫语');
INSERT INTO "languageNames" VALUES(7137,'zh','cv','楚瓦什语');
INSERT INTO "languageNames" VALUES(7138,'zh','cy','威尔士语');
INSERT INTO "languageNames" VALUES(7139,'zh','da','丹麦语');
INSERT INTO "languageNames" VALUES(7140,'zh','dar','达尔格瓦语');
INSERT INTO "languageNames" VALUES(7141,'zh','de','德语');
INSERT INTO "languageNames" VALUES(7142,'zh','dsb','下索布语');
INSERT INTO "languageNames" VALUES(7143,'zh','el','希腊语');
INSERT INTO "languageNames" VALUES(7144,'zh','en','英语');
INSERT INTO "languageNames" VALUES(7145,'zh','eo','世界语');
INSERT INTO "languageNames" VALUES(7146,'zh','es','西班牙语');
INSERT INTO "languageNames" VALUES(7147,'zh','et','爱沙尼亚语');
INSERT INTO "languageNames" VALUES(7148,'zh','eu','巴斯克语');
INSERT INTO "languageNames" VALUES(7149,'zh','fa','波斯语');
INSERT INTO "languageNames" VALUES(7150,'zh','fi','芬兰语');
INSERT INTO "languageNames" VALUES(7151,'zh','fo','法罗语');
INSERT INTO "languageNames" VALUES(7152,'zh','fr','法语');
INSERT INTO "languageNames" VALUES(7153,'zh','fy','西弗里西亚语');
INSERT INTO "languageNames" VALUES(7154,'zh','ga','爱尔兰语');
INSERT INTO "languageNames" VALUES(7155,'zh','gag','加告兹语');
INSERT INTO "languageNames" VALUES(7156,'zh','gd','苏格兰盖尔语');
INSERT INTO "languageNames" VALUES(7157,'zh','gl','加利西亚语');
INSERT INTO "languageNames" VALUES(7158,'zh','gn','瓜拉尼语');
INSERT INTO "languageNames" VALUES(7159,'zh','gu','古吉拉特语');
INSERT INTO "languageNames" VALUES(7160,'zh','gv','马恩语');
INSERT INTO "languageNames" VALUES(7161,'zh','ha','豪萨语');
INSERT INTO "languageNames" VALUES(7162,'zh','haw','夏威夷语');
INSERT INTO "languageNames" VALUES(7163,'zh','he','希伯来语');
INSERT INTO "languageNames" VALUES(7164,'zh','hi','印地语');
INSERT INTO "languageNames" VALUES(7165,'zh','hr','克罗地亚语');
INSERT INTO "languageNames" VALUES(7166,'zh','hsb','上索布语');
INSERT INTO "languageNames" VALUES(7167,'zh','ht','海地克里奥尔语');
INSERT INTO "languageNames" VALUES(7168,'zh','hu','匈牙利语');
INSERT INTO "languageNames" VALUES(7169,'zh','hy','亚美尼亚语');
INSERT INTO "languageNames" VALUES(7170,'zh','ia','国际语');
INSERT INTO "languageNames" VALUES(7171,'zh','id','印度尼西亚语');
INSERT INTO "languageNames" VALUES(7172,'zh','ig','伊博语');
INSERT INTO "languageNames" VALUES(7173,'zh','is','冰岛语');
INSERT INTO "languageNames" VALUES(7174,'zh','it','意大利语');
INSERT INTO "languageNames" VALUES(7175,'zh','ka','格鲁吉亚语');
INSERT INTO "languageNames" VALUES(7176,'zh','kaa','卡拉卡尔帕克语');
INSERT INTO "languageNames" VALUES(7177,'zh','kk','哈萨克语');
INSERT INTO "languageNames" VALUES(7178,'zh','ko','韩语');
INSERT INTO "languageNames" VALUES(7179,'zh','krc','卡拉恰伊巴尔卡尔语');
INSERT INTO "languageNames" VALUES(7180,'zh','krl','卡累利阿语');
INSERT INTO "languageNames" VALUES(7181,'zh','ks','克什米尔语');
INSERT INTO "languageNames" VALUES(7182,'zh','kum','库梅克语');
INSERT INTO "languageNames" VALUES(7183,'zh','kv','科米语');
INSERT INTO "languageNames" VALUES(7184,'zh','ky','柯尔克孜语');
INSERT INTO "languageNames" VALUES(7185,'zh','la','拉丁语');
INSERT INTO "languageNames" VALUES(7186,'zh','lb','卢森堡语');
INSERT INTO "languageNames" VALUES(7187,'zh','lg','卢干达语');
INSERT INTO "languageNames" VALUES(7188,'zh','ln','林加拉语');
INSERT INTO "languageNames" VALUES(7189,'zh','lo','老挝语');
INSERT INTO "languageNames" VALUES(7190,'zh','lt','立陶宛语');
INSERT INTO "languageNames" VALUES(7191,'zh','lv','拉脱维亚语');
INSERT INTO "languageNames" VALUES(7192,'zh','mdf','莫克沙语');
INSERT INTO "languageNames" VALUES(7193,'zh','mfe','毛里求斯克里奥尔语');
INSERT INTO "languageNames" VALUES(7194,'zh','mk','马其顿语');
INSERT INTO "languageNames" VALUES(7195,'zh','ml','马拉雅拉姆语');
INSERT INTO "languageNames" VALUES(7196,'zh','mr','马拉地语');
INSERT INTO "languageNames" VALUES(7197,'zh','ms','马来语');
INSERT INTO "languageNames" VALUES(7198,'zh','mt','马耳他语');
INSERT INTO "languageNames" VALUES(7199,'zh','myv','厄尔兹亚语');
INSERT INTO "languageNames" VALUES(7200,'zh','nap','那不勒斯语');
INSERT INTO "languageNames" VALUES(7201,'zh','nb','书面挪威语');
INSERT INTO "languageNames" VALUES(7202,'zh','ne','尼泊尔语');
INSERT INTO "languageNames" VALUES(7203,'zh','nl','荷兰语');
INSERT INTO "languageNames" VALUES(7204,'zh','nn','挪威尼诺斯克语');
INSERT INTO "languageNames" VALUES(7205,'zh','no','挪威语');
INSERT INTO "languageNames" VALUES(7206,'zh','nog','诺盖语');
INSERT INTO "languageNames" VALUES(7207,'zh','oc','奥克语');
INSERT INTO "languageNames" VALUES(7208,'zh','os','奥塞梯语');
INSERT INTO "languageNames" VALUES(7209,'zh','ota','奥斯曼土耳其语');
INSERT INTO "languageNames" VALUES(7210,'zh','pa','旁遮普语');
INSERT INTO "languageNames" VALUES(7211,'zh','pl','波兰语');
INSERT INTO "languageNames" VALUES(7212,'zh','pt','葡萄牙语');
INSERT INTO "languageNames" VALUES(7213,'zh','rm','罗曼什语');
INSERT INTO "languageNames" VALUES(7214,'zh','rn','隆迪语');
INSERT INTO "languageNames" VALUES(7215,'zh','ro','罗马尼亚语');
INSERT INTO "languageNames" VALUES(7216,'zh','ru','俄语');
INSERT INTO "languageNames" VALUES(7217,'zh','rup','阿罗马尼亚语');
INSERT INTO "languageNames" VALUES(7218,'zh','sa','梵语');
INSERT INTO "languageNames" VALUES(7219,'zh','sah','萨哈语');
INSERT INTO "languageNames" VALUES(7220,'zh','sc','萨丁语');
INSERT INTO "languageNames" VALUES(7221,'zh','scn','西西里语');
INSERT INTO "languageNames" VALUES(7222,'zh','sco','苏格兰语');
INSERT INTO "languageNames" VALUES(7223,'zh','sd','信德语');
INSERT INTO "languageNames" VALUES(7224,'zh','se','北方萨米语');
INSERT INTO "languageNames" VALUES(7225,'zh','sh','塞尔维亚-克罗地亚语');
INSERT INTO "languageNames" VALUES(7226,'zh','si','僧伽罗语');
INSERT INTO "languageNames" VALUES(7227,'zh','sk','斯洛伐克语');
INSERT INTO "languageNames" VALUES(7228,'zh','sl','斯洛文尼亚语');
INSERT INTO "languageNames" VALUES(7229,'zh','sma','南萨米语');
INSERT INTO "languageNames" VALUES(7230,'zh','smj','吕勒萨米语');
INSERT INTO "languageNames" VALUES(7231,'zh','smn','伊纳里萨米语');
INSERT INTO "languageNames" VALUES(7232,'zh','sq','阿尔巴尼亚语');
INSERT INTO "languageNames" VALUES(7233,'zh','sr','塞尔维亚语');
INSERT INTO "languageNames" VALUES(7234,'zh','srn','苏里南汤加语');
INSERT INTO "languageNames" VALUES(7235,'zh','ss','斯瓦蒂语');
INSERT INTO "languageNames" VALUES(7236,'zh','sv','瑞典语');
INSERT INTO "languageNames" VALUES(7237,'zh','sw','斯瓦希里语');
INSERT INTO "languageNames" VALUES(7238,'zh','ta','泰米尔语');
INSERT INTO "languageNames" VALUES(7239,'zh','te','泰卢固语');
INSERT INTO "languageNames" VALUES(7240,'zh','tet','德顿语');
INSERT INTO "languageNames" VALUES(7241,'zh','tg','塔吉克语');
INSERT INTO "languageNames" VALUES(7242,'zh','th','泰语');
INSERT INTO "languageNames" VALUES(7243,'zh','tk','土库曼语');
INSERT INTO "languageNames" VALUES(7244,'zh','tl','他加禄语');
INSERT INTO "languageNames" VALUES(7245,'zh','tr','土耳其语');
INSERT INTO "languageNames" VALUES(7246,'zh','tt','鞑靼语');
INSERT INTO "languageNames" VALUES(7247,'zh','tyv','图瓦语');
INSERT INTO "languageNames" VALUES(7248,'zh','udm','乌德穆尔特语');
INSERT INTO "languageNames" VALUES(7249,'zh','ug','维吾尔语');
INSERT INTO "languageNames" VALUES(7250,'zh','uk','乌克兰语');
INSERT INTO "languageNames" VALUES(7251,'zh','ur','乌尔都语');
INSERT INTO "languageNames" VALUES(7252,'zh','uz','乌兹别克语');
INSERT INTO "languageNames" VALUES(7253,'zh','vi','越南语');
INSERT INTO "languageNames" VALUES(7254,'zh','wal','瓦拉莫语');
INSERT INTO "languageNames" VALUES(7255,'zh','xh','科萨语');
INSERT INTO "languageNames" VALUES(7256,'zh','yi','意第绪语');
INSERT INTO "languageNames" VALUES(7257,'zh','yo','约鲁巴语');
INSERT INTO "languageNames" VALUES(7258,'zh','zh','中文');
INSERT INTO "languageNames" VALUES(7259,'zh','zu','祖鲁语');
INSERT INTO "languageNames" VALUES(7260,'nb','af','afrikaans');
INSERT INTO "languageNames" VALUES(7261,'nb','alt','søraltaisk');
INSERT INTO "languageNames" VALUES(7262,'nb','an','aragonsk');
INSERT INTO "languageNames" VALUES(7263,'nb','ar','arabisk');
INSERT INTO "languageNames" VALUES(7264,'nb','as','assamesisk');
INSERT INTO "languageNames" VALUES(7265,'nb','ast','asturisk');
INSERT INTO "languageNames" VALUES(7266,'nb','av','avarisk');
INSERT INTO "languageNames" VALUES(7268,'nb','az','azeri');
INSERT INTO "languageNames" VALUES(7269,'nb','ba','basjkirsk');
INSERT INTO "languageNames" VALUES(7270,'nb','be','hviterussisk');
INSERT INTO "languageNames" VALUES(7271,'nb','bg','bulgarsk');
INSERT INTO "languageNames" VALUES(7272,'nb','bi','bislama');
INSERT INTO "languageNames" VALUES(7273,'nb','bn','bengali');
INSERT INTO "languageNames" VALUES(7274,'nb','br','bretonsk');
INSERT INTO "languageNames" VALUES(7275,'nb','bs','bosnisk');
INSERT INTO "languageNames" VALUES(7276,'nb','bua','burjatisk');
INSERT INTO "languageNames" VALUES(7277,'nb','byv','medumba');
INSERT INTO "languageNames" VALUES(7278,'nb','ca','katalansk');
INSERT INTO "languageNames" VALUES(7279,'nb','ceb','cebuansk');
INSERT INTO "languageNames" VALUES(7280,'nb','chm','mari');
INSERT INTO "languageNames" VALUES(7281,'nb','ckb','kurdisk (sorani)');
INSERT INTO "languageNames" VALUES(7282,'nb','co','korsikansk');
INSERT INTO "languageNames" VALUES(7283,'nb','crh','krimtatarisk');
INSERT INTO "languageNames" VALUES(7284,'nb','cs','tsjekkisk');
INSERT INTO "languageNames" VALUES(7285,'nb','csb','kasjubisk');
INSERT INTO "languageNames" VALUES(7286,'nb','cu','kirkeslavisk');
INSERT INTO "languageNames" VALUES(7287,'nb','cv','tsjuvasjisk');
INSERT INTO "languageNames" VALUES(7288,'nb','cy','walisisk');
INSERT INTO "languageNames" VALUES(7289,'nb','da','dansk');
INSERT INTO "languageNames" VALUES(7290,'nb','dar','dargwa');
INSERT INTO "languageNames" VALUES(7291,'nb','de','tysk');
INSERT INTO "languageNames" VALUES(7292,'nb','dsb','lavsorbisk');
INSERT INTO "languageNames" VALUES(7293,'nb','el','gresk');
INSERT INTO "languageNames" VALUES(7294,'nb','en','engelsk');
INSERT INTO "languageNames" VALUES(7295,'nb','eo','esperanto');
INSERT INTO "languageNames" VALUES(7296,'nb','es','spansk');
INSERT INTO "languageNames" VALUES(7297,'nb','et','estisk');
INSERT INTO "languageNames" VALUES(7298,'nb','eu','baskisk');
INSERT INTO "languageNames" VALUES(7299,'nb','fa','persisk');
INSERT INTO "languageNames" VALUES(7300,'nb','fi','finsk');
INSERT INTO "languageNames" VALUES(7301,'nb','fo','færøysk');
INSERT INTO "languageNames" VALUES(7302,'nb','fr','fransk');
INSERT INTO "languageNames" VALUES(7303,'nb','fy','vestfrisisk');
INSERT INTO "languageNames" VALUES(7304,'nb','ga','irsk');
INSERT INTO "languageNames" VALUES(7305,'nb','gag','gagausisk');
INSERT INTO "languageNames" VALUES(7306,'nb','gd','skotsk-gælisk');
INSERT INTO "languageNames" VALUES(7307,'nb','gl','galisisk');
INSERT INTO "languageNames" VALUES(7308,'nb','glk','gileki');
INSERT INTO "languageNames" VALUES(7309,'nb','gn','guarani');
INSERT INTO "languageNames" VALUES(7310,'nb','gu','gujarati');
INSERT INTO "languageNames" VALUES(7311,'nb','guc','wayuu');
INSERT INTO "languageNames" VALUES(7312,'nb','gv','mansk');
INSERT INTO "languageNames" VALUES(7313,'nb','ha','hausa');
INSERT INTO "languageNames" VALUES(7314,'nb','haw','hawaiisk');
INSERT INTO "languageNames" VALUES(7315,'nb','he','hebraisk');
INSERT INTO "languageNames" VALUES(7316,'nb','hi','hindi');
INSERT INTO "languageNames" VALUES(7317,'nb','hr','kroatisk');
INSERT INTO "languageNames" VALUES(7318,'nb','hsb','høysorbisk');
INSERT INTO "languageNames" VALUES(7319,'nb','ht','haitisk');
INSERT INTO "languageNames" VALUES(7320,'nb','hu','ungarsk');
INSERT INTO "languageNames" VALUES(7321,'nb','hy','armensk');
INSERT INTO "languageNames" VALUES(7322,'nb','ia','interlingua');
INSERT INTO "languageNames" VALUES(7323,'nb','id','indonesisk');
INSERT INTO "languageNames" VALUES(7324,'nb','ig','ibo');
INSERT INTO "languageNames" VALUES(7325,'nb','is','islandsk');
INSERT INTO "languageNames" VALUES(7326,'nb','it','italiensk');
INSERT INTO "languageNames" VALUES(7327,'nb','ka','georgisk');
INSERT INTO "languageNames" VALUES(7328,'nb','kaa','karakalpakisk');
INSERT INTO "languageNames" VALUES(7329,'nb','kk','kasakhisk');
INSERT INTO "languageNames" VALUES(7330,'nb','ko','koreansk');
INSERT INTO "languageNames" VALUES(7331,'nb','krc','karatsjajbalkarsk');
INSERT INTO "languageNames" VALUES(7332,'nb','krl','karelsk');
INSERT INTO "languageNames" VALUES(7333,'nb','ks','kasjmiri');
INSERT INTO "languageNames" VALUES(7334,'nb','kum','kumykisk');
INSERT INTO "languageNames" VALUES(7335,'nb','kv','komi');
INSERT INTO "languageNames" VALUES(7336,'nb','ky','kirgisisk');
INSERT INTO "languageNames" VALUES(7337,'nb','la','latin');
INSERT INTO "languageNames" VALUES(7338,'nb','lb','luxemburgsk');
INSERT INTO "languageNames" VALUES(7339,'nb','lg','ganda');
INSERT INTO "languageNames" VALUES(7340,'nb','liv','livisk');
INSERT INTO "languageNames" VALUES(7341,'nb','ln','lingala');
INSERT INTO "languageNames" VALUES(7342,'nb','lo','laotisk');
INSERT INTO "languageNames" VALUES(7343,'nb','lt','litauisk');
INSERT INTO "languageNames" VALUES(7344,'nb','lv','latvisk');
INSERT INTO "languageNames" VALUES(7345,'nb','mdf','moksja');
INSERT INTO "languageNames" VALUES(7346,'nb','mfe','mauritisk-kreolsk');
INSERT INTO "languageNames" VALUES(7347,'nb','mk','makedonsk');
INSERT INTO "languageNames" VALUES(7348,'nb','ml','malayalam');
INSERT INTO "languageNames" VALUES(7349,'nb','mr','marathi');
INSERT INTO "languageNames" VALUES(7350,'nb','mrj','vestmarisk');
INSERT INTO "languageNames" VALUES(7351,'nb','ms','malayisk');
INSERT INTO "languageNames" VALUES(7352,'nb','mt','maltesisk');
INSERT INTO "languageNames" VALUES(7353,'nb','myv','erzia');
INSERT INTO "languageNames" VALUES(7354,'nb','nap','napolitansk');
INSERT INTO "languageNames" VALUES(7355,'nb','nb','norsk bokmål');
INSERT INTO "languageNames" VALUES(7356,'nb','ne','nepali');
INSERT INTO "languageNames" VALUES(7357,'nb','nl','nederlandsk');
INSERT INTO "languageNames" VALUES(7358,'nb','nn','norsk nynorsk');
INSERT INTO "languageNames" VALUES(7359,'nb','no','norsk');
INSERT INTO "languageNames" VALUES(7360,'nb','nog','nogaisk');
INSERT INTO "languageNames" VALUES(7361,'nb','oc','oksitansk');
INSERT INTO "languageNames" VALUES(7362,'nb','os','ossetisk');
INSERT INTO "languageNames" VALUES(7363,'nb','ota','ottomansk tyrkisk');
INSERT INTO "languageNames" VALUES(7364,'nb','pa','panjabi');
INSERT INTO "languageNames" VALUES(7365,'nb','pl','polsk');
INSERT INTO "languageNames" VALUES(7366,'nb','pt','portugisisk');
INSERT INTO "languageNames" VALUES(7367,'nb','rm','retoromansk');
INSERT INTO "languageNames" VALUES(7368,'nb','rn','rundi');
INSERT INTO "languageNames" VALUES(7369,'nb','ro','rumensk');
INSERT INTO "languageNames" VALUES(7370,'nb','ru','russisk');
INSERT INTO "languageNames" VALUES(7371,'nb','rup','aromansk');
INSERT INTO "languageNames" VALUES(7372,'nb','sa','sanskrit');
INSERT INTO "languageNames" VALUES(7373,'nb','sah','sakha');
INSERT INTO "languageNames" VALUES(7374,'nb','sc','sardisk');
INSERT INTO "languageNames" VALUES(7375,'nb','scn','siciliansk');
INSERT INTO "languageNames" VALUES(7376,'nb','sco','skotsk');
INSERT INTO "languageNames" VALUES(7377,'nb','sd','sindhi');
INSERT INTO "languageNames" VALUES(7378,'nb','se','nordsamisk');
INSERT INTO "languageNames" VALUES(7379,'nb','sh','serbokroatisk');
INSERT INTO "languageNames" VALUES(7380,'nb','si','singalesisk');
INSERT INTO "languageNames" VALUES(7381,'nb','sk','slovakisk');
INSERT INTO "languageNames" VALUES(7382,'nb','sl','slovensk');
INSERT INTO "languageNames" VALUES(7383,'nb','sma','sørsamisk');
INSERT INTO "languageNames" VALUES(7384,'nb','smj','lulesamisk');
INSERT INTO "languageNames" VALUES(7385,'nb','smn','enaresamisk');
INSERT INTO "languageNames" VALUES(7386,'nb','sq','albansk');
INSERT INTO "languageNames" VALUES(7387,'nb','sr','serbisk');
INSERT INTO "languageNames" VALUES(7388,'nb','srn','sranan');
INSERT INTO "languageNames" VALUES(7389,'nb','ss','swati');
INSERT INTO "languageNames" VALUES(7390,'nb','sv','svensk');
INSERT INTO "languageNames" VALUES(7391,'nb','sw','swahili');
INSERT INTO "languageNames" VALUES(7392,'nb','ta','tamil');
INSERT INTO "languageNames" VALUES(7393,'nb','te','telugu');
INSERT INTO "languageNames" VALUES(7394,'nb','tet','tetum');
INSERT INTO "languageNames" VALUES(7395,'nb','tg','tadsjikisk');
INSERT INTO "languageNames" VALUES(7396,'nb','th','thai');
INSERT INTO "languageNames" VALUES(7397,'nb','tk','turkmensk');
INSERT INTO "languageNames" VALUES(7398,'nb','tl','tagalog');
INSERT INTO "languageNames" VALUES(7399,'nb','tr','tyrkisk');
INSERT INTO "languageNames" VALUES(7400,'nb','tt','tatarisk');
INSERT INTO "languageNames" VALUES(7401,'nb','tyv','tuvinsk');
INSERT INTO "languageNames" VALUES(7402,'nb','udm','udmurtisk');
INSERT INTO "languageNames" VALUES(7403,'nb','ug','uigurisk');
INSERT INTO "languageNames" VALUES(7404,'nb','uk','ukrainsk');
INSERT INTO "languageNames" VALUES(7405,'nb','ur','urdu');
INSERT INTO "languageNames" VALUES(7406,'nb','uz','usbekisk');
INSERT INTO "languageNames" VALUES(7407,'nb','vi','vietnamesisk');
INSERT INTO "languageNames" VALUES(7408,'nb','vro','sørestisk');
INSERT INTO "languageNames" VALUES(7409,'nb','wal','wolaytta');
INSERT INTO "languageNames" VALUES(7410,'nb','xh','xhosa');
INSERT INTO "languageNames" VALUES(7411,'nb','yi','jiddisk');
INSERT INTO "languageNames" VALUES(7412,'nb','yo','joruba');
INSERT INTO "languageNames" VALUES(7413,'nb','zh','kinesisk');
INSERT INTO "languageNames" VALUES(7414,'nb','zu','zulu');
INSERT INTO "languageNames" VALUES(7415,'az','af','afrikaans');
INSERT INTO "languageNames" VALUES(7416,'az','alt','cənubi altay');
INSERT INTO "languageNames" VALUES(7417,'az','an','araqon');
INSERT INTO "languageNames" VALUES(7418,'az','ar','ərəb');
INSERT INTO "languageNames" VALUES(7419,'az','as','assam');
INSERT INTO "languageNames" VALUES(7420,'az','ast','asturiya');
INSERT INTO "languageNames" VALUES(7421,'az','av','avar');
INSERT INTO "languageNames" VALUES(7423,'az','az','azəri');
INSERT INTO "languageNames" VALUES(7424,'az','ba','başqırd');
INSERT INTO "languageNames" VALUES(7425,'az','be','belarus');
INSERT INTO "languageNames" VALUES(7426,'az','bg','bolqar');
INSERT INTO "languageNames" VALUES(7427,'az','bi','bislama');
INSERT INTO "languageNames" VALUES(7428,'az','bn','benqal');
INSERT INTO "languageNames" VALUES(7429,'az','br','breton');
INSERT INTO "languageNames" VALUES(7430,'az','bs','bosniya');
INSERT INTO "languageNames" VALUES(7431,'az','bua','buryat');
INSERT INTO "languageNames" VALUES(7432,'az','ca','katalan');
INSERT INTO "languageNames" VALUES(7433,'az','ceb','sebuan');
INSERT INTO "languageNames" VALUES(7434,'az','chm','mari');
INSERT INTO "languageNames" VALUES(7435,'az','ckb','soran');
INSERT INTO "languageNames" VALUES(7436,'az','co','korsika');
INSERT INTO "languageNames" VALUES(7437,'az','crh','krım türkcəsi');
INSERT INTO "languageNames" VALUES(7438,'az','cs','çex');
INSERT INTO "languageNames" VALUES(7439,'az','csb','kaşubyan');
INSERT INTO "languageNames" VALUES(7440,'az','cu','slavyan');
INSERT INTO "languageNames" VALUES(7441,'az','cv','çuvaş');
INSERT INTO "languageNames" VALUES(7442,'az','cy','uels');
INSERT INTO "languageNames" VALUES(7443,'az','da','danimarka');
INSERT INTO "languageNames" VALUES(7444,'az','dar','darqva');
INSERT INTO "languageNames" VALUES(7445,'az','de','alman');
INSERT INTO "languageNames" VALUES(7446,'az','dsb','aşağı sorb');
INSERT INTO "languageNames" VALUES(7447,'az','el','yunan');
INSERT INTO "languageNames" VALUES(7448,'az','en','ingilis');
INSERT INTO "languageNames" VALUES(7449,'az','eo','esperanto');
INSERT INTO "languageNames" VALUES(7450,'az','es','ispan');
INSERT INTO "languageNames" VALUES(7451,'az','et','eston');
INSERT INTO "languageNames" VALUES(7452,'az','eu','bask');
INSERT INTO "languageNames" VALUES(7453,'az','fa','fars');
INSERT INTO "languageNames" VALUES(7454,'az','fi','fin');
INSERT INTO "languageNames" VALUES(7455,'az','fo','farer');
INSERT INTO "languageNames" VALUES(7456,'az','fr','fransız');
INSERT INTO "languageNames" VALUES(7457,'az','fy','qərbi friz');
INSERT INTO "languageNames" VALUES(7458,'az','ga','irland');
INSERT INTO "languageNames" VALUES(7459,'az','gag','qaqauz');
INSERT INTO "languageNames" VALUES(7460,'az','gd','Şotlandiya keltcəsi');
INSERT INTO "languageNames" VALUES(7461,'az','gl','qalisiya');
INSERT INTO "languageNames" VALUES(7462,'az','gn','quarani');
INSERT INTO "languageNames" VALUES(7463,'az','gu','qucarat');
INSERT INTO "languageNames" VALUES(7464,'az','gv','manks');
INSERT INTO "languageNames" VALUES(7465,'az','ha','hausa');
INSERT INTO "languageNames" VALUES(7466,'az','haw','havay');
INSERT INTO "languageNames" VALUES(7467,'az','he','ivrit');
INSERT INTO "languageNames" VALUES(7468,'az','hi','hind');
INSERT INTO "languageNames" VALUES(7469,'az','hr','xorvat');
INSERT INTO "languageNames" VALUES(7470,'az','hsb','yuxarı sorb');
INSERT INTO "languageNames" VALUES(7471,'az','ht','haiti kreol');
INSERT INTO "languageNames" VALUES(7472,'az','hu','macar');
INSERT INTO "languageNames" VALUES(7473,'az','hy','erməni');
INSERT INTO "languageNames" VALUES(7474,'az','ia','interlinqua');
INSERT INTO "languageNames" VALUES(7475,'az','id','indoneziya');
INSERT INTO "languageNames" VALUES(7476,'az','ig','iqbo');
INSERT INTO "languageNames" VALUES(7477,'az','is','island');
INSERT INTO "languageNames" VALUES(7478,'az','it','italyan');
INSERT INTO "languageNames" VALUES(7479,'az','ka','gürcü');
INSERT INTO "languageNames" VALUES(7480,'az','kaa','qaraqalpaq');
INSERT INTO "languageNames" VALUES(7481,'az','kk','qazax');
INSERT INTO "languageNames" VALUES(7482,'az','ko','koreya');
INSERT INTO "languageNames" VALUES(7483,'az','krc','qaraçay-balkar');
INSERT INTO "languageNames" VALUES(7484,'az','krl','karel');
INSERT INTO "languageNames" VALUES(7485,'az','ks','kəşmir');
INSERT INTO "languageNames" VALUES(7486,'az','kum','kumık');
INSERT INTO "languageNames" VALUES(7487,'az','kv','komi');
INSERT INTO "languageNames" VALUES(7488,'az','ky','qırğız');
INSERT INTO "languageNames" VALUES(7489,'az','la','latın');
INSERT INTO "languageNames" VALUES(7490,'az','lb','lüksemburq');
INSERT INTO "languageNames" VALUES(7491,'az','lg','qanda');
INSERT INTO "languageNames" VALUES(7492,'az','ln','linqala');
INSERT INTO "languageNames" VALUES(7493,'az','lo','laos');
INSERT INTO "languageNames" VALUES(7494,'az','lt','litva');
INSERT INTO "languageNames" VALUES(7495,'az','lv','latış');
INSERT INTO "languageNames" VALUES(7496,'az','mdf','mokşa');
INSERT INTO "languageNames" VALUES(7497,'az','mfe','morisien');
INSERT INTO "languageNames" VALUES(7498,'az','mk','makedon');
INSERT INTO "languageNames" VALUES(7499,'az','ml','malayalam');
INSERT INTO "languageNames" VALUES(7500,'az','mr','marathi');
INSERT INTO "languageNames" VALUES(7501,'az','ms','malay');
INSERT INTO "languageNames" VALUES(7502,'az','mt','malta');
INSERT INTO "languageNames" VALUES(7503,'az','myv','erzya');
INSERT INTO "languageNames" VALUES(7504,'az','nap','neapolitan');
INSERT INTO "languageNames" VALUES(7505,'az','nb','bokmal norveç');
INSERT INTO "languageNames" VALUES(7506,'az','ne','nepal');
INSERT INTO "languageNames" VALUES(7507,'az','nl','holland');
INSERT INTO "languageNames" VALUES(7508,'az','nn','nünorsk norveç');
INSERT INTO "languageNames" VALUES(7509,'az','no','norveç');
INSERT INTO "languageNames" VALUES(7510,'az','nog','noqay');
INSERT INTO "languageNames" VALUES(7511,'az','oc','oksitan');
INSERT INTO "languageNames" VALUES(7512,'az','os','osetin');
INSERT INTO "languageNames" VALUES(7513,'az','ota','osman');
INSERT INTO "languageNames" VALUES(7514,'az','pa','pəncab');
INSERT INTO "languageNames" VALUES(7515,'az','pl','polyak');
INSERT INTO "languageNames" VALUES(7516,'az','pt','portuqal');
INSERT INTO "languageNames" VALUES(7517,'az','rm','romanş');
INSERT INTO "languageNames" VALUES(7518,'az','rn','rundi');
INSERT INTO "languageNames" VALUES(7519,'az','ro','rumın');
INSERT INTO "languageNames" VALUES(7520,'az','ru','rus');
INSERT INTO "languageNames" VALUES(7521,'az','rup','aroman');
INSERT INTO "languageNames" VALUES(7522,'az','sa','sanskrit');
INSERT INTO "languageNames" VALUES(7523,'az','sah','saxa');
INSERT INTO "languageNames" VALUES(7524,'az','sc','sardin');
INSERT INTO "languageNames" VALUES(7525,'az','scn','siciliya');
INSERT INTO "languageNames" VALUES(7526,'az','sco','skots');
INSERT INTO "languageNames" VALUES(7527,'az','sd','sindhi');
INSERT INTO "languageNames" VALUES(7528,'az','se','şimali sami');
INSERT INTO "languageNames" VALUES(7529,'az','sh','serb-xorvat');
INSERT INTO "languageNames" VALUES(7530,'az','si','sinhala');
INSERT INTO "languageNames" VALUES(7531,'az','sk','slovak');
INSERT INTO "languageNames" VALUES(7532,'az','sl','sloven');
INSERT INTO "languageNames" VALUES(7533,'az','sma','cənubi sami');
INSERT INTO "languageNames" VALUES(7534,'az','smj','lule sami');
INSERT INTO "languageNames" VALUES(7535,'az','smn','inari sami');
INSERT INTO "languageNames" VALUES(7536,'az','sq','alban');
INSERT INTO "languageNames" VALUES(7537,'az','sr','serb');
INSERT INTO "languageNames" VALUES(7538,'az','srn','sranan tonqo');
INSERT INTO "languageNames" VALUES(7539,'az','ss','svati');
INSERT INTO "languageNames" VALUES(7540,'az','sv','isveç');
INSERT INTO "languageNames" VALUES(7541,'az','sw','suahili');
INSERT INTO "languageNames" VALUES(7542,'az','ta','tamil');
INSERT INTO "languageNames" VALUES(7543,'az','te','teluqu');
INSERT INTO "languageNames" VALUES(7544,'az','tet','tetum');
INSERT INTO "languageNames" VALUES(7545,'az','tg','tacik');
INSERT INTO "languageNames" VALUES(7546,'az','th','tay');
INSERT INTO "languageNames" VALUES(7547,'az','tk','türkmən');
INSERT INTO "languageNames" VALUES(7548,'az','tl','taqaloq');
INSERT INTO "languageNames" VALUES(7549,'az','tr','türk');
INSERT INTO "languageNames" VALUES(7550,'az','tt','tatar');
INSERT INTO "languageNames" VALUES(7551,'az','tyv','tuvinyan');
INSERT INTO "languageNames" VALUES(7552,'az','udm','udmurt');
INSERT INTO "languageNames" VALUES(7553,'az','ug','uyğur');
INSERT INTO "languageNames" VALUES(7554,'az','uk','ukrayna');
INSERT INTO "languageNames" VALUES(7555,'az','ur','urdu');
INSERT INTO "languageNames" VALUES(7556,'az','uz','özbək');
INSERT INTO "languageNames" VALUES(7557,'az','vi','vyetnam');
INSERT INTO "languageNames" VALUES(7558,'az','wal','valamo');
INSERT INTO "languageNames" VALUES(7559,'az','xh','xosa');
INSERT INTO "languageNames" VALUES(7560,'az','yi','idiş');
INSERT INTO "languageNames" VALUES(7561,'az','yo','yoruba');
INSERT INTO "languageNames" VALUES(7562,'az','zh','çin');
INSERT INTO "languageNames" VALUES(7563,'az','zu','zulu');
INSERT INTO "languageNames" VALUES(7564,'os','af','африкаанс');
INSERT INTO "languageNames" VALUES(7565,'os','ar','араббаг');
INSERT INTO "languageNames" VALUES(7566,'os','av','авайраг');
INSERT INTO "languageNames" VALUES(7567,'os','az','тӕтӕйраг');
INSERT INTO "languageNames" VALUES(7568,'os','ba','башкираг');
INSERT INTO "languageNames" VALUES(7569,'os','bg','болгайраг');
INSERT INTO "languageNames" VALUES(7570,'os','bs','босниаг');
INSERT INTO "languageNames" VALUES(7571,'os','bua','бурятаг');
INSERT INTO "languageNames" VALUES(7572,'os','ca','каталайнаг');
INSERT INTO "languageNames" VALUES(7573,'os','cs','чехаг');
INSERT INTO "languageNames" VALUES(7574,'os','cv','чувашаг');
INSERT INTO "languageNames" VALUES(7575,'os','da','даниаг');
INSERT INTO "languageNames" VALUES(7576,'os','de','немыцаг');
INSERT INTO "languageNames" VALUES(7577,'os','el','бердзейнаг');
INSERT INTO "languageNames" VALUES(7578,'os','en','англисаг');
INSERT INTO "languageNames" VALUES(7579,'os','eo','есперанто');
INSERT INTO "languageNames" VALUES(7580,'os','es','испайнаг');
INSERT INTO "languageNames" VALUES(7581,'os','et','естойнаг');
INSERT INTO "languageNames" VALUES(7582,'os','eu','баскаг');
INSERT INTO "languageNames" VALUES(7583,'os','fa','персайнаг');
INSERT INTO "languageNames" VALUES(7584,'os','fi','финнаг');
INSERT INTO "languageNames" VALUES(7585,'os','fo','фарераг');
INSERT INTO "languageNames" VALUES(7586,'os','fr','францаг');
INSERT INTO "languageNames" VALUES(7587,'os','ga','ирландиаг');
INSERT INTO "languageNames" VALUES(7588,'os','he','уираг');
INSERT INTO "languageNames" VALUES(7589,'os','hr','хорватаг');
INSERT INTO "languageNames" VALUES(7590,'os','hu','венгериаг');
INSERT INTO "languageNames" VALUES(7591,'os','hy','сомихаг');
INSERT INTO "languageNames" VALUES(7592,'os','it','италиаг');
INSERT INTO "languageNames" VALUES(7593,'os','ka','гуырдзиаг');
INSERT INTO "languageNames" VALUES(7594,'os','krc','бӕлхъӕрон');
INSERT INTO "languageNames" VALUES(7595,'os','kum','хъуымыхъхъаг');
INSERT INTO "languageNames" VALUES(7596,'os','la','латинаг');
INSERT INTO "languageNames" VALUES(7597,'os','mk','мӕчъидон');
INSERT INTO "languageNames" VALUES(7598,'os','os','ирон');
INSERT INTO "languageNames" VALUES(7599,'os','pt','португалиаг');
INSERT INTO "languageNames" VALUES(7600,'os','ru','уырыссаг');
INSERT INTO "languageNames" VALUES(7601,'os','zh','китайаг');
INSERT INTO "languageNames" VALUES(7602,'fr','af','afrikaans');
INSERT INTO "languageNames" VALUES(7603,'fr','alt','altaï du Sud');
INSERT INTO "languageNames" VALUES(7604,'fr','an','aragonais');
INSERT INTO "languageNames" VALUES(7605,'fr','ar','arabe');
INSERT INTO "languageNames" VALUES(7606,'fr','as','assamais');
INSERT INTO "languageNames" VALUES(7607,'fr','ast','asturien');
INSERT INTO "languageNames" VALUES(7608,'fr','av','avar');
INSERT INTO "languageNames" VALUES(7610,'fr','az','azéri');
INSERT INTO "languageNames" VALUES(7611,'fr','ba','bachkir');
INSERT INTO "languageNames" VALUES(7612,'fr','be','biélorusse');
INSERT INTO "languageNames" VALUES(7613,'fr','bg','bulgare');
INSERT INTO "languageNames" VALUES(7614,'fr','bi','bichelamar');
INSERT INTO "languageNames" VALUES(7615,'fr','bn','bengali');
INSERT INTO "languageNames" VALUES(7616,'fr','br','breton');
INSERT INTO "languageNames" VALUES(7617,'fr','bs','bosniaque');
INSERT INTO "languageNames" VALUES(7618,'fr','bua','bouriate');
INSERT INTO "languageNames" VALUES(7619,'fr','byv','médumba');
INSERT INTO "languageNames" VALUES(7620,'fr','ca','catalan');
INSERT INTO "languageNames" VALUES(7621,'fr','ceb','cebuano');
INSERT INTO "languageNames" VALUES(7622,'fr','chm','mari');
INSERT INTO "languageNames" VALUES(7623,'fr','ckb','sorani');
INSERT INTO "languageNames" VALUES(7624,'fr','co','corse');
INSERT INTO "languageNames" VALUES(7625,'fr','crh','turc de Crimée');
INSERT INTO "languageNames" VALUES(7626,'fr','cs','tchèque');
INSERT INTO "languageNames" VALUES(7627,'fr','csb','kachoube');
INSERT INTO "languageNames" VALUES(7628,'fr','cu','slavon d’église');
INSERT INTO "languageNames" VALUES(7629,'fr','cv','tchouvache');
INSERT INTO "languageNames" VALUES(7630,'fr','cy','gallois');
INSERT INTO "languageNames" VALUES(7631,'fr','da','danois');
INSERT INTO "languageNames" VALUES(7632,'fr','dar','dargwa');
INSERT INTO "languageNames" VALUES(7633,'fr','de','allemand');
INSERT INTO "languageNames" VALUES(7634,'fr','dsb','bas-sorabe');
INSERT INTO "languageNames" VALUES(7635,'fr','el','grec');
INSERT INTO "languageNames" VALUES(7636,'fr','en','anglais');
INSERT INTO "languageNames" VALUES(7637,'fr','eo','espéranto');
INSERT INTO "languageNames" VALUES(7638,'fr','es','espagnol');
INSERT INTO "languageNames" VALUES(7639,'fr','et','estonien');
INSERT INTO "languageNames" VALUES(7640,'fr','eu','basque');
INSERT INTO "languageNames" VALUES(7641,'fr','fa','persan');
INSERT INTO "languageNames" VALUES(7642,'fr','fi','finnois');
INSERT INTO "languageNames" VALUES(7643,'fr','fo','féroïen');
INSERT INTO "languageNames" VALUES(7644,'fr','fr','français');
INSERT INTO "languageNames" VALUES(7645,'fr','fy','frison occidental');
INSERT INTO "languageNames" VALUES(7646,'fr','ga','irlandais');
INSERT INTO "languageNames" VALUES(7647,'fr','gag','gagaouze');
INSERT INTO "languageNames" VALUES(7648,'fr','gd','gaélique écossais');
INSERT INTO "languageNames" VALUES(7649,'fr','gl','galicien');
INSERT INTO "languageNames" VALUES(7650,'fr','glk','gilaki');
INSERT INTO "languageNames" VALUES(7651,'fr','gn','guarani');
INSERT INTO "languageNames" VALUES(7652,'fr','gu','goudjerati');
INSERT INTO "languageNames" VALUES(7653,'fr','guc','wayuu');
INSERT INTO "languageNames" VALUES(7654,'fr','gv','mannois');
INSERT INTO "languageNames" VALUES(7655,'fr','ha','haoussa');
INSERT INTO "languageNames" VALUES(7656,'fr','haw','hawaïen');
INSERT INTO "languageNames" VALUES(7657,'fr','he','hébreu');
INSERT INTO "languageNames" VALUES(7658,'fr','hi','hindi');
INSERT INTO "languageNames" VALUES(7659,'fr','hr','croate');
INSERT INTO "languageNames" VALUES(7660,'fr','hsb','haut-sorabe');
INSERT INTO "languageNames" VALUES(7661,'fr','ht','créole haïtien');
INSERT INTO "languageNames" VALUES(7662,'fr','hu','hongrois');
INSERT INTO "languageNames" VALUES(7663,'fr','hy','arménien');
INSERT INTO "languageNames" VALUES(7664,'fr','ia','interlingua');
INSERT INTO "languageNames" VALUES(7665,'fr','id','indonésien');
INSERT INTO "languageNames" VALUES(7666,'fr','ig','igbo');
INSERT INTO "languageNames" VALUES(7667,'fr','is','islandais');
INSERT INTO "languageNames" VALUES(7668,'fr','it','italien');
INSERT INTO "languageNames" VALUES(7669,'fr','ka','géorgien');
INSERT INTO "languageNames" VALUES(7670,'fr','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(7671,'fr','kk','kazakh');
INSERT INTO "languageNames" VALUES(7672,'fr','ko','coréen');
INSERT INTO "languageNames" VALUES(7673,'fr','krc','karatchaï balkar');
INSERT INTO "languageNames" VALUES(7674,'fr','krl','carélien');
INSERT INTO "languageNames" VALUES(7675,'fr','ks','kashmiri');
INSERT INTO "languageNames" VALUES(7676,'fr','kum','koumyk');
INSERT INTO "languageNames" VALUES(7677,'fr','kv','komi');
INSERT INTO "languageNames" VALUES(7678,'fr','ky','kirghize');
INSERT INTO "languageNames" VALUES(7679,'fr','la','latin');
INSERT INTO "languageNames" VALUES(7680,'fr','lb','luxembourgeois');
INSERT INTO "languageNames" VALUES(7681,'fr','lg','ganda');
INSERT INTO "languageNames" VALUES(7682,'fr','liv','livonien');
INSERT INTO "languageNames" VALUES(7683,'fr','ln','lingala');
INSERT INTO "languageNames" VALUES(7684,'fr','lo','lao');
INSERT INTO "languageNames" VALUES(7685,'fr','lt','lituanien');
INSERT INTO "languageNames" VALUES(7686,'fr','lv','letton');
INSERT INTO "languageNames" VALUES(7687,'fr','mdf','moksa');
INSERT INTO "languageNames" VALUES(7688,'fr','mfe','créole mauricien');
INSERT INTO "languageNames" VALUES(7689,'fr','mk','macédonien');
INSERT INTO "languageNames" VALUES(7690,'fr','ml','malayalam');
INSERT INTO "languageNames" VALUES(7691,'fr','mr','marathe');
INSERT INTO "languageNames" VALUES(7692,'fr','mrj','mari occidental');
INSERT INTO "languageNames" VALUES(7693,'fr','ms','malais');
INSERT INTO "languageNames" VALUES(7694,'fr','mt','maltais');
INSERT INTO "languageNames" VALUES(7695,'fr','myv','erzya');
INSERT INTO "languageNames" VALUES(7696,'fr','nap','napolitain');
INSERT INTO "languageNames" VALUES(7697,'fr','nb','norvégien bokmål');
INSERT INTO "languageNames" VALUES(7698,'fr','ne','népalais');
INSERT INTO "languageNames" VALUES(7699,'fr','nl','néerlandais');
INSERT INTO "languageNames" VALUES(7700,'fr','nn','norvégien nynorsk');
INSERT INTO "languageNames" VALUES(7701,'fr','no','norvégien');
INSERT INTO "languageNames" VALUES(7702,'fr','nog','nogaï');
INSERT INTO "languageNames" VALUES(7703,'fr','oc','occitan');
INSERT INTO "languageNames" VALUES(7704,'fr','os','ossète');
INSERT INTO "languageNames" VALUES(7705,'fr','ota','turc ottoman');
INSERT INTO "languageNames" VALUES(7706,'fr','pa','pendjabi');
INSERT INTO "languageNames" VALUES(7707,'fr','pl','polonais');
INSERT INTO "languageNames" VALUES(7708,'fr','pt','portugais');
INSERT INTO "languageNames" VALUES(7709,'fr','rm','romanche');
INSERT INTO "languageNames" VALUES(7710,'fr','rn','roundi');
INSERT INTO "languageNames" VALUES(7711,'fr','ro','roumain');
INSERT INTO "languageNames" VALUES(7712,'fr','ru','russe');
INSERT INTO "languageNames" VALUES(7713,'fr','rup','valaque');
INSERT INTO "languageNames" VALUES(7714,'fr','sa','sanskrit');
INSERT INTO "languageNames" VALUES(7715,'fr','sah','iakoute');
INSERT INTO "languageNames" VALUES(7716,'fr','sc','sarde');
INSERT INTO "languageNames" VALUES(7717,'fr','scn','sicilien');
INSERT INTO "languageNames" VALUES(7718,'fr','sco','écossais');
INSERT INTO "languageNames" VALUES(7719,'fr','sd','sindhi');
INSERT INTO "languageNames" VALUES(7720,'fr','se','sami du Nord');
INSERT INTO "languageNames" VALUES(7721,'fr','sh','serbo-croate');
INSERT INTO "languageNames" VALUES(7722,'fr','si','cinghalais');
INSERT INTO "languageNames" VALUES(7723,'fr','sk','slovaque');
INSERT INTO "languageNames" VALUES(7724,'fr','sl','slovène');
INSERT INTO "languageNames" VALUES(7725,'fr','sma','sami du Sud');
INSERT INTO "languageNames" VALUES(7726,'fr','smj','sami de Lule');
INSERT INTO "languageNames" VALUES(7727,'fr','smn','sami d’Inari');
INSERT INTO "languageNames" VALUES(7728,'fr','sq','albanais');
INSERT INTO "languageNames" VALUES(7729,'fr','sr','serbe');
INSERT INTO "languageNames" VALUES(7730,'fr','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(7731,'fr','ss','swati');
INSERT INTO "languageNames" VALUES(7732,'fr','sv','suédois');
INSERT INTO "languageNames" VALUES(7733,'fr','sw','swahili');
INSERT INTO "languageNames" VALUES(7734,'fr','ta','tamoul');
INSERT INTO "languageNames" VALUES(7735,'fr','te','télougou');
INSERT INTO "languageNames" VALUES(7736,'fr','tet','tetum');
INSERT INTO "languageNames" VALUES(7737,'fr','tg','tadjik');
INSERT INTO "languageNames" VALUES(7738,'fr','th','thaï');
INSERT INTO "languageNames" VALUES(7739,'fr','tk','turkmène');
INSERT INTO "languageNames" VALUES(7740,'fr','tl','tagalog');
INSERT INTO "languageNames" VALUES(7741,'fr','tr','turc');
INSERT INTO "languageNames" VALUES(7742,'fr','tt','tatar');
INSERT INTO "languageNames" VALUES(7743,'fr','tyv','touvain');
INSERT INTO "languageNames" VALUES(7744,'fr','udm','oudmourte');
INSERT INTO "languageNames" VALUES(7746,'fr','ug','ouïgour');
INSERT INTO "languageNames" VALUES(7747,'fr','uk','ukrainien');
INSERT INTO "languageNames" VALUES(7748,'fr','ur','ourdou');
INSERT INTO "languageNames" VALUES(7749,'fr','uz','ouzbek');
INSERT INTO "languageNames" VALUES(7750,'fr','vi','vietnamien');
INSERT INTO "languageNames" VALUES(7751,'fr','vro','võro');
INSERT INTO "languageNames" VALUES(7752,'fr','wal','walamo');
INSERT INTO "languageNames" VALUES(7753,'fr','xh','xhosa');
INSERT INTO "languageNames" VALUES(7754,'fr','yi','yiddish');
INSERT INTO "languageNames" VALUES(7755,'fr','yo','yoruba');
INSERT INTO "languageNames" VALUES(7756,'fr','zh','chinois');
INSERT INTO "languageNames" VALUES(7757,'fr','zu','zoulou');
INSERT INTO "languageNames" VALUES(7758,'el','af','Αφρικάανς');
INSERT INTO "languageNames" VALUES(7759,'el','alt','Νότια Αλτάι');
INSERT INTO "languageNames" VALUES(7760,'el','an','Αραγονικά');
INSERT INTO "languageNames" VALUES(7761,'el','ar','Αραβικά');
INSERT INTO "languageNames" VALUES(7762,'el','as','Ασαμικά');
INSERT INTO "languageNames" VALUES(7763,'el','ast','Αστουριανά');
INSERT INTO "languageNames" VALUES(7764,'el','av','Αβαρικά');
INSERT INTO "languageNames" VALUES(7766,'el','az','Αζερικά');
INSERT INTO "languageNames" VALUES(7767,'el','ba','Μπασκίρ');
INSERT INTO "languageNames" VALUES(7768,'el','be','Λευκορωσικά');
INSERT INTO "languageNames" VALUES(7769,'el','bg','Βουλγαρικά');
INSERT INTO "languageNames" VALUES(7770,'el','bi','Μπισλάμα');
INSERT INTO "languageNames" VALUES(7771,'el','bn','Βεγγαλικά');
INSERT INTO "languageNames" VALUES(7772,'el','br','Βρετονικά');
INSERT INTO "languageNames" VALUES(7773,'el','bs','Βοσνιακά');
INSERT INTO "languageNames" VALUES(7774,'el','bua','Μπουριάτ');
INSERT INTO "languageNames" VALUES(7775,'el','byv','Μεντούμπα');
INSERT INTO "languageNames" VALUES(7776,'el','ca','Καταλανικά');
INSERT INTO "languageNames" VALUES(7777,'el','ceb','Σεμπουάνο');
INSERT INTO "languageNames" VALUES(7778,'el','chm','Μάρι');
INSERT INTO "languageNames" VALUES(7779,'el','ckb','Κουρδικά Σοράνι');
INSERT INTO "languageNames" VALUES(7780,'el','co','Κορσικανικά');
INSERT INTO "languageNames" VALUES(7781,'el','crh','Τουρκικά Κριμαίας');
INSERT INTO "languageNames" VALUES(7782,'el','cs','Τσεχικά');
INSERT INTO "languageNames" VALUES(7783,'el','csb','Κασούμπιαν');
INSERT INTO "languageNames" VALUES(7784,'el','cu','Εκκλησιαστικά Σλαβικά');
INSERT INTO "languageNames" VALUES(7785,'el','cv','Τσουβασικά');
INSERT INTO "languageNames" VALUES(7786,'el','cy','Ουαλικά');
INSERT INTO "languageNames" VALUES(7787,'el','da','Δανικά');
INSERT INTO "languageNames" VALUES(7788,'el','dar','Ντάργκουα');
INSERT INTO "languageNames" VALUES(7789,'el','de','Γερμανικά');
INSERT INTO "languageNames" VALUES(7790,'el','dsb','Κάτω Σορβικά');
INSERT INTO "languageNames" VALUES(7791,'el','el','Ελληνικά');
INSERT INTO "languageNames" VALUES(7792,'el','en','Αγγλικά');
INSERT INTO "languageNames" VALUES(7793,'el','eo','Εσπεράντο');
INSERT INTO "languageNames" VALUES(7794,'el','es','Ισπανικά');
INSERT INTO "languageNames" VALUES(7795,'el','et','Εσθονικά');
INSERT INTO "languageNames" VALUES(7796,'el','eu','Βασκικά');
INSERT INTO "languageNames" VALUES(7797,'el','fa','Περσικά');
INSERT INTO "languageNames" VALUES(7798,'el','fi','Φινλανδικά');
INSERT INTO "languageNames" VALUES(7799,'el','fo','Φεροϊκά');
INSERT INTO "languageNames" VALUES(7800,'el','fr','Γαλλικά');
INSERT INTO "languageNames" VALUES(7801,'el','fy','Δυτικά Φριζικά');
INSERT INTO "languageNames" VALUES(7802,'el','ga','Ιρλανδικά');
INSERT INTO "languageNames" VALUES(7803,'el','gag','Γκαγκάουζ');
INSERT INTO "languageNames" VALUES(7804,'el','gd','Σκωτικά Κελτικά');
INSERT INTO "languageNames" VALUES(7805,'el','gl','Γαλικιανά');
INSERT INTO "languageNames" VALUES(7806,'el','gn','Γκουαρανί');
INSERT INTO "languageNames" VALUES(7807,'el','gu','Γκουγιαράτι');
INSERT INTO "languageNames" VALUES(7808,'el','gv','Μανξ');
INSERT INTO "languageNames" VALUES(7809,'el','ha','Χάουσα');
INSERT INTO "languageNames" VALUES(7810,'el','haw','Χαβαϊκά');
INSERT INTO "languageNames" VALUES(7811,'el','he','Εβραϊκά');
INSERT INTO "languageNames" VALUES(7812,'el','hi','Χίντι');
INSERT INTO "languageNames" VALUES(7813,'el','hr','Κροατικά');
INSERT INTO "languageNames" VALUES(7814,'el','hsb','Άνω Σορβικά');
INSERT INTO "languageNames" VALUES(7815,'el','ht','Αϊτιανά');
INSERT INTO "languageNames" VALUES(7816,'el','hu','Ουγγρικά');
INSERT INTO "languageNames" VALUES(7817,'el','hy','Αρμενικά');
INSERT INTO "languageNames" VALUES(7818,'el','ia','Ιντερλίνγκουα');
INSERT INTO "languageNames" VALUES(7819,'el','id','Ινδονησιακά');
INSERT INTO "languageNames" VALUES(7820,'el','ig','Ίγκμπο');
INSERT INTO "languageNames" VALUES(7821,'el','is','Ισλανδικά');
INSERT INTO "languageNames" VALUES(7822,'el','it','Ιταλικά');
INSERT INTO "languageNames" VALUES(7823,'el','ka','Γεωργιανά');
INSERT INTO "languageNames" VALUES(7824,'el','kaa','Κάρα-Καλπάκ');
INSERT INTO "languageNames" VALUES(7825,'el','kk','Καζακικά');
INSERT INTO "languageNames" VALUES(7826,'el','ko','Κορεατικά');
INSERT INTO "languageNames" VALUES(7827,'el','krc','Καρατσάι-Μπαλκάρ');
INSERT INTO "languageNames" VALUES(7828,'el','krl','Καρελικά');
INSERT INTO "languageNames" VALUES(7829,'el','ks','Κασμιρικά');
INSERT INTO "languageNames" VALUES(7830,'el','kum','Κουμγιούκ');
INSERT INTO "languageNames" VALUES(7831,'el','kv','Κόμι');
INSERT INTO "languageNames" VALUES(7832,'el','ky','Κιργιζικά');
INSERT INTO "languageNames" VALUES(7833,'el','la','Λατινικά');
INSERT INTO "languageNames" VALUES(7834,'el','lb','Λουξεμβουργιανά');
INSERT INTO "languageNames" VALUES(7835,'el','lg','Γκάντα');
INSERT INTO "languageNames" VALUES(7836,'el','ln','Λινγκάλα');
INSERT INTO "languageNames" VALUES(7837,'el','lo','Λαοτινά');
INSERT INTO "languageNames" VALUES(7838,'el','lt','Λιθουανικά');
INSERT INTO "languageNames" VALUES(7839,'el','lv','Λετονικά');
INSERT INTO "languageNames" VALUES(7840,'el','mdf','Μόκσα');
INSERT INTO "languageNames" VALUES(7841,'el','mfe','Μορισιέν');
INSERT INTO "languageNames" VALUES(7842,'el','mk','Σλαβομακεδονικά');
INSERT INTO "languageNames" VALUES(7843,'el','ml','Μαλαγιαλαμικά');
INSERT INTO "languageNames" VALUES(7844,'el','mr','Μαραθικά');
INSERT INTO "languageNames" VALUES(7845,'el','ms','Μαλαισιανά');
INSERT INTO "languageNames" VALUES(7846,'el','mt','Μαλτεζικά');
INSERT INTO "languageNames" VALUES(7847,'el','myv','Έρζυα');
INSERT INTO "languageNames" VALUES(7848,'el','nap','Ναπολιτανικά');
INSERT INTO "languageNames" VALUES(7849,'el','nb','Νορβηγικά Μποκμάλ');
INSERT INTO "languageNames" VALUES(7850,'el','ne','Νεπαλικά');
INSERT INTO "languageNames" VALUES(7851,'el','nl','Ολλανδικά');
INSERT INTO "languageNames" VALUES(7852,'el','nn','Νορβηγικά Νινόρσκ');
INSERT INTO "languageNames" VALUES(7853,'el','no','Νορβηγικά');
INSERT INTO "languageNames" VALUES(7854,'el','nog','Νογκάι');
INSERT INTO "languageNames" VALUES(7855,'el','oc','Οξιτανικά');
INSERT INTO "languageNames" VALUES(7856,'el','os','Οσετικά');
INSERT INTO "languageNames" VALUES(7857,'el','ota','Οθωμανικά Τουρκικά');
INSERT INTO "languageNames" VALUES(7858,'el','pa','Παντζαπικά');
INSERT INTO "languageNames" VALUES(7859,'el','pl','Πολωνικά');
INSERT INTO "languageNames" VALUES(7860,'el','pt','Πορτογαλικά');
INSERT INTO "languageNames" VALUES(7861,'el','rm','Ρομανικά');
INSERT INTO "languageNames" VALUES(7862,'el','rn','Ρούντι');
INSERT INTO "languageNames" VALUES(7863,'el','ro','Ρουμανικά');
INSERT INTO "languageNames" VALUES(7864,'el','ru','Ρωσικά');
INSERT INTO "languageNames" VALUES(7865,'el','rup','Αρομανικά');
INSERT INTO "languageNames" VALUES(7866,'el','sa','Σανσκριτικά');
INSERT INTO "languageNames" VALUES(7867,'el','sah','Σαχά');
INSERT INTO "languageNames" VALUES(7868,'el','sc','Σαρδηνιακά');
INSERT INTO "languageNames" VALUES(7869,'el','scn','Σικελικά');
INSERT INTO "languageNames" VALUES(7870,'el','sco','Σκωτικά');
INSERT INTO "languageNames" VALUES(7871,'el','sd','Σίντι');
INSERT INTO "languageNames" VALUES(7872,'el','se','Βόρεια Σάμι');
INSERT INTO "languageNames" VALUES(7873,'el','sh','Σερβοκροατικά');
INSERT INTO "languageNames" VALUES(7874,'el','si','Σινχαλεζικά');
INSERT INTO "languageNames" VALUES(7875,'el','sk','Σλοβακικά');
INSERT INTO "languageNames" VALUES(7876,'el','sl','Σλοβενικά');
INSERT INTO "languageNames" VALUES(7877,'el','sma','Νότια Σάμι');
INSERT INTO "languageNames" VALUES(7878,'el','smj','Λούλε Σάμι');
INSERT INTO "languageNames" VALUES(7879,'el','smn','Ινάρι Σάμι');
INSERT INTO "languageNames" VALUES(7880,'el','sq','Αλβανικά');
INSERT INTO "languageNames" VALUES(7881,'el','sr','Σερβικά');
INSERT INTO "languageNames" VALUES(7882,'el','srn','Σρανάν Τόνγκο');
INSERT INTO "languageNames" VALUES(7883,'el','ss','Σουάτι');
INSERT INTO "languageNames" VALUES(7884,'el','sv','Σουηδικά');
INSERT INTO "languageNames" VALUES(7885,'el','sw','Σουαχίλι');
INSERT INTO "languageNames" VALUES(7886,'el','ta','Ταμιλικά');
INSERT INTO "languageNames" VALUES(7887,'el','te','Τελούγκου');
INSERT INTO "languageNames" VALUES(7888,'el','tet','Τέτουμ');
INSERT INTO "languageNames" VALUES(7889,'el','tg','Τατζικικά');
INSERT INTO "languageNames" VALUES(7890,'el','th','Ταϊλανδικά');
INSERT INTO "languageNames" VALUES(7891,'el','tk','Τουρκμενικά');
INSERT INTO "languageNames" VALUES(7892,'el','tl','Τάγκαλογκ');
INSERT INTO "languageNames" VALUES(7893,'el','tr','Τουρκικά');
INSERT INTO "languageNames" VALUES(7894,'el','tt','Ταταρικά');
INSERT INTO "languageNames" VALUES(7895,'el','tyv','Τουβινικά');
INSERT INTO "languageNames" VALUES(7896,'el','udm','Ουντμούρτ');
INSERT INTO "languageNames" VALUES(7898,'el','ug','Ουιγκούρ');
INSERT INTO "languageNames" VALUES(7899,'el','uk','Ουκρανικά');
INSERT INTO "languageNames" VALUES(7900,'el','ur','Ουρντού');
INSERT INTO "languageNames" VALUES(7901,'el','uz','Ουζμπεκικά');
INSERT INTO "languageNames" VALUES(7902,'el','vi','Βιετναμικά');
INSERT INTO "languageNames" VALUES(7903,'el','wal','Γουολάιτα');
INSERT INTO "languageNames" VALUES(7904,'el','xh','Κόσα');
INSERT INTO "languageNames" VALUES(7905,'el','yi','Γίντις');
INSERT INTO "languageNames" VALUES(7906,'el','yo','Γιορούμπα');
INSERT INTO "languageNames" VALUES(7907,'el','zh','Κινεζικά');
INSERT INTO "languageNames" VALUES(7908,'el','zu','Ζουλού');
INSERT INTO "languageNames" VALUES(7909,'nn','af','afrikaans');
INSERT INTO "languageNames" VALUES(7910,'nn','alt','sør-altaj');
INSERT INTO "languageNames" VALUES(7911,'nn','an','aragonsk');
INSERT INTO "languageNames" VALUES(7912,'nn','ar','arabisk');
INSERT INTO "languageNames" VALUES(7913,'nn','as','assamesisk');
INSERT INTO "languageNames" VALUES(7914,'nn','ast','asturisk');
INSERT INTO "languageNames" VALUES(7915,'nn','av','avarisk');
INSERT INTO "languageNames" VALUES(7916,'nn','az','aserbajdsjansk');
INSERT INTO "languageNames" VALUES(7917,'nn','ba','basjkirsk');
INSERT INTO "languageNames" VALUES(7918,'nn','be','kviterussisk');
INSERT INTO "languageNames" VALUES(7919,'nn','bg','bulgarsk');
INSERT INTO "languageNames" VALUES(7920,'nn','bi','bislama');
INSERT INTO "languageNames" VALUES(7921,'nn','bn','bengali');
INSERT INTO "languageNames" VALUES(7922,'nn','br','bretonsk');
INSERT INTO "languageNames" VALUES(7923,'nn','bs','bosnisk');
INSERT INTO "languageNames" VALUES(7924,'nn','bua','burjatisk');
INSERT INTO "languageNames" VALUES(7925,'nn','ca','katalansk');
INSERT INTO "languageNames" VALUES(7926,'nn','ceb','cebuano');
INSERT INTO "languageNames" VALUES(7927,'nn','chm','mari');
INSERT INTO "languageNames" VALUES(7928,'nn','ckb','sorani');
INSERT INTO "languageNames" VALUES(7929,'nn','co','korsikansk');
INSERT INTO "languageNames" VALUES(7930,'nn','crh','krimtatarisk');
INSERT INTO "languageNames" VALUES(7931,'nn','cs','tsjekkisk');
INSERT INTO "languageNames" VALUES(7932,'nn','csb','kasjubisk');
INSERT INTO "languageNames" VALUES(7933,'nn','cu','kyrkjeslavisk');
INSERT INTO "languageNames" VALUES(7934,'nn','cv','tsjuvansk');
INSERT INTO "languageNames" VALUES(7935,'nn','cy','walisisk');
INSERT INTO "languageNames" VALUES(7936,'nn','da','dansk');
INSERT INTO "languageNames" VALUES(7937,'nn','dar','dargwa');
INSERT INTO "languageNames" VALUES(7938,'nn','de','tysk');
INSERT INTO "languageNames" VALUES(7939,'nn','dsb','lågsorbisk');
INSERT INTO "languageNames" VALUES(7940,'nn','el','gresk');
INSERT INTO "languageNames" VALUES(7941,'nn','en','engelsk');
INSERT INTO "languageNames" VALUES(7942,'nn','eo','esperanto');
INSERT INTO "languageNames" VALUES(7943,'nn','es','spansk');
INSERT INTO "languageNames" VALUES(7944,'nn','et','estisk');
INSERT INTO "languageNames" VALUES(7945,'nn','eu','baskisk');
INSERT INTO "languageNames" VALUES(7946,'nn','fa','persisk');
INSERT INTO "languageNames" VALUES(7947,'nn','fi','finsk');
INSERT INTO "languageNames" VALUES(7948,'nn','fo','færøysk');
INSERT INTO "languageNames" VALUES(7949,'nn','fr','fransk');
INSERT INTO "languageNames" VALUES(7950,'nn','fy','vestfrisisk');
INSERT INTO "languageNames" VALUES(7951,'nn','ga','irsk');
INSERT INTO "languageNames" VALUES(7952,'nn','gd','skotsk-gælisk');
INSERT INTO "languageNames" VALUES(7953,'nn','gl','galicisk');
INSERT INTO "languageNames" VALUES(7954,'nn','gn','guarani');
INSERT INTO "languageNames" VALUES(7955,'nn','gu','gujarati');
INSERT INTO "languageNames" VALUES(7956,'nn','gv','manx');
INSERT INTO "languageNames" VALUES(7957,'nn','ha','hausa');
INSERT INTO "languageNames" VALUES(7958,'nn','haw','hawaiisk');
INSERT INTO "languageNames" VALUES(7959,'nn','he','hebraisk');
INSERT INTO "languageNames" VALUES(7960,'nn','hi','hindi');
INSERT INTO "languageNames" VALUES(7961,'nn','hr','kroatisk');
INSERT INTO "languageNames" VALUES(7962,'nn','hsb','høgsorbisk');
INSERT INTO "languageNames" VALUES(7963,'nn','ht','haitisk');
INSERT INTO "languageNames" VALUES(7964,'nn','hu','ungarsk');
INSERT INTO "languageNames" VALUES(7965,'nn','hy','armensk');
INSERT INTO "languageNames" VALUES(7966,'nn','ia','interlingua');
INSERT INTO "languageNames" VALUES(7967,'nn','id','indonesisk');
INSERT INTO "languageNames" VALUES(7968,'nn','ig','ibo');
INSERT INTO "languageNames" VALUES(7969,'nn','is','islandsk');
INSERT INTO "languageNames" VALUES(7970,'nn','it','italiensk');
INSERT INTO "languageNames" VALUES(7971,'nn','ka','georgisk');
INSERT INTO "languageNames" VALUES(7972,'nn','kaa','karakalpakisk');
INSERT INTO "languageNames" VALUES(7973,'nn','kk','kasakhisk');
INSERT INTO "languageNames" VALUES(7974,'nn','ko','koreansk');
INSERT INTO "languageNames" VALUES(7975,'nn','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(7976,'nn','krl','karelsk');
INSERT INTO "languageNames" VALUES(7977,'nn','ks','kasjmiri');
INSERT INTO "languageNames" VALUES(7978,'nn','kum','kumyk');
INSERT INTO "languageNames" VALUES(7979,'nn','kv','komi');
INSERT INTO "languageNames" VALUES(7980,'nn','ky','kirgisisk');
INSERT INTO "languageNames" VALUES(7981,'nn','la','latin');
INSERT INTO "languageNames" VALUES(7982,'nn','lb','luxemburgsk');
INSERT INTO "languageNames" VALUES(7983,'nn','lg','ganda');
INSERT INTO "languageNames" VALUES(7984,'nn','ln','lingala');
INSERT INTO "languageNames" VALUES(7985,'nn','lo','laotisk');
INSERT INTO "languageNames" VALUES(7986,'nn','lt','litauisk');
INSERT INTO "languageNames" VALUES(7987,'nn','lv','latvisk');
INSERT INTO "languageNames" VALUES(7988,'nn','mdf','moksha');
INSERT INTO "languageNames" VALUES(7989,'nn','mfe','morisyen');
INSERT INTO "languageNames" VALUES(7990,'nn','mk','makedonsk');
INSERT INTO "languageNames" VALUES(7991,'nn','ml','malayalam');
INSERT INTO "languageNames" VALUES(7992,'nn','mr','marathi');
INSERT INTO "languageNames" VALUES(7993,'nn','ms','malayisk');
INSERT INTO "languageNames" VALUES(7994,'nn','mt','maltesisk');
INSERT INTO "languageNames" VALUES(7995,'nn','myv','erzia');
INSERT INTO "languageNames" VALUES(7996,'nn','nap','napolitansk');
INSERT INTO "languageNames" VALUES(7997,'nn','nb','bokmål');
INSERT INTO "languageNames" VALUES(7998,'nn','ne','nepalsk');
INSERT INTO "languageNames" VALUES(7999,'nn','nl','nederlandsk');
INSERT INTO "languageNames" VALUES(8000,'nn','nn','nynorsk');
INSERT INTO "languageNames" VALUES(8001,'nn','no','norsk');
INSERT INTO "languageNames" VALUES(8002,'nn','nog','nogai');
INSERT INTO "languageNames" VALUES(8003,'nn','oc','oksitansk');
INSERT INTO "languageNames" VALUES(8004,'nn','os','ossetisk');
INSERT INTO "languageNames" VALUES(8005,'nn','ota','ottomansk tyrkisk');
INSERT INTO "languageNames" VALUES(8006,'nn','pa','panjabi');
INSERT INTO "languageNames" VALUES(8007,'nn','pl','polsk');
INSERT INTO "languageNames" VALUES(8008,'nn','pt','portugisisk');
INSERT INTO "languageNames" VALUES(8009,'nn','rm','retoromansk');
INSERT INTO "languageNames" VALUES(8010,'nn','rn','rundi');
INSERT INTO "languageNames" VALUES(8011,'nn','ro','rumensk');
INSERT INTO "languageNames" VALUES(8012,'nn','ru','russisk');
INSERT INTO "languageNames" VALUES(8013,'nn','rup','arumensk');
INSERT INTO "languageNames" VALUES(8014,'nn','sa','sanskrit');
INSERT INTO "languageNames" VALUES(8015,'nn','sah','sakha');
INSERT INTO "languageNames" VALUES(8016,'nn','sc','sardinsk');
INSERT INTO "languageNames" VALUES(8017,'nn','scn','siciliansk');
INSERT INTO "languageNames" VALUES(8018,'nn','sco','skotsk');
INSERT INTO "languageNames" VALUES(8019,'nn','sd','sindhi');
INSERT INTO "languageNames" VALUES(8020,'nn','se','nordsamisk');
INSERT INTO "languageNames" VALUES(8021,'nn','sh','serbokroatisk');
INSERT INTO "languageNames" VALUES(8022,'nn','si','singalesisk');
INSERT INTO "languageNames" VALUES(8023,'nn','sk','slovakisk');
INSERT INTO "languageNames" VALUES(8024,'nn','sl','slovensk');
INSERT INTO "languageNames" VALUES(8025,'nn','sma','sørsamisk');
INSERT INTO "languageNames" VALUES(8026,'nn','smj','lulesamisk');
INSERT INTO "languageNames" VALUES(8027,'nn','smn','enaresamisk');
INSERT INTO "languageNames" VALUES(8028,'nn','sq','albansk');
INSERT INTO "languageNames" VALUES(8029,'nn','sr','serbisk');
INSERT INTO "languageNames" VALUES(8030,'nn','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(8031,'nn','ss','swati');
INSERT INTO "languageNames" VALUES(8032,'nn','sv','svensk');
INSERT INTO "languageNames" VALUES(8033,'nn','sw','swahili');
INSERT INTO "languageNames" VALUES(8034,'nn','ta','tamil');
INSERT INTO "languageNames" VALUES(8035,'nn','te','telugu');
INSERT INTO "languageNames" VALUES(8036,'nn','tet','tetum');
INSERT INTO "languageNames" VALUES(8037,'nn','tg','tadsjikisk');
INSERT INTO "languageNames" VALUES(8038,'nn','th','thai');
INSERT INTO "languageNames" VALUES(8039,'nn','tk','turkmensk');
INSERT INTO "languageNames" VALUES(8040,'nn','tl','tagalog');
INSERT INTO "languageNames" VALUES(8041,'nn','tr','tyrkisk');
INSERT INTO "languageNames" VALUES(8042,'nn','tt','tatarisk');
INSERT INTO "languageNames" VALUES(8043,'nn','tyv','tuvinisk');
INSERT INTO "languageNames" VALUES(8044,'nn','udm','udmurt');
INSERT INTO "languageNames" VALUES(8045,'nn','ug','uigurisk');
INSERT INTO "languageNames" VALUES(8046,'nn','uk','ukrainsk');
INSERT INTO "languageNames" VALUES(8047,'nn','ur','urdu');
INSERT INTO "languageNames" VALUES(8048,'nn','uz','usbekisk');
INSERT INTO "languageNames" VALUES(8049,'nn','vi','vietnamesisk');
INSERT INTO "languageNames" VALUES(8050,'nn','wal','wolaytta');
INSERT INTO "languageNames" VALUES(8051,'nn','xh','xhosa');
INSERT INTO "languageNames" VALUES(8052,'nn','yi','jiddisk');
INSERT INTO "languageNames" VALUES(8053,'nn','yo','joruba');
INSERT INTO "languageNames" VALUES(8054,'nn','zh','kinesisk');
INSERT INTO "languageNames" VALUES(8055,'nn','zu','zulu');
INSERT INTO "languageNames" VALUES(8056,'ms','af','Afrikaans');
INSERT INTO "languageNames" VALUES(8057,'ms','alt','Altai Selatan');
INSERT INTO "languageNames" VALUES(8058,'ms','an','Aragon');
INSERT INTO "languageNames" VALUES(8059,'ms','ar','Arab');
INSERT INTO "languageNames" VALUES(8060,'ms','as','Assam');
INSERT INTO "languageNames" VALUES(8061,'ms','ast','Asturia');
INSERT INTO "languageNames" VALUES(8062,'ms','av','Avaric');
INSERT INTO "languageNames" VALUES(8064,'ms','az','Azeri');
INSERT INTO "languageNames" VALUES(8065,'ms','ba','Bashkir');
INSERT INTO "languageNames" VALUES(8066,'ms','be','Belarus');
INSERT INTO "languageNames" VALUES(8067,'ms','bg','Bulgaria');
INSERT INTO "languageNames" VALUES(8068,'ms','bi','Bislama');
INSERT INTO "languageNames" VALUES(8069,'ms','bn','Benggala');
INSERT INTO "languageNames" VALUES(8070,'ms','br','Breton');
INSERT INTO "languageNames" VALUES(8071,'ms','bs','Bosnia');
INSERT INTO "languageNames" VALUES(8072,'ms','bua','Buriat');
INSERT INTO "languageNames" VALUES(8073,'ms','byv','Medumba');
INSERT INTO "languageNames" VALUES(8074,'ms','ca','Catalonia');
INSERT INTO "languageNames" VALUES(8075,'ms','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(8076,'ms','chm','Mari');
INSERT INTO "languageNames" VALUES(8077,'ms','ckb','Kurdi Sorani');
INSERT INTO "languageNames" VALUES(8078,'ms','co','Corsica');
INSERT INTO "languageNames" VALUES(8079,'ms','crh','Turki Krimea');
INSERT INTO "languageNames" VALUES(8080,'ms','cs','Czech');
INSERT INTO "languageNames" VALUES(8081,'ms','cu','Slavik Gereja');
INSERT INTO "languageNames" VALUES(8082,'ms','cv','Chuvash');
INSERT INTO "languageNames" VALUES(8083,'ms','cy','Wales');
INSERT INTO "languageNames" VALUES(8084,'ms','da','Denmark');
INSERT INTO "languageNames" VALUES(8085,'ms','dar','Dargwa');
INSERT INTO "languageNames" VALUES(8086,'ms','de','Jerman');
INSERT INTO "languageNames" VALUES(8087,'ms','dsb','Sorbian Rendah');
INSERT INTO "languageNames" VALUES(8088,'ms','el','Greek');
INSERT INTO "languageNames" VALUES(8089,'ms','en','Inggeris');
INSERT INTO "languageNames" VALUES(8090,'ms','eo','Esperanto');
INSERT INTO "languageNames" VALUES(8091,'ms','es','Sepanyol');
INSERT INTO "languageNames" VALUES(8092,'ms','et','Estonia');
INSERT INTO "languageNames" VALUES(8093,'ms','eu','Basque');
INSERT INTO "languageNames" VALUES(8094,'ms','fa','Parsi');
INSERT INTO "languageNames" VALUES(8095,'ms','fi','Finland');
INSERT INTO "languageNames" VALUES(8096,'ms','fo','Faroe');
INSERT INTO "languageNames" VALUES(8097,'ms','fr','Perancis');
INSERT INTO "languageNames" VALUES(8098,'ms','fy','Frisian Barat');
INSERT INTO "languageNames" VALUES(8099,'ms','ga','Ireland');
INSERT INTO "languageNames" VALUES(8100,'ms','gag','Gagauz');
INSERT INTO "languageNames" VALUES(8101,'ms','gd','Scots Gaelic');
INSERT INTO "languageNames" VALUES(8102,'ms','gl','Galicia');
INSERT INTO "languageNames" VALUES(8103,'ms','glk','Gilaki');
INSERT INTO "languageNames" VALUES(8104,'ms','gn','Guarani');
INSERT INTO "languageNames" VALUES(8105,'ms','gu','Gujerat');
INSERT INTO "languageNames" VALUES(8106,'ms','gv','Manx');
INSERT INTO "languageNames" VALUES(8107,'ms','ha','Hausa');
INSERT INTO "languageNames" VALUES(8108,'ms','haw','Hawaii');
INSERT INTO "languageNames" VALUES(8109,'ms','he','Ibrani');
INSERT INTO "languageNames" VALUES(8110,'ms','hi','Hindi');
INSERT INTO "languageNames" VALUES(8111,'ms','hr','Croatia');
INSERT INTO "languageNames" VALUES(8112,'ms','hsb','Sorbian Atas');
INSERT INTO "languageNames" VALUES(8113,'ms','ht','Haiti');
INSERT INTO "languageNames" VALUES(8114,'ms','hu','Hungary');
INSERT INTO "languageNames" VALUES(8115,'ms','hy','Armenia');
INSERT INTO "languageNames" VALUES(8116,'ms','ia','Interlingua');
INSERT INTO "languageNames" VALUES(8117,'ms','id','Indonesia');
INSERT INTO "languageNames" VALUES(8118,'ms','ig','Igbo');
INSERT INTO "languageNames" VALUES(8119,'ms','is','Iceland');
INSERT INTO "languageNames" VALUES(8120,'ms','it','Itali');
INSERT INTO "languageNames" VALUES(8121,'ms','ka','Georgia');
INSERT INTO "languageNames" VALUES(8122,'ms','kk','Kazakhstan');
INSERT INTO "languageNames" VALUES(8123,'ms','ko','Korea');
INSERT INTO "languageNames" VALUES(8124,'ms','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(8125,'ms','krl','Karelian');
INSERT INTO "languageNames" VALUES(8126,'ms','ks','Kashmir');
INSERT INTO "languageNames" VALUES(8127,'ms','kum','Kumyk');
INSERT INTO "languageNames" VALUES(8128,'ms','kv','Komi');
INSERT INTO "languageNames" VALUES(8129,'ms','ky','Kirghiz');
INSERT INTO "languageNames" VALUES(8130,'ms','la','Latin');
INSERT INTO "languageNames" VALUES(8131,'ms','lb','Luxembourg');
INSERT INTO "languageNames" VALUES(8132,'ms','lg','Ganda');
INSERT INTO "languageNames" VALUES(8133,'ms','ln','Lingala');
INSERT INTO "languageNames" VALUES(8134,'ms','lo','Laos');
INSERT INTO "languageNames" VALUES(8135,'ms','lt','Lithuania');
INSERT INTO "languageNames" VALUES(8136,'ms','lv','Latvia');
INSERT INTO "languageNames" VALUES(8137,'ms','mdf','Moksha');
INSERT INTO "languageNames" VALUES(8138,'ms','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(8139,'ms','mk','Macedonia');
INSERT INTO "languageNames" VALUES(8140,'ms','ml','Malayalam');
INSERT INTO "languageNames" VALUES(8141,'ms','mr','Marathi');
INSERT INTO "languageNames" VALUES(8142,'ms','ms','Melayu');
INSERT INTO "languageNames" VALUES(8143,'ms','mt','Malta');
INSERT INTO "languageNames" VALUES(8144,'ms','myv','Erzya');
INSERT INTO "languageNames" VALUES(8145,'ms','nap','Neapolitan');
INSERT INTO "languageNames" VALUES(8146,'ms','nb','Bokmål Norway');
INSERT INTO "languageNames" VALUES(8147,'ms','ne','Nepal');
INSERT INTO "languageNames" VALUES(8148,'ms','nl','Belanda');
INSERT INTO "languageNames" VALUES(8149,'ms','nn','Nynorsk Norway');
INSERT INTO "languageNames" VALUES(8150,'ms','no','Norway');
INSERT INTO "languageNames" VALUES(8151,'ms','nog','Nogai');
INSERT INTO "languageNames" VALUES(8152,'ms','oc','Occitania');
INSERT INTO "languageNames" VALUES(8153,'ms','os','Ossete');
INSERT INTO "languageNames" VALUES(8154,'ms','pa','Punjabi');
INSERT INTO "languageNames" VALUES(8155,'ms','pl','Poland');
INSERT INTO "languageNames" VALUES(8156,'ms','pt','Portugis');
INSERT INTO "languageNames" VALUES(8157,'ms','rm','Romansh');
INSERT INTO "languageNames" VALUES(8158,'ms','rn','Rundi');
INSERT INTO "languageNames" VALUES(8159,'ms','ro','Romania');
INSERT INTO "languageNames" VALUES(8160,'ms','ru','Rusia');
INSERT INTO "languageNames" VALUES(8161,'ms','rup','Aromanian');
INSERT INTO "languageNames" VALUES(8162,'ms','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(8163,'ms','sah','Sakha');
INSERT INTO "languageNames" VALUES(8164,'ms','sc','Sardinia');
INSERT INTO "languageNames" VALUES(8165,'ms','scn','Sicili');
INSERT INTO "languageNames" VALUES(8166,'ms','sco','Scots');
INSERT INTO "languageNames" VALUES(8167,'ms','sd','Sindhi');
INSERT INTO "languageNames" VALUES(8168,'ms','se','Sami Utara');
INSERT INTO "languageNames" VALUES(8169,'ms','sh','SerboCroatia');
INSERT INTO "languageNames" VALUES(8170,'ms','si','Sinhala');
INSERT INTO "languageNames" VALUES(8171,'ms','sk','Slovak');
INSERT INTO "languageNames" VALUES(8172,'ms','sl','Slovenia');
INSERT INTO "languageNames" VALUES(8173,'ms','sma','Sami Selatan');
INSERT INTO "languageNames" VALUES(8174,'ms','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(8175,'ms','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(8176,'ms','sq','Albania');
INSERT INTO "languageNames" VALUES(8177,'ms','sr','Serbia');
INSERT INTO "languageNames" VALUES(8178,'ms','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(8179,'ms','ss','Swati');
INSERT INTO "languageNames" VALUES(8180,'ms','sv','Sweden');
INSERT INTO "languageNames" VALUES(8181,'ms','sw','Swahili');
INSERT INTO "languageNames" VALUES(8182,'ms','ta','Tamil');
INSERT INTO "languageNames" VALUES(8183,'ms','te','Telugu');
INSERT INTO "languageNames" VALUES(8184,'ms','tet','Tetum');
INSERT INTO "languageNames" VALUES(8185,'ms','tg','Tajik');
INSERT INTO "languageNames" VALUES(8186,'ms','th','Thai');
INSERT INTO "languageNames" VALUES(8187,'ms','tk','Turkmen');
INSERT INTO "languageNames" VALUES(8188,'ms','tr','Turki');
INSERT INTO "languageNames" VALUES(8189,'ms','tt','Tatar');
INSERT INTO "languageNames" VALUES(8190,'ms','tyv','Tuvinian');
INSERT INTO "languageNames" VALUES(8191,'ms','udm','Udmurt');
INSERT INTO "languageNames" VALUES(8193,'ms','ug','Uighur');
INSERT INTO "languageNames" VALUES(8194,'ms','uk','Ukraine');
INSERT INTO "languageNames" VALUES(8195,'ms','ur','Urdu');
INSERT INTO "languageNames" VALUES(8196,'ms','uz','Uzbekistan');
INSERT INTO "languageNames" VALUES(8197,'ms','vi','Vietnam');
INSERT INTO "languageNames" VALUES(8198,'ms','wal','Wolaytta');
INSERT INTO "languageNames" VALUES(8199,'ms','xh','Xhosa');
INSERT INTO "languageNames" VALUES(8200,'ms','yi','Yiddish');
INSERT INTO "languageNames" VALUES(8201,'ms','yo','Yoruba');
INSERT INTO "languageNames" VALUES(8202,'ms','zh','Cina');
INSERT INTO "languageNames" VALUES(8203,'ms','zu','Zulu');
INSERT INTO "languageNames" VALUES(8204,'mt','af','Afrikans');
INSERT INTO "languageNames" VALUES(8205,'mt','alt','Altai tan-Nofsinhar');
INSERT INTO "languageNames" VALUES(8206,'mt','an','Aragoniż');
INSERT INTO "languageNames" VALUES(8207,'mt','ar','Għarbi');
INSERT INTO "languageNames" VALUES(8208,'mt','as','Assamiż');
INSERT INTO "languageNames" VALUES(8209,'mt','ast','Asturian');
INSERT INTO "languageNames" VALUES(8210,'mt','av','Avarik');
INSERT INTO "languageNames" VALUES(8212,'mt','az','Ażeri');
INSERT INTO "languageNames" VALUES(8213,'mt','ba','Bashkir');
INSERT INTO "languageNames" VALUES(8214,'mt','be','Belarussu');
INSERT INTO "languageNames" VALUES(8215,'mt','bg','Bulgaru');
INSERT INTO "languageNames" VALUES(8216,'mt','bi','Bislama');
INSERT INTO "languageNames" VALUES(8217,'mt','bn','Bengali');
INSERT INTO "languageNames" VALUES(8218,'mt','br','Breton');
INSERT INTO "languageNames" VALUES(8219,'mt','bs','Bożnijaku');
INSERT INTO "languageNames" VALUES(8220,'mt','bua','Burjat');
INSERT INTO "languageNames" VALUES(8221,'mt','ca','Katalan');
INSERT INTO "languageNames" VALUES(8222,'mt','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(8223,'mt','chm','Mari');
INSERT INTO "languageNames" VALUES(8224,'mt','ckb','Kurd Ċentrali');
INSERT INTO "languageNames" VALUES(8225,'mt','co','Korsiku');
INSERT INTO "languageNames" VALUES(8226,'mt','crh','Tork tal-Krimea');
INSERT INTO "languageNames" VALUES(8227,'mt','cs','Ċek');
INSERT INTO "languageNames" VALUES(8228,'mt','csb','Kashubian');
INSERT INTO "languageNames" VALUES(8229,'mt','cu','Slaviku tal-Knisja');
INSERT INTO "languageNames" VALUES(8230,'mt','cv','Chuvash');
INSERT INTO "languageNames" VALUES(8231,'mt','cy','Welsh');
INSERT INTO "languageNames" VALUES(8232,'mt','da','Daniż');
INSERT INTO "languageNames" VALUES(8233,'mt','dar','Dargwa');
INSERT INTO "languageNames" VALUES(8234,'mt','de','Ġermaniż');
INSERT INTO "languageNames" VALUES(8235,'mt','dsb','Sorbjan Komuni');
INSERT INTO "languageNames" VALUES(8236,'mt','el','Grieg');
INSERT INTO "languageNames" VALUES(8237,'mt','en','Ingliż');
INSERT INTO "languageNames" VALUES(8238,'mt','eo','Esperanto');
INSERT INTO "languageNames" VALUES(8239,'mt','es','Spanjol');
INSERT INTO "languageNames" VALUES(8240,'mt','et','Estonjan');
INSERT INTO "languageNames" VALUES(8241,'mt','eu','Bask');
INSERT INTO "languageNames" VALUES(8242,'mt','fa','Persjan');
INSERT INTO "languageNames" VALUES(8243,'mt','fi','Finlandiż');
INSERT INTO "languageNames" VALUES(8244,'mt','fo','Faroese');
INSERT INTO "languageNames" VALUES(8245,'mt','fr','Franċiż');
INSERT INTO "languageNames" VALUES(8246,'mt','fy','Frisian tal-Punent');
INSERT INTO "languageNames" VALUES(8247,'mt','ga','Irlandiż');
INSERT INTO "languageNames" VALUES(8248,'mt','gd','Galliku Skoċċiż');
INSERT INTO "languageNames" VALUES(8249,'mt','gl','Galiċjan');
INSERT INTO "languageNames" VALUES(8250,'mt','gn','Guarani');
INSERT INTO "languageNames" VALUES(8251,'mt','gu','Gujarati');
INSERT INTO "languageNames" VALUES(8252,'mt','gv','Manx');
INSERT INTO "languageNames" VALUES(8253,'mt','ha','Hausa');
INSERT INTO "languageNames" VALUES(8254,'mt','haw','Ħawajjan');
INSERT INTO "languageNames" VALUES(8255,'mt','he','Ebrajk');
INSERT INTO "languageNames" VALUES(8256,'mt','hi','Hindi');
INSERT INTO "languageNames" VALUES(8257,'mt','hr','Kroat');
INSERT INTO "languageNames" VALUES(8258,'mt','hsb','Sorbjan ta’ Fuq');
INSERT INTO "languageNames" VALUES(8259,'mt','ht','Creole ta’ Haiti');
INSERT INTO "languageNames" VALUES(8260,'mt','hu','Ungeriż');
INSERT INTO "languageNames" VALUES(8261,'mt','hy','Armen');
INSERT INTO "languageNames" VALUES(8262,'mt','ia','Interlingua');
INSERT INTO "languageNames" VALUES(8263,'mt','id','Indoneżjan');
INSERT INTO "languageNames" VALUES(8264,'mt','ig','Igbo');
INSERT INTO "languageNames" VALUES(8265,'mt','is','Iżlandiż');
INSERT INTO "languageNames" VALUES(8266,'mt','it','Taljan');
INSERT INTO "languageNames" VALUES(8267,'mt','ka','Ġorġjan');
INSERT INTO "languageNames" VALUES(8268,'mt','kaa','Kara-Kalpak');
INSERT INTO "languageNames" VALUES(8269,'mt','kk','Każak');
INSERT INTO "languageNames" VALUES(8270,'mt','ko','Korean');
INSERT INTO "languageNames" VALUES(8271,'mt','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(8272,'mt','krl','Kareljan');
INSERT INTO "languageNames" VALUES(8273,'mt','ks','Kashmiri');
INSERT INTO "languageNames" VALUES(8274,'mt','kum','Kumyk');
INSERT INTO "languageNames" VALUES(8275,'mt','kv','Komi');
INSERT INTO "languageNames" VALUES(8276,'mt','ky','Kirgiż');
INSERT INTO "languageNames" VALUES(8277,'mt','la','Latin');
INSERT INTO "languageNames" VALUES(8278,'mt','lb','Lussemburgiż');
INSERT INTO "languageNames" VALUES(8279,'mt','lg','Ganda');
INSERT INTO "languageNames" VALUES(8280,'mt','ln','Lingaljan');
INSERT INTO "languageNames" VALUES(8281,'mt','lo','Laosjan');
INSERT INTO "languageNames" VALUES(8282,'mt','lt','Litwan');
INSERT INTO "languageNames" VALUES(8283,'mt','lv','Latvjan');
INSERT INTO "languageNames" VALUES(8284,'mt','mdf','Moksha');
INSERT INTO "languageNames" VALUES(8285,'mt','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(8286,'mt','mk','Maċedonjan');
INSERT INTO "languageNames" VALUES(8287,'mt','ml','Malayalam');
INSERT INTO "languageNames" VALUES(8288,'mt','mr','Marathi');
INSERT INTO "languageNames" VALUES(8289,'mt','ms','Malay');
INSERT INTO "languageNames" VALUES(8290,'mt','mt','Malti');
INSERT INTO "languageNames" VALUES(8291,'mt','myv','Erzya');
INSERT INTO "languageNames" VALUES(8292,'mt','nap','Naplitan');
INSERT INTO "languageNames" VALUES(8293,'mt','nb','Bokmal Norveġiż');
INSERT INTO "languageNames" VALUES(8294,'mt','ne','Nepaliż');
INSERT INTO "languageNames" VALUES(8295,'mt','nl','Olandiż');
INSERT INTO "languageNames" VALUES(8296,'mt','nn','Ninorsk Norveġiż');
INSERT INTO "languageNames" VALUES(8297,'mt','no','Norveġiż');
INSERT INTO "languageNames" VALUES(8298,'mt','nog','Nogai');
INSERT INTO "languageNames" VALUES(8299,'mt','oc','Oċċitan');
INSERT INTO "languageNames" VALUES(8300,'mt','os','Ossettiku');
INSERT INTO "languageNames" VALUES(8301,'mt','ota','Tork Ottoman');
INSERT INTO "languageNames" VALUES(8302,'mt','pa','Punjabi');
INSERT INTO "languageNames" VALUES(8303,'mt','pl','Pollakk');
INSERT INTO "languageNames" VALUES(8304,'mt','pt','Portugiż');
INSERT INTO "languageNames" VALUES(8305,'mt','rm','Romanz');
INSERT INTO "languageNames" VALUES(8306,'mt','rn','Rundi');
INSERT INTO "languageNames" VALUES(8307,'mt','ro','Rumen');
INSERT INTO "languageNames" VALUES(8308,'mt','ru','Russu');
INSERT INTO "languageNames" VALUES(8309,'mt','rup','Aromanjan');
INSERT INTO "languageNames" VALUES(8310,'mt','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(8311,'mt','sah','Sakha');
INSERT INTO "languageNames" VALUES(8312,'mt','sc','Sardinjan');
INSERT INTO "languageNames" VALUES(8313,'mt','scn','Sqalli');
INSERT INTO "languageNames" VALUES(8314,'mt','sco','Skoċċiż');
INSERT INTO "languageNames" VALUES(8315,'mt','sd','Sindhi');
INSERT INTO "languageNames" VALUES(8316,'mt','se','Sami tat-Tramuntana');
INSERT INTO "languageNames" VALUES(8317,'mt','sh','Serbo-Kroat');
INSERT INTO "languageNames" VALUES(8318,'mt','si','Sinhala');
INSERT INTO "languageNames" VALUES(8319,'mt','sk','Slovakk');
INSERT INTO "languageNames" VALUES(8320,'mt','sl','Sloven');
INSERT INTO "languageNames" VALUES(8321,'mt','sma','Sami tan-Nofsinhar');
INSERT INTO "languageNames" VALUES(8322,'mt','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(8323,'mt','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(8324,'mt','sq','Albaniż');
INSERT INTO "languageNames" VALUES(8325,'mt','sr','Serb');
INSERT INTO "languageNames" VALUES(8326,'mt','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(8327,'mt','ss','Swati');
INSERT INTO "languageNames" VALUES(8328,'mt','sv','Żvediż');
INSERT INTO "languageNames" VALUES(8329,'mt','sw','Swahili');
INSERT INTO "languageNames" VALUES(8330,'mt','ta','Tamil');
INSERT INTO "languageNames" VALUES(8331,'mt','te','Telugu');
INSERT INTO "languageNames" VALUES(8332,'mt','tet','Tetum');
INSERT INTO "languageNames" VALUES(8333,'mt','tg','Tajik');
INSERT INTO "languageNames" VALUES(8334,'mt','th','Tajlandiż');
INSERT INTO "languageNames" VALUES(8335,'mt','tk','Turkmeni');
INSERT INTO "languageNames" VALUES(8336,'mt','tl','Tagalog');
INSERT INTO "languageNames" VALUES(8337,'mt','tr','Tork');
INSERT INTO "languageNames" VALUES(8338,'mt','tt','Tatar');
INSERT INTO "languageNames" VALUES(8339,'mt','tyv','Tuvinjan');
INSERT INTO "languageNames" VALUES(8340,'mt','udm','Udmurt');
INSERT INTO "languageNames" VALUES(8341,'mt','ug','Uyghur');
INSERT INTO "languageNames" VALUES(8342,'mt','uk','Ukren');
INSERT INTO "languageNames" VALUES(8343,'mt','ur','Urdu');
INSERT INTO "languageNames" VALUES(8344,'mt','uz','Uzbek');
INSERT INTO "languageNames" VALUES(8345,'mt','vi','Vjetnamiż');
INSERT INTO "languageNames" VALUES(8346,'mt','wal','Walamo');
INSERT INTO "languageNames" VALUES(8347,'mt','xh','Xhosa');
INSERT INTO "languageNames" VALUES(8348,'mt','yi','Yiddish');
INSERT INTO "languageNames" VALUES(8349,'mt','yo','Yoruba');
INSERT INTO "languageNames" VALUES(8350,'mt','zh','Ċiniż');
INSERT INTO "languageNames" VALUES(8351,'mt','zu','Zulu');
INSERT INTO "languageNames" VALUES(8352,'uk','af','африкаанс');
INSERT INTO "languageNames" VALUES(8353,'uk','alt','південноалтайська');
INSERT INTO "languageNames" VALUES(8354,'uk','an','арагонська');
INSERT INTO "languageNames" VALUES(8355,'uk','ar','арабська');
INSERT INTO "languageNames" VALUES(8356,'uk','as','ассамська');
INSERT INTO "languageNames" VALUES(8357,'uk','ast','астурська');
INSERT INTO "languageNames" VALUES(8358,'uk','av','аварська');
INSERT INTO "languageNames" VALUES(8360,'uk','az','азері');
INSERT INTO "languageNames" VALUES(8361,'uk','ba','башкирська');
INSERT INTO "languageNames" VALUES(8362,'uk','be','білоруська');
INSERT INTO "languageNames" VALUES(8363,'uk','bg','болгарська');
INSERT INTO "languageNames" VALUES(8364,'uk','bi','біслама');
INSERT INTO "languageNames" VALUES(8365,'uk','bn','банґла');
INSERT INTO "languageNames" VALUES(8366,'uk','br','бретонська');
INSERT INTO "languageNames" VALUES(8367,'uk','bs','боснійська');
INSERT INTO "languageNames" VALUES(8368,'uk','bua','бурятська');
INSERT INTO "languageNames" VALUES(8369,'uk','byv','медумба');
INSERT INTO "languageNames" VALUES(8370,'uk','ca','каталонська');
INSERT INTO "languageNames" VALUES(8371,'uk','ceb','себуанська');
INSERT INTO "languageNames" VALUES(8372,'uk','chm','марійська');
INSERT INTO "languageNames" VALUES(8373,'uk','ckb','центральнокурдська');
INSERT INTO "languageNames" VALUES(8374,'uk','co','корсиканська');
INSERT INTO "languageNames" VALUES(8375,'uk','crh','кримськотатарська');
INSERT INTO "languageNames" VALUES(8376,'uk','cs','чеська');
INSERT INTO "languageNames" VALUES(8377,'uk','csb','кашубська');
INSERT INTO "languageNames" VALUES(8378,'uk','cu','церковнословʼянська');
INSERT INTO "languageNames" VALUES(8379,'uk','cv','чуваська');
INSERT INTO "languageNames" VALUES(8380,'uk','cy','валлійська');
INSERT INTO "languageNames" VALUES(8381,'uk','da','данська');
INSERT INTO "languageNames" VALUES(8382,'uk','dar','даргінська');
INSERT INTO "languageNames" VALUES(8383,'uk','de','німецька');
INSERT INTO "languageNames" VALUES(8384,'uk','dsb','нижньолужицька');
INSERT INTO "languageNames" VALUES(8385,'uk','el','грецька');
INSERT INTO "languageNames" VALUES(8386,'uk','en','англійська');
INSERT INTO "languageNames" VALUES(8387,'uk','eo','есперанто');
INSERT INTO "languageNames" VALUES(8388,'uk','es','іспанська');
INSERT INTO "languageNames" VALUES(8389,'uk','et','естонська');
INSERT INTO "languageNames" VALUES(8390,'uk','eu','баскська');
INSERT INTO "languageNames" VALUES(8391,'uk','fa','перська');
INSERT INTO "languageNames" VALUES(8392,'uk','fi','фінська');
INSERT INTO "languageNames" VALUES(8393,'uk','fo','фарерська');
INSERT INTO "languageNames" VALUES(8394,'uk','fr','французька');
INSERT INTO "languageNames" VALUES(8395,'uk','fy','західнофризька');
INSERT INTO "languageNames" VALUES(8396,'uk','ga','ірландська');
INSERT INTO "languageNames" VALUES(8397,'uk','gag','гагаузька');
INSERT INTO "languageNames" VALUES(8398,'uk','gd','гаельська');
INSERT INTO "languageNames" VALUES(8399,'uk','gl','галісійська');
INSERT INTO "languageNames" VALUES(8400,'uk','gn','гуарані');
INSERT INTO "languageNames" VALUES(8401,'uk','gu','гуджараті');
INSERT INTO "languageNames" VALUES(8402,'uk','gv','менкська');
INSERT INTO "languageNames" VALUES(8403,'uk','ha','хауса');
INSERT INTO "languageNames" VALUES(8404,'uk','haw','гавайська');
INSERT INTO "languageNames" VALUES(8405,'uk','he','іврит');
INSERT INTO "languageNames" VALUES(8406,'uk','hi','гінді');
INSERT INTO "languageNames" VALUES(8407,'uk','hr','хорватська');
INSERT INTO "languageNames" VALUES(8408,'uk','hsb','верхньолужицька');
INSERT INTO "languageNames" VALUES(8409,'uk','ht','гаїтянська');
INSERT INTO "languageNames" VALUES(8410,'uk','hu','угорська');
INSERT INTO "languageNames" VALUES(8411,'uk','hy','вірменська');
INSERT INTO "languageNames" VALUES(8412,'uk','ia','інтерлінгва');
INSERT INTO "languageNames" VALUES(8413,'uk','id','індонезійська');
INSERT INTO "languageNames" VALUES(8414,'uk','ig','ігбо');
INSERT INTO "languageNames" VALUES(8415,'uk','is','ісландська');
INSERT INTO "languageNames" VALUES(8416,'uk','it','італійська');
INSERT INTO "languageNames" VALUES(8417,'uk','ka','грузинська');
INSERT INTO "languageNames" VALUES(8418,'uk','kaa','каракалпацька');
INSERT INTO "languageNames" VALUES(8419,'uk','kk','казахська');
INSERT INTO "languageNames" VALUES(8420,'uk','ko','корейська');
INSERT INTO "languageNames" VALUES(8421,'uk','krc','карачаєво-балкарська');
INSERT INTO "languageNames" VALUES(8422,'uk','krl','карельська');
INSERT INTO "languageNames" VALUES(8423,'uk','ks','кашмірська');
INSERT INTO "languageNames" VALUES(8424,'uk','kum','кумицька');
INSERT INTO "languageNames" VALUES(8425,'uk','kv','комі');
INSERT INTO "languageNames" VALUES(8426,'uk','ky','киргизька');
INSERT INTO "languageNames" VALUES(8427,'uk','la','латинська');
INSERT INTO "languageNames" VALUES(8428,'uk','lb','люксембурзька');
INSERT INTO "languageNames" VALUES(8429,'uk','lg','ганда');
INSERT INTO "languageNames" VALUES(8430,'uk','ln','лінгала');
INSERT INTO "languageNames" VALUES(8431,'uk','lo','лаоська');
INSERT INTO "languageNames" VALUES(8432,'uk','lt','литовська');
INSERT INTO "languageNames" VALUES(8433,'uk','lv','латвійська');
INSERT INTO "languageNames" VALUES(8434,'uk','mdf','мокша');
INSERT INTO "languageNames" VALUES(8435,'uk','mfe','маврикійська креольська');
INSERT INTO "languageNames" VALUES(8436,'uk','mk','македонська');
INSERT INTO "languageNames" VALUES(8437,'uk','ml','малаялам');
INSERT INTO "languageNames" VALUES(8438,'uk','mr','маратхі');
INSERT INTO "languageNames" VALUES(8439,'uk','ms','малайська');
INSERT INTO "languageNames" VALUES(8440,'uk','mt','мальтійська');
INSERT INTO "languageNames" VALUES(8441,'uk','myv','ерзя');
INSERT INTO "languageNames" VALUES(8442,'uk','nap','неаполітанська');
INSERT INTO "languageNames" VALUES(8443,'uk','nb','норвезька (букмол)');
INSERT INTO "languageNames" VALUES(8444,'uk','ne','непальська');
INSERT INTO "languageNames" VALUES(8445,'uk','nl','нідерландська');
INSERT INTO "languageNames" VALUES(8446,'uk','nn','норвезька (нюношк)');
INSERT INTO "languageNames" VALUES(8447,'uk','no','норвезька');
INSERT INTO "languageNames" VALUES(8448,'uk','nog','ногайська');
INSERT INTO "languageNames" VALUES(8449,'uk','oc','окситанська');
INSERT INTO "languageNames" VALUES(8450,'uk','os','осетинська');
INSERT INTO "languageNames" VALUES(8451,'uk','ota','османська');
INSERT INTO "languageNames" VALUES(8452,'uk','pa','панджабі');
INSERT INTO "languageNames" VALUES(8453,'uk','pl','польська');
INSERT INTO "languageNames" VALUES(8454,'uk','pt','портуґальська');
INSERT INTO "languageNames" VALUES(8455,'uk','rm','ретороманська');
INSERT INTO "languageNames" VALUES(8456,'uk','rn','рунді');
INSERT INTO "languageNames" VALUES(8457,'uk','ro','румунська');
INSERT INTO "languageNames" VALUES(8458,'uk','ru','російська');
INSERT INTO "languageNames" VALUES(8459,'uk','rup','арумунська');
INSERT INTO "languageNames" VALUES(8460,'uk','sa','санскрит');
INSERT INTO "languageNames" VALUES(8461,'uk','sah','якутська');
INSERT INTO "languageNames" VALUES(8462,'uk','sc','сардинська');
INSERT INTO "languageNames" VALUES(8463,'uk','scn','сицилійська');
INSERT INTO "languageNames" VALUES(8464,'uk','sco','шотландська');
INSERT INTO "languageNames" VALUES(8465,'uk','sd','сіндхі');
INSERT INTO "languageNames" VALUES(8466,'uk','se','північносаамська');
INSERT INTO "languageNames" VALUES(8467,'uk','sh','сербсько-хорватська');
INSERT INTO "languageNames" VALUES(8468,'uk','si','сингальська');
INSERT INTO "languageNames" VALUES(8469,'uk','sk','словацька');
INSERT INTO "languageNames" VALUES(8470,'uk','sl','словенська');
INSERT INTO "languageNames" VALUES(8471,'uk','sma','південносаамська');
INSERT INTO "languageNames" VALUES(8472,'uk','smj','саамська луле');
INSERT INTO "languageNames" VALUES(8473,'uk','smn','саамська інарі');
INSERT INTO "languageNames" VALUES(8474,'uk','sq','албанська');
INSERT INTO "languageNames" VALUES(8475,'uk','sr','сербська');
INSERT INTO "languageNames" VALUES(8476,'uk','srn','сранан тонго');
INSERT INTO "languageNames" VALUES(8477,'uk','ss','сісваті');
INSERT INTO "languageNames" VALUES(8478,'uk','sv','шведська');
INSERT INTO "languageNames" VALUES(8479,'uk','sw','суахілі');
INSERT INTO "languageNames" VALUES(8480,'uk','ta','тамільська');
INSERT INTO "languageNames" VALUES(8481,'uk','te','телугу');
INSERT INTO "languageNames" VALUES(8482,'uk','tet','тетум');
INSERT INTO "languageNames" VALUES(8483,'uk','tg','таджицька');
INSERT INTO "languageNames" VALUES(8484,'uk','th','тайська');
INSERT INTO "languageNames" VALUES(8485,'uk','tk','туркменська');
INSERT INTO "languageNames" VALUES(8486,'uk','tl','тагальська');
INSERT INTO "languageNames" VALUES(8487,'uk','tr','турецька');
INSERT INTO "languageNames" VALUES(8488,'uk','tt','татарська');
INSERT INTO "languageNames" VALUES(8489,'uk','tyv','тувинська');
INSERT INTO "languageNames" VALUES(8490,'uk','udm','удмуртська');
INSERT INTO "languageNames" VALUES(8491,'uk','ug','уйгурська');
INSERT INTO "languageNames" VALUES(8492,'uk','uk','українська');
INSERT INTO "languageNames" VALUES(8493,'uk','ur','урду');
INSERT INTO "languageNames" VALUES(8494,'uk','uz','узбецька');
INSERT INTO "languageNames" VALUES(8495,'uk','vi','вʼєтнамська');
INSERT INTO "languageNames" VALUES(8496,'uk','wal','волайтта');
INSERT INTO "languageNames" VALUES(8497,'uk','xh','кхоса');
INSERT INTO "languageNames" VALUES(8498,'uk','yi','їдиш');
INSERT INTO "languageNames" VALUES(8499,'uk','yo','йоруба');
INSERT INTO "languageNames" VALUES(8500,'uk','zh','китайська');
INSERT INTO "languageNames" VALUES(8501,'uk','zu','зулуська');
INSERT INTO "languageNames" VALUES(8502,'ro','af','afrikaans');
INSERT INTO "languageNames" VALUES(8503,'ro','alt','altaică meridională');
INSERT INTO "languageNames" VALUES(8504,'ro','an','aragoneză');
INSERT INTO "languageNames" VALUES(8505,'ro','ar','arabă');
INSERT INTO "languageNames" VALUES(8506,'ro','as','asameză');
INSERT INTO "languageNames" VALUES(8507,'ro','ast','asturiană');
INSERT INTO "languageNames" VALUES(8508,'ro','av','avară');
INSERT INTO "languageNames" VALUES(8510,'ro','az','azeră');
INSERT INTO "languageNames" VALUES(8511,'ro','ba','bașkiră');
INSERT INTO "languageNames" VALUES(8512,'ro','be','bielorusă');
INSERT INTO "languageNames" VALUES(8513,'ro','bg','bulgară');
INSERT INTO "languageNames" VALUES(8514,'ro','bi','bislama');
INSERT INTO "languageNames" VALUES(8515,'ro','bn','bengaleză');
INSERT INTO "languageNames" VALUES(8516,'ro','br','bretonă');
INSERT INTO "languageNames" VALUES(8517,'ro','bs','bosniacă');
INSERT INTO "languageNames" VALUES(8518,'ro','bua','buriat');
INSERT INTO "languageNames" VALUES(8519,'ro','byv','medumba');
INSERT INTO "languageNames" VALUES(8520,'ro','ca','catalană');
INSERT INTO "languageNames" VALUES(8521,'ro','ceb','cebuană');
INSERT INTO "languageNames" VALUES(8522,'ro','chm','mari');
INSERT INTO "languageNames" VALUES(8523,'ro','ckb','kurdă centrală');
INSERT INTO "languageNames" VALUES(8524,'ro','co','corsicană');
INSERT INTO "languageNames" VALUES(8525,'ro','crh','turcă crimeeană');
INSERT INTO "languageNames" VALUES(8526,'ro','cs','cehă');
INSERT INTO "languageNames" VALUES(8527,'ro','csb','cașubiană');
INSERT INTO "languageNames" VALUES(8528,'ro','cu','slavonă');
INSERT INTO "languageNames" VALUES(8529,'ro','cv','ciuvașă');
INSERT INTO "languageNames" VALUES(8530,'ro','cy','galeză');
INSERT INTO "languageNames" VALUES(8531,'ro','da','daneză');
INSERT INTO "languageNames" VALUES(8532,'ro','dar','dargwa');
INSERT INTO "languageNames" VALUES(8533,'ro','de','germană');
INSERT INTO "languageNames" VALUES(8534,'ro','dsb','sorabă de jos');
INSERT INTO "languageNames" VALUES(8535,'ro','el','greacă');
INSERT INTO "languageNames" VALUES(8536,'ro','en','engleză');
INSERT INTO "languageNames" VALUES(8537,'ro','eo','esperanto');
INSERT INTO "languageNames" VALUES(8538,'ro','es','spaniolă');
INSERT INTO "languageNames" VALUES(8539,'ro','et','estonă');
INSERT INTO "languageNames" VALUES(8540,'ro','eu','bască');
INSERT INTO "languageNames" VALUES(8541,'ro','fa','persană');
INSERT INTO "languageNames" VALUES(8542,'ro','fi','finlandeză');
INSERT INTO "languageNames" VALUES(8543,'ro','fo','faroeză');
INSERT INTO "languageNames" VALUES(8544,'ro','fr','franceză');
INSERT INTO "languageNames" VALUES(8545,'ro','fy','frizonă occidentală');
INSERT INTO "languageNames" VALUES(8546,'ro','ga','irlandeză');
INSERT INTO "languageNames" VALUES(8547,'ro','gag','găgăuză');
INSERT INTO "languageNames" VALUES(8548,'ro','gd','gaelică scoțiană');
INSERT INTO "languageNames" VALUES(8549,'ro','gl','galiciană');
INSERT INTO "languageNames" VALUES(8550,'ro','gn','guarani');
INSERT INTO "languageNames" VALUES(8551,'ro','gu','gujarati');
INSERT INTO "languageNames" VALUES(8552,'ro','gv','manx');
INSERT INTO "languageNames" VALUES(8553,'ro','ha','hausa');
INSERT INTO "languageNames" VALUES(8554,'ro','haw','hawaiiană');
INSERT INTO "languageNames" VALUES(8555,'ro','he','ebraică');
INSERT INTO "languageNames" VALUES(8556,'ro','hi','hindi');
INSERT INTO "languageNames" VALUES(8557,'ro','hr','croată');
INSERT INTO "languageNames" VALUES(8558,'ro','hsb','sorabă de sus');
INSERT INTO "languageNames" VALUES(8559,'ro','ht','haitiană');
INSERT INTO "languageNames" VALUES(8560,'ro','hu','maghiară');
INSERT INTO "languageNames" VALUES(8561,'ro','hy','armeană');
INSERT INTO "languageNames" VALUES(8562,'ro','ia','interlingua');
INSERT INTO "languageNames" VALUES(8563,'ro','id','indoneziană');
INSERT INTO "languageNames" VALUES(8564,'ro','ig','igbo');
INSERT INTO "languageNames" VALUES(8565,'ro','is','islandeză');
INSERT INTO "languageNames" VALUES(8566,'ro','it','italiană');
INSERT INTO "languageNames" VALUES(8567,'ro','ka','georgiană');
INSERT INTO "languageNames" VALUES(8568,'ro','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(8569,'ro','kk','kazahă');
INSERT INTO "languageNames" VALUES(8570,'ro','ko','coreeană');
INSERT INTO "languageNames" VALUES(8571,'ro','krc','karaceai-balkar');
INSERT INTO "languageNames" VALUES(8572,'ro','krl','kareliană');
INSERT INTO "languageNames" VALUES(8573,'ro','ks','cașmiră');
INSERT INTO "languageNames" VALUES(8574,'ro','kum','kumyk');
INSERT INTO "languageNames" VALUES(8575,'ro','kv','komi');
INSERT INTO "languageNames" VALUES(8576,'ro','ky','kârgâză');
INSERT INTO "languageNames" VALUES(8577,'ro','la','latină');
INSERT INTO "languageNames" VALUES(8578,'ro','lb','luxemburgheză');
INSERT INTO "languageNames" VALUES(8579,'ro','lg','ganda');
INSERT INTO "languageNames" VALUES(8580,'ro','ln','lingala');
INSERT INTO "languageNames" VALUES(8581,'ro','lo','laoțiană');
INSERT INTO "languageNames" VALUES(8582,'ro','lt','lituaniană');
INSERT INTO "languageNames" VALUES(8583,'ro','lv','letonă');
INSERT INTO "languageNames" VALUES(8584,'ro','mdf','moksha');
INSERT INTO "languageNames" VALUES(8585,'ro','mfe','morisyen');
INSERT INTO "languageNames" VALUES(8586,'ro','mk','macedoneană');
INSERT INTO "languageNames" VALUES(8587,'ro','ml','malayalam');
INSERT INTO "languageNames" VALUES(8588,'ro','mr','marathi');
INSERT INTO "languageNames" VALUES(8589,'ro','ms','malaeză');
INSERT INTO "languageNames" VALUES(8590,'ro','mt','malteză');
INSERT INTO "languageNames" VALUES(8591,'ro','myv','erzya');
INSERT INTO "languageNames" VALUES(8592,'ro','nap','napolitană');
INSERT INTO "languageNames" VALUES(8593,'ro','nb','norvegiană bokmål');
INSERT INTO "languageNames" VALUES(8594,'ro','ne','nepaleză');
INSERT INTO "languageNames" VALUES(8595,'ro','nl','neerlandeză');
INSERT INTO "languageNames" VALUES(8596,'ro','nn','norvegiană nynorsk');
INSERT INTO "languageNames" VALUES(8597,'ro','no','norvegiană');
INSERT INTO "languageNames" VALUES(8598,'ro','nog','nogai');
INSERT INTO "languageNames" VALUES(8599,'ro','oc','occitană');
INSERT INTO "languageNames" VALUES(8600,'ro','os','osetă');
INSERT INTO "languageNames" VALUES(8601,'ro','ota','turcă otomană');
INSERT INTO "languageNames" VALUES(8602,'ro','pa','punjabi');
INSERT INTO "languageNames" VALUES(8603,'ro','pl','poloneză');
INSERT INTO "languageNames" VALUES(8604,'ro','pt','portugheză');
INSERT INTO "languageNames" VALUES(8605,'ro','rm','romanșă');
INSERT INTO "languageNames" VALUES(8606,'ro','rn','kirundi');
INSERT INTO "languageNames" VALUES(8607,'ro','ro','română');
INSERT INTO "languageNames" VALUES(8608,'ro','ru','rusă');
INSERT INTO "languageNames" VALUES(8609,'ro','rup','aromână');
INSERT INTO "languageNames" VALUES(8610,'ro','sa','sanscrită');
INSERT INTO "languageNames" VALUES(8611,'ro','sah','sakha');
INSERT INTO "languageNames" VALUES(8612,'ro','sc','sardiniană');
INSERT INTO "languageNames" VALUES(8613,'ro','scn','siciliană');
INSERT INTO "languageNames" VALUES(8614,'ro','sco','scots');
INSERT INTO "languageNames" VALUES(8615,'ro','sd','sindhi');
INSERT INTO "languageNames" VALUES(8616,'ro','se','sami de nord');
INSERT INTO "languageNames" VALUES(8617,'ro','sh','sârbo-croată');
INSERT INTO "languageNames" VALUES(8618,'ro','si','singhaleză');
INSERT INTO "languageNames" VALUES(8619,'ro','sk','slovacă');
INSERT INTO "languageNames" VALUES(8620,'ro','sl','slovenă');
INSERT INTO "languageNames" VALUES(8621,'ro','sma','sami de sud');
INSERT INTO "languageNames" VALUES(8622,'ro','smj','lule sami');
INSERT INTO "languageNames" VALUES(8623,'ro','smn','inari sami');
INSERT INTO "languageNames" VALUES(8624,'ro','sq','albaneză');
INSERT INTO "languageNames" VALUES(8625,'ro','sr','sârbă');
INSERT INTO "languageNames" VALUES(8626,'ro','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(8627,'ro','ss','swati');
INSERT INTO "languageNames" VALUES(8628,'ro','sv','suedeză');
INSERT INTO "languageNames" VALUES(8629,'ro','sw','swahili');
INSERT INTO "languageNames" VALUES(8630,'ro','ta','tamilă');
INSERT INTO "languageNames" VALUES(8631,'ro','te','telugu');
INSERT INTO "languageNames" VALUES(8632,'ro','tet','tetum');
INSERT INTO "languageNames" VALUES(8633,'ro','tg','tadjică');
INSERT INTO "languageNames" VALUES(8634,'ro','th','thailandeză');
INSERT INTO "languageNames" VALUES(8635,'ro','tk','turkmenă');
INSERT INTO "languageNames" VALUES(8636,'ro','tl','tagalog');
INSERT INTO "languageNames" VALUES(8637,'ro','tr','turcă');
INSERT INTO "languageNames" VALUES(8638,'ro','tt','tătară');
INSERT INTO "languageNames" VALUES(8639,'ro','tyv','tuvană');
INSERT INTO "languageNames" VALUES(8640,'ro','udm','udmurt');
INSERT INTO "languageNames" VALUES(8641,'ro','ug','uigură');
INSERT INTO "languageNames" VALUES(8642,'ro','uk','ucraineană');
INSERT INTO "languageNames" VALUES(8643,'ro','ur','urdu');
INSERT INTO "languageNames" VALUES(8644,'ro','uz','uzbecă');
INSERT INTO "languageNames" VALUES(8645,'ro','vi','vietnameză');
INSERT INTO "languageNames" VALUES(8646,'ro','wal','wolaita');
INSERT INTO "languageNames" VALUES(8647,'ro','xh','xhosa');
INSERT INTO "languageNames" VALUES(8648,'ro','yi','idiș');
INSERT INTO "languageNames" VALUES(8649,'ro','yo','yoruba');
INSERT INTO "languageNames" VALUES(8650,'ro','zh','chineză');
INSERT INTO "languageNames" VALUES(8651,'ro','zu','zulu');
INSERT INTO "languageNames" VALUES(8652,'ur','af','افریقی');
INSERT INTO "languageNames" VALUES(8653,'ur','alt','جنوبی الٹائی');
INSERT INTO "languageNames" VALUES(8654,'ur','an','اراگونیز');
INSERT INTO "languageNames" VALUES(8655,'ur','ar','عربی');
INSERT INTO "languageNames" VALUES(8656,'ur','as','آسامی');
INSERT INTO "languageNames" VALUES(8657,'ur','ast','اسٹوریائی');
INSERT INTO "languageNames" VALUES(8658,'ur','av','اواری');
INSERT INTO "languageNames" VALUES(8660,'ur','az','ازیری');
INSERT INTO "languageNames" VALUES(8661,'ur','ba','باشکیر');
INSERT INTO "languageNames" VALUES(8662,'ur','be','بیلاروسی');
INSERT INTO "languageNames" VALUES(8663,'ur','bg','بلغاری');
INSERT INTO "languageNames" VALUES(8664,'ur','bi','بسلاما');
INSERT INTO "languageNames" VALUES(8665,'ur','bn','بنگالی');
INSERT INTO "languageNames" VALUES(8666,'ur','br','بریٹن');
INSERT INTO "languageNames" VALUES(8667,'ur','bs','بوسنی');
INSERT INTO "languageNames" VALUES(8668,'ur','ca','کیٹالان');
INSERT INTO "languageNames" VALUES(8669,'ur','ceb','سیبوآنو');
INSERT INTO "languageNames" VALUES(8670,'ur','chm','ماری');
INSERT INTO "languageNames" VALUES(8671,'ur','ckb','سینٹرل کردش');
INSERT INTO "languageNames" VALUES(8672,'ur','co','کوراسیکن');
INSERT INTO "languageNames" VALUES(8673,'ur','cs','چیک');
INSERT INTO "languageNames" VALUES(8674,'ur','cu','چرچ سلاوک');
INSERT INTO "languageNames" VALUES(8675,'ur','cv','چوواش');
INSERT INTO "languageNames" VALUES(8676,'ur','cy','ویلش');
INSERT INTO "languageNames" VALUES(8677,'ur','da','ڈینش');
INSERT INTO "languageNames" VALUES(8678,'ur','dar','درگوا');
INSERT INTO "languageNames" VALUES(8679,'ur','de','جرمن');
INSERT INTO "languageNames" VALUES(8680,'ur','dsb','ذیلی سربیائی');
INSERT INTO "languageNames" VALUES(8681,'ur','el','یونانی');
INSERT INTO "languageNames" VALUES(8682,'ur','en','انگریزی');
INSERT INTO "languageNames" VALUES(8683,'ur','eo','ایسپرانٹو');
INSERT INTO "languageNames" VALUES(8684,'ur','es','ہسپانوی');
INSERT INTO "languageNames" VALUES(8685,'ur','et','اسٹونین');
INSERT INTO "languageNames" VALUES(8686,'ur','eu','باسکی');
INSERT INTO "languageNames" VALUES(8687,'ur','fa','فارسی');
INSERT INTO "languageNames" VALUES(8688,'ur','fi','فینیش');
INSERT INTO "languageNames" VALUES(8689,'ur','fo','فیروئیز');
INSERT INTO "languageNames" VALUES(8690,'ur','fr','فرانسیسی');
INSERT INTO "languageNames" VALUES(8691,'ur','fy','مغربی فریسیئن');
INSERT INTO "languageNames" VALUES(8692,'ur','ga','آئیرِش');
INSERT INTO "languageNames" VALUES(8693,'ur','gag','غاغاوز');
INSERT INTO "languageNames" VALUES(8694,'ur','gd','سکاٹش گیلک');
INSERT INTO "languageNames" VALUES(8695,'ur','gl','گالیشیائی');
INSERT INTO "languageNames" VALUES(8696,'ur','gn','گُارانی');
INSERT INTO "languageNames" VALUES(8697,'ur','gu','گجراتی');
INSERT INTO "languageNames" VALUES(8698,'ur','gv','مینکس');
INSERT INTO "languageNames" VALUES(8699,'ur','ha','ہؤسا');
INSERT INTO "languageNames" VALUES(8700,'ur','haw','ہوائی');
INSERT INTO "languageNames" VALUES(8701,'ur','he','عبرانی');
INSERT INTO "languageNames" VALUES(8702,'ur','hi','ہندی');
INSERT INTO "languageNames" VALUES(8703,'ur','hr','کراتی');
INSERT INTO "languageNames" VALUES(8704,'ur','hsb','اپر سربیائی');
INSERT INTO "languageNames" VALUES(8705,'ur','ht','ہیتی');
INSERT INTO "languageNames" VALUES(8706,'ur','hu','ہنگیرین');
INSERT INTO "languageNames" VALUES(8707,'ur','hy','آرمینیائی');
INSERT INTO "languageNames" VALUES(8708,'ur','ia','بین لسانیات');
INSERT INTO "languageNames" VALUES(8709,'ur','id','انڈونیثیائی');
INSERT INTO "languageNames" VALUES(8710,'ur','ig','اِگبو');
INSERT INTO "languageNames" VALUES(8711,'ur','is','آئس لینڈک');
INSERT INTO "languageNames" VALUES(8712,'ur','it','اطالوی');
INSERT INTO "languageNames" VALUES(8713,'ur','ka','جارجیائی');
INSERT INTO "languageNames" VALUES(8714,'ur','kk','قزاخ');
INSERT INTO "languageNames" VALUES(8715,'ur','ko','کوریائی');
INSERT INTO "languageNames" VALUES(8716,'ur','krc','کراچے بالکر');
INSERT INTO "languageNames" VALUES(8717,'ur','krl','کیرلین');
INSERT INTO "languageNames" VALUES(8718,'ur','ks','کشمیری');
INSERT INTO "languageNames" VALUES(8719,'ur','kum','کومیک');
INSERT INTO "languageNames" VALUES(8720,'ur','kv','کومی');
INSERT INTO "languageNames" VALUES(8721,'ur','ky','کرغیزی');
INSERT INTO "languageNames" VALUES(8722,'ur','la','لاطینی');
INSERT INTO "languageNames" VALUES(8723,'ur','lb','لکسمبرگیش');
INSERT INTO "languageNames" VALUES(8724,'ur','lg','گینڈا');
INSERT INTO "languageNames" VALUES(8725,'ur','ln','لِنگَلا');
INSERT INTO "languageNames" VALUES(8726,'ur','lo','لاؤ');
INSERT INTO "languageNames" VALUES(8727,'ur','lt','لیتھوینین');
INSERT INTO "languageNames" VALUES(8728,'ur','lv','لیٹوین');
INSERT INTO "languageNames" VALUES(8729,'ur','mdf','موکشا');
INSERT INTO "languageNames" VALUES(8730,'ur','mfe','موریسیین');
INSERT INTO "languageNames" VALUES(8731,'ur','mk','مقدونیائی');
INSERT INTO "languageNames" VALUES(8732,'ur','ml','مالایالم');
INSERT INTO "languageNames" VALUES(8733,'ur','mr','مراٹهی');
INSERT INTO "languageNames" VALUES(8734,'ur','ms','مالے');
INSERT INTO "languageNames" VALUES(8735,'ur','mt','مالٹی');
INSERT INTO "languageNames" VALUES(8736,'ur','myv','ارزیا');
INSERT INTO "languageNames" VALUES(8737,'ur','nap','نیاپولیٹن');
INSERT INTO "languageNames" VALUES(8738,'ur','nb','نارویجین بوکمل');
INSERT INTO "languageNames" VALUES(8739,'ur','ne','نیپالی');
INSERT INTO "languageNames" VALUES(8740,'ur','nl','ڈچ');
INSERT INTO "languageNames" VALUES(8741,'ur','nn','نارویجین نینورسک');
INSERT INTO "languageNames" VALUES(8742,'ur','no','نارویجین');
INSERT INTO "languageNames" VALUES(8743,'ur','nog','نوگائی');
INSERT INTO "languageNames" VALUES(8744,'ur','oc','آكسیٹان');
INSERT INTO "languageNames" VALUES(8745,'ur','os','اوسیٹک');
INSERT INTO "languageNames" VALUES(8746,'ur','pa','پنجابی');
INSERT INTO "languageNames" VALUES(8747,'ur','pl','پولش');
INSERT INTO "languageNames" VALUES(8748,'ur','pt','پُرتگالی');
INSERT INTO "languageNames" VALUES(8749,'ur','rm','رومانش');
INSERT INTO "languageNames" VALUES(8750,'ur','rn','رونڈی');
INSERT INTO "languageNames" VALUES(8751,'ur','ro','رومینین');
INSERT INTO "languageNames" VALUES(8752,'ur','ru','روسی');
INSERT INTO "languageNames" VALUES(8753,'ur','rup','ارومانی');
INSERT INTO "languageNames" VALUES(8754,'ur','sa','سنسکرت');
INSERT INTO "languageNames" VALUES(8755,'ur','sah','ساکھا');
INSERT INTO "languageNames" VALUES(8756,'ur','sc','سردینین');
INSERT INTO "languageNames" VALUES(8757,'ur','scn','سیسیلین');
INSERT INTO "languageNames" VALUES(8758,'ur','sco','سکاٹ');
INSERT INTO "languageNames" VALUES(8759,'ur','sd','سندھی');
INSERT INTO "languageNames" VALUES(8760,'ur','se','شمالی سامی');
INSERT INTO "languageNames" VALUES(8761,'ur','sh','سربو-کروئیشین');
INSERT INTO "languageNames" VALUES(8762,'ur','si','سنہالا');
INSERT INTO "languageNames" VALUES(8763,'ur','sk','سلوواک');
INSERT INTO "languageNames" VALUES(8764,'ur','sl','سلووینیائی');
INSERT INTO "languageNames" VALUES(8765,'ur','sma','جنوبی سامی');
INSERT INTO "languageNames" VALUES(8766,'ur','smj','لول سامی');
INSERT INTO "languageNames" VALUES(8767,'ur','smn','اناری سامی');
INSERT INTO "languageNames" VALUES(8768,'ur','sq','البانی');
INSERT INTO "languageNames" VALUES(8769,'ur','sr','سربین');
INSERT INTO "languageNames" VALUES(8770,'ur','srn','سرانن ٹونگو');
INSERT INTO "languageNames" VALUES(8771,'ur','ss','سواتی');
INSERT INTO "languageNames" VALUES(8772,'ur','sv','سویڈش');
INSERT INTO "languageNames" VALUES(8773,'ur','sw','سواحلی');
INSERT INTO "languageNames" VALUES(8774,'ur','ta','تمل');
INSERT INTO "languageNames" VALUES(8775,'ur','te','تیلگو');
INSERT INTO "languageNames" VALUES(8776,'ur','tet','ٹیٹم');
INSERT INTO "languageNames" VALUES(8777,'ur','tg','تاجک');
INSERT INTO "languageNames" VALUES(8778,'ur','th','تھائی');
INSERT INTO "languageNames" VALUES(8779,'ur','tk','ترکمان');
INSERT INTO "languageNames" VALUES(8780,'ur','tl','ٹیگا لوگ');
INSERT INTO "languageNames" VALUES(8781,'ur','tr','ترکی');
INSERT INTO "languageNames" VALUES(8782,'ur','tt','تاتار');
INSERT INTO "languageNames" VALUES(8783,'ur','tyv','تووینین');
INSERT INTO "languageNames" VALUES(8784,'ur','udm','ادمورت');
INSERT INTO "languageNames" VALUES(8785,'ur','ug','یوئگہر');
INSERT INTO "languageNames" VALUES(8786,'ur','uk','یوکرینیائی');
INSERT INTO "languageNames" VALUES(8787,'ur','ur','اردو');
INSERT INTO "languageNames" VALUES(8788,'ur','uz','ازبیک');
INSERT INTO "languageNames" VALUES(8789,'ur','vi','ویتنامی');
INSERT INTO "languageNames" VALUES(8790,'ur','wal','وولایتا');
INSERT INTO "languageNames" VALUES(8791,'ur','xh','ژوسا');
INSERT INTO "languageNames" VALUES(8792,'ur','yi','یدش');
INSERT INTO "languageNames" VALUES(8793,'ur','yo','یوروبا');
INSERT INTO "languageNames" VALUES(8794,'ur','zh','چینی');
INSERT INTO "languageNames" VALUES(8795,'ur','zu','زولو');
INSERT INTO "languageNames" VALUES(8796,'hr','af','afrikaans');
INSERT INTO "languageNames" VALUES(8797,'hr','alt','južni altai');
INSERT INTO "languageNames" VALUES(8798,'hr','an','aragonski');
INSERT INTO "languageNames" VALUES(8799,'hr','ar','arapski');
INSERT INTO "languageNames" VALUES(8800,'hr','as','asamski');
INSERT INTO "languageNames" VALUES(8801,'hr','ast','asturijski');
INSERT INTO "languageNames" VALUES(8802,'hr','av','avarski');
INSERT INTO "languageNames" VALUES(8804,'hr','az','azerski');
INSERT INTO "languageNames" VALUES(8805,'hr','ba','baškirski');
INSERT INTO "languageNames" VALUES(8806,'hr','be','bjeloruski');
INSERT INTO "languageNames" VALUES(8807,'hr','bg','bugarski');
INSERT INTO "languageNames" VALUES(8808,'hr','bi','bislama');
INSERT INTO "languageNames" VALUES(8809,'hr','bn','bangla');
INSERT INTO "languageNames" VALUES(8810,'hr','br','bretonski');
INSERT INTO "languageNames" VALUES(8811,'hr','bs','bosanski');
INSERT INTO "languageNames" VALUES(8812,'hr','bua','burjatski');
INSERT INTO "languageNames" VALUES(8813,'hr','byv','medumba');
INSERT INTO "languageNames" VALUES(8814,'hr','ca','katalonski');
INSERT INTO "languageNames" VALUES(8815,'hr','ceb','cebuano');
INSERT INTO "languageNames" VALUES(8816,'hr','chm','marijski');
INSERT INTO "languageNames" VALUES(8817,'hr','ckb','soranski kurdski');
INSERT INTO "languageNames" VALUES(8818,'hr','co','korzički');
INSERT INTO "languageNames" VALUES(8819,'hr','crh','krimski turski');
INSERT INTO "languageNames" VALUES(8820,'hr','cs','češki');
INSERT INTO "languageNames" VALUES(8821,'hr','csb','kašupski');
INSERT INTO "languageNames" VALUES(8822,'hr','cu','crkvenoslavenski');
INSERT INTO "languageNames" VALUES(8823,'hr','cv','čuvaški');
INSERT INTO "languageNames" VALUES(8824,'hr','cy','velški');
INSERT INTO "languageNames" VALUES(8825,'hr','da','danski');
INSERT INTO "languageNames" VALUES(8826,'hr','dar','dargwa');
INSERT INTO "languageNames" VALUES(8827,'hr','de','njemački');
INSERT INTO "languageNames" VALUES(8828,'hr','dsb','donjolužički');
INSERT INTO "languageNames" VALUES(8829,'hr','el','grčki');
INSERT INTO "languageNames" VALUES(8830,'hr','en','engleski');
INSERT INTO "languageNames" VALUES(8831,'hr','eo','esperanto');
INSERT INTO "languageNames" VALUES(8832,'hr','es','španjolski');
INSERT INTO "languageNames" VALUES(8833,'hr','et','estonski');
INSERT INTO "languageNames" VALUES(8834,'hr','eu','baskijski');
INSERT INTO "languageNames" VALUES(8835,'hr','fa','perzijski');
INSERT INTO "languageNames" VALUES(8836,'hr','fi','finski');
INSERT INTO "languageNames" VALUES(8837,'hr','fo','ferojski');
INSERT INTO "languageNames" VALUES(8838,'hr','fr','francuski');
INSERT INTO "languageNames" VALUES(8839,'hr','fy','zapadnofrizijski');
INSERT INTO "languageNames" VALUES(8840,'hr','ga','irski');
INSERT INTO "languageNames" VALUES(8841,'hr','gag','gagauski');
INSERT INTO "languageNames" VALUES(8842,'hr','gd','škotski gaelski');
INSERT INTO "languageNames" VALUES(8843,'hr','gl','galicijski');
INSERT INTO "languageNames" VALUES(8844,'hr','gn','gvaranski');
INSERT INTO "languageNames" VALUES(8845,'hr','gu','gudžaratski');
INSERT INTO "languageNames" VALUES(8846,'hr','gv','manski');
INSERT INTO "languageNames" VALUES(8847,'hr','ha','hausa');
INSERT INTO "languageNames" VALUES(8848,'hr','haw','havajski');
INSERT INTO "languageNames" VALUES(8849,'hr','he','hebrejski');
INSERT INTO "languageNames" VALUES(8850,'hr','hi','hindski');
INSERT INTO "languageNames" VALUES(8851,'hr','hr','hrvatski');
INSERT INTO "languageNames" VALUES(8852,'hr','hsb','gornjolužički');
INSERT INTO "languageNames" VALUES(8853,'hr','ht','haićanski kreolski');
INSERT INTO "languageNames" VALUES(8854,'hr','hu','mađarski');
INSERT INTO "languageNames" VALUES(8855,'hr','hy','armenski');
INSERT INTO "languageNames" VALUES(8856,'hr','ia','interlingua');
INSERT INTO "languageNames" VALUES(8857,'hr','id','indonezijski');
INSERT INTO "languageNames" VALUES(8858,'hr','ig','igbo');
INSERT INTO "languageNames" VALUES(8859,'hr','is','islandski');
INSERT INTO "languageNames" VALUES(8860,'hr','it','talijanski');
INSERT INTO "languageNames" VALUES(8861,'hr','ka','gruzijski');
INSERT INTO "languageNames" VALUES(8862,'hr','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(8863,'hr','kk','kazaški');
INSERT INTO "languageNames" VALUES(8864,'hr','ko','korejski');
INSERT INTO "languageNames" VALUES(8865,'hr','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(8866,'hr','krl','karelijski');
INSERT INTO "languageNames" VALUES(8867,'hr','ks','kašmirski');
INSERT INTO "languageNames" VALUES(8868,'hr','kum','kumyk');
INSERT INTO "languageNames" VALUES(8869,'hr','kv','komi');
INSERT INTO "languageNames" VALUES(8870,'hr','ky','kirgiski');
INSERT INTO "languageNames" VALUES(8871,'hr','la','latinski');
INSERT INTO "languageNames" VALUES(8872,'hr','lb','luksemburški');
INSERT INTO "languageNames" VALUES(8873,'hr','lg','ganda');
INSERT INTO "languageNames" VALUES(8874,'hr','ln','lingala');
INSERT INTO "languageNames" VALUES(8875,'hr','lo','laoski');
INSERT INTO "languageNames" VALUES(8876,'hr','lt','litavski');
INSERT INTO "languageNames" VALUES(8877,'hr','lv','latvijski');
INSERT INTO "languageNames" VALUES(8878,'hr','mdf','moksha');
INSERT INTO "languageNames" VALUES(8879,'hr','mfe','mauricijski kreolski');
INSERT INTO "languageNames" VALUES(8880,'hr','mk','makedonski');
INSERT INTO "languageNames" VALUES(8881,'hr','ml','malajalamski');
INSERT INTO "languageNames" VALUES(8882,'hr','mr','marathski');
INSERT INTO "languageNames" VALUES(8883,'hr','ms','malajski');
INSERT INTO "languageNames" VALUES(8884,'hr','mt','malteški');
INSERT INTO "languageNames" VALUES(8885,'hr','myv','mordvinski');
INSERT INTO "languageNames" VALUES(8886,'hr','nap','napolitanski');
INSERT INTO "languageNames" VALUES(8887,'hr','nb','norveški bokmål');
INSERT INTO "languageNames" VALUES(8888,'hr','ne','nepalski');
INSERT INTO "languageNames" VALUES(8889,'hr','nl','nizozemski');
INSERT INTO "languageNames" VALUES(8890,'hr','nn','norveški nynorsk');
INSERT INTO "languageNames" VALUES(8891,'hr','no','norveški');
INSERT INTO "languageNames" VALUES(8892,'hr','nog','nogajski');
INSERT INTO "languageNames" VALUES(8893,'hr','oc','okcitanski');
INSERT INTO "languageNames" VALUES(8894,'hr','os','osetski');
INSERT INTO "languageNames" VALUES(8895,'hr','ota','turski - otomanski');
INSERT INTO "languageNames" VALUES(8896,'hr','pa','pandžapski');
INSERT INTO "languageNames" VALUES(8897,'hr','pl','poljski');
INSERT INTO "languageNames" VALUES(8898,'hr','pt','portugalski');
INSERT INTO "languageNames" VALUES(8899,'hr','rm','retoromanski');
INSERT INTO "languageNames" VALUES(8900,'hr','rn','rundi');
INSERT INTO "languageNames" VALUES(8901,'hr','ro','rumunjski');
INSERT INTO "languageNames" VALUES(8902,'hr','ru','ruski');
INSERT INTO "languageNames" VALUES(8903,'hr','rup','aromunski');
INSERT INTO "languageNames" VALUES(8904,'hr','sa','sanskrtski');
INSERT INTO "languageNames" VALUES(8905,'hr','sah','jakutski');
INSERT INTO "languageNames" VALUES(8906,'hr','sc','sardski');
INSERT INTO "languageNames" VALUES(8907,'hr','scn','sicilijski');
INSERT INTO "languageNames" VALUES(8908,'hr','sco','škotski');
INSERT INTO "languageNames" VALUES(8909,'hr','sd','sindski');
INSERT INTO "languageNames" VALUES(8910,'hr','se','sjeverni sami');
INSERT INTO "languageNames" VALUES(8911,'hr','sh','srpsko-hrvatski');
INSERT INTO "languageNames" VALUES(8912,'hr','si','sinhaleški');
INSERT INTO "languageNames" VALUES(8913,'hr','sk','slovački');
INSERT INTO "languageNames" VALUES(8914,'hr','sl','slovenski');
INSERT INTO "languageNames" VALUES(8915,'hr','sma','južni sami');
INSERT INTO "languageNames" VALUES(8916,'hr','smj','lule sami');
INSERT INTO "languageNames" VALUES(8917,'hr','smn','inari sami');
INSERT INTO "languageNames" VALUES(8918,'hr','sq','albanski');
INSERT INTO "languageNames" VALUES(8919,'hr','sr','srpski');
INSERT INTO "languageNames" VALUES(8920,'hr','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(8921,'hr','ss','svati');
INSERT INTO "languageNames" VALUES(8922,'hr','sv','švedski');
INSERT INTO "languageNames" VALUES(8923,'hr','sw','svahili');
INSERT INTO "languageNames" VALUES(8924,'hr','ta','tamilski');
INSERT INTO "languageNames" VALUES(8925,'hr','te','teluški');
INSERT INTO "languageNames" VALUES(8926,'hr','tet','tetum');
INSERT INTO "languageNames" VALUES(8927,'hr','tg','tadžički');
INSERT INTO "languageNames" VALUES(8928,'hr','th','tajlandski');
INSERT INTO "languageNames" VALUES(8929,'hr','tk','turkmenski');
INSERT INTO "languageNames" VALUES(8930,'hr','tl','tagalog');
INSERT INTO "languageNames" VALUES(8931,'hr','tr','turski');
INSERT INTO "languageNames" VALUES(8932,'hr','tt','tatarski');
INSERT INTO "languageNames" VALUES(8933,'hr','tyv','tuvinski');
INSERT INTO "languageNames" VALUES(8934,'hr','udm','udmurtski');
INSERT INTO "languageNames" VALUES(8935,'hr','ug','ujgurski');
INSERT INTO "languageNames" VALUES(8936,'hr','uk','ukrajinski');
INSERT INTO "languageNames" VALUES(8937,'hr','ur','urdski');
INSERT INTO "languageNames" VALUES(8938,'hr','uz','uzbečki');
INSERT INTO "languageNames" VALUES(8939,'hr','vi','vijetnamski');
INSERT INTO "languageNames" VALUES(8940,'hr','wal','walamo');
INSERT INTO "languageNames" VALUES(8941,'hr','xh','xhosa');
INSERT INTO "languageNames" VALUES(8942,'hr','yi','jidiš');
INSERT INTO "languageNames" VALUES(8943,'hr','yo','jorupski');
INSERT INTO "languageNames" VALUES(8944,'hr','zh','kineski');
INSERT INTO "languageNames" VALUES(8945,'hr','zu','zulu');
INSERT INTO "languageNames" VALUES(8946,'yi','af','אַפֿריקאַנס');
INSERT INTO "languageNames" VALUES(8947,'yi','an','אַראַגאניש');
INSERT INTO "languageNames" VALUES(8948,'yi','ar','אַראַביש');
INSERT INTO "languageNames" VALUES(8949,'yi','as','אַסאַמיש');
INSERT INTO "languageNames" VALUES(8950,'yi','az','אַזערביידזשאַניש');
INSERT INTO "languageNames" VALUES(8951,'yi','be','בעלאַרוסיש');
INSERT INTO "languageNames" VALUES(8952,'yi','bg','בולגאַריש');
INSERT INTO "languageNames" VALUES(8953,'yi','bn','בענגאַליש');
INSERT INTO "languageNames" VALUES(8954,'yi','br','ברעטאניש');
INSERT INTO "languageNames" VALUES(8955,'yi','bs','באסניש');
INSERT INTO "languageNames" VALUES(8956,'yi','ca','קאַטאַלאניש');
INSERT INTO "languageNames" VALUES(8957,'yi','ceb','סעבואַניש');
INSERT INTO "languageNames" VALUES(8958,'yi','crh','קרים־טערקיש');
INSERT INTO "languageNames" VALUES(8959,'yi','cs','טשעכיש');
INSERT INTO "languageNames" VALUES(8960,'yi','csb','קאַשוביש');
INSERT INTO "languageNames" VALUES(8961,'yi','cu','קלויסטער־סלאַוויש');
INSERT INTO "languageNames" VALUES(8962,'yi','cy','וועלשיש');
INSERT INTO "languageNames" VALUES(8963,'yi','da','דעניש');
INSERT INTO "languageNames" VALUES(8964,'yi','de','דײַטש');
INSERT INTO "languageNames" VALUES(8965,'yi','dsb','אונטער־סארביש');
INSERT INTO "languageNames" VALUES(8966,'yi','el','גריכיש');
INSERT INTO "languageNames" VALUES(8967,'yi','en','ענגליש');
INSERT INTO "languageNames" VALUES(8968,'yi','eo','עספּעראַנטא');
INSERT INTO "languageNames" VALUES(8969,'yi','es','שפּאַניש');
INSERT INTO "languageNames" VALUES(8970,'yi','et','עסטיש');
INSERT INTO "languageNames" VALUES(8971,'yi','eu','באַסקיש');
INSERT INTO "languageNames" VALUES(8972,'yi','fa','פּערסיש');
INSERT INTO "languageNames" VALUES(8973,'yi','fi','פֿיניש');
INSERT INTO "languageNames" VALUES(8974,'yi','fo','פֿאַראיש');
INSERT INTO "languageNames" VALUES(8975,'yi','fr','פֿראַנצויזיש');
INSERT INTO "languageNames" VALUES(8976,'yi','fy','מערב־פֿריזיש');
INSERT INTO "languageNames" VALUES(8977,'yi','ga','איריש');
INSERT INTO "languageNames" VALUES(8978,'yi','gd','סקאטיש געליש');
INSERT INTO "languageNames" VALUES(8979,'yi','gl','גאַלישיש');
INSERT INTO "languageNames" VALUES(8980,'yi','gv','מאַנקס');
INSERT INTO "languageNames" VALUES(8981,'yi','ha','האַוסאַ');
INSERT INTO "languageNames" VALUES(8982,'yi','he','העברעאיש');
INSERT INTO "languageNames" VALUES(8983,'yi','hi','הינדי');
INSERT INTO "languageNames" VALUES(8984,'yi','hr','קראאַטיש');
INSERT INTO "languageNames" VALUES(8985,'yi','hsb','אייבער־סארביש');
INSERT INTO "languageNames" VALUES(8986,'yi','hu','אונגעריש');
INSERT INTO "languageNames" VALUES(8987,'yi','hy','אַרמעניש');
INSERT INTO "languageNames" VALUES(8988,'yi','id','אינדאנעזיש');
INSERT INTO "languageNames" VALUES(8989,'yi','is','איסלאַנדיש');
INSERT INTO "languageNames" VALUES(8990,'yi','it','איטאַליעניש');
INSERT INTO "languageNames" VALUES(8991,'yi','ka','גרוזיניש');
INSERT INTO "languageNames" VALUES(8992,'yi','kk','קאַזאַכיש');
INSERT INTO "languageNames" VALUES(8993,'yi','ko','קארעאיש');
INSERT INTO "languageNames" VALUES(8994,'yi','ky','קירגיזיש');
INSERT INTO "languageNames" VALUES(8995,'yi','la','לאטייניש');
INSERT INTO "languageNames" VALUES(8996,'yi','lb','לוקסעמבורגיש');
INSERT INTO "languageNames" VALUES(8997,'yi','liv','ליוויש');
INSERT INTO "languageNames" VALUES(8998,'yi','lo','לאַא');
INSERT INTO "languageNames" VALUES(8999,'yi','lt','ליטוויש');
INSERT INTO "languageNames" VALUES(9000,'yi','lv','לעטיש');
INSERT INTO "languageNames" VALUES(9001,'yi','mk','מאַקעדאניש');
INSERT INTO "languageNames" VALUES(9002,'yi','ml','מאַלאַיאַלאַם');
INSERT INTO "languageNames" VALUES(9003,'yi','mt','מאַלטעזיש');
INSERT INTO "languageNames" VALUES(9004,'yi','nap','נאַפּאליטַניש');
INSERT INTO "languageNames" VALUES(9005,'yi','ne','נעפּאַליש');
INSERT INTO "languageNames" VALUES(9006,'yi','nl','האלענדיש');
INSERT INTO "languageNames" VALUES(9007,'yi','nn','נײַ־נארוועגיש');
INSERT INTO "languageNames" VALUES(9008,'yi','no','נארוועגיש');
INSERT INTO "languageNames" VALUES(9009,'yi','oc','אקסיטאַניש');
INSERT INTO "languageNames" VALUES(9010,'yi','os','אסעטיש');
INSERT INTO "languageNames" VALUES(9011,'yi','pl','פּויליש');
INSERT INTO "languageNames" VALUES(9012,'yi','pt','פּארטוגעזיש');
INSERT INTO "languageNames" VALUES(9013,'yi','ro','רומעניש');
INSERT INTO "languageNames" VALUES(9014,'yi','ru','רוסיש');
INSERT INTO "languageNames" VALUES(9015,'yi','sa','סאַנסקריט');
INSERT INTO "languageNames" VALUES(9016,'yi','sc','סאַרדיש');
INSERT INTO "languageNames" VALUES(9017,'yi','scn','סיציליאַניש');
INSERT INTO "languageNames" VALUES(9018,'yi','sco','סקאטס');
INSERT INTO "languageNames" VALUES(9019,'yi','sd','סינדהי');
INSERT INTO "languageNames" VALUES(9020,'yi','se','נארדסאַמיש');
INSERT INTO "languageNames" VALUES(9021,'yi','sh','סערבא־קראאַטיש');
INSERT INTO "languageNames" VALUES(9022,'yi','si','סינהאַליש');
INSERT INTO "languageNames" VALUES(9023,'yi','sk','סלאוואַקיש');
INSERT INTO "languageNames" VALUES(9024,'yi','sl','סלאוועניש');
INSERT INTO "languageNames" VALUES(9025,'yi','sq','אַלבאַניש');
INSERT INTO "languageNames" VALUES(9026,'yi','sr','סערביש');
INSERT INTO "languageNames" VALUES(9027,'yi','sv','שוועדיש');
INSERT INTO "languageNames" VALUES(9028,'yi','sw','סוואַהיליש');
INSERT INTO "languageNames" VALUES(9029,'yi','ta','טאַמיל');
INSERT INTO "languageNames" VALUES(9030,'yi','tk','טורקמעניש');
INSERT INTO "languageNames" VALUES(9031,'yi','tl','טאַגאַלאג');
INSERT INTO "languageNames" VALUES(9032,'yi','tt','טאָטעריש');
INSERT INTO "languageNames" VALUES(9033,'yi','uk','אוקראַאיניש');
INSERT INTO "languageNames" VALUES(9034,'yi','ur','אורדו');
INSERT INTO "languageNames" VALUES(9035,'yi','uz','אוזבעקיש');
INSERT INTO "languageNames" VALUES(9036,'yi','vi','וויעטנאַמעזיש');
INSERT INTO "languageNames" VALUES(9037,'yi','yi','ייִדיש');
INSERT INTO "languageNames" VALUES(9038,'yi','zh','כינעזיש');
INSERT INTO "languageNames" VALUES(9039,'yi','zu','זולו');
INSERT INTO "languageNames" VALUES(9040,'rn','ar','Icarabu');
INSERT INTO "languageNames" VALUES(9041,'rn','be','Ikibelarusiya');
INSERT INTO "languageNames" VALUES(9042,'rn','bg','Ikinyabuligariya');
INSERT INTO "languageNames" VALUES(9043,'rn','bn','Ikibengali');
INSERT INTO "languageNames" VALUES(9044,'rn','cs','Igiceke');
INSERT INTO "languageNames" VALUES(9045,'rn','de','Ikidage');
INSERT INTO "languageNames" VALUES(9046,'rn','el','Ikigereki');
INSERT INTO "languageNames" VALUES(9047,'rn','en','Icongereza');
INSERT INTO "languageNames" VALUES(9048,'rn','es','Icesipanyolo');
INSERT INTO "languageNames" VALUES(9049,'rn','fa','Igiperisi');
INSERT INTO "languageNames" VALUES(9050,'rn','fr','Igifaransa');
INSERT INTO "languageNames" VALUES(9051,'rn','ha','Igihawusa');
INSERT INTO "languageNames" VALUES(9052,'rn','hi','Igihindi');
INSERT INTO "languageNames" VALUES(9053,'rn','hu','Ikinyahongiriya');
INSERT INTO "languageNames" VALUES(9054,'rn','id','Ikinyendoziya');
INSERT INTO "languageNames" VALUES(9055,'rn','ig','Ikigubo');
INSERT INTO "languageNames" VALUES(9056,'rn','it','Igitaliyani');
INSERT INTO "languageNames" VALUES(9057,'rn','ko','Ikinyakoreya');
INSERT INTO "languageNames" VALUES(9058,'rn','ms','Ikinyamaleziya');
INSERT INTO "languageNames" VALUES(9059,'rn','ne','Ikinepali');
INSERT INTO "languageNames" VALUES(9060,'rn','nl','Igiholandi');
INSERT INTO "languageNames" VALUES(9061,'rn','pa','Igipunjabi');
INSERT INTO "languageNames" VALUES(9062,'rn','pl','Ikinyapolonye');
INSERT INTO "languageNames" VALUES(9063,'rn','pt','Igiporutugari');
INSERT INTO "languageNames" VALUES(9064,'rn','rn','Ikirundi');
INSERT INTO "languageNames" VALUES(9065,'rn','ro','Ikinyarumaniya');
INSERT INTO "languageNames" VALUES(9066,'rn','ru','Ikirusiya');
INSERT INTO "languageNames" VALUES(9067,'rn','sv','Igisuweduwa');
INSERT INTO "languageNames" VALUES(9068,'rn','ta','Igitamili');
INSERT INTO "languageNames" VALUES(9069,'rn','th','Ikinyatayilandi');
INSERT INTO "languageNames" VALUES(9070,'rn','tr','Igiturukiya');
INSERT INTO "languageNames" VALUES(9071,'rn','uk','Ikinyayukereni');
INSERT INTO "languageNames" VALUES(9072,'rn','ur','Inyeyurudu');
INSERT INTO "languageNames" VALUES(9073,'rn','vi','Ikinyaviyetinamu');
INSERT INTO "languageNames" VALUES(9074,'rn','yo','Ikiyoruba');
INSERT INTO "languageNames" VALUES(9075,'rn','zh','Igishinwa');
INSERT INTO "languageNames" VALUES(9076,'rn','zu','Ikizulu');
INSERT INTO "languageNames" VALUES(9077,'haw','ar','ʻAlapia');
INSERT INTO "languageNames" VALUES(9078,'haw','cy','Wale');
INSERT INTO "languageNames" VALUES(9079,'haw','da','Kenemaka');
INSERT INTO "languageNames" VALUES(9080,'haw','de','Kelemānia');
INSERT INTO "languageNames" VALUES(9081,'haw','el','Helene');
INSERT INTO "languageNames" VALUES(9082,'haw','en','Pelekānia');
INSERT INTO "languageNames" VALUES(9083,'haw','es','Paniolo');
INSERT INTO "languageNames" VALUES(9084,'haw','fr','Palani');
INSERT INTO "languageNames" VALUES(9085,'haw','ga','ʻAiliki');
INSERT INTO "languageNames" VALUES(9086,'haw','haw','ʻŌlelo Hawaiʻi');
INSERT INTO "languageNames" VALUES(9087,'haw','he','Hebera');
INSERT INTO "languageNames" VALUES(9088,'haw','it','ʻĪkālia');
INSERT INTO "languageNames" VALUES(9089,'haw','ko','Kōlea');
INSERT INTO "languageNames" VALUES(9090,'haw','la','Lākina');
INSERT INTO "languageNames" VALUES(9091,'haw','nl','Hōlani');
INSERT INTO "languageNames" VALUES(9092,'haw','pt','Pukikī');
INSERT INTO "languageNames" VALUES(9093,'haw','ru','Lūkia');
INSERT INTO "languageNames" VALUES(9094,'haw','sv','Kuekene');
INSERT INTO "languageNames" VALUES(9095,'haw','vi','Wiekanama');
INSERT INTO "languageNames" VALUES(9096,'haw','zh','Pākē');
INSERT INTO "languageNames" VALUES(9097,'fy','af','Afrikaansk');
INSERT INTO "languageNames" VALUES(9098,'fy','alt','Sûd-Altaïsk');
INSERT INTO "languageNames" VALUES(9099,'fy','an','Aragoneesk');
INSERT INTO "languageNames" VALUES(9100,'fy','ar','Arabysk');
INSERT INTO "languageNames" VALUES(9101,'fy','as','Assameesk');
INSERT INTO "languageNames" VALUES(9102,'fy','ast','Asturysk');
INSERT INTO "languageNames" VALUES(9103,'fy','av','Avarysk');
INSERT INTO "languageNames" VALUES(9105,'fy','az','Azeri');
INSERT INTO "languageNames" VALUES(9106,'fy','ba','Basjkiersk');
INSERT INTO "languageNames" VALUES(9107,'fy','be','Wyt-Russysk');
INSERT INTO "languageNames" VALUES(9108,'fy','bg','Bulgaarsk');
INSERT INTO "languageNames" VALUES(9109,'fy','bi','Bislama');
INSERT INTO "languageNames" VALUES(9110,'fy','bn','Bengaalsk');
INSERT INTO "languageNames" VALUES(9111,'fy','br','Bretonsk');
INSERT INTO "languageNames" VALUES(9112,'fy','bs','Bosnysk');
INSERT INTO "languageNames" VALUES(9113,'fy','bua','Buriat');
INSERT INTO "languageNames" VALUES(9114,'fy','byv','Medumba');
INSERT INTO "languageNames" VALUES(9115,'fy','ca','Katalaansk');
INSERT INTO "languageNames" VALUES(9116,'fy','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(9117,'fy','chm','Mari');
INSERT INTO "languageNames" VALUES(9118,'fy','ckb','Soranî');
INSERT INTO "languageNames" VALUES(9119,'fy','co','Korsikaansk');
INSERT INTO "languageNames" VALUES(9120,'fy','crh','Krim-Tataarsk');
INSERT INTO "languageNames" VALUES(9121,'fy','cs','Tsjechysk');
INSERT INTO "languageNames" VALUES(9122,'fy','csb','Kasjoebysk');
INSERT INTO "languageNames" VALUES(9123,'fy','cu','Kerkslavysk');
INSERT INTO "languageNames" VALUES(9124,'fy','cv','Tsjoevasjysk');
INSERT INTO "languageNames" VALUES(9125,'fy','cy','Welsk');
INSERT INTO "languageNames" VALUES(9126,'fy','da','Deensk');
INSERT INTO "languageNames" VALUES(9127,'fy','dar','Dargwa');
INSERT INTO "languageNames" VALUES(9128,'fy','de','Dútsk');
INSERT INTO "languageNames" VALUES(9129,'fy','dsb','Nedersorbysk');
INSERT INTO "languageNames" VALUES(9130,'fy','el','Gryks');
INSERT INTO "languageNames" VALUES(9131,'fy','en','Ingelsk');
INSERT INTO "languageNames" VALUES(9132,'fy','eo','Esperanto');
INSERT INTO "languageNames" VALUES(9133,'fy','es','Spaansk');
INSERT INTO "languageNames" VALUES(9134,'fy','et','Estlânsk');
INSERT INTO "languageNames" VALUES(9135,'fy','eu','Baskysk');
INSERT INTO "languageNames" VALUES(9136,'fy','fa','Perzysk');
INSERT INTO "languageNames" VALUES(9137,'fy','fi','Finsk');
INSERT INTO "languageNames" VALUES(9138,'fy','fo','Faeröersk');
INSERT INTO "languageNames" VALUES(9139,'fy','fr','Frânsk');
INSERT INTO "languageNames" VALUES(9140,'fy','fy','Frysk');
INSERT INTO "languageNames" VALUES(9141,'fy','ga','Iersk');
INSERT INTO "languageNames" VALUES(9142,'fy','gd','Schotsk Gaelic');
INSERT INTO "languageNames" VALUES(9143,'fy','gl','Galisysk');
INSERT INTO "languageNames" VALUES(9144,'fy','gn','Guaraní');
INSERT INTO "languageNames" VALUES(9145,'fy','gu','Gujarati');
INSERT INTO "languageNames" VALUES(9146,'fy','gv','Manks');
INSERT INTO "languageNames" VALUES(9147,'fy','ha','Hausa');
INSERT INTO "languageNames" VALUES(9148,'fy','haw','Hawaïaansk');
INSERT INTO "languageNames" VALUES(9149,'fy','he','Hebreeuwsk');
INSERT INTO "languageNames" VALUES(9150,'fy','hi','Hindi');
INSERT INTO "languageNames" VALUES(9151,'fy','hr','Kroatysk');
INSERT INTO "languageNames" VALUES(9152,'fy','hsb','Oppersorbysk');
INSERT INTO "languageNames" VALUES(9153,'fy','ht','Haïtiaansk');
INSERT INTO "languageNames" VALUES(9154,'fy','hu','Hongaarsk');
INSERT INTO "languageNames" VALUES(9155,'fy','hy','Armeensk');
INSERT INTO "languageNames" VALUES(9156,'fy','ia','Interlingua');
INSERT INTO "languageNames" VALUES(9157,'fy','id','Yndonezysk');
INSERT INTO "languageNames" VALUES(9158,'fy','ig','Igbo');
INSERT INTO "languageNames" VALUES(9159,'fy','is','Yslâns');
INSERT INTO "languageNames" VALUES(9160,'fy','it','Italiaansk');
INSERT INTO "languageNames" VALUES(9161,'fy','ka','Georgysk');
INSERT INTO "languageNames" VALUES(9162,'fy','kaa','Karakalpaks');
INSERT INTO "languageNames" VALUES(9163,'fy','kk','Kazachs');
INSERT INTO "languageNames" VALUES(9164,'fy','ko','Koreaansk');
INSERT INTO "languageNames" VALUES(9165,'fy','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(9166,'fy','krl','Karelysk');
INSERT INTO "languageNames" VALUES(9167,'fy','ks','Kasjmiri');
INSERT INTO "languageNames" VALUES(9168,'fy','kum','Koemuks');
INSERT INTO "languageNames" VALUES(9169,'fy','kv','Komi');
INSERT INTO "languageNames" VALUES(9170,'fy','ky','Kirgizysk');
INSERT INTO "languageNames" VALUES(9171,'fy','la','Latyn');
INSERT INTO "languageNames" VALUES(9172,'fy','lb','Luxemburgs');
INSERT INTO "languageNames" VALUES(9173,'fy','lg','Ganda');
INSERT INTO "languageNames" VALUES(9174,'fy','ln','Lingala');
INSERT INTO "languageNames" VALUES(9175,'fy','lo','Laotiaansk');
INSERT INTO "languageNames" VALUES(9176,'fy','lt','Litouws');
INSERT INTO "languageNames" VALUES(9177,'fy','lv','Letlâns');
INSERT INTO "languageNames" VALUES(9178,'fy','mdf','Moksha');
INSERT INTO "languageNames" VALUES(9179,'fy','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(9180,'fy','mk','Macedonysk');
INSERT INTO "languageNames" VALUES(9181,'fy','ml','Malayalam');
INSERT INTO "languageNames" VALUES(9182,'fy','mr','Marathi');
INSERT INTO "languageNames" VALUES(9183,'fy','ms','Maleis');
INSERT INTO "languageNames" VALUES(9184,'fy','mt','Maltees');
INSERT INTO "languageNames" VALUES(9185,'fy','myv','Erzja');
INSERT INTO "languageNames" VALUES(9186,'fy','nap','Napolitaansk');
INSERT INTO "languageNames" VALUES(9187,'fy','nb','Noors - Bokmål');
INSERT INTO "languageNames" VALUES(9188,'fy','ne','Nepalees');
INSERT INTO "languageNames" VALUES(9189,'fy','nl','Nederlânsk');
INSERT INTO "languageNames" VALUES(9190,'fy','nn','Noors - Nynorsk');
INSERT INTO "languageNames" VALUES(9191,'fy','no','Noors');
INSERT INTO "languageNames" VALUES(9192,'fy','nog','Nogai');
INSERT INTO "languageNames" VALUES(9193,'fy','oc','Occitaansk');
INSERT INTO "languageNames" VALUES(9194,'fy','os','Ossetysk');
INSERT INTO "languageNames" VALUES(9195,'fy','ota','Ottomaansk-Turks');
INSERT INTO "languageNames" VALUES(9196,'fy','pa','Punjabi');
INSERT INTO "languageNames" VALUES(9197,'fy','pl','Poalsk');
INSERT INTO "languageNames" VALUES(9198,'fy','pt','Portugeesk');
INSERT INTO "languageNames" VALUES(9199,'fy','rm','Reto-Romaansk');
INSERT INTO "languageNames" VALUES(9200,'fy','rn','Kirundi');
INSERT INTO "languageNames" VALUES(9201,'fy','ro','Roemeensk');
INSERT INTO "languageNames" VALUES(9202,'fy','ru','Russysk');
INSERT INTO "languageNames" VALUES(9203,'fy','rup','Aromaniaansk');
INSERT INTO "languageNames" VALUES(9204,'fy','sa','Sanskriet');
INSERT INTO "languageNames" VALUES(9205,'fy','sah','Jakoets');
INSERT INTO "languageNames" VALUES(9206,'fy','sc','Sardinysk');
INSERT INTO "languageNames" VALUES(9207,'fy','scn','Siciliaansk');
INSERT INTO "languageNames" VALUES(9208,'fy','sco','Schots');
INSERT INTO "languageNames" VALUES(9209,'fy','sd','Sindhi');
INSERT INTO "languageNames" VALUES(9210,'fy','se','Noard-Samysk');
INSERT INTO "languageNames" VALUES(9211,'fy','sh','Servokroatysk');
INSERT INTO "languageNames" VALUES(9212,'fy','si','Singalees');
INSERT INTO "languageNames" VALUES(9213,'fy','sk','Slowaaks');
INSERT INTO "languageNames" VALUES(9214,'fy','sl','Sloveensk');
INSERT INTO "languageNames" VALUES(9215,'fy','sma','Sûd-Samysk');
INSERT INTO "languageNames" VALUES(9216,'fy','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(9217,'fy','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(9218,'fy','sq','Albaneesk');
INSERT INTO "languageNames" VALUES(9219,'fy','sr','Servysk');
INSERT INTO "languageNames" VALUES(9220,'fy','srn','Sranantongo');
INSERT INTO "languageNames" VALUES(9221,'fy','ss','Swazi');
INSERT INTO "languageNames" VALUES(9222,'fy','sv','Zweeds');
INSERT INTO "languageNames" VALUES(9223,'fy','sw','Swahili');
INSERT INTO "languageNames" VALUES(9224,'fy','ta','Tamil');
INSERT INTO "languageNames" VALUES(9225,'fy','te','Telugu');
INSERT INTO "languageNames" VALUES(9226,'fy','tet','Tetun');
INSERT INTO "languageNames" VALUES(9227,'fy','tg','Tadzjieks');
INSERT INTO "languageNames" VALUES(9228,'fy','th','Thais');
INSERT INTO "languageNames" VALUES(9229,'fy','tk','Turkmeens');
INSERT INTO "languageNames" VALUES(9230,'fy','tl','Tagalog');
INSERT INTO "languageNames" VALUES(9231,'fy','tr','Turks');
INSERT INTO "languageNames" VALUES(9232,'fy','tt','Tataars');
INSERT INTO "languageNames" VALUES(9233,'fy','tyv','Tuvinysk');
INSERT INTO "languageNames" VALUES(9234,'fy','udm','Oedmoerts');
INSERT INTO "languageNames" VALUES(9235,'fy','ug','Oeigoers');
INSERT INTO "languageNames" VALUES(9236,'fy','uk','Oekraïens');
INSERT INTO "languageNames" VALUES(9237,'fy','ur','Urdu');
INSERT INTO "languageNames" VALUES(9238,'fy','uz','Oezbeeks');
INSERT INTO "languageNames" VALUES(9239,'fy','vi','Vietnamees');
INSERT INTO "languageNames" VALUES(9240,'fy','wal','Walamo');
INSERT INTO "languageNames" VALUES(9241,'fy','xh','Xhosa');
INSERT INTO "languageNames" VALUES(9242,'fy','yi','Jiddysk');
INSERT INTO "languageNames" VALUES(9243,'fy','yo','Yoruba');
INSERT INTO "languageNames" VALUES(9244,'fy','zh','Sineesk');
INSERT INTO "languageNames" VALUES(9245,'fy','zu','Zulu');
INSERT INTO "languageNames" VALUES(9246,'de','af','Afrikaans');
INSERT INTO "languageNames" VALUES(9247,'de','alt','Süd-Altaisch');
INSERT INTO "languageNames" VALUES(9248,'de','an','Aragonesisch');
INSERT INTO "languageNames" VALUES(9249,'de','ar','Arabisch');
INSERT INTO "languageNames" VALUES(9250,'de','as','Assamesisch');
INSERT INTO "languageNames" VALUES(9251,'de','ast','Asturianisch');
INSERT INTO "languageNames" VALUES(9252,'de','av','Awarisch');
INSERT INTO "languageNames" VALUES(9254,'de','az','Aserbaidschanisch');
INSERT INTO "languageNames" VALUES(9255,'de','ba','Baschkirisch');
INSERT INTO "languageNames" VALUES(9256,'de','be','Weißrussisch');
INSERT INTO "languageNames" VALUES(9257,'de','bg','Bulgarisch');
INSERT INTO "languageNames" VALUES(9258,'de','bi','Bislama');
INSERT INTO "languageNames" VALUES(9259,'de','bn','Bengalisch');
INSERT INTO "languageNames" VALUES(9260,'de','br','Bretonisch');
INSERT INTO "languageNames" VALUES(9261,'de','bs','Bosnisch');
INSERT INTO "languageNames" VALUES(9262,'de','bua','Burjatisch');
INSERT INTO "languageNames" VALUES(9263,'de','byv','Medumba');
INSERT INTO "languageNames" VALUES(9264,'de','ca','Katalanisch');
INSERT INTO "languageNames" VALUES(9265,'de','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(9266,'de','chm','Mari');
INSERT INTO "languageNames" VALUES(9267,'de','ckb','Zentralkurdisch');
INSERT INTO "languageNames" VALUES(9268,'de','co','Korsisch');
INSERT INTO "languageNames" VALUES(9269,'de','crh','Krimtatarisch');
INSERT INTO "languageNames" VALUES(9270,'de','cs','Tschechisch');
INSERT INTO "languageNames" VALUES(9271,'de','csb','Kaschubisch');
INSERT INTO "languageNames" VALUES(9272,'de','cu','Kirchenslawisch');
INSERT INTO "languageNames" VALUES(9273,'de','cv','Tschuwaschisch');
INSERT INTO "languageNames" VALUES(9274,'de','cy','Walisisch');
INSERT INTO "languageNames" VALUES(9275,'de','da','Dänisch');
INSERT INTO "languageNames" VALUES(9276,'de','dar','Darginisch');
INSERT INTO "languageNames" VALUES(9277,'de','de','Deutsch');
INSERT INTO "languageNames" VALUES(9278,'de','dsb','Niedersorbisch');
INSERT INTO "languageNames" VALUES(9279,'de','el','Griechisch');
INSERT INTO "languageNames" VALUES(9280,'de','en','Englisch');
INSERT INTO "languageNames" VALUES(9281,'de','eo','Esperanto');
INSERT INTO "languageNames" VALUES(9282,'de','es','Spanisch');
INSERT INTO "languageNames" VALUES(9283,'de','et','Estnisch');
INSERT INTO "languageNames" VALUES(9284,'de','eu','Baskisch');
INSERT INTO "languageNames" VALUES(9285,'de','fa','Persisch');
INSERT INTO "languageNames" VALUES(9286,'de','fi','Finnisch');
INSERT INTO "languageNames" VALUES(9287,'de','fo','Färöisch');
INSERT INTO "languageNames" VALUES(9288,'de','fr','Französisch');
INSERT INTO "languageNames" VALUES(9289,'de','fy','Westfriesisch');
INSERT INTO "languageNames" VALUES(9290,'de','ga','Irisch');
INSERT INTO "languageNames" VALUES(9291,'de','gag','Gagausisch');
INSERT INTO "languageNames" VALUES(9292,'de','gd','Schottisches Gälisch');
INSERT INTO "languageNames" VALUES(9293,'de','gl','Galicisch');
INSERT INTO "languageNames" VALUES(9294,'de','glk','Gilaki');
INSERT INTO "languageNames" VALUES(9295,'de','gn','Guarani');
INSERT INTO "languageNames" VALUES(9296,'de','gu','Gujarati');
INSERT INTO "languageNames" VALUES(9297,'de','guc','Wayúu');
INSERT INTO "languageNames" VALUES(9298,'de','gv','Manx');
INSERT INTO "languageNames" VALUES(9299,'de','ha','Haussa');
INSERT INTO "languageNames" VALUES(9300,'de','haw','Hawaiisch');
INSERT INTO "languageNames" VALUES(9301,'de','he','Hebräisch');
INSERT INTO "languageNames" VALUES(9302,'de','hi','Hindi');
INSERT INTO "languageNames" VALUES(9303,'de','hr','Kroatisch');
INSERT INTO "languageNames" VALUES(9304,'de','hsb','Obersorbisch');
INSERT INTO "languageNames" VALUES(9305,'de','ht','Haiti-Kreolisch');
INSERT INTO "languageNames" VALUES(9306,'de','hu','Ungarisch');
INSERT INTO "languageNames" VALUES(9307,'de','hy','Armenisch');
INSERT INTO "languageNames" VALUES(9308,'de','ia','Interlingua');
INSERT INTO "languageNames" VALUES(9309,'de','id','Indonesisch');
INSERT INTO "languageNames" VALUES(9310,'de','ig','Igbo');
INSERT INTO "languageNames" VALUES(9311,'de','is','Isländisch');
INSERT INTO "languageNames" VALUES(9312,'de','it','Italienisch');
INSERT INTO "languageNames" VALUES(9313,'de','ka','Georgisch');
INSERT INTO "languageNames" VALUES(9314,'de','kaa','Karakalpakisch');
INSERT INTO "languageNames" VALUES(9315,'de','kk','Kasachisch');
INSERT INTO "languageNames" VALUES(9316,'de','ko','Koreanisch');
INSERT INTO "languageNames" VALUES(9317,'de','krc','Karatschaiisch-Balkarisch');
INSERT INTO "languageNames" VALUES(9318,'de','krl','Karelisch');
INSERT INTO "languageNames" VALUES(9319,'de','ks','Kaschmiri');
INSERT INTO "languageNames" VALUES(9320,'de','kum','Kumükisch');
INSERT INTO "languageNames" VALUES(9321,'de','kv','Komi');
INSERT INTO "languageNames" VALUES(9322,'de','ky','Kirgisisch');
INSERT INTO "languageNames" VALUES(9323,'de','la','Latein');
INSERT INTO "languageNames" VALUES(9324,'de','lb','Luxemburgisch');
INSERT INTO "languageNames" VALUES(9325,'de','lg','Ganda');
INSERT INTO "languageNames" VALUES(9326,'de','liv','Livisch');
INSERT INTO "languageNames" VALUES(9327,'de','ln','Lingala');
INSERT INTO "languageNames" VALUES(9328,'de','lo','Laotisch');
INSERT INTO "languageNames" VALUES(9329,'de','lt','Litauisch');
INSERT INTO "languageNames" VALUES(9330,'de','lv','Lettisch');
INSERT INTO "languageNames" VALUES(9331,'de','mdf','Mokschanisch');
INSERT INTO "languageNames" VALUES(9332,'de','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(9333,'de','mk','Mazedonisch');
INSERT INTO "languageNames" VALUES(9334,'de','ml','Malayalam');
INSERT INTO "languageNames" VALUES(9335,'de','mr','Marathi');
INSERT INTO "languageNames" VALUES(9336,'de','mrj','Bergmari');
INSERT INTO "languageNames" VALUES(9337,'de','ms','Malaiisch');
INSERT INTO "languageNames" VALUES(9338,'de','mt','Maltesisch');
INSERT INTO "languageNames" VALUES(9339,'de','myv','Ersja-Mordwinisch');
INSERT INTO "languageNames" VALUES(9340,'de','nap','Neapolitanisch');
INSERT INTO "languageNames" VALUES(9341,'de','nb','Norwegisch Bokmål');
INSERT INTO "languageNames" VALUES(9342,'de','ne','Nepalesisch');
INSERT INTO "languageNames" VALUES(9343,'de','nl','Niederländisch');
INSERT INTO "languageNames" VALUES(9344,'de','nn','Norwegisch Nynorsk');
INSERT INTO "languageNames" VALUES(9345,'de','no','Norwegisch');
INSERT INTO "languageNames" VALUES(9346,'de','nog','Nogai');
INSERT INTO "languageNames" VALUES(9347,'de','oc','Okzitanisch');
INSERT INTO "languageNames" VALUES(9348,'de','os','Ossetisch');
INSERT INTO "languageNames" VALUES(9349,'de','ota','Osmanisch');
INSERT INTO "languageNames" VALUES(9350,'de','pa','Punjabi');
INSERT INTO "languageNames" VALUES(9351,'de','pl','Polnisch');
INSERT INTO "languageNames" VALUES(9352,'de','pt','Portugiesisch');
INSERT INTO "languageNames" VALUES(9353,'de','rm','Rätoromanisch');
INSERT INTO "languageNames" VALUES(9354,'de','rn','Rundi');
INSERT INTO "languageNames" VALUES(9355,'de','ro','Rumänisch');
INSERT INTO "languageNames" VALUES(9356,'de','ru','Russisch');
INSERT INTO "languageNames" VALUES(9357,'de','rup','Aromunisch');
INSERT INTO "languageNames" VALUES(9358,'de','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(9359,'de','sah','Jakutisch');
INSERT INTO "languageNames" VALUES(9360,'de','sc','Sardisch');
INSERT INTO "languageNames" VALUES(9361,'de','scn','Sizilianisch');
INSERT INTO "languageNames" VALUES(9362,'de','sco','Schottisch');
INSERT INTO "languageNames" VALUES(9363,'de','sd','Sindhi');
INSERT INTO "languageNames" VALUES(9364,'de','se','Nordsamisch');
INSERT INTO "languageNames" VALUES(9365,'de','sh','Serbo-Kroatisch');
INSERT INTO "languageNames" VALUES(9366,'de','si','Singhalesisch');
INSERT INTO "languageNames" VALUES(9367,'de','sk','Slowakisch');
INSERT INTO "languageNames" VALUES(9368,'de','sl','Slowenisch');
INSERT INTO "languageNames" VALUES(9369,'de','sma','Südsamisch');
INSERT INTO "languageNames" VALUES(9370,'de','smj','Lule-Samisch');
INSERT INTO "languageNames" VALUES(9371,'de','smn','Inari-Samisch');
INSERT INTO "languageNames" VALUES(9372,'de','sq','Albanisch');
INSERT INTO "languageNames" VALUES(9373,'de','sr','Serbisch');
INSERT INTO "languageNames" VALUES(9374,'de','srn','Srananisch');
INSERT INTO "languageNames" VALUES(9375,'de','ss','Swazi');
INSERT INTO "languageNames" VALUES(9376,'de','sv','Schwedisch');
INSERT INTO "languageNames" VALUES(9377,'de','sw','Suaheli');
INSERT INTO "languageNames" VALUES(9378,'de','ta','Tamil');
INSERT INTO "languageNames" VALUES(9379,'de','te','Telugu');
INSERT INTO "languageNames" VALUES(9380,'de','tet','Tetum');
INSERT INTO "languageNames" VALUES(9381,'de','tg','Tadschikisch');
INSERT INTO "languageNames" VALUES(9382,'de','th','Thailändisch');
INSERT INTO "languageNames" VALUES(9383,'de','tk','Turkmenisch');
INSERT INTO "languageNames" VALUES(9384,'de','tl','Tagalog');
INSERT INTO "languageNames" VALUES(9385,'de','tr','Türkisch');
INSERT INTO "languageNames" VALUES(9386,'de','tt','Tatarisch');
INSERT INTO "languageNames" VALUES(9387,'de','tyv','Tuwinisch');
INSERT INTO "languageNames" VALUES(9388,'de','udm','Udmurtisch');
INSERT INTO "languageNames" VALUES(9389,'de','ug','Uigurisch');
INSERT INTO "languageNames" VALUES(9390,'de','uk','Ukrainisch');
INSERT INTO "languageNames" VALUES(9391,'de','ur','Urdu');
INSERT INTO "languageNames" VALUES(9392,'de','uz','Usbekisch');
INSERT INTO "languageNames" VALUES(9393,'de','vi','Vietnamesisch');
INSERT INTO "languageNames" VALUES(9394,'de','vro','Võro');
INSERT INTO "languageNames" VALUES(9395,'de','wal','Walamo');
INSERT INTO "languageNames" VALUES(9396,'de','xh','Xhosa');
INSERT INTO "languageNames" VALUES(9397,'de','yi','Jiddisch');
INSERT INTO "languageNames" VALUES(9398,'de','yo','Yoruba');
INSERT INTO "languageNames" VALUES(9399,'de','zh','Chinesisch');
INSERT INTO "languageNames" VALUES(9400,'de','zu','Zulu');
INSERT INTO "languageNames" VALUES(9401,'da','af','afrikaans');
INSERT INTO "languageNames" VALUES(9402,'da','alt','sydaltaisk');
INSERT INTO "languageNames" VALUES(9403,'da','an','aragonesisk');
INSERT INTO "languageNames" VALUES(9404,'da','ar','arabisk');
INSERT INTO "languageNames" VALUES(9405,'da','as','assamesisk');
INSERT INTO "languageNames" VALUES(9406,'da','ast','asturisk');
INSERT INTO "languageNames" VALUES(9407,'da','av','avarisk');
INSERT INTO "languageNames" VALUES(9409,'da','az','azeri');
INSERT INTO "languageNames" VALUES(9410,'da','ba','bashkir');
INSERT INTO "languageNames" VALUES(9411,'da','be','hviderussisk');
INSERT INTO "languageNames" VALUES(9412,'da','bg','bulgarsk');
INSERT INTO "languageNames" VALUES(9413,'da','bi','bislama');
INSERT INTO "languageNames" VALUES(9414,'da','bn','bengali');
INSERT INTO "languageNames" VALUES(9415,'da','br','bretonsk');
INSERT INTO "languageNames" VALUES(9416,'da','bs','bosnisk');
INSERT INTO "languageNames" VALUES(9417,'da','bua','buriatisk');
INSERT INTO "languageNames" VALUES(9418,'da','byv','medumba');
INSERT INTO "languageNames" VALUES(9419,'da','ca','catalansk');
INSERT INTO "languageNames" VALUES(9420,'da','ceb','cebuano');
INSERT INTO "languageNames" VALUES(9421,'da','chm','mari');
INSERT INTO "languageNames" VALUES(9422,'da','ckb','sorani');
INSERT INTO "languageNames" VALUES(9423,'da','co','korsikansk');
INSERT INTO "languageNames" VALUES(9424,'da','crh','krim-tyrkisk');
INSERT INTO "languageNames" VALUES(9425,'da','cs','tjekkisk');
INSERT INTO "languageNames" VALUES(9426,'da','csb','kasjubisk');
INSERT INTO "languageNames" VALUES(9427,'da','cu','kirkeslavisk');
INSERT INTO "languageNames" VALUES(9428,'da','cv','chuvash');
INSERT INTO "languageNames" VALUES(9429,'da','cy','walisisk');
INSERT INTO "languageNames" VALUES(9430,'da','da','dansk');
INSERT INTO "languageNames" VALUES(9431,'da','dar','dargwa');
INSERT INTO "languageNames" VALUES(9432,'da','de','tysk');
INSERT INTO "languageNames" VALUES(9433,'da','dsb','nedersorbisk');
INSERT INTO "languageNames" VALUES(9434,'da','el','græsk');
INSERT INTO "languageNames" VALUES(9435,'da','en','engelsk');
INSERT INTO "languageNames" VALUES(9436,'da','eo','esperanto');
INSERT INTO "languageNames" VALUES(9437,'da','es','spansk');
INSERT INTO "languageNames" VALUES(9438,'da','et','estisk');
INSERT INTO "languageNames" VALUES(9439,'da','eu','baskisk');
INSERT INTO "languageNames" VALUES(9440,'da','fa','persisk');
INSERT INTO "languageNames" VALUES(9441,'da','fi','finsk');
INSERT INTO "languageNames" VALUES(9442,'da','fo','færøsk');
INSERT INTO "languageNames" VALUES(9443,'da','fr','fransk');
INSERT INTO "languageNames" VALUES(9444,'da','fy','frisisk');
INSERT INTO "languageNames" VALUES(9445,'da','ga','irsk');
INSERT INTO "languageNames" VALUES(9446,'da','gag','gagauzisk');
INSERT INTO "languageNames" VALUES(9447,'da','gd','skotsk gælisk');
INSERT INTO "languageNames" VALUES(9448,'da','gl','galicisk');
INSERT INTO "languageNames" VALUES(9449,'da','gn','guarani');
INSERT INTO "languageNames" VALUES(9450,'da','gu','gujarati');
INSERT INTO "languageNames" VALUES(9451,'da','gv','manx');
INSERT INTO "languageNames" VALUES(9452,'da','ha','hausa');
INSERT INTO "languageNames" VALUES(9453,'da','haw','hawaiiansk');
INSERT INTO "languageNames" VALUES(9454,'da','he','hebraisk');
INSERT INTO "languageNames" VALUES(9455,'da','hi','hindi');
INSERT INTO "languageNames" VALUES(9456,'da','hr','kroatisk');
INSERT INTO "languageNames" VALUES(9457,'da','hsb','øvresorbisk');
INSERT INTO "languageNames" VALUES(9458,'da','ht','haitisk');
INSERT INTO "languageNames" VALUES(9459,'da','hu','ungarsk');
INSERT INTO "languageNames" VALUES(9460,'da','hy','armensk');
INSERT INTO "languageNames" VALUES(9461,'da','ia','interlingua');
INSERT INTO "languageNames" VALUES(9462,'da','id','indonesisk');
INSERT INTO "languageNames" VALUES(9463,'da','ig','igbo');
INSERT INTO "languageNames" VALUES(9464,'da','is','islandsk');
INSERT INTO "languageNames" VALUES(9465,'da','it','italiensk');
INSERT INTO "languageNames" VALUES(9466,'da','ka','georgisk');
INSERT INTO "languageNames" VALUES(9467,'da','kaa','karakalpakisk');
INSERT INTO "languageNames" VALUES(9468,'da','kk','kasakhisk');
INSERT INTO "languageNames" VALUES(9469,'da','ko','koreansk');
INSERT INTO "languageNames" VALUES(9470,'da','krc','karatjai-balkar');
INSERT INTO "languageNames" VALUES(9471,'da','krl','karelsk');
INSERT INTO "languageNames" VALUES(9472,'da','ks','kashmiri');
INSERT INTO "languageNames" VALUES(9473,'da','kum','kymyk');
INSERT INTO "languageNames" VALUES(9474,'da','kv','komi');
INSERT INTO "languageNames" VALUES(9475,'da','ky','kirgisisk');
INSERT INTO "languageNames" VALUES(9476,'da','la','latin');
INSERT INTO "languageNames" VALUES(9477,'da','lb','luxembourgsk');
INSERT INTO "languageNames" VALUES(9478,'da','lg','ganda');
INSERT INTO "languageNames" VALUES(9479,'da','ln','lingala');
INSERT INTO "languageNames" VALUES(9480,'da','lo','lao');
INSERT INTO "languageNames" VALUES(9481,'da','lt','litauisk');
INSERT INTO "languageNames" VALUES(9482,'da','lv','lettisk');
INSERT INTO "languageNames" VALUES(9483,'da','mdf','moksha');
INSERT INTO "languageNames" VALUES(9484,'da','mfe','morisyen');
INSERT INTO "languageNames" VALUES(9485,'da','mk','makedonsk');
INSERT INTO "languageNames" VALUES(9486,'da','ml','malayalam');
INSERT INTO "languageNames" VALUES(9487,'da','mr','marathisk');
INSERT INTO "languageNames" VALUES(9488,'da','ms','malajisk');
INSERT INTO "languageNames" VALUES(9489,'da','mt','maltesisk');
INSERT INTO "languageNames" VALUES(9490,'da','myv','erzya');
INSERT INTO "languageNames" VALUES(9491,'da','nap','napolitansk');
INSERT INTO "languageNames" VALUES(9492,'da','nb','norsk bokmål');
INSERT INTO "languageNames" VALUES(9493,'da','ne','nepalesisk');
INSERT INTO "languageNames" VALUES(9494,'da','nl','hollandsk');
INSERT INTO "languageNames" VALUES(9495,'da','nn','nynorsk');
INSERT INTO "languageNames" VALUES(9496,'da','no','norsk');
INSERT INTO "languageNames" VALUES(9497,'da','nog','nogai');
INSERT INTO "languageNames" VALUES(9498,'da','oc','occitansk');
INSERT INTO "languageNames" VALUES(9499,'da','os','ossetisk');
INSERT INTO "languageNames" VALUES(9500,'da','ota','osmannisk tyrkisk');
INSERT INTO "languageNames" VALUES(9501,'da','pa','punjabisk');
INSERT INTO "languageNames" VALUES(9502,'da','pl','polsk');
INSERT INTO "languageNames" VALUES(9503,'da','pt','portugisisk');
INSERT INTO "languageNames" VALUES(9504,'da','rm','rætoromansk');
INSERT INTO "languageNames" VALUES(9505,'da','rn','rundi');
INSERT INTO "languageNames" VALUES(9506,'da','ro','rumænsk');
INSERT INTO "languageNames" VALUES(9507,'da','ru','russisk');
INSERT INTO "languageNames" VALUES(9508,'da','rup','arumænsk');
INSERT INTO "languageNames" VALUES(9509,'da','sa','sanskrit');
INSERT INTO "languageNames" VALUES(9510,'da','sah','yakut');
INSERT INTO "languageNames" VALUES(9511,'da','sc','sardinsk');
INSERT INTO "languageNames" VALUES(9512,'da','scn','siciliansk');
INSERT INTO "languageNames" VALUES(9513,'da','sco','skotsk');
INSERT INTO "languageNames" VALUES(9514,'da','sd','sindhi');
INSERT INTO "languageNames" VALUES(9515,'da','se','nordsamisk');
INSERT INTO "languageNames" VALUES(9516,'da','sh','serbokroatisk');
INSERT INTO "languageNames" VALUES(9517,'da','si','singalesisk');
INSERT INTO "languageNames" VALUES(9518,'da','sk','slovakisk');
INSERT INTO "languageNames" VALUES(9519,'da','sl','slovensk');
INSERT INTO "languageNames" VALUES(9520,'da','sma','sydsamisk');
INSERT INTO "languageNames" VALUES(9521,'da','smj','lulesamisk');
INSERT INTO "languageNames" VALUES(9522,'da','smn','enaresamisk');
INSERT INTO "languageNames" VALUES(9523,'da','sq','albansk');
INSERT INTO "languageNames" VALUES(9524,'da','sr','serbisk');
INSERT INTO "languageNames" VALUES(9525,'da','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(9526,'da','ss','swati');
INSERT INTO "languageNames" VALUES(9527,'da','sv','svensk');
INSERT INTO "languageNames" VALUES(9528,'da','sw','swahili');
INSERT INTO "languageNames" VALUES(9529,'da','ta','tamil');
INSERT INTO "languageNames" VALUES(9530,'da','te','telugu');
INSERT INTO "languageNames" VALUES(9531,'da','tet','tetum');
INSERT INTO "languageNames" VALUES(9532,'da','tg','tadsjikisk');
INSERT INTO "languageNames" VALUES(9533,'da','th','thai');
INSERT INTO "languageNames" VALUES(9534,'da','tk','turkmensk');
INSERT INTO "languageNames" VALUES(9535,'da','tl','tagalog');
INSERT INTO "languageNames" VALUES(9536,'da','tr','tyrkisk');
INSERT INTO "languageNames" VALUES(9537,'da','tt','tatarisk');
INSERT INTO "languageNames" VALUES(9538,'da','tyv','tuvinian');
INSERT INTO "languageNames" VALUES(9539,'da','udm','udmurt');
INSERT INTO "languageNames" VALUES(9541,'da','ug','uighurisk');
INSERT INTO "languageNames" VALUES(9542,'da','uk','ukrainsk');
INSERT INTO "languageNames" VALUES(9543,'da','ur','urdu');
INSERT INTO "languageNames" VALUES(9544,'da','uz','usbekisk');
INSERT INTO "languageNames" VALUES(9545,'da','vi','vietnamesisk');
INSERT INTO "languageNames" VALUES(9546,'da','wal','walamo');
INSERT INTO "languageNames" VALUES(9547,'da','xh','isiXhosa');
INSERT INTO "languageNames" VALUES(9548,'da','yi','jiddisch');
INSERT INTO "languageNames" VALUES(9549,'da','yo','yoruba');
INSERT INTO "languageNames" VALUES(9550,'da','zh','kinesisk');
INSERT INTO "languageNames" VALUES(9551,'da','zu','zulu');
INSERT INTO "languageNames" VALUES(9552,'bg','af','африканс');
INSERT INTO "languageNames" VALUES(9553,'bg','alt','южноалтайски');
INSERT INTO "languageNames" VALUES(9554,'bg','an','арагонски');
INSERT INTO "languageNames" VALUES(9555,'bg','ar','арабски');
INSERT INTO "languageNames" VALUES(9556,'bg','as','асамски');
INSERT INTO "languageNames" VALUES(9557,'bg','ast','астурски');
INSERT INTO "languageNames" VALUES(9558,'bg','av','аварски');
INSERT INTO "languageNames" VALUES(9560,'bg','az','азерски');
INSERT INTO "languageNames" VALUES(9561,'bg','ba','башкирски');
INSERT INTO "languageNames" VALUES(9562,'bg','be','беларуски');
INSERT INTO "languageNames" VALUES(9563,'bg','bg','български');
INSERT INTO "languageNames" VALUES(9564,'bg','bi','бислама');
INSERT INTO "languageNames" VALUES(9565,'bg','bn','бенгалски');
INSERT INTO "languageNames" VALUES(9566,'bg','br','бретонски');
INSERT INTO "languageNames" VALUES(9567,'bg','bs','босненски');
INSERT INTO "languageNames" VALUES(9568,'bg','bua','бурятски');
INSERT INTO "languageNames" VALUES(9569,'bg','ca','каталонски');
INSERT INTO "languageNames" VALUES(9570,'bg','ceb','себуански');
INSERT INTO "languageNames" VALUES(9571,'bg','chm','марийски');
INSERT INTO "languageNames" VALUES(9572,'bg','ckb','кюрдски (централен)');
INSERT INTO "languageNames" VALUES(9573,'bg','co','корсикански');
INSERT INTO "languageNames" VALUES(9574,'bg','crh','кримскотатарски');
INSERT INTO "languageNames" VALUES(9575,'bg','cs','чешки');
INSERT INTO "languageNames" VALUES(9576,'bg','csb','кашубски');
INSERT INTO "languageNames" VALUES(9577,'bg','cu','църковнославянски');
INSERT INTO "languageNames" VALUES(9578,'bg','cv','чувашки');
INSERT INTO "languageNames" VALUES(9579,'bg','cy','уелски');
INSERT INTO "languageNames" VALUES(9580,'bg','da','датски');
INSERT INTO "languageNames" VALUES(9581,'bg','dar','даргва');
INSERT INTO "languageNames" VALUES(9582,'bg','de','немски');
INSERT INTO "languageNames" VALUES(9583,'bg','dsb','долнолужишки');
INSERT INTO "languageNames" VALUES(9584,'bg','el','гръцки');
INSERT INTO "languageNames" VALUES(9585,'bg','en','английски');
INSERT INTO "languageNames" VALUES(9586,'bg','eo','есперанто');
INSERT INTO "languageNames" VALUES(9587,'bg','es','испански');
INSERT INTO "languageNames" VALUES(9588,'bg','et','естонски');
INSERT INTO "languageNames" VALUES(9589,'bg','eu','баски');
INSERT INTO "languageNames" VALUES(9590,'bg','fa','персийски');
INSERT INTO "languageNames" VALUES(9591,'bg','fi','фински');
INSERT INTO "languageNames" VALUES(9592,'bg','fo','фарьорски');
INSERT INTO "languageNames" VALUES(9593,'bg','fr','френски');
INSERT INTO "languageNames" VALUES(9594,'bg','fy','западнофризийски');
INSERT INTO "languageNames" VALUES(9595,'bg','ga','ирландски');
INSERT INTO "languageNames" VALUES(9596,'bg','gag','гагаузки');
INSERT INTO "languageNames" VALUES(9597,'bg','gd','шотландски галски');
INSERT INTO "languageNames" VALUES(9598,'bg','gl','галисийски');
INSERT INTO "languageNames" VALUES(9599,'bg','gn','гуарани');
INSERT INTO "languageNames" VALUES(9600,'bg','gu','гуджарати');
INSERT INTO "languageNames" VALUES(9601,'bg','gv','манкски');
INSERT INTO "languageNames" VALUES(9602,'bg','ha','хауса');
INSERT INTO "languageNames" VALUES(9603,'bg','haw','хавайски');
INSERT INTO "languageNames" VALUES(9604,'bg','he','иврит');
INSERT INTO "languageNames" VALUES(9605,'bg','hi','хинди');
INSERT INTO "languageNames" VALUES(9606,'bg','hr','хърватски');
INSERT INTO "languageNames" VALUES(9607,'bg','hsb','горнолужишки');
INSERT INTO "languageNames" VALUES(9608,'bg','ht','хаитянски креолски');
INSERT INTO "languageNames" VALUES(9609,'bg','hu','унгарски');
INSERT INTO "languageNames" VALUES(9610,'bg','hy','арменски');
INSERT INTO "languageNames" VALUES(9611,'bg','ia','интерлингва');
INSERT INTO "languageNames" VALUES(9612,'bg','id','индонезийски');
INSERT INTO "languageNames" VALUES(9613,'bg','ig','игбо');
INSERT INTO "languageNames" VALUES(9614,'bg','is','исландски');
INSERT INTO "languageNames" VALUES(9615,'bg','it','италиански');
INSERT INTO "languageNames" VALUES(9616,'bg','ka','грузински');
INSERT INTO "languageNames" VALUES(9617,'bg','kaa','каракалпашки');
INSERT INTO "languageNames" VALUES(9618,'bg','kk','казахски');
INSERT INTO "languageNames" VALUES(9619,'bg','ko','корейски');
INSERT INTO "languageNames" VALUES(9620,'bg','krc','карачай-балкарски');
INSERT INTO "languageNames" VALUES(9621,'bg','krl','карелски');
INSERT INTO "languageNames" VALUES(9622,'bg','ks','кашмирски');
INSERT INTO "languageNames" VALUES(9623,'bg','kum','кумикски');
INSERT INTO "languageNames" VALUES(9624,'bg','kv','коми');
INSERT INTO "languageNames" VALUES(9625,'bg','ky','киргизки');
INSERT INTO "languageNames" VALUES(9626,'bg','la','латински');
INSERT INTO "languageNames" VALUES(9627,'bg','lb','люксембургски');
INSERT INTO "languageNames" VALUES(9628,'bg','lg','ганда');
INSERT INTO "languageNames" VALUES(9629,'bg','ln','лингала');
INSERT INTO "languageNames" VALUES(9630,'bg','lo','лаоски');
INSERT INTO "languageNames" VALUES(9631,'bg','lt','литовски');
INSERT INTO "languageNames" VALUES(9632,'bg','lv','латвийски');
INSERT INTO "languageNames" VALUES(9633,'bg','mdf','мокша');
INSERT INTO "languageNames" VALUES(9634,'bg','mfe','морисиен');
INSERT INTO "languageNames" VALUES(9635,'bg','mk','македонски');
INSERT INTO "languageNames" VALUES(9636,'bg','ml','малаялам');
INSERT INTO "languageNames" VALUES(9637,'bg','mr','марати');
INSERT INTO "languageNames" VALUES(9638,'bg','ms','малайски');
INSERT INTO "languageNames" VALUES(9639,'bg','mt','малтийски');
INSERT INTO "languageNames" VALUES(9640,'bg','myv','ерзиа');
INSERT INTO "languageNames" VALUES(9641,'bg','nap','неаполитански');
INSERT INTO "languageNames" VALUES(9642,'bg','nb','норвежки (букмол)');
INSERT INTO "languageNames" VALUES(9643,'bg','ne','непалски');
INSERT INTO "languageNames" VALUES(9644,'bg','nl','нидерландски');
INSERT INTO "languageNames" VALUES(9645,'bg','nn','норвежки (нюношк)');
INSERT INTO "languageNames" VALUES(9646,'bg','no','норвежки');
INSERT INTO "languageNames" VALUES(9647,'bg','nog','ногаи');
INSERT INTO "languageNames" VALUES(9648,'bg','oc','окситански');
INSERT INTO "languageNames" VALUES(9649,'bg','os','осетски');
INSERT INTO "languageNames" VALUES(9650,'bg','ota','отомански турски');
INSERT INTO "languageNames" VALUES(9651,'bg','pa','пенджабски');
INSERT INTO "languageNames" VALUES(9652,'bg','pl','полски');
INSERT INTO "languageNames" VALUES(9653,'bg','pt','португалски');
INSERT INTO "languageNames" VALUES(9654,'bg','rm','реторомански');
INSERT INTO "languageNames" VALUES(9655,'bg','rn','рунди');
INSERT INTO "languageNames" VALUES(9656,'bg','ro','румънски');
INSERT INTO "languageNames" VALUES(9657,'bg','ru','руски');
INSERT INTO "languageNames" VALUES(9658,'bg','rup','арумънски');
INSERT INTO "languageNames" VALUES(9659,'bg','sa','санскрит');
INSERT INTO "languageNames" VALUES(9660,'bg','sah','якутски');
INSERT INTO "languageNames" VALUES(9661,'bg','sc','сардински');
INSERT INTO "languageNames" VALUES(9662,'bg','scn','сицилиански');
INSERT INTO "languageNames" VALUES(9663,'bg','sco','шотландски');
INSERT INTO "languageNames" VALUES(9664,'bg','sd','синдхи');
INSERT INTO "languageNames" VALUES(9665,'bg','se','северносаамски');
INSERT INTO "languageNames" VALUES(9666,'bg','sh','сърбохърватски');
INSERT INTO "languageNames" VALUES(9667,'bg','si','синхалски');
INSERT INTO "languageNames" VALUES(9668,'bg','sk','словашки');
INSERT INTO "languageNames" VALUES(9669,'bg','sl','словенски');
INSERT INTO "languageNames" VALUES(9670,'bg','sma','южносаамски');
INSERT INTO "languageNames" VALUES(9671,'bg','smj','луле-саамски');
INSERT INTO "languageNames" VALUES(9672,'bg','smn','инари-саамски');
INSERT INTO "languageNames" VALUES(9673,'bg','sq','албански');
INSERT INTO "languageNames" VALUES(9674,'bg','sr','сръбски');
INSERT INTO "languageNames" VALUES(9675,'bg','srn','сранан тонго');
INSERT INTO "languageNames" VALUES(9676,'bg','ss','свати');
INSERT INTO "languageNames" VALUES(9677,'bg','sv','шведски');
INSERT INTO "languageNames" VALUES(9678,'bg','sw','суахили');
INSERT INTO "languageNames" VALUES(9679,'bg','ta','тамилски');
INSERT INTO "languageNames" VALUES(9680,'bg','te','телугу');
INSERT INTO "languageNames" VALUES(9681,'bg','tet','тетум');
INSERT INTO "languageNames" VALUES(9682,'bg','tg','таджикски');
INSERT INTO "languageNames" VALUES(9683,'bg','th','тайски');
INSERT INTO "languageNames" VALUES(9684,'bg','tk','туркменски');
INSERT INTO "languageNames" VALUES(9685,'bg','tl','тагалог');
INSERT INTO "languageNames" VALUES(9686,'bg','tr','турски');
INSERT INTO "languageNames" VALUES(9687,'bg','tt','татарски');
INSERT INTO "languageNames" VALUES(9688,'bg','tyv','тувински');
INSERT INTO "languageNames" VALUES(9689,'bg','udm','удмуртски');
INSERT INTO "languageNames" VALUES(9690,'bg','ug','уйгурски');
INSERT INTO "languageNames" VALUES(9691,'bg','uk','украински');
INSERT INTO "languageNames" VALUES(9692,'bg','ur','урду');
INSERT INTO "languageNames" VALUES(9693,'bg','uz','узбекски');
INSERT INTO "languageNames" VALUES(9694,'bg','vi','виетнамски');
INSERT INTO "languageNames" VALUES(9695,'bg','wal','валамо');
INSERT INTO "languageNames" VALUES(9696,'bg','xh','ксоса');
INSERT INTO "languageNames" VALUES(9697,'bg','yi','идиш');
INSERT INTO "languageNames" VALUES(9698,'bg','yo','йоруба');
INSERT INTO "languageNames" VALUES(9699,'bg','zh','китайски');
INSERT INTO "languageNames" VALUES(9700,'bg','zu','зулуски');
INSERT INTO "languageNames" VALUES(9701,'se','af','afrikánsagiella');
INSERT INTO "languageNames" VALUES(9702,'se','an','aragoniagiella');
INSERT INTO "languageNames" VALUES(9703,'se','ar','arábagiella');
INSERT INTO "languageNames" VALUES(9704,'se','ast','asturiagiella');
INSERT INTO "languageNames" VALUES(9705,'se','be','vilges-ruoššagiella');
INSERT INTO "languageNames" VALUES(9706,'se','bg','bulgáriagiella');
INSERT INTO "languageNames" VALUES(9707,'se','bn','bengalgiella');
INSERT INTO "languageNames" VALUES(9708,'se','br','bretonagiella');
INSERT INTO "languageNames" VALUES(9709,'se','bs','bosniagiella');
INSERT INTO "languageNames" VALUES(9710,'se','ca','katalánagiella');
INSERT INTO "languageNames" VALUES(9711,'se','chm','marigiella');
INSERT INTO "languageNames" VALUES(9712,'se','co','corsicagiella');
INSERT INTO "languageNames" VALUES(9713,'se','cs','čeahkagiella');
INSERT INTO "languageNames" VALUES(9714,'se','cy','kymragiella');
INSERT INTO "languageNames" VALUES(9715,'se','da','dánskkagiella');
INSERT INTO "languageNames" VALUES(9716,'se','de','duiskkagiella');
INSERT INTO "languageNames" VALUES(9717,'se','el','greikkagiella');
INSERT INTO "languageNames" VALUES(9718,'se','en','eaŋgalsgiella');
INSERT INTO "languageNames" VALUES(9719,'se','es','spánskkagiella');
INSERT INTO "languageNames" VALUES(9720,'se','et','esttegiella');
INSERT INTO "languageNames" VALUES(9721,'se','fa','persijagiella');
INSERT INTO "languageNames" VALUES(9722,'se','fi','suomagiella');
INSERT INTO "languageNames" VALUES(9723,'se','fo','fearagiella');
INSERT INTO "languageNames" VALUES(9724,'se','fr','fránskkagiella');
INSERT INTO "languageNames" VALUES(9725,'se','fy','oarjifriisagiella');
INSERT INTO "languageNames" VALUES(9726,'se','ga','iirragiella');
INSERT INTO "languageNames" VALUES(9727,'se','gu','gujaratagiella');
INSERT INTO "languageNames" VALUES(9728,'se','gv','manksgiella');
INSERT INTO "languageNames" VALUES(9729,'se','ha','haussagiella');
INSERT INTO "languageNames" VALUES(9730,'se','haw','hawaiigiella');
INSERT INTO "languageNames" VALUES(9731,'se','hi','hindigiella');
INSERT INTO "languageNames" VALUES(9732,'se','hr','kroátiagiella');
INSERT INTO "languageNames" VALUES(9733,'se','ht','haitigiella');
INSERT INTO "languageNames" VALUES(9734,'se','hu','ungárgiella');
INSERT INTO "languageNames" VALUES(9735,'se','hy','armeenagiella');
INSERT INTO "languageNames" VALUES(9736,'se','id','indonesiagiella');
INSERT INTO "languageNames" VALUES(9737,'se','is','islánddagiella');
INSERT INTO "languageNames" VALUES(9738,'se','it','itáliagiella');
INSERT INTO "languageNames" VALUES(9739,'se','ka','georgiagiella');
INSERT INTO "languageNames" VALUES(9740,'se','kk','kazakgiella');
INSERT INTO "languageNames" VALUES(9741,'se','ko','koreagiella');
INSERT INTO "languageNames" VALUES(9742,'se','krl','gárjilgiella');
INSERT INTO "languageNames" VALUES(9743,'se','kv','komigiella');
INSERT INTO "languageNames" VALUES(9744,'se','la','láhtengiella');
INSERT INTO "languageNames" VALUES(9745,'se','lb','luxemburggagiella');
INSERT INTO "languageNames" VALUES(9746,'se','lo','laogiella');
INSERT INTO "languageNames" VALUES(9747,'se','lt','liettuvagiella');
INSERT INTO "languageNames" VALUES(9748,'se','lv','látviagiella');
INSERT INTO "languageNames" VALUES(9749,'se','mdf','mokšagiella');
INSERT INTO "languageNames" VALUES(9750,'se','mk','makedoniagiella');
INSERT INTO "languageNames" VALUES(9751,'se','mt','maltagiella');
INSERT INTO "languageNames" VALUES(9752,'se','myv','ersagiella');
INSERT INTO "languageNames" VALUES(9753,'se','nb','girjedárogiella');
INSERT INTO "languageNames" VALUES(9754,'se','ne','nepaligiella');
INSERT INTO "languageNames" VALUES(9755,'se','nl','hollánddagiella');
INSERT INTO "languageNames" VALUES(9756,'se','nn','ođđadárogiella');
INSERT INTO "languageNames" VALUES(9757,'se','no','dárogiella');
INSERT INTO "languageNames" VALUES(9758,'se','oc','oksitánagiella');
INSERT INTO "languageNames" VALUES(9759,'se','pa','panjabigiella');
INSERT INTO "languageNames" VALUES(9760,'se','pl','polskkagiella');
INSERT INTO "languageNames" VALUES(9761,'se','pt','portugálagiella');
INSERT INTO "languageNames" VALUES(9762,'se','rm','romanšgiella');
INSERT INTO "languageNames" VALUES(9763,'se','ro','romániagiella');
INSERT INTO "languageNames" VALUES(9764,'se','ru','ruoššagiella');
INSERT INTO "languageNames" VALUES(9765,'se','sc','sardigiella');
INSERT INTO "languageNames" VALUES(9766,'se','scn','sisiliagiella');
INSERT INTO "languageNames" VALUES(9767,'se','se','davvisámegiella');
INSERT INTO "languageNames" VALUES(9768,'se','sh','serbokroatiagiella');
INSERT INTO "languageNames" VALUES(9769,'se','sk','slovákiagiella');
INSERT INTO "languageNames" VALUES(9770,'se','sl','slovenagiella');
INSERT INTO "languageNames" VALUES(9771,'se','sma','lullisámegiella');
INSERT INTO "languageNames" VALUES(9772,'se','smj','julevsámegiella');
INSERT INTO "languageNames" VALUES(9773,'se','smn','anárašgiella');
INSERT INTO "languageNames" VALUES(9774,'se','sq','albánagiella');
INSERT INTO "languageNames" VALUES(9775,'se','sr','serbiagiella');
INSERT INTO "languageNames" VALUES(9776,'se','sv','ruoŧagiella');
INSERT INTO "languageNames" VALUES(9777,'se','th','ŧaigiella');
INSERT INTO "languageNames" VALUES(9778,'se','tr','durkagiella');
INSERT INTO "languageNames" VALUES(9779,'se','udm','udmurtagiella');
INSERT INTO "languageNames" VALUES(9780,'se','uk','ukrainagiella');
INSERT INTO "languageNames" VALUES(9781,'se','ur','urdugiella');
INSERT INTO "languageNames" VALUES(9782,'se','vi','vietnamgiella');
INSERT INTO "languageNames" VALUES(9783,'se','zh','kiinnágiella');
INSERT INTO "languageNames" VALUES(9784,'br','af','afrikaans');
INSERT INTO "languageNames" VALUES(9785,'br','alt','altaieg ar Su');
INSERT INTO "languageNames" VALUES(9786,'br','an','aragoneg');
INSERT INTO "languageNames" VALUES(9787,'br','ar','arabeg');
INSERT INTO "languageNames" VALUES(9788,'br','as','asameg');
INSERT INTO "languageNames" VALUES(9789,'br','ast','asturianeg');
INSERT INTO "languageNames" VALUES(9790,'br','av','avar');
INSERT INTO "languageNames" VALUES(9792,'br','az','azeri');
INSERT INTO "languageNames" VALUES(9793,'br','ba','bachkir');
INSERT INTO "languageNames" VALUES(9794,'br','be','belaruseg');
INSERT INTO "languageNames" VALUES(9795,'br','bg','bulgareg');
INSERT INTO "languageNames" VALUES(9796,'br','bi','bislama');
INSERT INTO "languageNames" VALUES(9797,'br','bn','bengali');
INSERT INTO "languageNames" VALUES(9798,'br','br','brezhoneg');
INSERT INTO "languageNames" VALUES(9799,'br','bs','bosneg');
INSERT INTO "languageNames" VALUES(9800,'br','bua','bouriat');
INSERT INTO "languageNames" VALUES(9801,'br','ca','katalaneg');
INSERT INTO "languageNames" VALUES(9802,'br','ceb','cebuano');
INSERT INTO "languageNames" VALUES(9803,'br','chm','marieg');
INSERT INTO "languageNames" VALUES(9804,'br','ckb','kurdeg sorani');
INSERT INTO "languageNames" VALUES(9805,'br','co','korseg');
INSERT INTO "languageNames" VALUES(9806,'br','crh','turkeg Krimea');
INSERT INTO "languageNames" VALUES(9807,'br','cs','tchekeg');
INSERT INTO "languageNames" VALUES(9808,'br','csb','kachoubeg');
INSERT INTO "languageNames" VALUES(9809,'br','cu','slavoneg iliz');
INSERT INTO "languageNames" VALUES(9810,'br','cv','tchouvatch');
INSERT INTO "languageNames" VALUES(9811,'br','cy','kembraeg');
INSERT INTO "languageNames" VALUES(9812,'br','da','daneg');
INSERT INTO "languageNames" VALUES(9813,'br','dar','dargwa');
INSERT INTO "languageNames" VALUES(9814,'br','de','alamaneg');
INSERT INTO "languageNames" VALUES(9815,'br','dsb','izelsorabeg');
INSERT INTO "languageNames" VALUES(9816,'br','el','gresianeg');
INSERT INTO "languageNames" VALUES(9817,'br','en','saozneg');
INSERT INTO "languageNames" VALUES(9818,'br','eo','esperanteg');
INSERT INTO "languageNames" VALUES(9819,'br','es','spagnoleg');
INSERT INTO "languageNames" VALUES(9820,'br','et','estoneg');
INSERT INTO "languageNames" VALUES(9821,'br','eu','euskareg');
INSERT INTO "languageNames" VALUES(9822,'br','fa','perseg');
INSERT INTO "languageNames" VALUES(9823,'br','fi','finneg');
INSERT INTO "languageNames" VALUES(9824,'br','fo','faeroeg');
INSERT INTO "languageNames" VALUES(9825,'br','fr','galleg');
INSERT INTO "languageNames" VALUES(9826,'br','fy','frizeg ar Cʼhornôg');
INSERT INTO "languageNames" VALUES(9827,'br','ga','iwerzhoneg');
INSERT INTO "languageNames" VALUES(9828,'br','gag','gagaouzeg');
INSERT INTO "languageNames" VALUES(9829,'br','gd','skoseg');
INSERT INTO "languageNames" VALUES(9830,'br','gl','galizeg');
INSERT INTO "languageNames" VALUES(9831,'br','gn','guarani');
INSERT INTO "languageNames" VALUES(9832,'br','gu','gujarati');
INSERT INTO "languageNames" VALUES(9833,'br','gv','manaveg');
INSERT INTO "languageNames" VALUES(9834,'br','ha','haousa');
INSERT INTO "languageNames" VALUES(9835,'br','haw','hawaieg');
INSERT INTO "languageNames" VALUES(9836,'br','he','hebraeg');
INSERT INTO "languageNames" VALUES(9837,'br','hi','hindi');
INSERT INTO "languageNames" VALUES(9838,'br','hr','kroateg');
INSERT INTO "languageNames" VALUES(9839,'br','hsb','uhelsorabeg');
INSERT INTO "languageNames" VALUES(9840,'br','ht','haitieg');
INSERT INTO "languageNames" VALUES(9841,'br','hu','hungareg');
INSERT INTO "languageNames" VALUES(9842,'br','hy','armenianeg');
INSERT INTO "languageNames" VALUES(9843,'br','ia','interlingua');
INSERT INTO "languageNames" VALUES(9844,'br','id','indonezeg');
INSERT INTO "languageNames" VALUES(9845,'br','ig','igbo');
INSERT INTO "languageNames" VALUES(9846,'br','is','islandeg');
INSERT INTO "languageNames" VALUES(9847,'br','it','italianeg');
INSERT INTO "languageNames" VALUES(9848,'br','ka','jorjianeg');
INSERT INTO "languageNames" VALUES(9849,'br','kaa','karakalpak');
INSERT INTO "languageNames" VALUES(9850,'br','kk','kazak');
INSERT INTO "languageNames" VALUES(9851,'br','ko','koreaneg');
INSERT INTO "languageNames" VALUES(9852,'br','krc','karatchay-balkar');
INSERT INTO "languageNames" VALUES(9853,'br','krl','karelieg');
INSERT INTO "languageNames" VALUES(9854,'br','ks','kashmiri');
INSERT INTO "languageNames" VALUES(9855,'br','ky','kirgiz');
INSERT INTO "languageNames" VALUES(9856,'br','la','latin');
INSERT INTO "languageNames" VALUES(9857,'br','lb','luksembourgeg');
INSERT INTO "languageNames" VALUES(9858,'br','lg','ganda');
INSERT INTO "languageNames" VALUES(9859,'br','ln','lingala');
INSERT INTO "languageNames" VALUES(9860,'br','lo','laoseg');
INSERT INTO "languageNames" VALUES(9861,'br','lt','lituaneg');
INSERT INTO "languageNames" VALUES(9862,'br','lv','latvieg');
INSERT INTO "languageNames" VALUES(9863,'br','mdf','moksha');
INSERT INTO "languageNames" VALUES(9864,'br','mfe','moriseg');
INSERT INTO "languageNames" VALUES(9865,'br','mk','makedoneg');
INSERT INTO "languageNames" VALUES(9866,'br','ml','malayalam');
INSERT INTO "languageNames" VALUES(9867,'br','mr','marathi');
INSERT INTO "languageNames" VALUES(9868,'br','mrj','marieg ar Cʼhornôg');
INSERT INTO "languageNames" VALUES(9869,'br','ms','malayseg');
INSERT INTO "languageNames" VALUES(9870,'br','mt','malteg');
INSERT INTO "languageNames" VALUES(9871,'br','myv','erza');
INSERT INTO "languageNames" VALUES(9872,'br','nap','napolitaneg');
INSERT INTO "languageNames" VALUES(9873,'br','nb','norvegeg bokmål');
INSERT INTO "languageNames" VALUES(9874,'br','ne','nepaleg');
INSERT INTO "languageNames" VALUES(9875,'br','nl','nederlandeg');
INSERT INTO "languageNames" VALUES(9876,'br','nn','norvegeg nynorsk');
INSERT INTO "languageNames" VALUES(9877,'br','no','norvegeg');
INSERT INTO "languageNames" VALUES(9878,'br','nog','nogay');
INSERT INTO "languageNames" VALUES(9879,'br','oc','okitaneg');
INSERT INTO "languageNames" VALUES(9880,'br','os','oseteg');
INSERT INTO "languageNames" VALUES(9881,'br','ota','turkeg otoman');
INSERT INTO "languageNames" VALUES(9882,'br','pa','punjabi');
INSERT INTO "languageNames" VALUES(9883,'br','pl','poloneg');
INSERT INTO "languageNames" VALUES(9884,'br','pt','portugaleg');
INSERT INTO "languageNames" VALUES(9885,'br','rm','romañcheg');
INSERT INTO "languageNames" VALUES(9886,'br','rn','rundi');
INSERT INTO "languageNames" VALUES(9887,'br','ro','roumaneg');
INSERT INTO "languageNames" VALUES(9888,'br','ru','rusianeg');
INSERT INTO "languageNames" VALUES(9889,'br','rup','aroumaneg');
INSERT INTO "languageNames" VALUES(9890,'br','sa','sanskriteg');
INSERT INTO "languageNames" VALUES(9891,'br','sah','yakouteg');
INSERT INTO "languageNames" VALUES(9892,'br','sc','sardeg');
INSERT INTO "languageNames" VALUES(9893,'br','scn','sikilieg');
INSERT INTO "languageNames" VALUES(9894,'br','sco','skoteg');
INSERT INTO "languageNames" VALUES(9895,'br','sd','sindhi');
INSERT INTO "languageNames" VALUES(9896,'br','se','sámi an Norzh');
INSERT INTO "languageNames" VALUES(9897,'br','sh','serb-kroateg');
INSERT INTO "languageNames" VALUES(9898,'br','si','singhaleg');
INSERT INTO "languageNames" VALUES(9899,'br','sk','slovakeg');
INSERT INTO "languageNames" VALUES(9900,'br','sl','sloveneg');
INSERT INTO "languageNames" VALUES(9901,'br','sma','sámi ar Su');
INSERT INTO "languageNames" VALUES(9902,'br','smj','sámi Luleå');
INSERT INTO "languageNames" VALUES(9903,'br','smn','sámi Inari');
INSERT INTO "languageNames" VALUES(9904,'br','sq','albaneg');
INSERT INTO "languageNames" VALUES(9905,'br','sr','serbeg');
INSERT INTO "languageNames" VALUES(9906,'br','ss','swati');
INSERT INTO "languageNames" VALUES(9907,'br','sv','svedeg');
INSERT INTO "languageNames" VALUES(9908,'br','sw','swahili');
INSERT INTO "languageNames" VALUES(9909,'br','ta','tamileg');
INSERT INTO "languageNames" VALUES(9910,'br','te','telougou');
INSERT INTO "languageNames" VALUES(9911,'br','tet','tetum');
INSERT INTO "languageNames" VALUES(9912,'br','tg','tadjik');
INSERT INTO "languageNames" VALUES(9913,'br','th','thai');
INSERT INTO "languageNames" VALUES(9914,'br','tk','turkmeneg');
INSERT INTO "languageNames" VALUES(9915,'br','tl','tagalog');
INSERT INTO "languageNames" VALUES(9916,'br','tr','turkeg');
INSERT INTO "languageNames" VALUES(9917,'br','tt','tatar');
INSERT INTO "languageNames" VALUES(9918,'br','tyv','touva');
INSERT INTO "languageNames" VALUES(9919,'br','udm','oudmourteg');
INSERT INTO "languageNames" VALUES(9920,'br','ug','ouigoureg');
INSERT INTO "languageNames" VALUES(9921,'br','uk','ukraineg');
INSERT INTO "languageNames" VALUES(9922,'br','ur','ourdou');
INSERT INTO "languageNames" VALUES(9923,'br','uz','ouzbekeg');
INSERT INTO "languageNames" VALUES(9924,'br','vi','vietnameg');
INSERT INTO "languageNames" VALUES(9925,'br','vro','voroeg');
INSERT INTO "languageNames" VALUES(9926,'br','wal','walamo');
INSERT INTO "languageNames" VALUES(9927,'br','xh','xhosa');
INSERT INTO "languageNames" VALUES(9928,'br','yi','yiddish');
INSERT INTO "languageNames" VALUES(9929,'br','yo','yorouba');
INSERT INTO "languageNames" VALUES(9930,'br','zh','sinaeg');
INSERT INTO "languageNames" VALUES(9931,'br','zu','zouloueg');
INSERT INTO "languageNames" VALUES(9932,'mfe','ar','arab');
INSERT INTO "languageNames" VALUES(9933,'mfe','be','bieloris');
INSERT INTO "languageNames" VALUES(9934,'mfe','bg','bilgar');
INSERT INTO "languageNames" VALUES(9935,'mfe','bn','bengali');
INSERT INTO "languageNames" VALUES(9936,'mfe','cs','tchek');
INSERT INTO "languageNames" VALUES(9937,'mfe','de','alman');
INSERT INTO "languageNames" VALUES(9938,'mfe','el','grek');
INSERT INTO "languageNames" VALUES(9939,'mfe','en','angle');
INSERT INTO "languageNames" VALUES(9940,'mfe','es','espagnol');
INSERT INTO "languageNames" VALUES(9941,'mfe','fa','persan');
INSERT INTO "languageNames" VALUES(9942,'mfe','fr','franse');
INSERT INTO "languageNames" VALUES(9943,'mfe','ha','haoussa');
INSERT INTO "languageNames" VALUES(9944,'mfe','hi','hindi');
INSERT INTO "languageNames" VALUES(9945,'mfe','hu','hongrwa');
INSERT INTO "languageNames" VALUES(9946,'mfe','id','indonezien');
INSERT INTO "languageNames" VALUES(9947,'mfe','ig','igbo');
INSERT INTO "languageNames" VALUES(9948,'mfe','it','italien');
INSERT INTO "languageNames" VALUES(9949,'mfe','ko','koreen');
INSERT INTO "languageNames" VALUES(9950,'mfe','mfe','kreol morisien');
INSERT INTO "languageNames" VALUES(9951,'mfe','ms','male');
INSERT INTO "languageNames" VALUES(9952,'mfe','ne','nepale');
INSERT INTO "languageNames" VALUES(9953,'mfe','nl','olande');
INSERT INTO "languageNames" VALUES(9954,'mfe','pa','penjabi');
INSERT INTO "languageNames" VALUES(9955,'mfe','pl','polone');
INSERT INTO "languageNames" VALUES(9956,'mfe','pt','portige');
INSERT INTO "languageNames" VALUES(9957,'mfe','ro','roumin');
INSERT INTO "languageNames" VALUES(9958,'mfe','ru','ris');
INSERT INTO "languageNames" VALUES(9959,'mfe','sv','swedwa');
INSERT INTO "languageNames" VALUES(9960,'mfe','ta','tamoul');
INSERT INTO "languageNames" VALUES(9961,'mfe','th','thaï');
INSERT INTO "languageNames" VALUES(9962,'mfe','tr','tirk');
INSERT INTO "languageNames" VALUES(9963,'mfe','uk','ikrenien');
INSERT INTO "languageNames" VALUES(9964,'mfe','ur','ourdou');
INSERT INTO "languageNames" VALUES(9965,'mfe','vi','vietnamien');
INSERT INTO "languageNames" VALUES(9966,'mfe','yo','yoruba');
INSERT INTO "languageNames" VALUES(9967,'mfe','zh','sinwa, mandarin');
INSERT INTO "languageNames" VALUES(9968,'mfe','zu','zoulou');
INSERT INTO "languageNames" VALUES(9969,'pl','af','afrikaans');
INSERT INTO "languageNames" VALUES(9970,'pl','alt','południowoałtajski');
INSERT INTO "languageNames" VALUES(9971,'pl','an','aragoński');
INSERT INTO "languageNames" VALUES(9972,'pl','ar','arabski');
INSERT INTO "languageNames" VALUES(9973,'pl','as','asamski');
INSERT INTO "languageNames" VALUES(9974,'pl','ast','asturyjski');
INSERT INTO "languageNames" VALUES(9975,'pl','av','awarski');
INSERT INTO "languageNames" VALUES(9977,'pl','az','azerski');
INSERT INTO "languageNames" VALUES(9978,'pl','ba','baszkirski');
INSERT INTO "languageNames" VALUES(9979,'pl','be','białoruski');
INSERT INTO "languageNames" VALUES(9980,'pl','bg','bułgarski');
INSERT INTO "languageNames" VALUES(9981,'pl','bi','bislama');
INSERT INTO "languageNames" VALUES(9982,'pl','bn','bengalski');
INSERT INTO "languageNames" VALUES(9983,'pl','br','bretoński');
INSERT INTO "languageNames" VALUES(9984,'pl','bs','bośniacki');
INSERT INTO "languageNames" VALUES(9985,'pl','bua','buriacki');
INSERT INTO "languageNames" VALUES(9986,'pl','byv','medumba');
INSERT INTO "languageNames" VALUES(9987,'pl','ca','kataloński');
INSERT INTO "languageNames" VALUES(9988,'pl','ceb','cebuano');
INSERT INTO "languageNames" VALUES(9989,'pl','chm','maryjski');
INSERT INTO "languageNames" VALUES(9990,'pl','ckb','sorani');
INSERT INTO "languageNames" VALUES(9991,'pl','co','korsykański');
INSERT INTO "languageNames" VALUES(9992,'pl','crh','krymskotatarski');
INSERT INTO "languageNames" VALUES(9993,'pl','cs','czeski');
INSERT INTO "languageNames" VALUES(9994,'pl','csb','kaszubski');
INSERT INTO "languageNames" VALUES(9995,'pl','cu','cerkiewnosłowiański');
INSERT INTO "languageNames" VALUES(9996,'pl','cv','czuwaski');
INSERT INTO "languageNames" VALUES(9997,'pl','cy','walijski');
INSERT INTO "languageNames" VALUES(9998,'pl','da','duński');
INSERT INTO "languageNames" VALUES(9999,'pl','dar','dargwijski');
INSERT INTO "languageNames" VALUES(10000,'pl','de','niemiecki');
INSERT INTO "languageNames" VALUES(10001,'pl','dsb','dolnołużycki');
INSERT INTO "languageNames" VALUES(10002,'pl','el','grecki');
INSERT INTO "languageNames" VALUES(10003,'pl','en','angielski');
INSERT INTO "languageNames" VALUES(10004,'pl','eo','esperanto');
INSERT INTO "languageNames" VALUES(10005,'pl','es','hiszpański');
INSERT INTO "languageNames" VALUES(10006,'pl','et','estoński');
INSERT INTO "languageNames" VALUES(10007,'pl','eu','baskijski');
INSERT INTO "languageNames" VALUES(10008,'pl','fa','perski');
INSERT INTO "languageNames" VALUES(10009,'pl','fi','fiński');
INSERT INTO "languageNames" VALUES(10010,'pl','fo','farerski');
INSERT INTO "languageNames" VALUES(10011,'pl','fr','francuski');
INSERT INTO "languageNames" VALUES(10012,'pl','fy','zachodniofryzyjski');
INSERT INTO "languageNames" VALUES(10013,'pl','ga','irlandzki');
INSERT INTO "languageNames" VALUES(10014,'pl','gag','gagauski');
INSERT INTO "languageNames" VALUES(10015,'pl','gd','szkocki gaelicki');
INSERT INTO "languageNames" VALUES(10016,'pl','gl','galicyjski');
INSERT INTO "languageNames" VALUES(10017,'pl','glk','giliański');
INSERT INTO "languageNames" VALUES(10018,'pl','gn','guarani');
INSERT INTO "languageNames" VALUES(10019,'pl','gu','gudżarati');
INSERT INTO "languageNames" VALUES(10020,'pl','guc','wayúu');
INSERT INTO "languageNames" VALUES(10021,'pl','gv','manx');
INSERT INTO "languageNames" VALUES(10022,'pl','ha','hausa');
INSERT INTO "languageNames" VALUES(10023,'pl','haw','hawajski');
INSERT INTO "languageNames" VALUES(10024,'pl','he','hebrajski');
INSERT INTO "languageNames" VALUES(10025,'pl','hi','hindi');
INSERT INTO "languageNames" VALUES(10026,'pl','hr','chorwacki');
INSERT INTO "languageNames" VALUES(10027,'pl','hsb','górnołużycki');
INSERT INTO "languageNames" VALUES(10028,'pl','ht','kreolski haitański');
INSERT INTO "languageNames" VALUES(10029,'pl','hu','węgierski');
INSERT INTO "languageNames" VALUES(10030,'pl','hy','ormiański');
INSERT INTO "languageNames" VALUES(10031,'pl','ia','interlingua');
INSERT INTO "languageNames" VALUES(10032,'pl','id','indonezyjski');
INSERT INTO "languageNames" VALUES(10033,'pl','ig','igbo');
INSERT INTO "languageNames" VALUES(10034,'pl','is','islandzki');
INSERT INTO "languageNames" VALUES(10035,'pl','it','włoski');
INSERT INTO "languageNames" VALUES(10036,'pl','ka','gruziński');
INSERT INTO "languageNames" VALUES(10037,'pl','kaa','karakałpacki');
INSERT INTO "languageNames" VALUES(10038,'pl','kk','kazachski');
INSERT INTO "languageNames" VALUES(10039,'pl','ko','koreański');
INSERT INTO "languageNames" VALUES(10040,'pl','krc','karaczajsko-bałkarski');
INSERT INTO "languageNames" VALUES(10041,'pl','krl','karelski');
INSERT INTO "languageNames" VALUES(10042,'pl','ks','kaszmirski');
INSERT INTO "languageNames" VALUES(10043,'pl','kum','kumycki');
INSERT INTO "languageNames" VALUES(10044,'pl','kv','komi');
INSERT INTO "languageNames" VALUES(10045,'pl','ky','kirgiski');
INSERT INTO "languageNames" VALUES(10046,'pl','la','łaciński');
INSERT INTO "languageNames" VALUES(10047,'pl','lb','luksemburski');
INSERT INTO "languageNames" VALUES(10048,'pl','lg','ganda');
INSERT INTO "languageNames" VALUES(10049,'pl','liv','liwski');
INSERT INTO "languageNames" VALUES(10050,'pl','ln','lingala');
INSERT INTO "languageNames" VALUES(10051,'pl','lo','laotański');
INSERT INTO "languageNames" VALUES(10052,'pl','lt','litewski');
INSERT INTO "languageNames" VALUES(10053,'pl','lv','łotewski');
INSERT INTO "languageNames" VALUES(10054,'pl','mdf','moksza');
INSERT INTO "languageNames" VALUES(10055,'pl','mfe','kreolski Mauritiusa');
INSERT INTO "languageNames" VALUES(10056,'pl','mk','macedoński');
INSERT INTO "languageNames" VALUES(10057,'pl','ml','malajalam');
INSERT INTO "languageNames" VALUES(10058,'pl','mr','marathi');
INSERT INTO "languageNames" VALUES(10059,'pl','mrj','zachodniomaryjski');
INSERT INTO "languageNames" VALUES(10060,'pl','ms','malajski');
INSERT INTO "languageNames" VALUES(10061,'pl','mt','maltański');
INSERT INTO "languageNames" VALUES(10062,'pl','myv','erzja');
INSERT INTO "languageNames" VALUES(10063,'pl','nap','neapolitański');
INSERT INTO "languageNames" VALUES(10064,'pl','nb','norweski (bokmål)');
INSERT INTO "languageNames" VALUES(10065,'pl','ne','nepalski');
INSERT INTO "languageNames" VALUES(10066,'pl','nl','niderlandzki');
INSERT INTO "languageNames" VALUES(10067,'pl','nn','norweski (nynorsk)');
INSERT INTO "languageNames" VALUES(10068,'pl','no','norweski');
INSERT INTO "languageNames" VALUES(10069,'pl','nog','nogajski');
INSERT INTO "languageNames" VALUES(10070,'pl','oc','oksytański');
INSERT INTO "languageNames" VALUES(10071,'pl','os','osetyjski');
INSERT INTO "languageNames" VALUES(10072,'pl','ota','osmańsko-turecki');
INSERT INTO "languageNames" VALUES(10073,'pl','pa','pendżabski');
INSERT INTO "languageNames" VALUES(10074,'pl','pl','polski');
INSERT INTO "languageNames" VALUES(10075,'pl','pt','portugalski');
INSERT INTO "languageNames" VALUES(10076,'pl','rm','retoromański');
INSERT INTO "languageNames" VALUES(10077,'pl','rn','rundi');
INSERT INTO "languageNames" VALUES(10078,'pl','ro','rumuński');
INSERT INTO "languageNames" VALUES(10079,'pl','ru','rosyjski');
INSERT INTO "languageNames" VALUES(10080,'pl','rup','arumuński');
INSERT INTO "languageNames" VALUES(10081,'pl','sa','sanskryt');
INSERT INTO "languageNames" VALUES(10082,'pl','sah','jakucki');
INSERT INTO "languageNames" VALUES(10083,'pl','sc','sardyński');
INSERT INTO "languageNames" VALUES(10084,'pl','scn','sycylijski');
INSERT INTO "languageNames" VALUES(10085,'pl','sco','scots');
INSERT INTO "languageNames" VALUES(10086,'pl','sd','sindhi');
INSERT INTO "languageNames" VALUES(10087,'pl','se','północnolapoński');
INSERT INTO "languageNames" VALUES(10088,'pl','sh','serbsko-chorwacki');
INSERT INTO "languageNames" VALUES(10089,'pl','si','syngaleski');
INSERT INTO "languageNames" VALUES(10090,'pl','sk','słowacki');
INSERT INTO "languageNames" VALUES(10091,'pl','sl','słoweński');
INSERT INTO "languageNames" VALUES(10092,'pl','sma','południowolapoński');
INSERT INTO "languageNames" VALUES(10093,'pl','smj','lule');
INSERT INTO "languageNames" VALUES(10094,'pl','smn','inari');
INSERT INTO "languageNames" VALUES(10095,'pl','sq','albański');
INSERT INTO "languageNames" VALUES(10096,'pl','sr','serbski');
INSERT INTO "languageNames" VALUES(10097,'pl','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(10098,'pl','ss','suazi');
INSERT INTO "languageNames" VALUES(10099,'pl','sv','szwedzki');
INSERT INTO "languageNames" VALUES(10100,'pl','sw','suahili');
INSERT INTO "languageNames" VALUES(10101,'pl','ta','tamilski');
INSERT INTO "languageNames" VALUES(10102,'pl','te','telugu');
INSERT INTO "languageNames" VALUES(10103,'pl','tet','tetum');
INSERT INTO "languageNames" VALUES(10104,'pl','tg','tadżycki');
INSERT INTO "languageNames" VALUES(10105,'pl','th','tajski');
INSERT INTO "languageNames" VALUES(10106,'pl','tk','turkmeński');
INSERT INTO "languageNames" VALUES(10107,'pl','tl','tagalski');
INSERT INTO "languageNames" VALUES(10108,'pl','tr','turecki');
INSERT INTO "languageNames" VALUES(10109,'pl','tt','tatarski');
INSERT INTO "languageNames" VALUES(10110,'pl','tyv','tuwiński');
INSERT INTO "languageNames" VALUES(10111,'pl','udm','udmurcki');
INSERT INTO "languageNames" VALUES(10112,'pl','ug','ujgurski');
INSERT INTO "languageNames" VALUES(10113,'pl','uk','ukraiński');
INSERT INTO "languageNames" VALUES(10114,'pl','ur','urdu');
INSERT INTO "languageNames" VALUES(10115,'pl','uz','uzbecki');
INSERT INTO "languageNames" VALUES(10116,'pl','vi','wietnamski');
INSERT INTO "languageNames" VALUES(10117,'pl','vro','võro');
INSERT INTO "languageNames" VALUES(10118,'pl','wal','wolayta');
INSERT INTO "languageNames" VALUES(10119,'pl','xh','khosa');
INSERT INTO "languageNames" VALUES(10120,'pl','yi','jidysz');
INSERT INTO "languageNames" VALUES(10121,'pl','yo','joruba');
INSERT INTO "languageNames" VALUES(10122,'pl','zh','chiński');
INSERT INTO "languageNames" VALUES(10123,'pl','zu','zulu');
INSERT INTO "languageNames" VALUES(10124,'ml','af','ആഫ്രിക്കാൻസ്');
INSERT INTO "languageNames" VALUES(10125,'ml','alt','തെക്കൻ അൾത്തായി');
INSERT INTO "languageNames" VALUES(10126,'ml','an','അരഗോണീസ്');
INSERT INTO "languageNames" VALUES(10127,'ml','ar','അറബിക്');
INSERT INTO "languageNames" VALUES(10128,'ml','as','ആസ്സാമീസ്');
INSERT INTO "languageNames" VALUES(10129,'ml','ast','ഓസ്‌ട്രിയൻ');
INSERT INTO "languageNames" VALUES(10130,'ml','av','അവാരിക്');
INSERT INTO "languageNames" VALUES(10132,'ml','az','അസേരി');
INSERT INTO "languageNames" VALUES(10133,'ml','ba','ബഷ്ഖിർ');
INSERT INTO "languageNames" VALUES(10134,'ml','be','ബെലാറുഷ്യൻ');
INSERT INTO "languageNames" VALUES(10135,'ml','bg','ബൾഗേറിയൻ');
INSERT INTO "languageNames" VALUES(10136,'ml','bi','ബിസ്‌ലാമ');
INSERT INTO "languageNames" VALUES(10137,'ml','bn','ബംഗാളി');
INSERT INTO "languageNames" VALUES(10138,'ml','br','ബ്രെട്ടൺ');
INSERT INTO "languageNames" VALUES(10139,'ml','bs','ബോസ്നിയൻ');
INSERT INTO "languageNames" VALUES(10140,'ml','bua','ബുറിയത്ത്');
INSERT INTO "languageNames" VALUES(10141,'ml','byv','മെഡുംബ');
INSERT INTO "languageNames" VALUES(10142,'ml','ca','കറ്റാലാൻ');
INSERT INTO "languageNames" VALUES(10143,'ml','ceb','സെബുവാനോ');
INSERT INTO "languageNames" VALUES(10144,'ml','chm','മാരി');
INSERT INTO "languageNames" VALUES(10145,'ml','ckb','സെൻട്രൽ കുർദിഷ്');
INSERT INTO "languageNames" VALUES(10146,'ml','co','കോർസിക്കൻ');
INSERT INTO "languageNames" VALUES(10147,'ml','crh','ക്രിമിയൻ ടർക്കിഷ്');
INSERT INTO "languageNames" VALUES(10148,'ml','cs','ചെക്ക്');
INSERT INTO "languageNames" VALUES(10149,'ml','csb','കാഷുബിയാൻ');
INSERT INTO "languageNames" VALUES(10150,'ml','cu','ചർച്ച് സ്ലാവിക്');
INSERT INTO "languageNames" VALUES(10151,'ml','cv','ചുവാഷ്');
INSERT INTO "languageNames" VALUES(10152,'ml','cy','വെൽഷ്');
INSERT INTO "languageNames" VALUES(10153,'ml','da','ഡാനിഷ്');
INSERT INTO "languageNames" VALUES(10154,'ml','dar','ഡർഗ്വാ');
INSERT INTO "languageNames" VALUES(10155,'ml','de','ജർമ്മൻ');
INSERT INTO "languageNames" VALUES(10156,'ml','dsb','ലോവർ സോർബിയൻ');
INSERT INTO "languageNames" VALUES(10157,'ml','el','ഗ്രീക്ക്');
INSERT INTO "languageNames" VALUES(10158,'ml','en','ഇംഗ്ലീഷ്');
INSERT INTO "languageNames" VALUES(10159,'ml','eo','എസ്‌പരാന്റോ');
INSERT INTO "languageNames" VALUES(10160,'ml','es','സ്‌പാനിഷ്');
INSERT INTO "languageNames" VALUES(10161,'ml','et','എസ്റ്റോണിയൻ');
INSERT INTO "languageNames" VALUES(10162,'ml','eu','ബാസ്‌ക്');
INSERT INTO "languageNames" VALUES(10163,'ml','fa','പേർഷ്യൻ');
INSERT INTO "languageNames" VALUES(10164,'ml','fi','ഫിന്നിഷ്');
INSERT INTO "languageNames" VALUES(10165,'ml','fo','ഫാറോസ്');
INSERT INTO "languageNames" VALUES(10166,'ml','fr','ഫ്രഞ്ച്');
INSERT INTO "languageNames" VALUES(10167,'ml','fy','പശ്ചിമ ഫ്രിഷിയൻ');
INSERT INTO "languageNames" VALUES(10168,'ml','ga','ഐറിഷ്');
INSERT INTO "languageNames" VALUES(10169,'ml','gag','ഗാഗൂസ്');
INSERT INTO "languageNames" VALUES(10170,'ml','gd','സ്കോട്ടിഷ് ഗൈലിക്');
INSERT INTO "languageNames" VALUES(10171,'ml','gl','ഗലീഷ്യൻ');
INSERT INTO "languageNames" VALUES(10172,'ml','gn','ഗ്വരനീ');
INSERT INTO "languageNames" VALUES(10173,'ml','gu','ഗുജറാത്തി');
INSERT INTO "languageNames" VALUES(10174,'ml','gv','മാൻസ്');
INSERT INTO "languageNames" VALUES(10175,'ml','ha','ഹൗസ');
INSERT INTO "languageNames" VALUES(10176,'ml','haw','ഹവായിയൻ');
INSERT INTO "languageNames" VALUES(10177,'ml','he','ഹീബ്രു');
INSERT INTO "languageNames" VALUES(10178,'ml','hi','ഹിന്ദി');
INSERT INTO "languageNames" VALUES(10179,'ml','hr','ക്രൊയേഷ്യൻ');
INSERT INTO "languageNames" VALUES(10180,'ml','hsb','അപ്പർ സോർബിയൻ');
INSERT INTO "languageNames" VALUES(10181,'ml','ht','ഹെയ്‌തിയൻ ക്രിയോൾ');
INSERT INTO "languageNames" VALUES(10182,'ml','hu','ഹംഗേറിയൻ');
INSERT INTO "languageNames" VALUES(10183,'ml','hy','അർമേനിയൻ');
INSERT INTO "languageNames" VALUES(10184,'ml','ia','ഇന്റർലിംഗ്വ');
INSERT INTO "languageNames" VALUES(10185,'ml','id','ഇന്തോനേഷ്യൻ');
INSERT INTO "languageNames" VALUES(10186,'ml','ig','ഇഗ്ബോ');
INSERT INTO "languageNames" VALUES(10187,'ml','is','ഐസ്‌ലാൻഡിക്');
INSERT INTO "languageNames" VALUES(10188,'ml','it','ഇറ്റാലിയൻ');
INSERT INTO "languageNames" VALUES(10189,'ml','ka','ജോർജിയൻ');
INSERT INTO "languageNames" VALUES(10190,'ml','kaa','കര-കാൽപ്പക്');
INSERT INTO "languageNames" VALUES(10191,'ml','kk','കസാഖ്');
INSERT INTO "languageNames" VALUES(10192,'ml','ko','കൊറിയൻ');
INSERT INTO "languageNames" VALUES(10193,'ml','krc','കരചൈ-ബാൽകർ');
INSERT INTO "languageNames" VALUES(10194,'ml','krl','കരീലിയൻ');
INSERT INTO "languageNames" VALUES(10195,'ml','ks','കാശ്‌മീരി');
INSERT INTO "languageNames" VALUES(10196,'ml','kum','കുമൈക്');
INSERT INTO "languageNames" VALUES(10197,'ml','kv','കോമി');
INSERT INTO "languageNames" VALUES(10198,'ml','ky','കിർഗിസ്');
INSERT INTO "languageNames" VALUES(10199,'ml','la','ലാറ്റിൻ');
INSERT INTO "languageNames" VALUES(10200,'ml','lb','ലക്‌സംബർഗിഷ്');
INSERT INTO "languageNames" VALUES(10201,'ml','lg','ഗാണ്ട');
INSERT INTO "languageNames" VALUES(10202,'ml','ln','ലിംഗാല');
INSERT INTO "languageNames" VALUES(10203,'ml','lo','ലാവോ');
INSERT INTO "languageNames" VALUES(10204,'ml','lt','ലിത്വാനിയൻ');
INSERT INTO "languageNames" VALUES(10205,'ml','lv','ലാറ്റ്വിയൻ');
INSERT INTO "languageNames" VALUES(10206,'ml','mdf','മോക്ഷ');
INSERT INTO "languageNames" VALUES(10207,'ml','mfe','മൊറിസിൻ');
INSERT INTO "languageNames" VALUES(10208,'ml','mk','മാസിഡോണിയൻ');
INSERT INTO "languageNames" VALUES(10209,'ml','ml','മലയാളം');
INSERT INTO "languageNames" VALUES(10210,'ml','mr','മറാത്തി');
INSERT INTO "languageNames" VALUES(10211,'ml','ms','മലെയ്');
INSERT INTO "languageNames" VALUES(10212,'ml','mt','മാൾട്ടീസ്');
INSERT INTO "languageNames" VALUES(10213,'ml','myv','ഏഴ്സ്യ');
INSERT INTO "languageNames" VALUES(10214,'ml','nap','നെപ്പോളിറ്റാൻ');
INSERT INTO "languageNames" VALUES(10215,'ml','nb','നോർവീജിയൻ ബുക്‌മൽ');
INSERT INTO "languageNames" VALUES(10216,'ml','ne','നേപ്പാളി');
INSERT INTO "languageNames" VALUES(10217,'ml','nl','ഡച്ച്');
INSERT INTO "languageNames" VALUES(10218,'ml','nn','നോർവീജിയൻ നൈനോർക്‌സ്');
INSERT INTO "languageNames" VALUES(10219,'ml','no','നോർവീജിയൻ');
INSERT INTO "languageNames" VALUES(10220,'ml','nog','നോഗൈ');
INSERT INTO "languageNames" VALUES(10221,'ml','oc','ഓക്‌സിറ്റൻ');
INSERT INTO "languageNames" VALUES(10222,'ml','os','ഒസ്സെറ്റിക്');
INSERT INTO "languageNames" VALUES(10223,'ml','ota','ഓട്ടോമൻ തുർക്കിഷ്');
INSERT INTO "languageNames" VALUES(10224,'ml','pa','പഞ്ചാബി');
INSERT INTO "languageNames" VALUES(10225,'ml','pl','പോളിഷ്');
INSERT INTO "languageNames" VALUES(10226,'ml','pt','പോർച്ചുഗീസ്');
INSERT INTO "languageNames" VALUES(10227,'ml','rm','റൊമാഞ്ച്');
INSERT INTO "languageNames" VALUES(10228,'ml','rn','റുണ്ടി');
INSERT INTO "languageNames" VALUES(10229,'ml','ro','റൊമാനിയൻ');
INSERT INTO "languageNames" VALUES(10230,'ml','ru','റഷ്യൻ');
INSERT INTO "languageNames" VALUES(10231,'ml','rup','ആരോമാനിയൻ');
INSERT INTO "languageNames" VALUES(10232,'ml','sa','സംസ്‌കൃതം');
INSERT INTO "languageNames" VALUES(10233,'ml','sah','സാഖ');
INSERT INTO "languageNames" VALUES(10234,'ml','sc','സർഡിനിയാൻ');
INSERT INTO "languageNames" VALUES(10235,'ml','scn','സിസിലിയൻ');
INSERT INTO "languageNames" VALUES(10236,'ml','sco','സ്കോട്സ്');
INSERT INTO "languageNames" VALUES(10237,'ml','sd','സിന്ധി');
INSERT INTO "languageNames" VALUES(10238,'ml','se','വടക്കൻ സമി');
INSERT INTO "languageNames" VALUES(10239,'ml','sh','സെർബോ-ക്രൊയേഷ്യൻ');
INSERT INTO "languageNames" VALUES(10240,'ml','si','സിംഹള');
INSERT INTO "languageNames" VALUES(10241,'ml','sk','സ്ലോവാക്');
INSERT INTO "languageNames" VALUES(10242,'ml','sl','സ്ലോവേനിയൻ');
INSERT INTO "languageNames" VALUES(10243,'ml','sma','തെക്കൻ സമി');
INSERT INTO "languageNames" VALUES(10244,'ml','smj','ലൂലീ സമി');
INSERT INTO "languageNames" VALUES(10245,'ml','smn','ഇനാരി സമി');
INSERT INTO "languageNames" VALUES(10246,'ml','sq','അൽബേനിയൻ');
INSERT INTO "languageNames" VALUES(10247,'ml','sr','സെർബിയൻ');
INSERT INTO "languageNames" VALUES(10248,'ml','srn','ശ്രാനൻ ഡോങ്കോ');
INSERT INTO "languageNames" VALUES(10249,'ml','ss','സ്വാറ്റി');
INSERT INTO "languageNames" VALUES(10250,'ml','sv','സ്വീഡിഷ്');
INSERT INTO "languageNames" VALUES(10251,'ml','sw','സ്വാഹിലി');
INSERT INTO "languageNames" VALUES(10252,'ml','ta','തമിഴ്');
INSERT INTO "languageNames" VALUES(10253,'ml','te','തെലുങ്ക്');
INSERT INTO "languageNames" VALUES(10254,'ml','tet','ടെറ്റും');
INSERT INTO "languageNames" VALUES(10255,'ml','tg','താജിക്');
INSERT INTO "languageNames" VALUES(10256,'ml','th','തായ്');
INSERT INTO "languageNames" VALUES(10257,'ml','tk','തുർക്‌മെൻ');
INSERT INTO "languageNames" VALUES(10258,'ml','tl','തഗാലോഗ്');
INSERT INTO "languageNames" VALUES(10259,'ml','tr','ടർക്കിഷ്');
INSERT INTO "languageNames" VALUES(10260,'ml','tt','ടാട്ടർ');
INSERT INTO "languageNames" VALUES(10261,'ml','tyv','തുവിനിയൻ');
INSERT INTO "languageNames" VALUES(10262,'ml','udm','ഉഡ്മുർട്ട്');
INSERT INTO "languageNames" VALUES(10264,'ml','ug','ഉയ്ഗൂർ');
INSERT INTO "languageNames" VALUES(10265,'ml','uk','ഉക്രേനിയൻ');
INSERT INTO "languageNames" VALUES(10266,'ml','ur','ഉറുദു');
INSERT INTO "languageNames" VALUES(10267,'ml','uz','ഉസ്‌ബെക്ക്');
INSERT INTO "languageNames" VALUES(10268,'ml','vi','വിയറ്റ്നാമീസ്');
INSERT INTO "languageNames" VALUES(10269,'ml','wal','വൊലൈറ്റ');
INSERT INTO "languageNames" VALUES(10270,'ml','xh','ഖോസ');
INSERT INTO "languageNames" VALUES(10271,'ml','yi','യിദ്ദിഷ്');
INSERT INTO "languageNames" VALUES(10272,'ml','yo','യൊറൂബാ');
INSERT INTO "languageNames" VALUES(10273,'ml','zh','ചൈനീസ്');
INSERT INTO "languageNames" VALUES(10274,'ml','zu','സുലു');
INSERT INTO "languageNames" VALUES(10275,'ru','af','африкаанс');
INSERT INTO "languageNames" VALUES(10276,'ru','alt','южноалтайский');
INSERT INTO "languageNames" VALUES(10277,'ru','an','арагонский');
INSERT INTO "languageNames" VALUES(10278,'ru','ar','арабский');
INSERT INTO "languageNames" VALUES(10279,'ru','as','ассамский');
INSERT INTO "languageNames" VALUES(10280,'ru','ast','астурийский');
INSERT INTO "languageNames" VALUES(10281,'ru','av','аварский');
INSERT INTO "languageNames" VALUES(10283,'ru','az','азербайджанский');
INSERT INTO "languageNames" VALUES(10284,'ru','ba','башкирский');
INSERT INTO "languageNames" VALUES(10285,'ru','be','белорусский');
INSERT INTO "languageNames" VALUES(10286,'ru','bg','болгарский');
INSERT INTO "languageNames" VALUES(10287,'ru','bi','бислама');
INSERT INTO "languageNames" VALUES(10288,'ru','bn','бенгальский');
INSERT INTO "languageNames" VALUES(10289,'ru','br','бретонский');
INSERT INTO "languageNames" VALUES(10290,'ru','bs','боснийский');
INSERT INTO "languageNames" VALUES(10291,'ru','bua','бурятский');
INSERT INTO "languageNames" VALUES(10292,'ru','byv','медумба');
INSERT INTO "languageNames" VALUES(10293,'ru','ca','каталанский');
INSERT INTO "languageNames" VALUES(10294,'ru','ceb','себуано');
INSERT INTO "languageNames" VALUES(10295,'ru','chm','марийский');
INSERT INTO "languageNames" VALUES(10296,'ru','ckb','сорани');
INSERT INTO "languageNames" VALUES(10297,'ru','co','корсиканский');
INSERT INTO "languageNames" VALUES(10298,'ru','crh','крымско-татарский');
INSERT INTO "languageNames" VALUES(10299,'ru','cs','чешский');
INSERT INTO "languageNames" VALUES(10300,'ru','csb','кашубский');
INSERT INTO "languageNames" VALUES(10301,'ru','cu','церковнославянский');
INSERT INTO "languageNames" VALUES(10302,'ru','cv','чувашский');
INSERT INTO "languageNames" VALUES(10303,'ru','cy','валлийский');
INSERT INTO "languageNames" VALUES(10304,'ru','da','датский');
INSERT INTO "languageNames" VALUES(10305,'ru','dar','даргинский');
INSERT INTO "languageNames" VALUES(10306,'ru','de','немецкий');
INSERT INTO "languageNames" VALUES(10307,'ru','dsb','нижнелужицкий');
INSERT INTO "languageNames" VALUES(10308,'ru','el','греческий');
INSERT INTO "languageNames" VALUES(10309,'ru','en','английский');
INSERT INTO "languageNames" VALUES(10310,'ru','eo','эсперанто');
INSERT INTO "languageNames" VALUES(10311,'ru','es','испанский');
INSERT INTO "languageNames" VALUES(10312,'ru','et','эстонский');
INSERT INTO "languageNames" VALUES(10313,'ru','eu','баскский');
INSERT INTO "languageNames" VALUES(10314,'ru','fa','персидский');
INSERT INTO "languageNames" VALUES(10315,'ru','fi','финский');
INSERT INTO "languageNames" VALUES(10316,'ru','fo','фарерский');
INSERT INTO "languageNames" VALUES(10317,'ru','fr','французский');
INSERT INTO "languageNames" VALUES(10318,'ru','fy','западнофризский');
INSERT INTO "languageNames" VALUES(10319,'ru','ga','ирландский');
INSERT INTO "languageNames" VALUES(10320,'ru','gag','гагаузский');
INSERT INTO "languageNames" VALUES(10321,'ru','gd','гэльский');
INSERT INTO "languageNames" VALUES(10322,'ru','gl','галисийский');
INSERT INTO "languageNames" VALUES(10323,'ru','gn','гуарани');
INSERT INTO "languageNames" VALUES(10324,'ru','gu','гуджарати');
INSERT INTO "languageNames" VALUES(10325,'ru','gv','мэнский');
INSERT INTO "languageNames" VALUES(10326,'ru','ha','хауса');
INSERT INTO "languageNames" VALUES(10327,'ru','haw','гавайский');
INSERT INTO "languageNames" VALUES(10328,'ru','he','иврит');
INSERT INTO "languageNames" VALUES(10329,'ru','hi','хинди');
INSERT INTO "languageNames" VALUES(10330,'ru','hr','хорватский');
INSERT INTO "languageNames" VALUES(10331,'ru','hsb','верхнелужицкий');
INSERT INTO "languageNames" VALUES(10332,'ru','ht','гаитянский');
INSERT INTO "languageNames" VALUES(10333,'ru','hu','венгерский');
INSERT INTO "languageNames" VALUES(10334,'ru','hy','армянский');
INSERT INTO "languageNames" VALUES(10335,'ru','ia','интерлингва');
INSERT INTO "languageNames" VALUES(10336,'ru','id','индонезийский');
INSERT INTO "languageNames" VALUES(10337,'ru','ig','игбо');
INSERT INTO "languageNames" VALUES(10338,'ru','is','исландский');
INSERT INTO "languageNames" VALUES(10339,'ru','it','итальянский');
INSERT INTO "languageNames" VALUES(10340,'ru','ka','грузинский');
INSERT INTO "languageNames" VALUES(10341,'ru','kaa','каракалпакский');
INSERT INTO "languageNames" VALUES(10342,'ru','kk','казахский');
INSERT INTO "languageNames" VALUES(10343,'ru','ko','корейский');
INSERT INTO "languageNames" VALUES(10344,'ru','krc','карачаево-балкарский');
INSERT INTO "languageNames" VALUES(10345,'ru','krl','карельский');
INSERT INTO "languageNames" VALUES(10346,'ru','ks','кашмири');
INSERT INTO "languageNames" VALUES(10347,'ru','kum','кумыкский');
INSERT INTO "languageNames" VALUES(10348,'ru','kv','коми');
INSERT INTO "languageNames" VALUES(10349,'ru','ky','киргизский');
INSERT INTO "languageNames" VALUES(10350,'ru','la','латинский');
INSERT INTO "languageNames" VALUES(10351,'ru','lb','люксембургский');
INSERT INTO "languageNames" VALUES(10352,'ru','lg','ганда');
INSERT INTO "languageNames" VALUES(10353,'ru','ln','лингала');
INSERT INTO "languageNames" VALUES(10354,'ru','lo','лаосский');
INSERT INTO "languageNames" VALUES(10355,'ru','lt','литовский');
INSERT INTO "languageNames" VALUES(10356,'ru','lv','латышский');
INSERT INTO "languageNames" VALUES(10357,'ru','mdf','мокшанский');
INSERT INTO "languageNames" VALUES(10358,'ru','mfe','маврикийский креольский');
INSERT INTO "languageNames" VALUES(10359,'ru','mk','македонский');
INSERT INTO "languageNames" VALUES(10360,'ru','ml','малаялам');
INSERT INTO "languageNames" VALUES(10361,'ru','mr','маратхи');
INSERT INTO "languageNames" VALUES(10362,'ru','ms','малайский');
INSERT INTO "languageNames" VALUES(10363,'ru','mt','мальтийский');
INSERT INTO "languageNames" VALUES(10364,'ru','myv','эрзянский');
INSERT INTO "languageNames" VALUES(10365,'ru','nap','неаполитанский');
INSERT INTO "languageNames" VALUES(10366,'ru','nb','норвежский букмол');
INSERT INTO "languageNames" VALUES(10367,'ru','ne','непальский');
INSERT INTO "languageNames" VALUES(10368,'ru','nl','нидерландский');
INSERT INTO "languageNames" VALUES(10369,'ru','nn','нюнорск');
INSERT INTO "languageNames" VALUES(10370,'ru','no','норвежский');
INSERT INTO "languageNames" VALUES(10371,'ru','nog','ногайский');
INSERT INTO "languageNames" VALUES(10372,'ru','oc','окситанский');
INSERT INTO "languageNames" VALUES(10373,'ru','os','осетинский');
INSERT INTO "languageNames" VALUES(10374,'ru','ota','старотурецкий');
INSERT INTO "languageNames" VALUES(10375,'ru','pa','панджаби');
INSERT INTO "languageNames" VALUES(10376,'ru','pl','польский');
INSERT INTO "languageNames" VALUES(10377,'ru','pt','португальский');
INSERT INTO "languageNames" VALUES(10378,'ru','rm','романшский');
INSERT INTO "languageNames" VALUES(10379,'ru','rn','рунди');
INSERT INTO "languageNames" VALUES(10380,'ru','ro','румынский');
INSERT INTO "languageNames" VALUES(10381,'ru','ru','русский');
INSERT INTO "languageNames" VALUES(10382,'ru','rup','арумынский');
INSERT INTO "languageNames" VALUES(10383,'ru','sa','санскрит');
INSERT INTO "languageNames" VALUES(10384,'ru','sah','саха');
INSERT INTO "languageNames" VALUES(10385,'ru','sc','сардинский');
INSERT INTO "languageNames" VALUES(10386,'ru','scn','сицилийский');
INSERT INTO "languageNames" VALUES(10387,'ru','sco','шотландский');
INSERT INTO "languageNames" VALUES(10388,'ru','sd','синдхи');
INSERT INTO "languageNames" VALUES(10389,'ru','se','северносаамский');
INSERT INTO "languageNames" VALUES(10390,'ru','sh','сербскохорватский');
INSERT INTO "languageNames" VALUES(10391,'ru','si','сингальский');
INSERT INTO "languageNames" VALUES(10392,'ru','sk','словацкий');
INSERT INTO "languageNames" VALUES(10393,'ru','sl','словенский');
INSERT INTO "languageNames" VALUES(10394,'ru','sma','южносаамский');
INSERT INTO "languageNames" VALUES(10395,'ru','smj','луле-саамский');
INSERT INTO "languageNames" VALUES(10396,'ru','smn','инари-саамский');
INSERT INTO "languageNames" VALUES(10397,'ru','sq','албанский');
INSERT INTO "languageNames" VALUES(10398,'ru','sr','сербский');
INSERT INTO "languageNames" VALUES(10399,'ru','srn','сранан-тонго');
INSERT INTO "languageNames" VALUES(10400,'ru','ss','свази');
INSERT INTO "languageNames" VALUES(10401,'ru','sv','шведский');
INSERT INTO "languageNames" VALUES(10402,'ru','sw','суахили');
INSERT INTO "languageNames" VALUES(10403,'ru','ta','тамильский');
INSERT INTO "languageNames" VALUES(10404,'ru','te','телугу');
INSERT INTO "languageNames" VALUES(10405,'ru','tet','тетум');
INSERT INTO "languageNames" VALUES(10406,'ru','tg','таджикский');
INSERT INTO "languageNames" VALUES(10407,'ru','th','тайский');
INSERT INTO "languageNames" VALUES(10408,'ru','tk','туркменский');
INSERT INTO "languageNames" VALUES(10409,'ru','tl','тагалог');
INSERT INTO "languageNames" VALUES(10410,'ru','tr','турецкий');
INSERT INTO "languageNames" VALUES(10411,'ru','tt','татарский');
INSERT INTO "languageNames" VALUES(10412,'ru','tyv','тувинский');
INSERT INTO "languageNames" VALUES(10413,'ru','udm','удмуртский');
INSERT INTO "languageNames" VALUES(10414,'ru','ug','уйгурский');
INSERT INTO "languageNames" VALUES(10415,'ru','uk','украинский');
INSERT INTO "languageNames" VALUES(10416,'ru','ur','урду');
INSERT INTO "languageNames" VALUES(10417,'ru','uz','узбекский');
INSERT INTO "languageNames" VALUES(10418,'ru','vi','вьетнамский');
INSERT INTO "languageNames" VALUES(10419,'ru','wal','воламо');
INSERT INTO "languageNames" VALUES(10420,'ru','xh','коса');
INSERT INTO "languageNames" VALUES(10421,'ru','yi','идиш');
INSERT INTO "languageNames" VALUES(10422,'ru','yo','йоруба');
INSERT INTO "languageNames" VALUES(10423,'ru','zh','китайский');
INSERT INTO "languageNames" VALUES(10424,'ru','zu','зулу');
INSERT INTO "languageNames" VALUES(10425,'gv','gv','Gaelg');
INSERT INTO "languageNames" VALUES(10426,'gl','af','afrikaans');
INSERT INTO "languageNames" VALUES(10427,'gl','alt','altai meridional');
INSERT INTO "languageNames" VALUES(10428,'gl','an','aragonés');
INSERT INTO "languageNames" VALUES(10429,'gl','ar','árabe');
INSERT INTO "languageNames" VALUES(10430,'gl','as','assamés');
INSERT INTO "languageNames" VALUES(10431,'gl','ast','asturiano');
INSERT INTO "languageNames" VALUES(10432,'gl','av','avar');
INSERT INTO "languageNames" VALUES(10434,'gl','az','azerí');
INSERT INTO "languageNames" VALUES(10435,'gl','ba','baskir');
INSERT INTO "languageNames" VALUES(10436,'gl','be','bielorruso');
INSERT INTO "languageNames" VALUES(10437,'gl','bg','búlgaro');
INSERT INTO "languageNames" VALUES(10438,'gl','bi','bislama');
INSERT INTO "languageNames" VALUES(10439,'gl','bn','bengalí');
INSERT INTO "languageNames" VALUES(10440,'gl','br','bretón');
INSERT INTO "languageNames" VALUES(10441,'gl','bs','bosníaco');
INSERT INTO "languageNames" VALUES(10442,'gl','ca','catalán');
INSERT INTO "languageNames" VALUES(10443,'gl','ceb','cebuano');
INSERT INTO "languageNames" VALUES(10444,'gl','chm','mari');
INSERT INTO "languageNames" VALUES(10445,'gl','ckb','kurdo soraní');
INSERT INTO "languageNames" VALUES(10446,'gl','co','corso');
INSERT INTO "languageNames" VALUES(10447,'gl','cs','checo');
INSERT INTO "languageNames" VALUES(10448,'gl','cu','eslavo eclesiástico');
INSERT INTO "languageNames" VALUES(10449,'gl','cv','chuvaxo');
INSERT INTO "languageNames" VALUES(10450,'gl','cy','galés');
INSERT INTO "languageNames" VALUES(10451,'gl','da','dinamarqués');
INSERT INTO "languageNames" VALUES(10452,'gl','dar','dargwa');
INSERT INTO "languageNames" VALUES(10453,'gl','de','alemán');
INSERT INTO "languageNames" VALUES(10454,'gl','dsb','baixo sorbio');
INSERT INTO "languageNames" VALUES(10455,'gl','el','grego');
INSERT INTO "languageNames" VALUES(10456,'gl','en','inglés');
INSERT INTO "languageNames" VALUES(10457,'gl','eo','esperanto');
INSERT INTO "languageNames" VALUES(10458,'gl','es','español');
INSERT INTO "languageNames" VALUES(10459,'gl','et','estoniano');
INSERT INTO "languageNames" VALUES(10460,'gl','eu','éuscaro');
INSERT INTO "languageNames" VALUES(10461,'gl','fa','persa');
INSERT INTO "languageNames" VALUES(10462,'gl','fi','finés');
INSERT INTO "languageNames" VALUES(10463,'gl','fo','feroés');
INSERT INTO "languageNames" VALUES(10464,'gl','fr','francés');
INSERT INTO "languageNames" VALUES(10465,'gl','fy','frisón occidental');
INSERT INTO "languageNames" VALUES(10466,'gl','ga','irlandés');
INSERT INTO "languageNames" VALUES(10467,'gl','gag','gagauz');
INSERT INTO "languageNames" VALUES(10468,'gl','gd','gaélico escocés');
INSERT INTO "languageNames" VALUES(10469,'gl','gl','galego');
INSERT INTO "languageNames" VALUES(10470,'gl','gn','guaraní');
INSERT INTO "languageNames" VALUES(10471,'gl','gu','guxaratí');
INSERT INTO "languageNames" VALUES(10472,'gl','gv','manx');
INSERT INTO "languageNames" VALUES(10473,'gl','ha','hausa');
INSERT INTO "languageNames" VALUES(10474,'gl','haw','hawaiano');
INSERT INTO "languageNames" VALUES(10475,'gl','he','hebreo');
INSERT INTO "languageNames" VALUES(10476,'gl','hi','hindi');
INSERT INTO "languageNames" VALUES(10477,'gl','hr','croata');
INSERT INTO "languageNames" VALUES(10478,'gl','hsb','alto sorbio');
INSERT INTO "languageNames" VALUES(10479,'gl','ht','crioulo haitiano');
INSERT INTO "languageNames" VALUES(10480,'gl','hu','húngaro');
INSERT INTO "languageNames" VALUES(10481,'gl','hy','armenio');
INSERT INTO "languageNames" VALUES(10482,'gl','ia','interlingua');
INSERT INTO "languageNames" VALUES(10483,'gl','id','indonesio');
INSERT INTO "languageNames" VALUES(10484,'gl','ig','ibo');
INSERT INTO "languageNames" VALUES(10485,'gl','is','islandés');
INSERT INTO "languageNames" VALUES(10486,'gl','it','italiano');
INSERT INTO "languageNames" VALUES(10487,'gl','ka','xeorxiano');
INSERT INTO "languageNames" VALUES(10488,'gl','kk','casaco');
INSERT INTO "languageNames" VALUES(10489,'gl','ko','coreano');
INSERT INTO "languageNames" VALUES(10490,'gl','krc','carachaio-bálcara');
INSERT INTO "languageNames" VALUES(10491,'gl','krl','carelio');
INSERT INTO "languageNames" VALUES(10492,'gl','ks','cachemir');
INSERT INTO "languageNames" VALUES(10493,'gl','kum','kumyk');
INSERT INTO "languageNames" VALUES(10494,'gl','kv','komi');
INSERT INTO "languageNames" VALUES(10495,'gl','ky','kirguiz');
INSERT INTO "languageNames" VALUES(10496,'gl','la','latín');
INSERT INTO "languageNames" VALUES(10497,'gl','lb','luxemburgués');
INSERT INTO "languageNames" VALUES(10498,'gl','lg','ganda');
INSERT INTO "languageNames" VALUES(10499,'gl','ln','lingala');
INSERT INTO "languageNames" VALUES(10500,'gl','lo','laosiano');
INSERT INTO "languageNames" VALUES(10501,'gl','lt','lituano');
INSERT INTO "languageNames" VALUES(10502,'gl','lv','letón');
INSERT INTO "languageNames" VALUES(10503,'gl','mdf','moksha');
INSERT INTO "languageNames" VALUES(10504,'gl','mfe','crioulo mauriciano');
INSERT INTO "languageNames" VALUES(10505,'gl','mk','macedonio');
INSERT INTO "languageNames" VALUES(10506,'gl','ml','malabar');
INSERT INTO "languageNames" VALUES(10507,'gl','mr','marathi');
INSERT INTO "languageNames" VALUES(10508,'gl','ms','malaio');
INSERT INTO "languageNames" VALUES(10509,'gl','mt','maltés');
INSERT INTO "languageNames" VALUES(10510,'gl','myv','erzya');
INSERT INTO "languageNames" VALUES(10511,'gl','nap','napolitano');
INSERT INTO "languageNames" VALUES(10512,'gl','nb','noruegués bokmål');
INSERT INTO "languageNames" VALUES(10513,'gl','ne','nepalí');
INSERT INTO "languageNames" VALUES(10514,'gl','nl','neerlandés');
INSERT INTO "languageNames" VALUES(10515,'gl','nn','noruegués nynorsk');
INSERT INTO "languageNames" VALUES(10516,'gl','no','noruegués');
INSERT INTO "languageNames" VALUES(10517,'gl','nog','nogai');
INSERT INTO "languageNames" VALUES(10518,'gl','oc','occitano');
INSERT INTO "languageNames" VALUES(10519,'gl','os','ossetio');
INSERT INTO "languageNames" VALUES(10520,'gl','pa','panxabiano');
INSERT INTO "languageNames" VALUES(10521,'gl','pl','polaco');
INSERT INTO "languageNames" VALUES(10522,'gl','pt','portugués');
INSERT INTO "languageNames" VALUES(10523,'gl','rm','romanche');
INSERT INTO "languageNames" VALUES(10524,'gl','rn','rundi');
INSERT INTO "languageNames" VALUES(10525,'gl','ro','romanés');
INSERT INTO "languageNames" VALUES(10526,'gl','ru','ruso');
INSERT INTO "languageNames" VALUES(10527,'gl','rup','aromanés');
INSERT INTO "languageNames" VALUES(10528,'gl','sa','sánscrito');
INSERT INTO "languageNames" VALUES(10529,'gl','sah','sakha');
INSERT INTO "languageNames" VALUES(10530,'gl','sc','sardo');
INSERT INTO "languageNames" VALUES(10531,'gl','scn','siciliano');
INSERT INTO "languageNames" VALUES(10532,'gl','sco','escocés');
INSERT INTO "languageNames" VALUES(10533,'gl','sd','sindhi');
INSERT INTO "languageNames" VALUES(10534,'gl','se','saami setentrional');
INSERT INTO "languageNames" VALUES(10535,'gl','sh','serbocroata');
INSERT INTO "languageNames" VALUES(10536,'gl','si','cingalés');
INSERT INTO "languageNames" VALUES(10537,'gl','sk','eslovaco');
INSERT INTO "languageNames" VALUES(10538,'gl','sl','esloveno');
INSERT INTO "languageNames" VALUES(10539,'gl','sma','saami meridional');
INSERT INTO "languageNames" VALUES(10540,'gl','smj','saami de Lule');
INSERT INTO "languageNames" VALUES(10541,'gl','smn','saami de Inari');
INSERT INTO "languageNames" VALUES(10542,'gl','sq','albanés');
INSERT INTO "languageNames" VALUES(10543,'gl','sr','serbio');
INSERT INTO "languageNames" VALUES(10544,'gl','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(10545,'gl','ss','swazi');
INSERT INTO "languageNames" VALUES(10546,'gl','sv','sueco');
INSERT INTO "languageNames" VALUES(10547,'gl','sw','suahili');
INSERT INTO "languageNames" VALUES(10548,'gl','ta','támil');
INSERT INTO "languageNames" VALUES(10549,'gl','te','telugu');
INSERT INTO "languageNames" VALUES(10550,'gl','tet','tetun');
INSERT INTO "languageNames" VALUES(10551,'gl','tg','taxico');
INSERT INTO "languageNames" VALUES(10552,'gl','th','tailandés');
INSERT INTO "languageNames" VALUES(10553,'gl','tk','turcomán');
INSERT INTO "languageNames" VALUES(10554,'gl','tl','tagalo');
INSERT INTO "languageNames" VALUES(10555,'gl','tr','turco');
INSERT INTO "languageNames" VALUES(10556,'gl','tt','tártaro');
INSERT INTO "languageNames" VALUES(10557,'gl','tyv','tuvaniano');
INSERT INTO "languageNames" VALUES(10558,'gl','udm','udmurto');
INSERT INTO "languageNames" VALUES(10559,'gl','ug','uigur');
INSERT INTO "languageNames" VALUES(10560,'gl','uk','ucraíno');
INSERT INTO "languageNames" VALUES(10561,'gl','ur','urdú');
INSERT INTO "languageNames" VALUES(10562,'gl','uz','uzbeco');
INSERT INTO "languageNames" VALUES(10563,'gl','vi','vietnamita');
INSERT INTO "languageNames" VALUES(10564,'gl','wal','wolaytta');
INSERT INTO "languageNames" VALUES(10565,'gl','xh','xosa');
INSERT INTO "languageNames" VALUES(10566,'gl','yi','yiddish');
INSERT INTO "languageNames" VALUES(10567,'gl','yo','yoruba');
INSERT INTO "languageNames" VALUES(10568,'gl','zh','chinés');
INSERT INTO "languageNames" VALUES(10569,'gl','zu','zulú');
INSERT INTO "languageNames" VALUES(10570,'ha','af','Afirkanci');
INSERT INTO "languageNames" VALUES(10571,'ha','ar','Larabci');
INSERT INTO "languageNames" VALUES(10572,'ha','as','Asamisanci');
INSERT INTO "languageNames" VALUES(10573,'ha','az','Azerbaijanci');
INSERT INTO "languageNames" VALUES(10574,'ha','be','Belarusanci');
INSERT INTO "languageNames" VALUES(10575,'ha','bg','Bulgaranci');
INSERT INTO "languageNames" VALUES(10576,'ha','bn','Bengali');
INSERT INTO "languageNames" VALUES(10577,'ha','br','Buretananci');
INSERT INTO "languageNames" VALUES(10578,'ha','bs','Bosniyanci');
INSERT INTO "languageNames" VALUES(10579,'ha','ca','Kataloniyanci');
INSERT INTO "languageNames" VALUES(10580,'ha','cs','Harshen Cak');
INSERT INTO "languageNames" VALUES(10581,'ha','cy','Kabilar Welsh');
INSERT INTO "languageNames" VALUES(10582,'ha','da','Danish');
INSERT INTO "languageNames" VALUES(10583,'ha','de','Jamusanci');
INSERT INTO "languageNames" VALUES(10584,'ha','el','Girkanci');
INSERT INTO "languageNames" VALUES(10585,'ha','en','Turanci');
INSERT INTO "languageNames" VALUES(10586,'ha','eo','Dʼan/ʼYar Kabilar Andalus');
INSERT INTO "languageNames" VALUES(10587,'ha','es','Ispaniyanci');
INSERT INTO "languageNames" VALUES(10588,'ha','et','Istoniyanci');
INSERT INTO "languageNames" VALUES(10589,'ha','eu','Dan/ʼYar Kabilar Bas');
INSERT INTO "languageNames" VALUES(10590,'ha','fa','Parisanci');
INSERT INTO "languageNames" VALUES(10591,'ha','fi','Yaren mutanen Finland');
INSERT INTO "languageNames" VALUES(10592,'ha','fo','Faroese');
INSERT INTO "languageNames" VALUES(10593,'ha','fr','Faransanci');
INSERT INTO "languageNames" VALUES(10594,'ha','fy','Kʼabilan Firsi');
INSERT INTO "languageNames" VALUES(10595,'ha','ga','Dan Ailan');
INSERT INTO "languageNames" VALUES(10596,'ha','gd','Kʼabilan Scots Gaelic');
INSERT INTO "languageNames" VALUES(10597,'ha','gl','Bagalike');
INSERT INTO "languageNames" VALUES(10598,'ha','gn','Guwaraniyanci');
INSERT INTO "languageNames" VALUES(10599,'ha','gu','Gujarati');
INSERT INTO "languageNames" VALUES(10600,'ha','ha','Hausa');
INSERT INTO "languageNames" VALUES(10601,'ha','he','Yahudanci');
INSERT INTO "languageNames" VALUES(10602,'ha','hi','Harshen Hindi');
INSERT INTO "languageNames" VALUES(10603,'ha','hr','Kuroshiyan');
INSERT INTO "languageNames" VALUES(10604,'ha','hu','Harshen Hungari');
INSERT INTO "languageNames" VALUES(10605,'ha','hy','Armeniyanci');
INSERT INTO "languageNames" VALUES(10606,'ha','ia','Yare Tsakanin Kasashe');
INSERT INTO "languageNames" VALUES(10607,'ha','id','Harshen Indunusiya');
INSERT INTO "languageNames" VALUES(10608,'ha','ig','Inyamuranci');
INSERT INTO "languageNames" VALUES(10609,'ha','is','Yaren mutanen Iceland');
INSERT INTO "languageNames" VALUES(10610,'ha','it','Italiyanci');
INSERT INTO "languageNames" VALUES(10611,'ha','ka','Jojiyanci');
INSERT INTO "languageNames" VALUES(10612,'ha','ko','Harshen Koreya');
INSERT INTO "languageNames" VALUES(10613,'ha','ky','Kirgizanci');
INSERT INTO "languageNames" VALUES(10614,'ha','la','Dan Kabilar Latin');
INSERT INTO "languageNames" VALUES(10615,'ha','ln','Lingala');
INSERT INTO "languageNames" VALUES(10616,'ha','lo','Laothian');
INSERT INTO "languageNames" VALUES(10617,'ha','lt','Lituweniyanci');
INSERT INTO "languageNames" VALUES(10618,'ha','lv','Latbiyanci');
INSERT INTO "languageNames" VALUES(10619,'ha','mk','Dan Masedoniya');
INSERT INTO "languageNames" VALUES(10620,'ha','ml','Kabilar Maleyalam');
INSERT INTO "languageNames" VALUES(10621,'ha','mr','Kʼabilan Marathi');
INSERT INTO "languageNames" VALUES(10622,'ha','ms','Harshen Malai');
INSERT INTO "languageNames" VALUES(10623,'ha','mt','Harshen Maltis');
INSERT INTO "languageNames" VALUES(10624,'ha','ne','Nepali');
INSERT INTO "languageNames" VALUES(10625,'ha','nl','Holanci');
INSERT INTO "languageNames" VALUES(10626,'ha','nn','Yaren Kasar Norway');
INSERT INTO "languageNames" VALUES(10627,'ha','no','Yaren mutanen Norway');
INSERT INTO "languageNames" VALUES(10628,'ha','oc','Ositanci');
INSERT INTO "languageNames" VALUES(10629,'ha','pa','Punjabi');
INSERT INTO "languageNames" VALUES(10630,'ha','pl','Harshen Polan');
INSERT INTO "languageNames" VALUES(10631,'ha','pt','Harshen Portugal');
INSERT INTO "languageNames" VALUES(10632,'ha','ro','Romaniyanci');
INSERT INTO "languageNames" VALUES(10633,'ha','ru','Rashanci');
INSERT INTO "languageNames" VALUES(10634,'ha','sa','sanskrit');
INSERT INTO "languageNames" VALUES(10635,'ha','sd','Sindiyanci');
INSERT INTO "languageNames" VALUES(10636,'ha','sh','Kuroweshiyancin-Sabiya');
INSERT INTO "languageNames" VALUES(10637,'ha','si','Sinhalanci');
INSERT INTO "languageNames" VALUES(10638,'ha','sk','Basulake');
INSERT INTO "languageNames" VALUES(10639,'ha','sl','Basulabe');
INSERT INTO "languageNames" VALUES(10640,'ha','sq','Dʼan/ʼYar Kabilar Albaniya');
INSERT INTO "languageNames" VALUES(10641,'ha','sr','Sabiyan');
INSERT INTO "languageNames" VALUES(10642,'ha','sv','Harshen Suwedan');
INSERT INTO "languageNames" VALUES(10643,'ha','sw','Harshen Suwahili');
INSERT INTO "languageNames" VALUES(10644,'ha','ta','Tamil');
INSERT INTO "languageNames" VALUES(10645,'ha','te','Dʼan/ʼYar Kabilar Telug');
INSERT INTO "languageNames" VALUES(10646,'ha','th','Thai');
INSERT INTO "languageNames" VALUES(10647,'ha','tk','Tukmenistanci');
INSERT INTO "languageNames" VALUES(10648,'ha','tr','Harshen Turkiyya');
INSERT INTO "languageNames" VALUES(10649,'ha','ug','Ugiranci');
INSERT INTO "languageNames" VALUES(10650,'ha','uk','Harshen Yukuren');
INSERT INTO "languageNames" VALUES(10651,'ha','ur','Harshen Urdu');
INSERT INTO "languageNames" VALUES(10652,'ha','uz','Uzbek');
INSERT INTO "languageNames" VALUES(10653,'ha','vi','Harshen Biyetinam');
INSERT INTO "languageNames" VALUES(10654,'ha','xh','Bazosa');
INSERT INTO "languageNames" VALUES(10655,'ha','yo','Yarbanci');
INSERT INTO "languageNames" VALUES(10656,'ha','zh','Harshen Sin');
INSERT INTO "languageNames" VALUES(10657,'ha','zu','Harshen Zulu');
INSERT INTO "languageNames" VALUES(10658,'ckb','af','ئه‌فریكای');
INSERT INTO "languageNames" VALUES(10659,'ckb','ar','عەرەبی');
INSERT INTO "languageNames" VALUES(10660,'ckb','as','ئاسامی');
INSERT INTO "languageNames" VALUES(10662,'ckb','az','ئازەربایجانی');
INSERT INTO "languageNames" VALUES(10663,'ckb','be','بیلاڕووسی');
INSERT INTO "languageNames" VALUES(10664,'ckb','bg','بۆلگاری');
INSERT INTO "languageNames" VALUES(10665,'ckb','bn','بەنگلادێشی');
INSERT INTO "languageNames" VALUES(10666,'ckb','br','برێتونی');
INSERT INTO "languageNames" VALUES(10667,'ckb','bs','بۆسنی');
INSERT INTO "languageNames" VALUES(10668,'ckb','ca','كاتالۆنی');
INSERT INTO "languageNames" VALUES(10669,'ckb','ckb','کوردیی ناوەندی');
INSERT INTO "languageNames" VALUES(10670,'ckb','cs','چەكی');
INSERT INTO "languageNames" VALUES(10671,'ckb','cy','وێلزی');
INSERT INTO "languageNames" VALUES(10672,'ckb','da','دانماركی');
INSERT INTO "languageNames" VALUES(10673,'ckb','de','ئاڵمانی');
INSERT INTO "languageNames" VALUES(10674,'ckb','el','یۆنانی');
INSERT INTO "languageNames" VALUES(10675,'ckb','en','ئینگلیزی');
INSERT INTO "languageNames" VALUES(10676,'ckb','eo','ئێسپیرانتۆ');
INSERT INTO "languageNames" VALUES(10677,'ckb','es','ئیسپانی');
INSERT INTO "languageNames" VALUES(10678,'ckb','et','ئیستۆنی');
INSERT INTO "languageNames" VALUES(10679,'ckb','eu','باسکی');
INSERT INTO "languageNames" VALUES(10680,'ckb','fa','فارسی');
INSERT INTO "languageNames" VALUES(10681,'ckb','fi','فینلەندی');
INSERT INTO "languageNames" VALUES(10682,'ckb','fo','فه‌رئۆیی');
INSERT INTO "languageNames" VALUES(10683,'ckb','fr','فەرانسی');
INSERT INTO "languageNames" VALUES(10684,'ckb','fy','فریسیی ڕۆژاوا');
INSERT INTO "languageNames" VALUES(10685,'ckb','ga','ئیرلەندی');
INSERT INTO "languageNames" VALUES(10686,'ckb','gd','گه‌لیكی سكۆتله‌ندی');
INSERT INTO "languageNames" VALUES(10687,'ckb','gl','گالیسی');
INSERT INTO "languageNames" VALUES(10688,'ckb','gn','گووارانی');
INSERT INTO "languageNames" VALUES(10689,'ckb','gu','گوجاراتی');
INSERT INTO "languageNames" VALUES(10690,'ckb','he','هیبرێ');
INSERT INTO "languageNames" VALUES(10691,'ckb','hi','هیندی');
INSERT INTO "languageNames" VALUES(10692,'ckb','hr','كرواتی');
INSERT INTO "languageNames" VALUES(10693,'ckb','hu','هەنگاری (مەجاری)');
INSERT INTO "languageNames" VALUES(10694,'ckb','hy','ئەرمەنی');
INSERT INTO "languageNames" VALUES(10695,'ckb','ia','ئینترلینگوی');
INSERT INTO "languageNames" VALUES(10696,'ckb','id','ئێەندونیزی');
INSERT INTO "languageNames" VALUES(10697,'ckb','is','ئیسلەندی');
INSERT INTO "languageNames" VALUES(10698,'ckb','it','ئیتالی');
INSERT INTO "languageNames" VALUES(10699,'ckb','ka','گۆرجستانی');
INSERT INTO "languageNames" VALUES(10700,'ckb','kk','کازاخی');
INSERT INTO "languageNames" VALUES(10701,'ckb','ko','كۆری');
INSERT INTO "languageNames" VALUES(10702,'ckb','ky','كرگیزی');
INSERT INTO "languageNames" VALUES(10703,'ckb','la','لاتینی');
INSERT INTO "languageNames" VALUES(10704,'ckb','ln','لينگالا');
INSERT INTO "languageNames" VALUES(10705,'ckb','lo','لاوی');
INSERT INTO "languageNames" VALUES(10706,'ckb','lt','لیتوانی');
INSERT INTO "languageNames" VALUES(10707,'ckb','lv','لێتۆنی');
INSERT INTO "languageNames" VALUES(10708,'ckb','mk','ماكێدۆنی');
INSERT INTO "languageNames" VALUES(10709,'ckb','ml','مالایلام');
INSERT INTO "languageNames" VALUES(10710,'ckb','mr','ماراتی');
INSERT INTO "languageNames" VALUES(10711,'ckb','ms','مالیزی');
INSERT INTO "languageNames" VALUES(10712,'ckb','mt','ماڵتایی');
INSERT INTO "languageNames" VALUES(10713,'ckb','ne','نیپالی');
INSERT INTO "languageNames" VALUES(10714,'ckb','nl','هۆڵەندی');
INSERT INTO "languageNames" VALUES(10715,'ckb','no','نۆروێژی');
INSERT INTO "languageNames" VALUES(10716,'ckb','oc','ئۆسیتانی');
INSERT INTO "languageNames" VALUES(10717,'ckb','pa','پەنجابی');
INSERT INTO "languageNames" VALUES(10718,'ckb','pl','پۆڵۆنیایی (لەهستانی)');
INSERT INTO "languageNames" VALUES(10719,'ckb','pt','پورتوگالی');
INSERT INTO "languageNames" VALUES(10720,'ckb','ro','ڕۆمانی');
INSERT INTO "languageNames" VALUES(10721,'ckb','ru','ڕووسی');
INSERT INTO "languageNames" VALUES(10722,'ckb','sa','سانسکريت');
INSERT INTO "languageNames" VALUES(10723,'ckb','sd','سيندی');
INSERT INTO "languageNames" VALUES(10724,'ckb','sh','سێربۆكرواتی');
INSERT INTO "languageNames" VALUES(10725,'ckb','si','سینهەلی');
INSERT INTO "languageNames" VALUES(10726,'ckb','sk','سلۆڤاكی');
INSERT INTO "languageNames" VALUES(10727,'ckb','sl','سلۆڤێنی');
INSERT INTO "languageNames" VALUES(10728,'ckb','sma','سامی باشووری');
INSERT INTO "languageNames" VALUES(10729,'ckb','sq','ئەڵبانی');
INSERT INTO "languageNames" VALUES(10730,'ckb','sr','سەربی');
INSERT INTO "languageNames" VALUES(10731,'ckb','sv','سویدی');
INSERT INTO "languageNames" VALUES(10732,'ckb','sw','سواهیلی');
INSERT INTO "languageNames" VALUES(10733,'ckb','ta','تامیلی');
INSERT INTO "languageNames" VALUES(10734,'ckb','te','تەلۆگوی');
INSERT INTO "languageNames" VALUES(10735,'ckb','tg','تاجیکی');
INSERT INTO "languageNames" VALUES(10736,'ckb','th','تایلەندی');
INSERT INTO "languageNames" VALUES(10737,'ckb','tk','تورکمانی');
INSERT INTO "languageNames" VALUES(10738,'ckb','tr','تورکی');
INSERT INTO "languageNames" VALUES(10739,'ckb','ug','ئويخووری');
INSERT INTO "languageNames" VALUES(10740,'ckb','uk','ئۆكراینی');
INSERT INTO "languageNames" VALUES(10741,'ckb','ur','ئۆردوو');
INSERT INTO "languageNames" VALUES(10742,'ckb','uz','ئوزبەکی');
INSERT INTO "languageNames" VALUES(10743,'ckb','vi','ڤیەتنامی');
INSERT INTO "languageNames" VALUES(10744,'ckb','xh','سسوسا');
INSERT INTO "languageNames" VALUES(10745,'ckb','yi','یوددی');
INSERT INTO "languageNames" VALUES(10746,'ckb','zh','چینی');
INSERT INTO "languageNames" VALUES(10747,'ckb','zu','زولو');
INSERT INTO "languageNames" VALUES(10748,'pt','af','africâner');
INSERT INTO "languageNames" VALUES(10749,'pt','alt','altai do sul');
INSERT INTO "languageNames" VALUES(10750,'pt','an','aragonês');
INSERT INTO "languageNames" VALUES(10751,'pt','ar','árabe');
INSERT INTO "languageNames" VALUES(10752,'pt','as','assamês');
INSERT INTO "languageNames" VALUES(10753,'pt','ast','asturiano');
INSERT INTO "languageNames" VALUES(10754,'pt','av','avárico');
INSERT INTO "languageNames" VALUES(10756,'pt','az','azeri');
INSERT INTO "languageNames" VALUES(10757,'pt','ba','bashkir');
INSERT INTO "languageNames" VALUES(10758,'pt','be','bielorrusso');
INSERT INTO "languageNames" VALUES(10759,'pt','bg','búlgaro');
INSERT INTO "languageNames" VALUES(10760,'pt','bi','bislamá');
INSERT INTO "languageNames" VALUES(10761,'pt','bn','bengali');
INSERT INTO "languageNames" VALUES(10762,'pt','br','bretão');
INSERT INTO "languageNames" VALUES(10763,'pt','bs','bósnio');
INSERT INTO "languageNames" VALUES(10764,'pt','bua','buriato');
INSERT INTO "languageNames" VALUES(10765,'pt','byv','medumba');
INSERT INTO "languageNames" VALUES(10766,'pt','ca','catalão');
INSERT INTO "languageNames" VALUES(10767,'pt','ceb','cebuano');
INSERT INTO "languageNames" VALUES(10768,'pt','chm','mari');
INSERT INTO "languageNames" VALUES(10769,'pt','ckb','curdo central');
INSERT INTO "languageNames" VALUES(10770,'pt','co','corso');
INSERT INTO "languageNames" VALUES(10771,'pt','crh','turco da Crimeia');
INSERT INTO "languageNames" VALUES(10772,'pt','cs','tcheco');
INSERT INTO "languageNames" VALUES(10773,'pt','csb','kashubian');
INSERT INTO "languageNames" VALUES(10774,'pt','cu','eslavo eclesiástico');
INSERT INTO "languageNames" VALUES(10775,'pt','cv','tchuvache');
INSERT INTO "languageNames" VALUES(10776,'pt','cy','galês');
INSERT INTO "languageNames" VALUES(10777,'pt','da','dinamarquês');
INSERT INTO "languageNames" VALUES(10778,'pt','dar','dargwa');
INSERT INTO "languageNames" VALUES(10779,'pt','de','alemão');
INSERT INTO "languageNames" VALUES(10780,'pt','dsb','baixo sorábio');
INSERT INTO "languageNames" VALUES(10781,'pt','el','grego');
INSERT INTO "languageNames" VALUES(10782,'pt','en','inglês');
INSERT INTO "languageNames" VALUES(10783,'pt','eo','esperanto');
INSERT INTO "languageNames" VALUES(10784,'pt','es','espanhol');
INSERT INTO "languageNames" VALUES(10785,'pt','et','estoniano');
INSERT INTO "languageNames" VALUES(10786,'pt','eu','basco');
INSERT INTO "languageNames" VALUES(10787,'pt','fa','persa');
INSERT INTO "languageNames" VALUES(10788,'pt','fi','finlandês');
INSERT INTO "languageNames" VALUES(10789,'pt','fo','feroês');
INSERT INTO "languageNames" VALUES(10790,'pt','fr','francês');
INSERT INTO "languageNames" VALUES(10791,'pt','fy','frísio ocidental');
INSERT INTO "languageNames" VALUES(10792,'pt','ga','irlandês');
INSERT INTO "languageNames" VALUES(10793,'pt','gag','gagauz');
INSERT INTO "languageNames" VALUES(10794,'pt','gd','gaélico escocês');
INSERT INTO "languageNames" VALUES(10795,'pt','gl','galego');
INSERT INTO "languageNames" VALUES(10796,'pt','gn','guarani');
INSERT INTO "languageNames" VALUES(10797,'pt','gu','guzerate');
INSERT INTO "languageNames" VALUES(10798,'pt','gv','manx');
INSERT INTO "languageNames" VALUES(10799,'pt','ha','hauçá');
INSERT INTO "languageNames" VALUES(10800,'pt','haw','havaiano');
INSERT INTO "languageNames" VALUES(10801,'pt','he','hebraico');
INSERT INTO "languageNames" VALUES(10802,'pt','hi','híndi');
INSERT INTO "languageNames" VALUES(10803,'pt','hr','croata');
INSERT INTO "languageNames" VALUES(10804,'pt','hsb','alto sorábio');
INSERT INTO "languageNames" VALUES(10805,'pt','ht','haitiano');
INSERT INTO "languageNames" VALUES(10806,'pt','hu','húngaro');
INSERT INTO "languageNames" VALUES(10807,'pt','hy','armênio');
INSERT INTO "languageNames" VALUES(10808,'pt','ia','interlíngua');
INSERT INTO "languageNames" VALUES(10809,'pt','id','indonésio');
INSERT INTO "languageNames" VALUES(10810,'pt','ig','igbo');
INSERT INTO "languageNames" VALUES(10811,'pt','is','islandês');
INSERT INTO "languageNames" VALUES(10812,'pt','it','italiano');
INSERT INTO "languageNames" VALUES(10813,'pt','ka','georgiano');
INSERT INTO "languageNames" VALUES(10814,'pt','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(10815,'pt','kk','cazaque');
INSERT INTO "languageNames" VALUES(10816,'pt','ko','coreano');
INSERT INTO "languageNames" VALUES(10817,'pt','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(10818,'pt','krl','carélio');
INSERT INTO "languageNames" VALUES(10819,'pt','ks','caxemira');
INSERT INTO "languageNames" VALUES(10820,'pt','kum','kumyk');
INSERT INTO "languageNames" VALUES(10821,'pt','kv','komi');
INSERT INTO "languageNames" VALUES(10822,'pt','ky','quirguiz');
INSERT INTO "languageNames" VALUES(10823,'pt','la','latim');
INSERT INTO "languageNames" VALUES(10824,'pt','lb','luxemburguês');
INSERT INTO "languageNames" VALUES(10825,'pt','lg','luganda');
INSERT INTO "languageNames" VALUES(10826,'pt','ln','lingala');
INSERT INTO "languageNames" VALUES(10827,'pt','lo','laosiano');
INSERT INTO "languageNames" VALUES(10828,'pt','lt','lituano');
INSERT INTO "languageNames" VALUES(10829,'pt','lv','letão');
INSERT INTO "languageNames" VALUES(10830,'pt','mdf','mocsa');
INSERT INTO "languageNames" VALUES(10831,'pt','mfe','morisyen');
INSERT INTO "languageNames" VALUES(10832,'pt','mk','macedônio');
INSERT INTO "languageNames" VALUES(10833,'pt','ml','malaiala');
INSERT INTO "languageNames" VALUES(10834,'pt','mr','marati');
INSERT INTO "languageNames" VALUES(10835,'pt','ms','malaio');
INSERT INTO "languageNames" VALUES(10836,'pt','mt','maltês');
INSERT INTO "languageNames" VALUES(10837,'pt','myv','erzya');
INSERT INTO "languageNames" VALUES(10838,'pt','nap','napolitano');
INSERT INTO "languageNames" VALUES(10839,'pt','nb','bokmål norueguês');
INSERT INTO "languageNames" VALUES(10840,'pt','ne','nepalês');
INSERT INTO "languageNames" VALUES(10841,'pt','nl','holandês');
INSERT INTO "languageNames" VALUES(10842,'pt','nn','nynorsk norueguês');
INSERT INTO "languageNames" VALUES(10843,'pt','no','norueguês');
INSERT INTO "languageNames" VALUES(10844,'pt','nog','nogai');
INSERT INTO "languageNames" VALUES(10845,'pt','oc','occitânico');
INSERT INTO "languageNames" VALUES(10846,'pt','os','osseto');
INSERT INTO "languageNames" VALUES(10847,'pt','ota','turco otomano');
INSERT INTO "languageNames" VALUES(10848,'pt','pa','panjabi');
INSERT INTO "languageNames" VALUES(10849,'pt','pl','polonês');
INSERT INTO "languageNames" VALUES(10850,'pt','pt','português');
INSERT INTO "languageNames" VALUES(10851,'pt','rm','romanche');
INSERT INTO "languageNames" VALUES(10852,'pt','rn','rundi');
INSERT INTO "languageNames" VALUES(10853,'pt','ro','romeno');
INSERT INTO "languageNames" VALUES(10854,'pt','ru','russo');
INSERT INTO "languageNames" VALUES(10855,'pt','rup','aromeno');
INSERT INTO "languageNames" VALUES(10856,'pt','sa','sânscrito');
INSERT INTO "languageNames" VALUES(10857,'pt','sah','sakha');
INSERT INTO "languageNames" VALUES(10858,'pt','sc','sardo');
INSERT INTO "languageNames" VALUES(10859,'pt','scn','siciliano');
INSERT INTO "languageNames" VALUES(10860,'pt','sco','scots');
INSERT INTO "languageNames" VALUES(10861,'pt','sd','sindi');
INSERT INTO "languageNames" VALUES(10862,'pt','se','sami setentrional');
INSERT INTO "languageNames" VALUES(10863,'pt','sh','servo-croata');
INSERT INTO "languageNames" VALUES(10864,'pt','si','cingalês');
INSERT INTO "languageNames" VALUES(10865,'pt','sk','eslovaco');
INSERT INTO "languageNames" VALUES(10866,'pt','sl','esloveno');
INSERT INTO "languageNames" VALUES(10867,'pt','sma','sami do sul');
INSERT INTO "languageNames" VALUES(10868,'pt','smj','sami de Lule');
INSERT INTO "languageNames" VALUES(10869,'pt','smn','sami de Inari');
INSERT INTO "languageNames" VALUES(10870,'pt','sq','albanês');
INSERT INTO "languageNames" VALUES(10871,'pt','sr','sérvio');
INSERT INTO "languageNames" VALUES(10872,'pt','srn','surinamês');
INSERT INTO "languageNames" VALUES(10873,'pt','ss','suázi');
INSERT INTO "languageNames" VALUES(10874,'pt','sv','sueco');
INSERT INTO "languageNames" VALUES(10875,'pt','sw','suaíli');
INSERT INTO "languageNames" VALUES(10876,'pt','ta','tâmil');
INSERT INTO "languageNames" VALUES(10877,'pt','te','télugo');
INSERT INTO "languageNames" VALUES(10878,'pt','tet','tétum');
INSERT INTO "languageNames" VALUES(10879,'pt','tg','tadjique');
INSERT INTO "languageNames" VALUES(10880,'pt','th','tailandês');
INSERT INTO "languageNames" VALUES(10881,'pt','tk','turcomeno');
INSERT INTO "languageNames" VALUES(10882,'pt','tl','tagalo');
INSERT INTO "languageNames" VALUES(10883,'pt','tr','turco');
INSERT INTO "languageNames" VALUES(10884,'pt','tt','tártaro');
INSERT INTO "languageNames" VALUES(10885,'pt','tyv','tuviniano');
INSERT INTO "languageNames" VALUES(10886,'pt','udm','udmurte');
INSERT INTO "languageNames" VALUES(10887,'pt','ug','uigur');
INSERT INTO "languageNames" VALUES(10888,'pt','uk','ucraniano');
INSERT INTO "languageNames" VALUES(10889,'pt','ur','urdu');
INSERT INTO "languageNames" VALUES(10890,'pt','uz','uzbeque');
INSERT INTO "languageNames" VALUES(10891,'pt','vi','vietnamita');
INSERT INTO "languageNames" VALUES(10892,'pt','wal','wolaytta');
INSERT INTO "languageNames" VALUES(10893,'pt','xh','xhosa');
INSERT INTO "languageNames" VALUES(10894,'pt','yi','iídiche');
INSERT INTO "languageNames" VALUES(10895,'pt','yo','iorubá');
INSERT INTO "languageNames" VALUES(10896,'pt','zh','chinês');
INSERT INTO "languageNames" VALUES(10897,'pt','zu','zulu');
INSERT INTO "languageNames" VALUES(10898,'ky','af','африкаанча');
INSERT INTO "languageNames" VALUES(10899,'ky','alt','түштүк алтайча');
INSERT INTO "languageNames" VALUES(10900,'ky','an','арагончо');
INSERT INTO "languageNames" VALUES(10901,'ky','ar','арабча');
INSERT INTO "languageNames" VALUES(10902,'ky','as','ассамча');
INSERT INTO "languageNames" VALUES(10903,'ky','ast','астурийче');
INSERT INTO "languageNames" VALUES(10904,'ky','av','аварикче');
INSERT INTO "languageNames" VALUES(10906,'ky','az','азерче');
INSERT INTO "languageNames" VALUES(10907,'ky','ba','башкырча');
INSERT INTO "languageNames" VALUES(10908,'ky','be','беларусча');
INSERT INTO "languageNames" VALUES(10909,'ky','bg','болгарча');
INSERT INTO "languageNames" VALUES(10910,'ky','bi','бисламача');
INSERT INTO "languageNames" VALUES(10911,'ky','bn','бангладешче');
INSERT INTO "languageNames" VALUES(10912,'ky','br','бретончо');
INSERT INTO "languageNames" VALUES(10913,'ky','bs','боснийче');
INSERT INTO "languageNames" VALUES(10914,'ky','ca','каталонча');
INSERT INTO "languageNames" VALUES(10915,'ky','ceb','себуанча');
INSERT INTO "languageNames" VALUES(10916,'ky','chm','мариче');
INSERT INTO "languageNames" VALUES(10917,'ky','ckb','борбордук курдча');
INSERT INTO "languageNames" VALUES(10918,'ky','co','корсиканча');
INSERT INTO "languageNames" VALUES(10919,'ky','cs','чехче');
INSERT INTO "languageNames" VALUES(10920,'ky','cu','чиркөө славянча');
INSERT INTO "languageNames" VALUES(10921,'ky','cv','чувашча');
INSERT INTO "languageNames" VALUES(10922,'ky','cy','уелшче');
INSERT INTO "languageNames" VALUES(10923,'ky','da','датча');
INSERT INTO "languageNames" VALUES(10924,'ky','dar','даргинче');
INSERT INTO "languageNames" VALUES(10925,'ky','de','немисче');
INSERT INTO "languageNames" VALUES(10926,'ky','dsb','төмөнкү сорбианча');
INSERT INTO "languageNames" VALUES(10927,'ky','el','грекче');
INSERT INTO "languageNames" VALUES(10928,'ky','en','англисче');
INSERT INTO "languageNames" VALUES(10929,'ky','eo','эсперанто');
INSERT INTO "languageNames" VALUES(10930,'ky','es','испанча');
INSERT INTO "languageNames" VALUES(10931,'ky','et','эстончо');
INSERT INTO "languageNames" VALUES(10932,'ky','eu','баскча');
INSERT INTO "languageNames" VALUES(10933,'ky','fa','фарсча');
INSERT INTO "languageNames" VALUES(10934,'ky','fi','финче');
INSERT INTO "languageNames" VALUES(10935,'ky','fo','фарерче');
INSERT INTO "languageNames" VALUES(10936,'ky','fr','французча');
INSERT INTO "languageNames" VALUES(10937,'ky','fy','батыш фризче');
INSERT INTO "languageNames" VALUES(10938,'ky','ga','ирландча');
INSERT INTO "languageNames" VALUES(10939,'ky','gag','гагаузча');
INSERT INTO "languageNames" VALUES(10940,'ky','gd','шотладиялык гелча');
INSERT INTO "languageNames" VALUES(10941,'ky','gl','галисияча');
INSERT INTO "languageNames" VALUES(10942,'ky','gn','гуараниче');
INSERT INTO "languageNames" VALUES(10943,'ky','gu','гужаратча');
INSERT INTO "languageNames" VALUES(10944,'ky','gv','мэнксыча');
INSERT INTO "languageNames" VALUES(10945,'ky','ha','хаусача');
INSERT INTO "languageNames" VALUES(10946,'ky','haw','гавайча');
INSERT INTO "languageNames" VALUES(10947,'ky','he','ивритче');
INSERT INTO "languageNames" VALUES(10948,'ky','hi','хиндиче');
INSERT INTO "languageNames" VALUES(10949,'ky','hr','хорватча');
INSERT INTO "languageNames" VALUES(10950,'ky','hsb','жогорку сорбианча');
INSERT INTO "languageNames" VALUES(10951,'ky','ht','гаитиче');
INSERT INTO "languageNames" VALUES(10952,'ky','hu','венгерче');
INSERT INTO "languageNames" VALUES(10953,'ky','hy','армянча');
INSERT INTO "languageNames" VALUES(10954,'ky','ia','интерлингва');
INSERT INTO "languageNames" VALUES(10955,'ky','id','индонезияча');
INSERT INTO "languageNames" VALUES(10956,'ky','ig','игбочо');
INSERT INTO "languageNames" VALUES(10957,'ky','is','исландча');
INSERT INTO "languageNames" VALUES(10958,'ky','it','италиянча');
INSERT INTO "languageNames" VALUES(10959,'ky','ka','грузинче');
INSERT INTO "languageNames" VALUES(10960,'ky','kk','казакча');
INSERT INTO "languageNames" VALUES(10961,'ky','ko','корейче');
INSERT INTO "languageNames" VALUES(10962,'ky','krc','карачай-балкарча');
INSERT INTO "languageNames" VALUES(10963,'ky','krl','карелче');
INSERT INTO "languageNames" VALUES(10964,'ky','ks','кашмирче');
INSERT INTO "languageNames" VALUES(10965,'ky','kum','кумыкча');
INSERT INTO "languageNames" VALUES(10966,'ky','kv','комиче');
INSERT INTO "languageNames" VALUES(10967,'ky','ky','кыргызча');
INSERT INTO "languageNames" VALUES(10968,'ky','la','латынча');
INSERT INTO "languageNames" VALUES(10969,'ky','lb','люксембургча');
INSERT INTO "languageNames" VALUES(10970,'ky','lg','гандача');
INSERT INTO "languageNames" VALUES(10971,'ky','ln','лингалача');
INSERT INTO "languageNames" VALUES(10972,'ky','lo','лаочо');
INSERT INTO "languageNames" VALUES(10973,'ky','lt','литовчо');
INSERT INTO "languageNames" VALUES(10974,'ky','lv','латышча');
INSERT INTO "languageNames" VALUES(10975,'ky','mdf','мокшача');
INSERT INTO "languageNames" VALUES(10976,'ky','mfe','морисианча');
INSERT INTO "languageNames" VALUES(10977,'ky','mk','македончо');
INSERT INTO "languageNames" VALUES(10978,'ky','ml','малайаламча');
INSERT INTO "languageNames" VALUES(10979,'ky','mr','маратиче');
INSERT INTO "languageNames" VALUES(10980,'ky','ms','малайча');
INSERT INTO "languageNames" VALUES(10981,'ky','mt','малтизче');
INSERT INTO "languageNames" VALUES(10982,'ky','myv','эрзянча');
INSERT INTO "languageNames" VALUES(10983,'ky','nap','неополитанча');
INSERT INTO "languageNames" VALUES(10984,'ky','nb','норвежче (Букмал)');
INSERT INTO "languageNames" VALUES(10985,'ky','ne','непалча');
INSERT INTO "languageNames" VALUES(10986,'ky','nl','голландча');
INSERT INTO "languageNames" VALUES(10987,'ky','nn','норвежче (нинорск)');
INSERT INTO "languageNames" VALUES(10988,'ky','no','норвежче');
INSERT INTO "languageNames" VALUES(10989,'ky','nog','ногайча');
INSERT INTO "languageNames" VALUES(10990,'ky','oc','окситанча');
INSERT INTO "languageNames" VALUES(10991,'ky','os','осетинче');
INSERT INTO "languageNames" VALUES(10992,'ky','pa','пунжабиче');
INSERT INTO "languageNames" VALUES(10993,'ky','pl','полякча');
INSERT INTO "languageNames" VALUES(10994,'ky','pt','португалча');
INSERT INTO "languageNames" VALUES(10995,'ky','rm','романшча');
INSERT INTO "languageNames" VALUES(10996,'ky','rn','рундиче');
INSERT INTO "languageNames" VALUES(10997,'ky','ro','румынча');
INSERT INTO "languageNames" VALUES(10998,'ky','ru','орусча');
INSERT INTO "languageNames" VALUES(10999,'ky','rup','аромунча');
INSERT INTO "languageNames" VALUES(11000,'ky','sa','санскритче');
INSERT INTO "languageNames" VALUES(11001,'ky','sah','сахача');
INSERT INTO "languageNames" VALUES(11002,'ky','sc','сардинче');
INSERT INTO "languageNames" VALUES(11003,'ky','scn','сицилийче');
INSERT INTO "languageNames" VALUES(11004,'ky','sco','шотландча');
INSERT INTO "languageNames" VALUES(11005,'ky','sd','синдхиче');
INSERT INTO "languageNames" VALUES(11006,'ky','se','түндүк саамиче');
INSERT INTO "languageNames" VALUES(11007,'ky','sh','серб-хорват');
INSERT INTO "languageNames" VALUES(11008,'ky','si','сингалача');
INSERT INTO "languageNames" VALUES(11009,'ky','sk','словакча');
INSERT INTO "languageNames" VALUES(11010,'ky','sl','словенче');
INSERT INTO "languageNames" VALUES(11011,'ky','sma','түштүк саамиче');
INSERT INTO "languageNames" VALUES(11012,'ky','smj','луле саамиче');
INSERT INTO "languageNames" VALUES(11013,'ky','smn','инари саамиче');
INSERT INTO "languageNames" VALUES(11014,'ky','sq','албанча');
INSERT INTO "languageNames" VALUES(11015,'ky','sr','сербче');
INSERT INTO "languageNames" VALUES(11016,'ky','srn','сранан тонгочо');
INSERT INTO "languageNames" VALUES(11017,'ky','ss','сватиче');
INSERT INTO "languageNames" VALUES(11018,'ky','sv','шведче');
INSERT INTO "languageNames" VALUES(11019,'ky','sw','суахиличе');
INSERT INTO "languageNames" VALUES(11020,'ky','ta','тамилче');
INSERT INTO "languageNames" VALUES(11021,'ky','te','телугуча');
INSERT INTO "languageNames" VALUES(11022,'ky','tet','тетумча');
INSERT INTO "languageNames" VALUES(11023,'ky','tg','тажикче');
INSERT INTO "languageNames" VALUES(11024,'ky','th','тайча');
INSERT INTO "languageNames" VALUES(11025,'ky','tk','түркмөнчө');
INSERT INTO "languageNames" VALUES(11026,'ky','tr','түркчө');
INSERT INTO "languageNames" VALUES(11027,'ky','tt','татарча');
INSERT INTO "languageNames" VALUES(11028,'ky','tyv','тувинче');
INSERT INTO "languageNames" VALUES(11029,'ky','udm','удмуртча');
INSERT INTO "languageNames" VALUES(11030,'ky','ug','уйгурча');
INSERT INTO "languageNames" VALUES(11031,'ky','uk','украинче');
INSERT INTO "languageNames" VALUES(11032,'ky','ur','урдуча');
INSERT INTO "languageNames" VALUES(11033,'ky','uz','өзбекче');
INSERT INTO "languageNames" VALUES(11034,'ky','vi','вьетнамча');
INSERT INTO "languageNames" VALUES(11035,'ky','wal','вольяттача');
INSERT INTO "languageNames" VALUES(11036,'ky','xh','косача');
INSERT INTO "languageNames" VALUES(11037,'ky','yi','идишче');
INSERT INTO "languageNames" VALUES(11038,'ky','yo','йорубача');
INSERT INTO "languageNames" VALUES(11039,'ky','zh','кытайча');
INSERT INTO "languageNames" VALUES(11040,'ky','zu','зулуча');
INSERT INTO "languageNames" VALUES(11041,'hi','af','अफ़्रीकी');
INSERT INTO "languageNames" VALUES(11042,'hi','alt','दक्षिणी अल्ताई');
INSERT INTO "languageNames" VALUES(11043,'hi','an','अर्गोनी');
INSERT INTO "languageNames" VALUES(11044,'hi','ar','अरबी');
INSERT INTO "languageNames" VALUES(11045,'hi','as','असमिया');
INSERT INTO "languageNames" VALUES(11046,'hi','ast','अस्तुरियन');
INSERT INTO "languageNames" VALUES(11047,'hi','av','अवेरिक');
INSERT INTO "languageNames" VALUES(11049,'hi','az','अज़ेरी');
INSERT INTO "languageNames" VALUES(11050,'hi','ba','बशख़िर');
INSERT INTO "languageNames" VALUES(11051,'hi','be','बेलारूसी');
INSERT INTO "languageNames" VALUES(11052,'hi','bg','बुल्गारियाई');
INSERT INTO "languageNames" VALUES(11053,'hi','bi','बिस्लामा');
INSERT INTO "languageNames" VALUES(11054,'hi','bn','बंगाली');
INSERT INTO "languageNames" VALUES(11055,'hi','br','ब्रेटन');
INSERT INTO "languageNames" VALUES(11056,'hi','bs','बोस्नियाई');
INSERT INTO "languageNames" VALUES(11057,'hi','bua','बुरियात');
INSERT INTO "languageNames" VALUES(11058,'hi','ca','कातालान');
INSERT INTO "languageNames" VALUES(11059,'hi','ceb','सिबुआनो');
INSERT INTO "languageNames" VALUES(11060,'hi','chm','मारी');
INSERT INTO "languageNames" VALUES(11061,'hi','ckb','सोरानी कुर्दिश');
INSERT INTO "languageNames" VALUES(11062,'hi','co','कोर्सीकन');
INSERT INTO "languageNames" VALUES(11063,'hi','crh','क्रीमीन तुर्की');
INSERT INTO "languageNames" VALUES(11064,'hi','cs','चेक');
INSERT INTO "languageNames" VALUES(11065,'hi','csb','काशुबियन');
INSERT INTO "languageNames" VALUES(11066,'hi','cu','चर्च साल्विक');
INSERT INTO "languageNames" VALUES(11067,'hi','cv','चूवाश');
INSERT INTO "languageNames" VALUES(11068,'hi','cy','वेल्श');
INSERT INTO "languageNames" VALUES(11069,'hi','da','डेनिश');
INSERT INTO "languageNames" VALUES(11070,'hi','dar','दार्गवा');
INSERT INTO "languageNames" VALUES(11071,'hi','de','जर्मन');
INSERT INTO "languageNames" VALUES(11072,'hi','dsb','निचला सॉर्बियन');
INSERT INTO "languageNames" VALUES(11073,'hi','el','यूनानी');
INSERT INTO "languageNames" VALUES(11074,'hi','en','अंग्रेज़ी');
INSERT INTO "languageNames" VALUES(11075,'hi','eo','एस्पेरेंतो');
INSERT INTO "languageNames" VALUES(11076,'hi','es','स्पेनी');
INSERT INTO "languageNames" VALUES(11077,'hi','et','एस्टोनियाई');
INSERT INTO "languageNames" VALUES(11078,'hi','eu','बास्क');
INSERT INTO "languageNames" VALUES(11079,'hi','fa','फ़ारसी');
INSERT INTO "languageNames" VALUES(11080,'hi','fi','फ़िनिश');
INSERT INTO "languageNames" VALUES(11081,'hi','fo','फ़ैरोइज़');
INSERT INTO "languageNames" VALUES(11082,'hi','fr','फ़्रेंच');
INSERT INTO "languageNames" VALUES(11083,'hi','fy','पश्चिमी फ़्रिसियाई');
INSERT INTO "languageNames" VALUES(11084,'hi','ga','आइरिश');
INSERT INTO "languageNames" VALUES(11085,'hi','gag','गागौज़');
INSERT INTO "languageNames" VALUES(11086,'hi','gd','स्कॉटिश गाएलिक');
INSERT INTO "languageNames" VALUES(11087,'hi','gl','गैलिशियन');
INSERT INTO "languageNames" VALUES(11088,'hi','gn','गुआरानी');
INSERT INTO "languageNames" VALUES(11089,'hi','gu','गुजराती');
INSERT INTO "languageNames" VALUES(11090,'hi','gv','मैंक्स');
INSERT INTO "languageNames" VALUES(11091,'hi','ha','हौसा');
INSERT INTO "languageNames" VALUES(11092,'hi','haw','हवाई');
INSERT INTO "languageNames" VALUES(11093,'hi','he','हिब्रू');
INSERT INTO "languageNames" VALUES(11094,'hi','hi','हिन्दी');
INSERT INTO "languageNames" VALUES(11095,'hi','hr','क्रोएशियाई');
INSERT INTO "languageNames" VALUES(11096,'hi','hsb','ऊपरी सॉर्बियन');
INSERT INTO "languageNames" VALUES(11097,'hi','ht','हैतियाई');
INSERT INTO "languageNames" VALUES(11098,'hi','hu','हंगेरियाई');
INSERT INTO "languageNames" VALUES(11099,'hi','hy','आर्मेनियाई');
INSERT INTO "languageNames" VALUES(11100,'hi','ia','इंटरलिंगुआ');
INSERT INTO "languageNames" VALUES(11101,'hi','id','इंडोनेशियाई');
INSERT INTO "languageNames" VALUES(11102,'hi','ig','ईग्बो');
INSERT INTO "languageNames" VALUES(11103,'hi','is','आइसलैंडिक');
INSERT INTO "languageNames" VALUES(11104,'hi','it','इतालवी');
INSERT INTO "languageNames" VALUES(11105,'hi','ka','जॉर्जियाई');
INSERT INTO "languageNames" VALUES(11106,'hi','kaa','कारा-कल्पक');
INSERT INTO "languageNames" VALUES(11107,'hi','kk','कज़ाख़');
INSERT INTO "languageNames" VALUES(11108,'hi','ko','कोरियाई');
INSERT INTO "languageNames" VALUES(11109,'hi','krc','कराचय-बल्कार');
INSERT INTO "languageNames" VALUES(11110,'hi','krl','करेलियन');
INSERT INTO "languageNames" VALUES(11111,'hi','ks','कश्मीरी');
INSERT INTO "languageNames" VALUES(11112,'hi','kum','कुमीक');
INSERT INTO "languageNames" VALUES(11113,'hi','kv','कोमी');
INSERT INTO "languageNames" VALUES(11114,'hi','ky','किर्गीज़');
INSERT INTO "languageNames" VALUES(11115,'hi','la','लैटिन');
INSERT INTO "languageNames" VALUES(11116,'hi','lb','लग्ज़मबर्गी');
INSERT INTO "languageNames" VALUES(11117,'hi','lg','गांडा');
INSERT INTO "languageNames" VALUES(11118,'hi','ln','लिंगाला');
INSERT INTO "languageNames" VALUES(11119,'hi','lo','लाओ');
INSERT INTO "languageNames" VALUES(11120,'hi','lt','लिथुआनियाई');
INSERT INTO "languageNames" VALUES(11121,'hi','lv','लातवियाई');
INSERT INTO "languageNames" VALUES(11122,'hi','mdf','मोक्ष');
INSERT INTO "languageNames" VALUES(11123,'hi','mfe','मोरीस्येन');
INSERT INTO "languageNames" VALUES(11124,'hi','mk','मकदूनियाई');
INSERT INTO "languageNames" VALUES(11125,'hi','ml','मलयालम');
INSERT INTO "languageNames" VALUES(11126,'hi','mr','मराठी');
INSERT INTO "languageNames" VALUES(11127,'hi','ms','मलय');
INSERT INTO "languageNames" VALUES(11128,'hi','mt','माल्टीज़');
INSERT INTO "languageNames" VALUES(11129,'hi','myv','एर्ज़या');
INSERT INTO "languageNames" VALUES(11130,'hi','nap','नीपोलिटन');
INSERT INTO "languageNames" VALUES(11131,'hi','nb','नॉर्वेजियाई बोकमाल');
INSERT INTO "languageNames" VALUES(11132,'hi','ne','नेपाली');
INSERT INTO "languageNames" VALUES(11133,'hi','nl','डच');
INSERT INTO "languageNames" VALUES(11134,'hi','nn','नॉर्वेजियाई नॉयनॉर्स्क');
INSERT INTO "languageNames" VALUES(11135,'hi','no','नॉर्वेजियाई');
INSERT INTO "languageNames" VALUES(11136,'hi','nog','नोगाई');
INSERT INTO "languageNames" VALUES(11137,'hi','oc','ओसीटान');
INSERT INTO "languageNames" VALUES(11138,'hi','os','ओस्सेटिक');
INSERT INTO "languageNames" VALUES(11139,'hi','ota','ओटोमान तुर्किश');
INSERT INTO "languageNames" VALUES(11140,'hi','pa','पंजाबी');
INSERT INTO "languageNames" VALUES(11141,'hi','pl','पोलिश');
INSERT INTO "languageNames" VALUES(11142,'hi','pt','पुर्तगाली');
INSERT INTO "languageNames" VALUES(11143,'hi','rm','रोमान्श');
INSERT INTO "languageNames" VALUES(11144,'hi','rn','रुन्दी');
INSERT INTO "languageNames" VALUES(11145,'hi','ro','रोमानियाई');
INSERT INTO "languageNames" VALUES(11146,'hi','ru','रूसी');
INSERT INTO "languageNames" VALUES(11147,'hi','rup','अरोमानियन');
INSERT INTO "languageNames" VALUES(11148,'hi','sa','संस्कृत');
INSERT INTO "languageNames" VALUES(11149,'hi','sah','याकूत');
INSERT INTO "languageNames" VALUES(11150,'hi','sc','सार्दिनियन');
INSERT INTO "languageNames" VALUES(11151,'hi','scn','सिसिलियन');
INSERT INTO "languageNames" VALUES(11152,'hi','sco','स्कॉट्स');
INSERT INTO "languageNames" VALUES(11153,'hi','sd','सिंधी');
INSERT INTO "languageNames" VALUES(11154,'hi','se','नॉर्दन सामी');
INSERT INTO "languageNames" VALUES(11155,'hi','sh','सेर्बो-क्रोएशियाई');
INSERT INTO "languageNames" VALUES(11156,'hi','si','सिंहली');
INSERT INTO "languageNames" VALUES(11157,'hi','sk','स्लोवाक');
INSERT INTO "languageNames" VALUES(11158,'hi','sl','स्लोवेनियाई');
INSERT INTO "languageNames" VALUES(11159,'hi','sma','दक्षिणी सामी');
INSERT INTO "languageNames" VALUES(11160,'hi','smj','ल्युल सामी');
INSERT INTO "languageNames" VALUES(11161,'hi','smn','इनारी सामी');
INSERT INTO "languageNames" VALUES(11162,'hi','sq','अल्बानियाई');
INSERT INTO "languageNames" VALUES(11163,'hi','sr','सर्बियाई');
INSERT INTO "languageNames" VALUES(11164,'hi','srn','स्रानान टॉन्गो');
INSERT INTO "languageNames" VALUES(11165,'hi','ss','स्वाती');
INSERT INTO "languageNames" VALUES(11166,'hi','sv','स्वीडिश');
INSERT INTO "languageNames" VALUES(11167,'hi','sw','स्वाहिली');
INSERT INTO "languageNames" VALUES(11168,'hi','ta','तमिल');
INSERT INTO "languageNames" VALUES(11169,'hi','te','तेलुगू');
INSERT INTO "languageNames" VALUES(11170,'hi','tet','तेतुम');
INSERT INTO "languageNames" VALUES(11171,'hi','tg','ताजिक');
INSERT INTO "languageNames" VALUES(11172,'hi','th','थाई');
INSERT INTO "languageNames" VALUES(11173,'hi','tk','तुर्कमेन');
INSERT INTO "languageNames" VALUES(11174,'hi','tl','टैगलॉग');
INSERT INTO "languageNames" VALUES(11175,'hi','tr','तुर्की');
INSERT INTO "languageNames" VALUES(11176,'hi','tt','तातार');
INSERT INTO "languageNames" VALUES(11177,'hi','tyv','तुवीनियन');
INSERT INTO "languageNames" VALUES(11178,'hi','udm','उदमुर्त');
INSERT INTO "languageNames" VALUES(11179,'hi','ug','विघुर');
INSERT INTO "languageNames" VALUES(11180,'hi','uk','यूक्रेनियाई');
INSERT INTO "languageNames" VALUES(11181,'hi','ur','उर्दू');
INSERT INTO "languageNames" VALUES(11182,'hi','uz','उज़्बेक');
INSERT INTO "languageNames" VALUES(11183,'hi','vi','वियतनामी');
INSERT INTO "languageNames" VALUES(11184,'hi','wal','वलामो');
INSERT INTO "languageNames" VALUES(11185,'hi','xh','ख़ोसा');
INSERT INTO "languageNames" VALUES(11186,'hi','yi','यहूदी');
INSERT INTO "languageNames" VALUES(11187,'hi','yo','योरूबा');
INSERT INTO "languageNames" VALUES(11188,'hi','zh','चीनी');
INSERT INTO "languageNames" VALUES(11189,'hi','zu','ज़ुलू');
INSERT INTO "languageNames" VALUES(11190,'ug','af','ئافرىكانچە');
INSERT INTO "languageNames" VALUES(11191,'ug','alt','جەنۇبى ئالتاي تىللىرى');
INSERT INTO "languageNames" VALUES(11192,'ug','an','ئاراگونچە');
INSERT INTO "languageNames" VALUES(11193,'ug','ar','ئەرەبچە');
INSERT INTO "languageNames" VALUES(11194,'ug','as','ئاسامچە');
INSERT INTO "languageNames" VALUES(11195,'ug','ast','ئاستۇرىيەچە');
INSERT INTO "languageNames" VALUES(11196,'ug','av','ئاۋارچە');
INSERT INTO "languageNames" VALUES(11197,'ug','az','ئەزەربەيجانچە');
INSERT INTO "languageNames" VALUES(11198,'ug','ba','باشقىرتچە');
INSERT INTO "languageNames" VALUES(11199,'ug','be','بېلارۇسچە');
INSERT INTO "languageNames" VALUES(11200,'ug','bg','بۇلغارچە');
INSERT INTO "languageNames" VALUES(11201,'ug','bi','بىسلاماچە');
INSERT INTO "languageNames" VALUES(11202,'ug','bn','بېنگالچە');
INSERT INTO "languageNames" VALUES(11203,'ug','br','بىرېتونچە');
INSERT INTO "languageNames" VALUES(11204,'ug','bs','بوسىنچە');
INSERT INTO "languageNames" VALUES(11205,'ug','bua','بۇرىياتچە');
INSERT INTO "languageNames" VALUES(11206,'ug','byv','مېدۇمباچە');
INSERT INTO "languageNames" VALUES(11207,'ug','ca','كاتالانچە');
INSERT INTO "languageNames" VALUES(11208,'ug','ceb','سېبۇچە');
INSERT INTO "languageNames" VALUES(11209,'ug','chm','مارىچە');
INSERT INTO "languageNames" VALUES(11210,'ug','ckb','مەركىزىي كۇردچە');
INSERT INTO "languageNames" VALUES(11211,'ug','co','كورسۇچە');
INSERT INTO "languageNames" VALUES(11212,'ug','crh','قىرىم تۈركچە');
INSERT INTO "languageNames" VALUES(11213,'ug','cs','چېخچە');
INSERT INTO "languageNames" VALUES(11214,'ug','csb','كاسزۇبىچە');
INSERT INTO "languageNames" VALUES(11215,'ug','cu','قەدىمكى سلاۋيانچە');
INSERT INTO "languageNames" VALUES(11216,'ug','cv','چۇۋاشچە');
INSERT INTO "languageNames" VALUES(11217,'ug','cy','ۋېلشچە');
INSERT INTO "languageNames" VALUES(11218,'ug','da','دانىشچە');
INSERT INTO "languageNames" VALUES(11219,'ug','dar','دارگىۋاچە');
INSERT INTO "languageNames" VALUES(11220,'ug','de','گېرمانچە');
INSERT INTO "languageNames" VALUES(11221,'ug','dsb','تۆۋەن سوربچە');
INSERT INTO "languageNames" VALUES(11222,'ug','el','گىرېكچە');
INSERT INTO "languageNames" VALUES(11223,'ug','en','ئىنگلىزچە');
INSERT INTO "languageNames" VALUES(11224,'ug','eo','ئېسپرانتوچە');
INSERT INTO "languageNames" VALUES(11225,'ug','es','ئىسپانچە');
INSERT INTO "languageNames" VALUES(11226,'ug','et','ئېستونچە');
INSERT INTO "languageNames" VALUES(11227,'ug','eu','باسكىچە');
INSERT INTO "languageNames" VALUES(11228,'ug','fa','پارسچە');
INSERT INTO "languageNames" VALUES(11229,'ug','fi','فىنچە');
INSERT INTO "languageNames" VALUES(11230,'ug','fo','فائېروچە');
INSERT INTO "languageNames" VALUES(11231,'ug','fr','فىرانسۇزچە');
INSERT INTO "languageNames" VALUES(11232,'ug','fy','غەربىي فىرسچە');
INSERT INTO "languageNames" VALUES(11233,'ug','ga','ئىرېلاندچە');
INSERT INTO "languageNames" VALUES(11234,'ug','gd','شوتلاندىيە گايلچىسى');
INSERT INTO "languageNames" VALUES(11235,'ug','gl','گالىچە');
INSERT INTO "languageNames" VALUES(11236,'ug','gn','گۇئارانىچە');
INSERT INTO "languageNames" VALUES(11237,'ug','gu','گۇجاراتچە');
INSERT INTO "languageNames" VALUES(11238,'ug','gv','مانچە');
INSERT INTO "languageNames" VALUES(11239,'ug','ha','خائۇساچە');
INSERT INTO "languageNames" VALUES(11240,'ug','haw','ھاۋايچە');
INSERT INTO "languageNames" VALUES(11241,'ug','he','ئىبرانىيچە');
INSERT INTO "languageNames" VALUES(11242,'ug','hi','ھىندىچە');
INSERT INTO "languageNames" VALUES(11243,'ug','hr','كىرودىچە');
INSERT INTO "languageNames" VALUES(11244,'ug','hsb','ئۈستۈن سوربچە');
INSERT INTO "languageNames" VALUES(11245,'ug','ht','ھايتىچە');
INSERT INTO "languageNames" VALUES(11246,'ug','hu','ۋېنگىرچە');
INSERT INTO "languageNames" VALUES(11247,'ug','hy','ئەرمېنچە');
INSERT INTO "languageNames" VALUES(11248,'ug','ia','ئارىلىق تىل');
INSERT INTO "languageNames" VALUES(11249,'ug','id','ھىندونېزچە');
INSERT INTO "languageNames" VALUES(11250,'ug','ig','ئىگبوچە');
INSERT INTO "languageNames" VALUES(11251,'ug','is','ئىسلاندچە');
INSERT INTO "languageNames" VALUES(11252,'ug','it','ئىتالىيانچە');
INSERT INTO "languageNames" VALUES(11253,'ug','ka','گىرۇزچە');
INSERT INTO "languageNames" VALUES(11254,'ug','kaa','قارا-قالپاقچە');
INSERT INTO "languageNames" VALUES(11255,'ug','kk','قازاقچە');
INSERT INTO "languageNames" VALUES(11256,'ug','ko','كورېيەچە');
INSERT INTO "languageNames" VALUES(11257,'ug','krc','قاراچاي-بالقارچە');
INSERT INTO "languageNames" VALUES(11258,'ug','krl','كارەلچە');
INSERT INTO "languageNames" VALUES(11259,'ug','ks','كەشمىرچە');
INSERT INTO "languageNames" VALUES(11260,'ug','kum','قۇمۇقچە');
INSERT INTO "languageNames" VALUES(11261,'ug','kv','كومىچە');
INSERT INTO "languageNames" VALUES(11262,'ug','ky','قىرغىزچە');
INSERT INTO "languageNames" VALUES(11263,'ug','la','لاتىنچە');
INSERT INTO "languageNames" VALUES(11264,'ug','lb','لىيۇكسېمبۇرگچە');
INSERT INTO "languageNames" VALUES(11265,'ug','lg','گانداچە');
INSERT INTO "languageNames" VALUES(11266,'ug','ln','لىنگالاچە');
INSERT INTO "languageNames" VALUES(11267,'ug','lo','لائوسچە');
INSERT INTO "languageNames" VALUES(11268,'ug','lt','لىتۋانىچە');
INSERT INTO "languageNames" VALUES(11269,'ug','lv','لاتچە');
INSERT INTO "languageNames" VALUES(11270,'ug','mdf','موكشاچە');
INSERT INTO "languageNames" VALUES(11271,'ug','mfe','مورىسيېنچە');
INSERT INTO "languageNames" VALUES(11272,'ug','mk','ماكېدونچە');
INSERT INTO "languageNames" VALUES(11273,'ug','ml','مالايالامچە');
INSERT INTO "languageNames" VALUES(11274,'ug','mr','ماراتىچە');
INSERT INTO "languageNames" VALUES(11275,'ug','ms','مالايچە');
INSERT INTO "languageNames" VALUES(11276,'ug','mt','مالتاچە');
INSERT INTO "languageNames" VALUES(11277,'ug','myv','ئېرزاچە');
INSERT INTO "languageNames" VALUES(11278,'ug','nap','ناپولىچە');
INSERT INTO "languageNames" VALUES(11279,'ug','nb','نورۋىگىيە بوكمالچە');
INSERT INTO "languageNames" VALUES(11280,'ug','ne','نېپالچە');
INSERT INTO "languageNames" VALUES(11281,'ug','nl','گوللاندچە');
INSERT INTO "languageNames" VALUES(11282,'ug','nn','يېڭى نورۋېگچە');
INSERT INTO "languageNames" VALUES(11283,'ug','no','نورۋېگچە');
INSERT INTO "languageNames" VALUES(11284,'ug','nog','نوغايچە');
INSERT INTO "languageNames" VALUES(11285,'ug','oc','ئوكسىتچە');
INSERT INTO "languageNames" VALUES(11286,'ug','os','ئوسسېتچەچە');
INSERT INTO "languageNames" VALUES(11287,'ug','ota','ئوسمان تۈركچە');
INSERT INTO "languageNames" VALUES(11288,'ug','pa','پەنجابچە');
INSERT INTO "languageNames" VALUES(11289,'ug','pl','پولەكچە');
INSERT INTO "languageNames" VALUES(11290,'ug','pt','پورتۇگالچە');
INSERT INTO "languageNames" VALUES(11291,'ug','rm','رومانسچە');
INSERT INTO "languageNames" VALUES(11292,'ug','rn','رۇندىچە');
INSERT INTO "languageNames" VALUES(11293,'ug','ro','رومىنچە');
INSERT INTO "languageNames" VALUES(11294,'ug','ru','رۇسچە');
INSERT INTO "languageNames" VALUES(11295,'ug','rup','ئارومانچە');
INSERT INTO "languageNames" VALUES(11296,'ug','sa','سانسكرىتچە');
INSERT INTO "languageNames" VALUES(11297,'ug','sah','ساخاچە');
INSERT INTO "languageNames" VALUES(11298,'ug','sc','ساردىنىيەچە');
INSERT INTO "languageNames" VALUES(11299,'ug','scn','سىتسىلىيەچە');
INSERT INTO "languageNames" VALUES(11300,'ug','sco','شوتلاندىيەچە');
INSERT INTO "languageNames" VALUES(11301,'ug','sd','سىندىچە');
INSERT INTO "languageNames" VALUES(11302,'ug','se','شىمالىي سامىچە');
INSERT INTO "languageNames" VALUES(11303,'ug','sh','سېرب-كرودىيەچە');
INSERT INTO "languageNames" VALUES(11304,'ug','si','سىنگالچە');
INSERT INTO "languageNames" VALUES(11305,'ug','sk','سىلوۋاكچە');
INSERT INTO "languageNames" VALUES(11306,'ug','sl','سىلوۋېنچە');
INSERT INTO "languageNames" VALUES(11307,'ug','sma','جەنۇبىي سامىچە');
INSERT INTO "languageNames" VALUES(11308,'ug','smj','لۇلې سامىچە');
INSERT INTO "languageNames" VALUES(11309,'ug','smn','ئىنارى سامىچە');
INSERT INTO "languageNames" VALUES(11310,'ug','sq','ئالبانچە');
INSERT INTO "languageNames" VALUES(11311,'ug','sr','سېربچە');
INSERT INTO "languageNames" VALUES(11312,'ug','srn','سىرانان-توڭوچە');
INSERT INTO "languageNames" VALUES(11313,'ug','ss','سىۋاتىچە');
INSERT INTO "languageNames" VALUES(11314,'ug','sv','شىۋېدچە');
INSERT INTO "languageNames" VALUES(11315,'ug','sw','سىۋاھىلچە');
INSERT INTO "languageNames" VALUES(11316,'ug','ta','تامىلچە');
INSERT INTO "languageNames" VALUES(11317,'ug','te','تېلۇگۇچە');
INSERT INTO "languageNames" VALUES(11318,'ug','tet','تېتۇمچە');
INSERT INTO "languageNames" VALUES(11319,'ug','tg','تاجىكچە');
INSERT INTO "languageNames" VALUES(11320,'ug','th','تايلاندچە');
INSERT INTO "languageNames" VALUES(11321,'ug','tk','تۈركمەنچە');
INSERT INTO "languageNames" VALUES(11322,'ug','tl','تاگالوگچە');
INSERT INTO "languageNames" VALUES(11323,'ug','tr','تۈركچە');
INSERT INTO "languageNames" VALUES(11324,'ug','tt','تاتارچە');
INSERT INTO "languageNames" VALUES(11325,'ug','tyv','توۋاچە');
INSERT INTO "languageNames" VALUES(11326,'ug','udm','ئۇدمۇرتچە');
INSERT INTO "languageNames" VALUES(11327,'ug','ug','ئۇيغۇرچە');
INSERT INTO "languageNames" VALUES(11328,'ug','uk','ئۇكرائىنچە');
INSERT INTO "languageNames" VALUES(11329,'ug','ur','ئوردۇچە');
INSERT INTO "languageNames" VALUES(11330,'ug','uz','ئۆزبېكچە');
INSERT INTO "languageNames" VALUES(11331,'ug','vi','ۋىيېتنامچە');
INSERT INTO "languageNames" VALUES(11332,'ug','wal','ۋولايتاچە');
INSERT INTO "languageNames" VALUES(11333,'ug','xh','خوساچە');
INSERT INTO "languageNames" VALUES(11334,'ug','yi','يىددىشچە');
INSERT INTO "languageNames" VALUES(11335,'ug','yo','يورۇباچە');
INSERT INTO "languageNames" VALUES(11336,'ug','zh','خەنزۇچە');
INSERT INTO "languageNames" VALUES(11337,'ug','zu','زۇلۇچە');
INSERT INTO "languageNames" VALUES(11338,'as','as','অসমীয়া');
INSERT INTO "languageNames" VALUES(11339,'cs','af','afrikánština');
INSERT INTO "languageNames" VALUES(11340,'cs','alt','altajština (jižní)');
INSERT INTO "languageNames" VALUES(11341,'cs','an','aragonština');
INSERT INTO "languageNames" VALUES(11342,'cs','ar','arabština');
INSERT INTO "languageNames" VALUES(11343,'cs','as','ásámština');
INSERT INTO "languageNames" VALUES(11344,'cs','ast','asturština');
INSERT INTO "languageNames" VALUES(11345,'cs','av','avarština');
INSERT INTO "languageNames" VALUES(11347,'cs','az','ázerbájdžánština');
INSERT INTO "languageNames" VALUES(11348,'cs','ba','baškirština');
INSERT INTO "languageNames" VALUES(11349,'cs','be','běloruština');
INSERT INTO "languageNames" VALUES(11350,'cs','bg','bulharština');
INSERT INTO "languageNames" VALUES(11351,'cs','bi','bislamština');
INSERT INTO "languageNames" VALUES(11352,'cs','bn','bengálština');
INSERT INTO "languageNames" VALUES(11353,'cs','br','bretonština');
INSERT INTO "languageNames" VALUES(11354,'cs','bs','bosenština');
INSERT INTO "languageNames" VALUES(11355,'cs','bua','burjatština');
INSERT INTO "languageNames" VALUES(11356,'cs','byv','medumba');
INSERT INTO "languageNames" VALUES(11357,'cs','ca','katalánština');
INSERT INTO "languageNames" VALUES(11358,'cs','ceb','cebuánština');
INSERT INTO "languageNames" VALUES(11359,'cs','chm','marijština');
INSERT INTO "languageNames" VALUES(11360,'cs','ckb','kurdština (sorání)');
INSERT INTO "languageNames" VALUES(11361,'cs','co','korsičtina');
INSERT INTO "languageNames" VALUES(11362,'cs','crh','turečtina (krymská)');
INSERT INTO "languageNames" VALUES(11363,'cs','cs','čeština');
INSERT INTO "languageNames" VALUES(11364,'cs','csb','kašubština');
INSERT INTO "languageNames" VALUES(11365,'cs','cu','staroslověnština');
INSERT INTO "languageNames" VALUES(11366,'cs','cv','čuvaština');
INSERT INTO "languageNames" VALUES(11367,'cs','cy','velština');
INSERT INTO "languageNames" VALUES(11368,'cs','da','dánština');
INSERT INTO "languageNames" VALUES(11369,'cs','dar','dargština');
INSERT INTO "languageNames" VALUES(11370,'cs','de','němčina');
INSERT INTO "languageNames" VALUES(11371,'cs','dsb','dolnolužická srbština');
INSERT INTO "languageNames" VALUES(11372,'cs','el','řečtina');
INSERT INTO "languageNames" VALUES(11373,'cs','en','angličtina');
INSERT INTO "languageNames" VALUES(11374,'cs','eo','esperanto');
INSERT INTO "languageNames" VALUES(11375,'cs','es','španělština');
INSERT INTO "languageNames" VALUES(11376,'cs','et','estonština');
INSERT INTO "languageNames" VALUES(11377,'cs','eu','baskičtina');
INSERT INTO "languageNames" VALUES(11378,'cs','fa','perština');
INSERT INTO "languageNames" VALUES(11379,'cs','fi','finština');
INSERT INTO "languageNames" VALUES(11380,'cs','fo','faerština');
INSERT INTO "languageNames" VALUES(11381,'cs','fr','francouzština');
INSERT INTO "languageNames" VALUES(11382,'cs','fy','fríština (západní)');
INSERT INTO "languageNames" VALUES(11383,'cs','ga','irština');
INSERT INTO "languageNames" VALUES(11384,'cs','gag','gagauzština');
INSERT INTO "languageNames" VALUES(11385,'cs','gd','skotská gaelština');
INSERT INTO "languageNames" VALUES(11386,'cs','gl','galicijština');
INSERT INTO "languageNames" VALUES(11387,'cs','glk','gilačtina');
INSERT INTO "languageNames" VALUES(11388,'cs','gn','guaranština');
INSERT INTO "languageNames" VALUES(11389,'cs','gu','gudžarátština');
INSERT INTO "languageNames" VALUES(11390,'cs','guc','wayúuština');
INSERT INTO "languageNames" VALUES(11391,'cs','gv','manština');
INSERT INTO "languageNames" VALUES(11392,'cs','ha','hauština');
INSERT INTO "languageNames" VALUES(11393,'cs','haw','havajština');
INSERT INTO "languageNames" VALUES(11394,'cs','he','hebrejština');
INSERT INTO "languageNames" VALUES(11395,'cs','hi','hindština');
INSERT INTO "languageNames" VALUES(11396,'cs','hr','chorvatština');
INSERT INTO "languageNames" VALUES(11397,'cs','hsb','hornolužická srbština');
INSERT INTO "languageNames" VALUES(11398,'cs','ht','haitština');
INSERT INTO "languageNames" VALUES(11399,'cs','hu','maďarština');
INSERT INTO "languageNames" VALUES(11400,'cs','hy','arménština');
INSERT INTO "languageNames" VALUES(11401,'cs','ia','interlingua');
INSERT INTO "languageNames" VALUES(11402,'cs','id','indonéština');
INSERT INTO "languageNames" VALUES(11403,'cs','ig','igboština');
INSERT INTO "languageNames" VALUES(11404,'cs','is','islandština');
INSERT INTO "languageNames" VALUES(11405,'cs','it','italština');
INSERT INTO "languageNames" VALUES(11406,'cs','ka','gruzínština');
INSERT INTO "languageNames" VALUES(11407,'cs','kaa','karakalpačtina');
INSERT INTO "languageNames" VALUES(11408,'cs','kk','kazaština');
INSERT INTO "languageNames" VALUES(11409,'cs','ko','korejština');
INSERT INTO "languageNames" VALUES(11410,'cs','krc','karačajevo-balkarština');
INSERT INTO "languageNames" VALUES(11411,'cs','krl','karelština');
INSERT INTO "languageNames" VALUES(11412,'cs','ks','kašmírština');
INSERT INTO "languageNames" VALUES(11413,'cs','kum','kumyčtina');
INSERT INTO "languageNames" VALUES(11414,'cs','kv','komijština');
INSERT INTO "languageNames" VALUES(11415,'cs','ky','kyrgyzština');
INSERT INTO "languageNames" VALUES(11416,'cs','la','latina');
INSERT INTO "languageNames" VALUES(11417,'cs','lb','lucemburština');
INSERT INTO "languageNames" VALUES(11418,'cs','lg','gandština');
INSERT INTO "languageNames" VALUES(11419,'cs','liv','livonština');
INSERT INTO "languageNames" VALUES(11420,'cs','ln','lingalština');
INSERT INTO "languageNames" VALUES(11421,'cs','lo','laoština');
INSERT INTO "languageNames" VALUES(11422,'cs','lt','litevština');
INSERT INTO "languageNames" VALUES(11423,'cs','lv','lotyština');
INSERT INTO "languageNames" VALUES(11424,'cs','mdf','mokšanština');
INSERT INTO "languageNames" VALUES(11425,'cs','mfe','mauricijská kreolština');
INSERT INTO "languageNames" VALUES(11426,'cs','mk','makedonština');
INSERT INTO "languageNames" VALUES(11427,'cs','ml','malajálamština');
INSERT INTO "languageNames" VALUES(11428,'cs','mr','maráthština');
INSERT INTO "languageNames" VALUES(11429,'cs','mrj','marijština (západní)');
INSERT INTO "languageNames" VALUES(11430,'cs','ms','malajština');
INSERT INTO "languageNames" VALUES(11431,'cs','mt','maltština');
INSERT INTO "languageNames" VALUES(11432,'cs','myv','erzjanština');
INSERT INTO "languageNames" VALUES(11433,'cs','nap','neapolština');
INSERT INTO "languageNames" VALUES(11434,'cs','nb','norština (bokmål)');
INSERT INTO "languageNames" VALUES(11435,'cs','ne','nepálština');
INSERT INTO "languageNames" VALUES(11436,'cs','nl','nizozemština');
INSERT INTO "languageNames" VALUES(11437,'cs','nn','norština (nynorsk)');
INSERT INTO "languageNames" VALUES(11438,'cs','no','norština');
INSERT INTO "languageNames" VALUES(11439,'cs','nog','nogajština');
INSERT INTO "languageNames" VALUES(11440,'cs','oc','okcitánština');
INSERT INTO "languageNames" VALUES(11441,'cs','os','osetština');
INSERT INTO "languageNames" VALUES(11442,'cs','ota','turečtina (osmanská)');
INSERT INTO "languageNames" VALUES(11443,'cs','pa','paňdžábština');
INSERT INTO "languageNames" VALUES(11444,'cs','pl','polština');
INSERT INTO "languageNames" VALUES(11445,'cs','pt','portugalština');
INSERT INTO "languageNames" VALUES(11446,'cs','rm','rétorománština');
INSERT INTO "languageNames" VALUES(11447,'cs','rn','kirundština');
INSERT INTO "languageNames" VALUES(11448,'cs','ro','rumunština');
INSERT INTO "languageNames" VALUES(11449,'cs','ru','ruština');
INSERT INTO "languageNames" VALUES(11450,'cs','rup','arumunština');
INSERT INTO "languageNames" VALUES(11451,'cs','sa','sanskrt');
INSERT INTO "languageNames" VALUES(11452,'cs','sah','jakutština');
INSERT INTO "languageNames" VALUES(11453,'cs','sc','sardština');
INSERT INTO "languageNames" VALUES(11454,'cs','scn','sicilština');
INSERT INTO "languageNames" VALUES(11455,'cs','sco','skotština');
INSERT INTO "languageNames" VALUES(11456,'cs','sd','sindhština');
INSERT INTO "languageNames" VALUES(11457,'cs','se','sámština (severní)');
INSERT INTO "languageNames" VALUES(11458,'cs','sh','srbochorvatština');
INSERT INTO "languageNames" VALUES(11459,'cs','si','sinhálština');
INSERT INTO "languageNames" VALUES(11460,'cs','sk','slovenština');
INSERT INTO "languageNames" VALUES(11461,'cs','sl','slovinština');
INSERT INTO "languageNames" VALUES(11462,'cs','sma','sámština (jižní)');
INSERT INTO "languageNames" VALUES(11463,'cs','smj','sámština (lulejská)');
INSERT INTO "languageNames" VALUES(11464,'cs','smn','sámština (inarijská)');
INSERT INTO "languageNames" VALUES(11465,'cs','sq','albánština');
INSERT INTO "languageNames" VALUES(11466,'cs','sr','srbština');
INSERT INTO "languageNames" VALUES(11467,'cs','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(11468,'cs','ss','siswatština');
INSERT INTO "languageNames" VALUES(11469,'cs','sv','švédština');
INSERT INTO "languageNames" VALUES(11470,'cs','sw','svahilština');
INSERT INTO "languageNames" VALUES(11471,'cs','ta','tamilština');
INSERT INTO "languageNames" VALUES(11472,'cs','te','telugština');
INSERT INTO "languageNames" VALUES(11473,'cs','tet','tetumština');
INSERT INTO "languageNames" VALUES(11474,'cs','tg','tádžičtina');
INSERT INTO "languageNames" VALUES(11475,'cs','th','thajština');
INSERT INTO "languageNames" VALUES(11476,'cs','tk','turkmenština');
INSERT INTO "languageNames" VALUES(11477,'cs','tl','tagalog');
INSERT INTO "languageNames" VALUES(11478,'cs','tr','turečtina');
INSERT INTO "languageNames" VALUES(11479,'cs','tt','tatarština');
INSERT INTO "languageNames" VALUES(11480,'cs','tyv','tuvinština');
INSERT INTO "languageNames" VALUES(11481,'cs','udm','udmurtština');
INSERT INTO "languageNames" VALUES(11482,'cs','ug','ujgurština');
INSERT INTO "languageNames" VALUES(11483,'cs','uk','ukrajinština');
INSERT INTO "languageNames" VALUES(11484,'cs','ur','urdština');
INSERT INTO "languageNames" VALUES(11485,'cs','uz','uzbečtina');
INSERT INTO "languageNames" VALUES(11486,'cs','vi','vietnamština');
INSERT INTO "languageNames" VALUES(11487,'cs','vro','võruština');
INSERT INTO "languageNames" VALUES(11488,'cs','wal','wolajtština');
INSERT INTO "languageNames" VALUES(11489,'cs','xh','xhoština');
INSERT INTO "languageNames" VALUES(11490,'cs','yi','jidiš');
INSERT INTO "languageNames" VALUES(11491,'cs','yo','jorubština');
INSERT INTO "languageNames" VALUES(11492,'cs','zh','čínština');
INSERT INTO "languageNames" VALUES(11493,'cs','zu','zuluština');
INSERT INTO "languageNames" VALUES(11494,'sd','af','آفريڪي');
INSERT INTO "languageNames" VALUES(11495,'sd','alt','ڏکڻ التائي');
INSERT INTO "languageNames" VALUES(11496,'sd','an','ارگني');
INSERT INTO "languageNames" VALUES(11497,'sd','ar','عربي');
INSERT INTO "languageNames" VALUES(11498,'sd','as','آسامي');
INSERT INTO "languageNames" VALUES(11499,'sd','ast','اسٽورين');
INSERT INTO "languageNames" VALUES(11500,'sd','av','اويرس');
INSERT INTO "languageNames" VALUES(11502,'sd','az','ازري');
INSERT INTO "languageNames" VALUES(11503,'sd','ba','بشڪر');
INSERT INTO "languageNames" VALUES(11504,'sd','be','بيلاروسي');
INSERT INTO "languageNames" VALUES(11505,'sd','bg','بلغاريائي');
INSERT INTO "languageNames" VALUES(11506,'sd','bi','بسلاما');
INSERT INTO "languageNames" VALUES(11507,'sd','bn','بنگلا');
INSERT INTO "languageNames" VALUES(11508,'sd','br','بريٽن');
INSERT INTO "languageNames" VALUES(11509,'sd','bs','بوسنيائي');
INSERT INTO "languageNames" VALUES(11510,'sd','ca','ڪيٽالان');
INSERT INTO "languageNames" VALUES(11511,'sd','ceb','سبوانو');
INSERT INTO "languageNames" VALUES(11512,'sd','chm','ماري');
INSERT INTO "languageNames" VALUES(11513,'sd','ckb','مرڪزي ڪردش');
INSERT INTO "languageNames" VALUES(11514,'sd','co','ڪارسيڪائي');
INSERT INTO "languageNames" VALUES(11515,'sd','cs','چيڪ');
INSERT INTO "languageNames" VALUES(11516,'sd','cu','چرچ سلاوی');
INSERT INTO "languageNames" VALUES(11517,'sd','cv','چو واش');
INSERT INTO "languageNames" VALUES(11518,'sd','cy','ويلش');
INSERT INTO "languageNames" VALUES(11519,'sd','da','ڊينش');
INSERT INTO "languageNames" VALUES(11520,'sd','dar','ڊارگوا');
INSERT INTO "languageNames" VALUES(11521,'sd','de','جرمن');
INSERT INTO "languageNames" VALUES(11522,'sd','dsb','لوئر سوربين');
INSERT INTO "languageNames" VALUES(11523,'sd','el','يوناني');
INSERT INTO "languageNames" VALUES(11524,'sd','en','انگريزي');
INSERT INTO "languageNames" VALUES(11525,'sd','eo','ايسپرانٽو');
INSERT INTO "languageNames" VALUES(11526,'sd','es','اسپيني');
INSERT INTO "languageNames" VALUES(11527,'sd','et','ايستونائي');
INSERT INTO "languageNames" VALUES(11528,'sd','eu','باسڪي');
INSERT INTO "languageNames" VALUES(11529,'sd','fa','فارسي');
INSERT INTO "languageNames" VALUES(11530,'sd','fi','فنش');
INSERT INTO "languageNames" VALUES(11531,'sd','fo','فيروايس');
INSERT INTO "languageNames" VALUES(11532,'sd','fr','فرانسي');
INSERT INTO "languageNames" VALUES(11533,'sd','fy','مغربي فريشن');
INSERT INTO "languageNames" VALUES(11534,'sd','ga','آئرش');
INSERT INTO "languageNames" VALUES(11535,'sd','gd','اسڪاٽش گيلڪ');
INSERT INTO "languageNames" VALUES(11536,'sd','gl','گليشئين');
INSERT INTO "languageNames" VALUES(11537,'sd','gn','گواراني');
INSERT INTO "languageNames" VALUES(11538,'sd','gu','گجراتي');
INSERT INTO "languageNames" VALUES(11539,'sd','gv','مينڪس');
INSERT INTO "languageNames" VALUES(11540,'sd','ha','هوسا');
INSERT INTO "languageNames" VALUES(11541,'sd','haw','هوائي');
INSERT INTO "languageNames" VALUES(11542,'sd','he','عبراني');
INSERT INTO "languageNames" VALUES(11543,'sd','hi','هندي');
INSERT INTO "languageNames" VALUES(11544,'sd','hr','ڪروشيائي');
INSERT INTO "languageNames" VALUES(11545,'sd','hsb','اپر سربيائي');
INSERT INTO "languageNames" VALUES(11546,'sd','ht','هيٽي ڪرولي');
INSERT INTO "languageNames" VALUES(11547,'sd','hu','هنگري');
INSERT INTO "languageNames" VALUES(11548,'sd','hy','ارماني');
INSERT INTO "languageNames" VALUES(11549,'sd','ia','انٽرلنگئا');
INSERT INTO "languageNames" VALUES(11550,'sd','id','انڊونيشي');
INSERT INTO "languageNames" VALUES(11551,'sd','ig','اگبو');
INSERT INTO "languageNames" VALUES(11552,'sd','is','آئيس لينڊڪ');
INSERT INTO "languageNames" VALUES(11553,'sd','it','اطالوي');
INSERT INTO "languageNames" VALUES(11554,'sd','ka','جارجين');
INSERT INTO "languageNames" VALUES(11555,'sd','kk','قازق');
INSERT INTO "languageNames" VALUES(11556,'sd','ko','ڪوريائي');
INSERT INTO "languageNames" VALUES(11557,'sd','krc','ڪراچي بالڪر');
INSERT INTO "languageNames" VALUES(11558,'sd','krl','ڪريلئين');
INSERT INTO "languageNames" VALUES(11559,'sd','ks','ڪشميري');
INSERT INTO "languageNames" VALUES(11560,'sd','kum','ڪومڪ');
INSERT INTO "languageNames" VALUES(11561,'sd','kv','ڪومي');
INSERT INTO "languageNames" VALUES(11562,'sd','ky','ڪرغيز');
INSERT INTO "languageNames" VALUES(11563,'sd','la','لاطيني');
INSERT INTO "languageNames" VALUES(11564,'sd','lb','لگزمبرگ');
INSERT INTO "languageNames" VALUES(11565,'sd','lg','گاندا');
INSERT INTO "languageNames" VALUES(11566,'sd','ln','لنگالا');
INSERT INTO "languageNames" VALUES(11567,'sd','lo','لائو');
INSERT INTO "languageNames" VALUES(11568,'sd','lt','ليٿونيائي');
INSERT INTO "languageNames" VALUES(11569,'sd','lv','لاتوين');
INSERT INTO "languageNames" VALUES(11570,'sd','mdf','موڪشا');
INSERT INTO "languageNames" VALUES(11571,'sd','mfe','موریسیین');
INSERT INTO "languageNames" VALUES(11572,'sd','mk','ميسي ڊونيائي');
INSERT INTO "languageNames" VALUES(11573,'sd','ml','مليالم');
INSERT INTO "languageNames" VALUES(11574,'sd','mr','مراٺي');
INSERT INTO "languageNames" VALUES(11575,'sd','ms','ملي');
INSERT INTO "languageNames" VALUES(11576,'sd','mt','مالٽي');
INSERT INTO "languageNames" VALUES(11577,'sd','myv','ايريزيا');
INSERT INTO "languageNames" VALUES(11578,'sd','nap','نيپولٽن');
INSERT INTO "languageNames" VALUES(11579,'sd','nb','نارويائي بوڪمال');
INSERT INTO "languageNames" VALUES(11580,'sd','ne','نيپالي');
INSERT INTO "languageNames" VALUES(11581,'sd','nl','ڊچ');
INSERT INTO "languageNames" VALUES(11582,'sd','nn','نارويائي نيوناسڪ');
INSERT INTO "languageNames" VALUES(11583,'sd','nog','نوگائي');
INSERT INTO "languageNames" VALUES(11584,'sd','oc','آڪسيٽن');
INSERT INTO "languageNames" VALUES(11585,'sd','os','اوسيٽڪ');
INSERT INTO "languageNames" VALUES(11586,'sd','pa','پنجابي');
INSERT INTO "languageNames" VALUES(11587,'sd','pl','پولش');
INSERT INTO "languageNames" VALUES(11588,'sd','pt','پرتگالي');
INSERT INTO "languageNames" VALUES(11589,'sd','rm','رومانش');
INSERT INTO "languageNames" VALUES(11590,'sd','rn','رونڊي');
INSERT INTO "languageNames" VALUES(11591,'sd','ro','روماني');
INSERT INTO "languageNames" VALUES(11592,'sd','ru','روسي');
INSERT INTO "languageNames" VALUES(11593,'sd','rup','ارومينين');
INSERT INTO "languageNames" VALUES(11594,'sd','sa','سنسڪرت');
INSERT INTO "languageNames" VALUES(11595,'sd','sah','ساخا');
INSERT INTO "languageNames" VALUES(11596,'sd','sc','سارڊيني');
INSERT INTO "languageNames" VALUES(11597,'sd','scn','سسلي');
INSERT INTO "languageNames" VALUES(11598,'sd','sco','اسڪاٽس');
INSERT INTO "languageNames" VALUES(11599,'sd','sd','سنڌي');
INSERT INTO "languageNames" VALUES(11600,'sd','se','اتر سامي');
INSERT INTO "languageNames" VALUES(11601,'sd','si','سنهالا');
INSERT INTO "languageNames" VALUES(11602,'sd','sk','سلواڪي');
INSERT INTO "languageNames" VALUES(11603,'sd','sl','سلوويني');
INSERT INTO "languageNames" VALUES(11604,'sd','sma','ڏکڻ سامي');
INSERT INTO "languageNames" VALUES(11605,'sd','smj','لولي سامي');
INSERT INTO "languageNames" VALUES(11606,'sd','smn','اناري سامي');
INSERT INTO "languageNames" VALUES(11607,'sd','sq','الباني');
INSERT INTO "languageNames" VALUES(11608,'sd','sr','سربيائي');
INSERT INTO "languageNames" VALUES(11609,'sd','srn','سرانن تانگو');
INSERT INTO "languageNames" VALUES(11610,'sd','ss','سواتي');
INSERT INTO "languageNames" VALUES(11611,'sd','sv','سويڊني');
INSERT INTO "languageNames" VALUES(11612,'sd','sw','سواحيلي');
INSERT INTO "languageNames" VALUES(11613,'sd','ta','تامل');
INSERT INTO "languageNames" VALUES(11614,'sd','te','تلگو');
INSERT INTO "languageNames" VALUES(11615,'sd','tet','تيتم');
INSERT INTO "languageNames" VALUES(11616,'sd','tg','تاجڪي');
INSERT INTO "languageNames" VALUES(11617,'sd','th','ٿائي');
INSERT INTO "languageNames" VALUES(11618,'sd','tk','ترڪماني');
INSERT INTO "languageNames" VALUES(11619,'sd','tr','ترڪ');
INSERT INTO "languageNames" VALUES(11620,'sd','tt','تاتري');
INSERT INTO "languageNames" VALUES(11621,'sd','tyv','تووينيائي');
INSERT INTO "languageNames" VALUES(11622,'sd','udm','ادمورتيا');
INSERT INTO "languageNames" VALUES(11623,'sd','ug','يوغور');
INSERT INTO "languageNames" VALUES(11624,'sd','uk','يوڪراني');
INSERT INTO "languageNames" VALUES(11625,'sd','ur','اردو');
INSERT INTO "languageNames" VALUES(11626,'sd','uz','ازبڪ');
INSERT INTO "languageNames" VALUES(11627,'sd','vi','ويتنامي');
INSERT INTO "languageNames" VALUES(11628,'sd','wal','وولايٽا');
INSERT INTO "languageNames" VALUES(11629,'sd','xh','زھوسا');
INSERT INTO "languageNames" VALUES(11630,'sd','yi','يدش');
INSERT INTO "languageNames" VALUES(11631,'sd','yo','يوروبا');
INSERT INTO "languageNames" VALUES(11632,'sd','zh','چيني');
INSERT INTO "languageNames" VALUES(11633,'sd','zu','زولو');
INSERT INTO "languageNames" VALUES(11634,'eo','af','afrikansa');
INSERT INTO "languageNames" VALUES(11635,'eo','ar','araba');
INSERT INTO "languageNames" VALUES(11636,'eo','as','asama');
INSERT INTO "languageNames" VALUES(11637,'eo','az','azerbajĝana');
INSERT INTO "languageNames" VALUES(11638,'eo','ba','baŝkira');
INSERT INTO "languageNames" VALUES(11639,'eo','be','belorusa');
INSERT INTO "languageNames" VALUES(11640,'eo','bg','bulgara');
INSERT INTO "languageNames" VALUES(11641,'eo','bi','bislamo');
INSERT INTO "languageNames" VALUES(11642,'eo','bn','bengala');
INSERT INTO "languageNames" VALUES(11643,'eo','br','bretona');
INSERT INTO "languageNames" VALUES(11644,'eo','bs','bosnia');
INSERT INTO "languageNames" VALUES(11645,'eo','ca','kataluna');
INSERT INTO "languageNames" VALUES(11646,'eo','ckb','sorana');
INSERT INTO "languageNames" VALUES(11647,'eo','co','korsika');
INSERT INTO "languageNames" VALUES(11648,'eo','cs','ĉeĥa');
INSERT INTO "languageNames" VALUES(11649,'eo','cy','kimra');
INSERT INTO "languageNames" VALUES(11650,'eo','da','dana');
INSERT INTO "languageNames" VALUES(11651,'eo','de','germana');
INSERT INTO "languageNames" VALUES(11652,'eo','dsb','malsuprasoraba');
INSERT INTO "languageNames" VALUES(11653,'eo','el','greka');
INSERT INTO "languageNames" VALUES(11654,'eo','en','angla');
INSERT INTO "languageNames" VALUES(11655,'eo','eo','esperanto');
INSERT INTO "languageNames" VALUES(11656,'eo','es','hispana');
INSERT INTO "languageNames" VALUES(11657,'eo','et','estona');
INSERT INTO "languageNames" VALUES(11658,'eo','eu','eŭska');
INSERT INTO "languageNames" VALUES(11659,'eo','fa','persa');
INSERT INTO "languageNames" VALUES(11660,'eo','fi','finna');
INSERT INTO "languageNames" VALUES(11661,'eo','fo','feroa');
INSERT INTO "languageNames" VALUES(11662,'eo','fr','franca');
INSERT INTO "languageNames" VALUES(11663,'eo','fy','frisa');
INSERT INTO "languageNames" VALUES(11664,'eo','ga','irlanda');
INSERT INTO "languageNames" VALUES(11665,'eo','gd','gaela');
INSERT INTO "languageNames" VALUES(11666,'eo','gl','galega');
INSERT INTO "languageNames" VALUES(11667,'eo','gn','gvarania');
INSERT INTO "languageNames" VALUES(11668,'eo','gu','guĝarata');
INSERT INTO "languageNames" VALUES(11669,'eo','ha','haŭsa');
INSERT INTO "languageNames" VALUES(11670,'eo','haw','havaja');
INSERT INTO "languageNames" VALUES(11671,'eo','he','hebrea');
INSERT INTO "languageNames" VALUES(11672,'eo','hi','hinda');
INSERT INTO "languageNames" VALUES(11673,'eo','hr','kroata');
INSERT INTO "languageNames" VALUES(11674,'eo','ht','haitia kreola');
INSERT INTO "languageNames" VALUES(11675,'eo','hu','hungara');
INSERT INTO "languageNames" VALUES(11676,'eo','hy','armena');
INSERT INTO "languageNames" VALUES(11677,'eo','ia','interlingvao');
INSERT INTO "languageNames" VALUES(11678,'eo','id','indonezia');
INSERT INTO "languageNames" VALUES(11679,'eo','is','islanda');
INSERT INTO "languageNames" VALUES(11680,'eo','it','itala');
INSERT INTO "languageNames" VALUES(11681,'eo','ka','kartvela');
INSERT INTO "languageNames" VALUES(11682,'eo','kk','kazaĥa');
INSERT INTO "languageNames" VALUES(11683,'eo','ko','korea');
INSERT INTO "languageNames" VALUES(11684,'eo','ks','kaŝmira');
INSERT INTO "languageNames" VALUES(11685,'eo','ky','kirgiza');
INSERT INTO "languageNames" VALUES(11686,'eo','la','latino');
INSERT INTO "languageNames" VALUES(11687,'eo','lb','luksemburga');
INSERT INTO "languageNames" VALUES(11688,'eo','ln','lingala');
INSERT INTO "languageNames" VALUES(11689,'eo','lo','laŭa');
INSERT INTO "languageNames" VALUES(11690,'eo','lt','litova');
INSERT INTO "languageNames" VALUES(11691,'eo','lv','latva');
INSERT INTO "languageNames" VALUES(11692,'eo','mk','makedona');
INSERT INTO "languageNames" VALUES(11693,'eo','ml','malajalama');
INSERT INTO "languageNames" VALUES(11694,'eo','mr','marata');
INSERT INTO "languageNames" VALUES(11695,'eo','ms','malaja');
INSERT INTO "languageNames" VALUES(11696,'eo','mt','malta');
INSERT INTO "languageNames" VALUES(11697,'eo','nb','dannorvega');
INSERT INTO "languageNames" VALUES(11698,'eo','ne','nepala');
INSERT INTO "languageNames" VALUES(11699,'eo','nl','nederlanda');
INSERT INTO "languageNames" VALUES(11700,'eo','nn','novnorvega');
INSERT INTO "languageNames" VALUES(11701,'eo','no','norvega');
INSERT INTO "languageNames" VALUES(11702,'eo','oc','okcitana');
INSERT INTO "languageNames" VALUES(11703,'eo','pa','panĝaba');
INSERT INTO "languageNames" VALUES(11704,'eo','pl','pola');
INSERT INTO "languageNames" VALUES(11705,'eo','pt','portugala');
INSERT INTO "languageNames" VALUES(11706,'eo','rm','romanĉa');
INSERT INTO "languageNames" VALUES(11707,'eo','rn','burunda');
INSERT INTO "languageNames" VALUES(11708,'eo','ro','rumana');
INSERT INTO "languageNames" VALUES(11709,'eo','ru','rusa');
INSERT INTO "languageNames" VALUES(11710,'eo','sa','sanskrito');
INSERT INTO "languageNames" VALUES(11711,'eo','sd','sinda');
INSERT INTO "languageNames" VALUES(11712,'eo','sh','serbo-Kroata');
INSERT INTO "languageNames" VALUES(11713,'eo','si','sinhala');
INSERT INTO "languageNames" VALUES(11714,'eo','sk','slovaka');
INSERT INTO "languageNames" VALUES(11715,'eo','sl','slovena');
INSERT INTO "languageNames" VALUES(11716,'eo','sq','albana');
INSERT INTO "languageNames" VALUES(11717,'eo','sr','serba');
INSERT INTO "languageNames" VALUES(11718,'eo','ss','svazia');
INSERT INTO "languageNames" VALUES(11719,'eo','sv','sveda');
INSERT INTO "languageNames" VALUES(11720,'eo','sw','svahila');
INSERT INTO "languageNames" VALUES(11721,'eo','ta','tamila');
INSERT INTO "languageNames" VALUES(11722,'eo','te','telugua');
INSERT INTO "languageNames" VALUES(11723,'eo','tg','taĝika');
INSERT INTO "languageNames" VALUES(11724,'eo','th','taja');
INSERT INTO "languageNames" VALUES(11725,'eo','tk','turkmena');
INSERT INTO "languageNames" VALUES(11726,'eo','tl','tagaloga');
INSERT INTO "languageNames" VALUES(11727,'eo','tr','turka');
INSERT INTO "languageNames" VALUES(11728,'eo','tt','tatara');
INSERT INTO "languageNames" VALUES(11729,'eo','ug','ujgura');
INSERT INTO "languageNames" VALUES(11730,'eo','uk','ukraina');
INSERT INTO "languageNames" VALUES(11731,'eo','ur','urduo');
INSERT INTO "languageNames" VALUES(11732,'eo','uz','uzbeka');
INSERT INTO "languageNames" VALUES(11733,'eo','vi','vjetnama');
INSERT INTO "languageNames" VALUES(11734,'eo','xh','ksosa');
INSERT INTO "languageNames" VALUES(11735,'eo','yi','jida');
INSERT INTO "languageNames" VALUES(11736,'eo','yo','joruba');
INSERT INTO "languageNames" VALUES(11737,'eo','zh','ĉina');
INSERT INTO "languageNames" VALUES(11738,'eo','zu','zulua');
INSERT INTO "languageNames" VALUES(11739,'tr','af','Afrikaanca');
INSERT INTO "languageNames" VALUES(11740,'tr','alt','Güney Altayca');
INSERT INTO "languageNames" VALUES(11741,'tr','an','Aragonca');
INSERT INTO "languageNames" VALUES(11742,'tr','ar','Arapça');
INSERT INTO "languageNames" VALUES(11743,'tr','as','Assamca');
INSERT INTO "languageNames" VALUES(11744,'tr','ast','Asturyasca');
INSERT INTO "languageNames" VALUES(11745,'tr','av','Avar Dili');
INSERT INTO "languageNames" VALUES(11747,'tr','az','Azerice');
INSERT INTO "languageNames" VALUES(11748,'tr','ba','Başkırtça');
INSERT INTO "languageNames" VALUES(11749,'tr','be','Belarusça');
INSERT INTO "languageNames" VALUES(11750,'tr','bg','Bulgarca');
INSERT INTO "languageNames" VALUES(11751,'tr','bi','Bislama');
INSERT INTO "languageNames" VALUES(11752,'tr','bn','Bengalce');
INSERT INTO "languageNames" VALUES(11753,'tr','br','Bretonca');
INSERT INTO "languageNames" VALUES(11754,'tr','bs','Boşnakça');
INSERT INTO "languageNames" VALUES(11755,'tr','bua','Buryatça');
INSERT INTO "languageNames" VALUES(11756,'tr','byv','Medumba');
INSERT INTO "languageNames" VALUES(11757,'tr','ca','Katalanca');
INSERT INTO "languageNames" VALUES(11758,'tr','ceb','Sebuano dili');
INSERT INTO "languageNames" VALUES(11759,'tr','chm','Mari dili');
INSERT INTO "languageNames" VALUES(11760,'tr','ckb','Orta Kürtçe');
INSERT INTO "languageNames" VALUES(11761,'tr','co','Korsikaca');
INSERT INTO "languageNames" VALUES(11762,'tr','crh','Kırım Türkçesi');
INSERT INTO "languageNames" VALUES(11763,'tr','cs','Çekçe');
INSERT INTO "languageNames" VALUES(11764,'tr','csb','Kashubian');
INSERT INTO "languageNames" VALUES(11765,'tr','cu','Kilise Slavcası');
INSERT INTO "languageNames" VALUES(11766,'tr','cv','Çuvaşça');
INSERT INTO "languageNames" VALUES(11767,'tr','cy','Galce');
INSERT INTO "languageNames" VALUES(11768,'tr','da','Danca');
INSERT INTO "languageNames" VALUES(11769,'tr','dar','Dargince');
INSERT INTO "languageNames" VALUES(11770,'tr','de','Almanca');
INSERT INTO "languageNames" VALUES(11771,'tr','dsb','Aşağı Sorbça');
INSERT INTO "languageNames" VALUES(11772,'tr','el','Yunanca');
INSERT INTO "languageNames" VALUES(11773,'tr','en','İngilizce');
INSERT INTO "languageNames" VALUES(11774,'tr','eo','Esperanto');
INSERT INTO "languageNames" VALUES(11775,'tr','es','İspanyolca');
INSERT INTO "languageNames" VALUES(11776,'tr','et','Estonca');
INSERT INTO "languageNames" VALUES(11777,'tr','eu','Baskça');
INSERT INTO "languageNames" VALUES(11778,'tr','fa','Farsça');
INSERT INTO "languageNames" VALUES(11779,'tr','fi','Fince');
INSERT INTO "languageNames" VALUES(11780,'tr','fo','Faroe Dili');
INSERT INTO "languageNames" VALUES(11781,'tr','fr','Fransızca');
INSERT INTO "languageNames" VALUES(11782,'tr','fy','Batı Frizcesi');
INSERT INTO "languageNames" VALUES(11783,'tr','ga','İrlandaca');
INSERT INTO "languageNames" VALUES(11784,'tr','gag','Gagavuzca');
INSERT INTO "languageNames" VALUES(11785,'tr','gd','İskoç Gaelcesi');
INSERT INTO "languageNames" VALUES(11786,'tr','gl','Galiçyaca');
INSERT INTO "languageNames" VALUES(11787,'tr','glk','Gilanice');
INSERT INTO "languageNames" VALUES(11788,'tr','gn','Guarani dili');
INSERT INTO "languageNames" VALUES(11789,'tr','gu','Güceratça');
INSERT INTO "languageNames" VALUES(11790,'tr','guc','Wayuu dili');
INSERT INTO "languageNames" VALUES(11791,'tr','gv','Man dili');
INSERT INTO "languageNames" VALUES(11792,'tr','ha','Hausa dili');
INSERT INTO "languageNames" VALUES(11793,'tr','haw','Hawaii dili');
INSERT INTO "languageNames" VALUES(11794,'tr','he','İbranice');
INSERT INTO "languageNames" VALUES(11795,'tr','hi','Hintçe');
INSERT INTO "languageNames" VALUES(11796,'tr','hr','Hırvatça');
INSERT INTO "languageNames" VALUES(11797,'tr','hsb','Yukarı Sorbça');
INSERT INTO "languageNames" VALUES(11798,'tr','ht','Haiti Kreyolu');
INSERT INTO "languageNames" VALUES(11799,'tr','hu','Macarca');
INSERT INTO "languageNames" VALUES(11800,'tr','hy','Ermenice');
INSERT INTO "languageNames" VALUES(11801,'tr','ia','Interlingua');
INSERT INTO "languageNames" VALUES(11802,'tr','id','Endonezce');
INSERT INTO "languageNames" VALUES(11803,'tr','ig','İbo dili');
INSERT INTO "languageNames" VALUES(11804,'tr','is','İzlandaca');
INSERT INTO "languageNames" VALUES(11805,'tr','it','İtalyanca');
INSERT INTO "languageNames" VALUES(11806,'tr','ka','Gürcüce');
INSERT INTO "languageNames" VALUES(11807,'tr','kaa','Karakalpakça');
INSERT INTO "languageNames" VALUES(11808,'tr','kk','Kazakça');
INSERT INTO "languageNames" VALUES(11809,'tr','ko','Korece');
INSERT INTO "languageNames" VALUES(11810,'tr','krc','Karaçay-Balkarca');
INSERT INTO "languageNames" VALUES(11811,'tr','krl','Karelyaca');
INSERT INTO "languageNames" VALUES(11812,'tr','ks','Keşmir dili');
INSERT INTO "languageNames" VALUES(11813,'tr','kum','Kumukça');
INSERT INTO "languageNames" VALUES(11814,'tr','kv','Komi');
INSERT INTO "languageNames" VALUES(11815,'tr','ky','Kırgızca');
INSERT INTO "languageNames" VALUES(11816,'tr','la','Latince');
INSERT INTO "languageNames" VALUES(11817,'tr','lb','Lüksemburgca');
INSERT INTO "languageNames" VALUES(11818,'tr','lg','Ganda');
INSERT INTO "languageNames" VALUES(11819,'tr','liv','Livonca');
INSERT INTO "languageNames" VALUES(11820,'tr','ln','Lingala');
INSERT INTO "languageNames" VALUES(11821,'tr','lo','Lao dili');
INSERT INTO "languageNames" VALUES(11822,'tr','lt','Litvanca');
INSERT INTO "languageNames" VALUES(11823,'tr','lv','Letonca');
INSERT INTO "languageNames" VALUES(11824,'tr','mdf','Mokşa dili');
INSERT INTO "languageNames" VALUES(11825,'tr','mfe','Morisyen');
INSERT INTO "languageNames" VALUES(11826,'tr','mk','Makedonca');
INSERT INTO "languageNames" VALUES(11827,'tr','ml','Malayalam dili');
INSERT INTO "languageNames" VALUES(11828,'tr','mr','Marathi dili');
INSERT INTO "languageNames" VALUES(11829,'tr','mrj','Ova Çirmişçesi');
INSERT INTO "languageNames" VALUES(11830,'tr','ms','Malayca');
INSERT INTO "languageNames" VALUES(11831,'tr','mt','Maltaca');
INSERT INTO "languageNames" VALUES(11832,'tr','myv','Erzya');
INSERT INTO "languageNames" VALUES(11833,'tr','nap','Napolice');
INSERT INTO "languageNames" VALUES(11834,'tr','nb','Norveççe Bokmål');
INSERT INTO "languageNames" VALUES(11835,'tr','ne','Nepalce');
INSERT INTO "languageNames" VALUES(11836,'tr','nl','Felemenkçe');
INSERT INTO "languageNames" VALUES(11837,'tr','nn','Norveççe Nynorsk');
INSERT INTO "languageNames" VALUES(11838,'tr','no','Norveççe');
INSERT INTO "languageNames" VALUES(11839,'tr','nog','Nogayca');
INSERT INTO "languageNames" VALUES(11840,'tr','oc','Oksitan dili');
INSERT INTO "languageNames" VALUES(11841,'tr','os','Osetçe');
INSERT INTO "languageNames" VALUES(11842,'tr','ota','Osmanlı Türkçesi');
INSERT INTO "languageNames" VALUES(11843,'tr','pa','Pencapça');
INSERT INTO "languageNames" VALUES(11844,'tr','pl','Lehçe');
INSERT INTO "languageNames" VALUES(11845,'tr','pt','Portekizce');
INSERT INTO "languageNames" VALUES(11846,'tr','rm','Romanşça');
INSERT INTO "languageNames" VALUES(11847,'tr','rn','Kirundi');
INSERT INTO "languageNames" VALUES(11848,'tr','ro','Rumence');
INSERT INTO "languageNames" VALUES(11849,'tr','ru','Rusça');
INSERT INTO "languageNames" VALUES(11850,'tr','rup','Ulahça');
INSERT INTO "languageNames" VALUES(11851,'tr','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(11852,'tr','sah','Yakutça');
INSERT INTO "languageNames" VALUES(11853,'tr','sc','Sardunya dili');
INSERT INTO "languageNames" VALUES(11854,'tr','scn','Sicilyaca');
INSERT INTO "languageNames" VALUES(11855,'tr','sco','İskoçça');
INSERT INTO "languageNames" VALUES(11856,'tr','sd','Sindhi dili');
INSERT INTO "languageNames" VALUES(11857,'tr','se','Kuzey Laponcası');
INSERT INTO "languageNames" VALUES(11858,'tr','sh','Sırp-Hırvat Dili');
INSERT INTO "languageNames" VALUES(11859,'tr','si','Sinhali dili');
INSERT INTO "languageNames" VALUES(11860,'tr','sk','Slovakça');
INSERT INTO "languageNames" VALUES(11861,'tr','sl','Slovence');
INSERT INTO "languageNames" VALUES(11862,'tr','sma','Güney Laponcası');
INSERT INTO "languageNames" VALUES(11863,'tr','smj','Lule Laponcası');
INSERT INTO "languageNames" VALUES(11864,'tr','smn','İnari Laponcası');
INSERT INTO "languageNames" VALUES(11865,'tr','sq','Arnavutça');
INSERT INTO "languageNames" VALUES(11866,'tr','sr','Sırpça');
INSERT INTO "languageNames" VALUES(11867,'tr','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(11868,'tr','ss','Sisvati');
INSERT INTO "languageNames" VALUES(11869,'tr','sv','İsveççe');
INSERT INTO "languageNames" VALUES(11870,'tr','sw','Svahili dili');
INSERT INTO "languageNames" VALUES(11871,'tr','ta','Tamilce');
INSERT INTO "languageNames" VALUES(11872,'tr','te','Telugu dili');
INSERT INTO "languageNames" VALUES(11873,'tr','tet','Tetum');
INSERT INTO "languageNames" VALUES(11874,'tr','tg','Tacikçe');
INSERT INTO "languageNames" VALUES(11875,'tr','th','Tayca');
INSERT INTO "languageNames" VALUES(11876,'tr','tk','Türkmence');
INSERT INTO "languageNames" VALUES(11877,'tr','tl','Tagalogca');
INSERT INTO "languageNames" VALUES(11878,'tr','tr','Türkçe');
INSERT INTO "languageNames" VALUES(11879,'tr','tt','Tatarca');
INSERT INTO "languageNames" VALUES(11880,'tr','tyv','Tuvaca');
INSERT INTO "languageNames" VALUES(11881,'tr','udm','Udmurtça');
INSERT INTO "languageNames" VALUES(11882,'tr','ug','Uygurca');
INSERT INTO "languageNames" VALUES(11883,'tr','uk','Ukraynaca');
INSERT INTO "languageNames" VALUES(11884,'tr','ur','Urduca');
INSERT INTO "languageNames" VALUES(11885,'tr','uz','Özbekçe');
INSERT INTO "languageNames" VALUES(11886,'tr','vi','Vietnamca');
INSERT INTO "languageNames" VALUES(11887,'tr','vro','Võro');
INSERT INTO "languageNames" VALUES(11888,'tr','wal','Valamo');
INSERT INTO "languageNames" VALUES(11889,'tr','xh','Zosa dili');
INSERT INTO "languageNames" VALUES(11890,'tr','yi','Yidiş');
INSERT INTO "languageNames" VALUES(11891,'tr','yo','Yorubaca');
INSERT INTO "languageNames" VALUES(11892,'tr','zh','Çince');
INSERT INTO "languageNames" VALUES(11893,'tr','zu','Zuluca');
INSERT INTO "languageNames" VALUES(11894,'pa','af','ਅਫ਼ਰੀਕੀ');
INSERT INTO "languageNames" VALUES(11895,'pa','alt','ਦੱਖਣੀ ਅਲਤਾਈ');
INSERT INTO "languageNames" VALUES(11896,'pa','an','ਅਰਾਗੋਨੀ');
INSERT INTO "languageNames" VALUES(11897,'pa','ar','ਅਰਬੀ');
INSERT INTO "languageNames" VALUES(11898,'pa','as','ਅਸਾਮੀ');
INSERT INTO "languageNames" VALUES(11899,'pa','ast','ਅਸਤੂਰੀ');
INSERT INTO "languageNames" VALUES(11900,'pa','av','ਅਵਾਰਿਕ');
INSERT INTO "languageNames" VALUES(11902,'pa','az','ਅਜ਼ੇਰੀ');
INSERT INTO "languageNames" VALUES(11903,'pa','ba','ਬਸ਼ਕੀਰ');
INSERT INTO "languageNames" VALUES(11904,'pa','be','ਬੇਲਾਰੂਸੀ');
INSERT INTO "languageNames" VALUES(11905,'pa','bg','ਬੁਲਗਾਰੀਆਈ');
INSERT INTO "languageNames" VALUES(11906,'pa','bi','ਬਿਸਲਾਮਾ');
INSERT INTO "languageNames" VALUES(11907,'pa','bn','ਬੰਗਾਲੀ');
INSERT INTO "languageNames" VALUES(11908,'pa','br','ਬਰੇਟਨ');
INSERT INTO "languageNames" VALUES(11909,'pa','bs','ਬੋਸਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11910,'pa','ca','ਕੈਟਾਲਾਨ');
INSERT INTO "languageNames" VALUES(11911,'pa','ceb','ਸੀਬੂਆਨੋ');
INSERT INTO "languageNames" VALUES(11912,'pa','chm','ਮਾਰੀ');
INSERT INTO "languageNames" VALUES(11913,'pa','ckb','ਕੇਂਦਰੀ ਕੁਰਦਿਸ਼');
INSERT INTO "languageNames" VALUES(11914,'pa','co','ਕੋਰਸੀਕਨ');
INSERT INTO "languageNames" VALUES(11915,'pa','cs','ਚੈੱਕ');
INSERT INTO "languageNames" VALUES(11916,'pa','cu','ਚਰਚ ਸਲਾਵੀ');
INSERT INTO "languageNames" VALUES(11917,'pa','cv','ਚੁਵਾਸ਼');
INSERT INTO "languageNames" VALUES(11918,'pa','cy','ਵੈਲਸ਼');
INSERT INTO "languageNames" VALUES(11919,'pa','da','ਡੈਨਿਸ਼');
INSERT INTO "languageNames" VALUES(11920,'pa','dar','ਦਾਰਗਵਾ');
INSERT INTO "languageNames" VALUES(11921,'pa','de','ਜਰਮਨ');
INSERT INTO "languageNames" VALUES(11922,'pa','dsb','ਲੋਅਰ ਸੋਰਬੀਅਨ');
INSERT INTO "languageNames" VALUES(11923,'pa','el','ਯੂਨਾਨੀ');
INSERT INTO "languageNames" VALUES(11924,'pa','en','ਅੰਗਰੇਜ਼ੀ');
INSERT INTO "languageNames" VALUES(11925,'pa','eo','ਇਸਪੇਰਾਂਟੋ');
INSERT INTO "languageNames" VALUES(11926,'pa','es','ਸਪੇਨੀ');
INSERT INTO "languageNames" VALUES(11927,'pa','et','ਇਸਟੋਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11928,'pa','eu','ਬਾਸਕ');
INSERT INTO "languageNames" VALUES(11929,'pa','fa','ਫ਼ਾਰਸੀ');
INSERT INTO "languageNames" VALUES(11930,'pa','fi','ਫਿਨਿਸ਼');
INSERT INTO "languageNames" VALUES(11931,'pa','fo','ਫ਼ੇਰੋਸੇ');
INSERT INTO "languageNames" VALUES(11932,'pa','fr','ਫਰਾਂਸੀਸੀ');
INSERT INTO "languageNames" VALUES(11933,'pa','fy','ਪੱਛਮੀ ਫ੍ਰਿਸੀਅਨ');
INSERT INTO "languageNames" VALUES(11934,'pa','ga','ਆਇਰਸ਼');
INSERT INTO "languageNames" VALUES(11935,'pa','gag','ਗਾਗੌਜ਼');
INSERT INTO "languageNames" VALUES(11936,'pa','gd','ਸਕਾਟਿਸ਼ ਗੇਲਿਕ');
INSERT INTO "languageNames" VALUES(11937,'pa','gl','ਗੈਲਿਸ਼ਿਅਨ');
INSERT INTO "languageNames" VALUES(11938,'pa','gn','ਗੁਆਰਾਨੀ');
INSERT INTO "languageNames" VALUES(11939,'pa','gu','ਗੁਜਰਾਤੀ');
INSERT INTO "languageNames" VALUES(11940,'pa','gv','ਮੈਂਕਸ');
INSERT INTO "languageNames" VALUES(11941,'pa','ha','ਹੌਸਾ');
INSERT INTO "languageNames" VALUES(11942,'pa','haw','ਹਵਾਈ');
INSERT INTO "languageNames" VALUES(11943,'pa','he','ਹਿਬਰੂ');
INSERT INTO "languageNames" VALUES(11944,'pa','hi','ਹਿੰਦੀ');
INSERT INTO "languageNames" VALUES(11945,'pa','hr','ਕ੍ਰੋਏਸ਼ਿਆਈ');
INSERT INTO "languageNames" VALUES(11946,'pa','hsb','ਅੱਪਰ ਸੋਰਬੀਅਨ');
INSERT INTO "languageNames" VALUES(11947,'pa','ht','ਹੈਤੀਆਈ');
INSERT INTO "languageNames" VALUES(11948,'pa','hu','ਹੰਗਰੀਆਈ');
INSERT INTO "languageNames" VALUES(11949,'pa','hy','ਅਰਮੀਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11950,'pa','ia','ਇੰਟਰਲਿੰਗੁਆ');
INSERT INTO "languageNames" VALUES(11951,'pa','id','ਇੰਡੋਨੇਸ਼ੀਆਈ');
INSERT INTO "languageNames" VALUES(11952,'pa','ig','ਇਗਬੋ');
INSERT INTO "languageNames" VALUES(11953,'pa','is','ਆਈਸਲੈਂਡਿਕ');
INSERT INTO "languageNames" VALUES(11954,'pa','it','ਇਤਾਲਵੀ');
INSERT INTO "languageNames" VALUES(11955,'pa','ka','ਜਾਰਜੀਆਈ');
INSERT INTO "languageNames" VALUES(11956,'pa','kk','ਕਜ਼ਾਖ਼');
INSERT INTO "languageNames" VALUES(11957,'pa','ko','ਕੋਰੀਆਈ');
INSERT INTO "languageNames" VALUES(11958,'pa','krc','ਕਰਾਚੇ ਬਲਕਾਰ');
INSERT INTO "languageNames" VALUES(11959,'pa','krl','ਕਰੀਲੀਅਨ');
INSERT INTO "languageNames" VALUES(11960,'pa','ks','ਕਸ਼ਮੀਰੀ');
INSERT INTO "languageNames" VALUES(11961,'pa','kum','ਕੁਮੀਕ');
INSERT INTO "languageNames" VALUES(11962,'pa','kv','ਕੋਮੀ');
INSERT INTO "languageNames" VALUES(11963,'pa','ky','ਕਿਰਗੀਜ਼');
INSERT INTO "languageNames" VALUES(11964,'pa','la','ਲਾਤੀਨੀ');
INSERT INTO "languageNames" VALUES(11965,'pa','lb','ਲਕਜ਼ਮਬਰਗਿਸ਼');
INSERT INTO "languageNames" VALUES(11966,'pa','lg','ਗਾਂਡਾ');
INSERT INTO "languageNames" VALUES(11967,'pa','ln','ਲਿੰਗਾਲਾ');
INSERT INTO "languageNames" VALUES(11968,'pa','lo','ਲਾਓ');
INSERT INTO "languageNames" VALUES(11969,'pa','lt','ਲਿਥੁਆਨੀਅਨ');
INSERT INTO "languageNames" VALUES(11970,'pa','lv','ਲਾਤੀਵੀ');
INSERT INTO "languageNames" VALUES(11971,'pa','mdf','ਮੋਕਸ਼ਾ');
INSERT INTO "languageNames" VALUES(11972,'pa','mfe','ਮੋਰੀਸਿਅਨ');
INSERT INTO "languageNames" VALUES(11973,'pa','mk','ਮੈਕਡੋਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11974,'pa','ml','ਮਲਿਆਲਮ');
INSERT INTO "languageNames" VALUES(11975,'pa','mr','ਮਰਾਠੀ');
INSERT INTO "languageNames" VALUES(11976,'pa','ms','ਮਲਯ');
INSERT INTO "languageNames" VALUES(11977,'pa','mt','ਮਾਲਟੀਜ਼');
INSERT INTO "languageNames" VALUES(11978,'pa','myv','ਇਰਜ਼ੀਆ');
INSERT INTO "languageNames" VALUES(11979,'pa','nap','ਨਿਆਪੋਲੀਟਨ');
INSERT INTO "languageNames" VALUES(11980,'pa','nb','ਨਾਰਵੇਜਿਆਈ ਬੋਕਮਲ');
INSERT INTO "languageNames" VALUES(11981,'pa','ne','ਨੇਪਾਲੀ');
INSERT INTO "languageNames" VALUES(11982,'pa','nl','ਡੱਚ');
INSERT INTO "languageNames" VALUES(11983,'pa','nn','ਨਾਰਵੇਜਿਆਈ ਨਿਓਨੌਰਸਕ');
INSERT INTO "languageNames" VALUES(11984,'pa','no','ਨਾਰਵੇਜਿਆਈ');
INSERT INTO "languageNames" VALUES(11985,'pa','nog','ਨੋਗਾਈ');
INSERT INTO "languageNames" VALUES(11986,'pa','oc','ਓਕਸੀਟਾਨ');
INSERT INTO "languageNames" VALUES(11987,'pa','os','ਓਸੈਟਿਕ');
INSERT INTO "languageNames" VALUES(11988,'pa','pa','ਪੰਜਾਬੀ');
INSERT INTO "languageNames" VALUES(11989,'pa','pl','ਪੋਲੈਂਡੀ');
INSERT INTO "languageNames" VALUES(11990,'pa','pt','ਪੁਰਤਗਾਲੀ');
INSERT INTO "languageNames" VALUES(11991,'pa','rm','ਰੋਮਾਂਸ਼');
INSERT INTO "languageNames" VALUES(11992,'pa','rn','ਰੁੰਡੀ');
INSERT INTO "languageNames" VALUES(11993,'pa','ro','ਰੋਮਾਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11994,'pa','ru','ਰੂਸੀ');
INSERT INTO "languageNames" VALUES(11995,'pa','rup','ਅਰੋਮੀਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11996,'pa','sa','ਸੰਸਕ੍ਰਿਤ');
INSERT INTO "languageNames" VALUES(11997,'pa','sah','ਸਾਖਾ');
INSERT INTO "languageNames" VALUES(11998,'pa','sc','ਸਾਰਡੀਨੀਆਈ');
INSERT INTO "languageNames" VALUES(11999,'pa','scn','ਸਿਸੀਲੀਅਨ');
INSERT INTO "languageNames" VALUES(12000,'pa','sco','ਸਕਾਟਸ');
INSERT INTO "languageNames" VALUES(12001,'pa','sd','ਸਿੰਧੀ');
INSERT INTO "languageNames" VALUES(12002,'pa','se','ਉੱਤਰੀ ਸਾਮੀ');
INSERT INTO "languageNames" VALUES(12003,'pa','si','ਸਿੰਹਾਲਾ');
INSERT INTO "languageNames" VALUES(12004,'pa','sk','ਸਲੋਵਾਕ');
INSERT INTO "languageNames" VALUES(12005,'pa','sl','ਸਲੋਵੇਨੀਆਈ');
INSERT INTO "languageNames" VALUES(12006,'pa','sma','ਦੱਖਣੀ ਸਾਮੀ');
INSERT INTO "languageNames" VALUES(12007,'pa','smj','ਲਿਊਲ ਸਾਮੀ');
INSERT INTO "languageNames" VALUES(12008,'pa','smn','ਇਨਾਰੀ ਸਾਮੀ');
INSERT INTO "languageNames" VALUES(12009,'pa','sq','ਅਲਬਾਨੀਆਈ');
INSERT INTO "languageNames" VALUES(12010,'pa','sr','ਸਰਬੀਆਈ');
INSERT INTO "languageNames" VALUES(12011,'pa','srn','ਸ੍ਰਾਨਾਨ ਟੋਂਗੋ');
INSERT INTO "languageNames" VALUES(12012,'pa','ss','ਸਵਾਤੀ');
INSERT INTO "languageNames" VALUES(12013,'pa','sv','ਸਵੀਡਿਸ਼');
INSERT INTO "languageNames" VALUES(12014,'pa','sw','ਸਵਾਹਿਲੀ');
INSERT INTO "languageNames" VALUES(12015,'pa','ta','ਤਮਿਲ');
INSERT INTO "languageNames" VALUES(12016,'pa','te','ਤੇਲਗੂ');
INSERT INTO "languageNames" VALUES(12017,'pa','tet','ਟੇਟਮ');
INSERT INTO "languageNames" VALUES(12018,'pa','tg','ਤਾਜਿਕ');
INSERT INTO "languageNames" VALUES(12019,'pa','th','ਥਾਈ');
INSERT INTO "languageNames" VALUES(12020,'pa','tk','ਤੁਰਕਮੇਨ');
INSERT INTO "languageNames" VALUES(12021,'pa','tr','ਤੁਰਕੀ');
INSERT INTO "languageNames" VALUES(12022,'pa','tt','ਤਤਾਰ');
INSERT INTO "languageNames" VALUES(12023,'pa','tyv','ਤੁਵੀਨੀਅਨ');
INSERT INTO "languageNames" VALUES(12024,'pa','udm','ਉਦਮੁਰਤ');
INSERT INTO "languageNames" VALUES(12025,'pa','ug','ਉਇਗੁਰ');
INSERT INTO "languageNames" VALUES(12026,'pa','uk','ਯੂਕਰੇਨੀਆਈ');
INSERT INTO "languageNames" VALUES(12027,'pa','ur','ਉੜਦੂ');
INSERT INTO "languageNames" VALUES(12028,'pa','uz','ਉਜ਼ਬੇਕ');
INSERT INTO "languageNames" VALUES(12029,'pa','vi','ਵੀਅਤਨਾਮੀ');
INSERT INTO "languageNames" VALUES(12030,'pa','wal','ਵੋਲਾਏਟਾ');
INSERT INTO "languageNames" VALUES(12031,'pa','xh','ਖੋਸਾ');
INSERT INTO "languageNames" VALUES(12032,'pa','yi','ਯਿਦਿਸ਼');
INSERT INTO "languageNames" VALUES(12033,'pa','yo','ਯੋਰੂਬਾ');
INSERT INTO "languageNames" VALUES(12034,'pa','zh','ਚੀਨੀ (ਮੈਂਡਰਿਨ)');
INSERT INTO "languageNames" VALUES(12035,'pa','zu','ਜ਼ੁਲੂ');
INSERT INTO "languageNames" VALUES(12036,'bs','af','afrikans');
INSERT INTO "languageNames" VALUES(12037,'bs','alt','južni altai');
INSERT INTO "languageNames" VALUES(12038,'bs','an','aragonski');
INSERT INTO "languageNames" VALUES(12039,'bs','ar','arapski');
INSERT INTO "languageNames" VALUES(12040,'bs','as','asamski');
INSERT INTO "languageNames" VALUES(12041,'bs','ast','asturijski');
INSERT INTO "languageNames" VALUES(12042,'bs','av','avarski');
INSERT INTO "languageNames" VALUES(12044,'bs','az','azerski');
INSERT INTO "languageNames" VALUES(12045,'bs','ba','baškirski');
INSERT INTO "languageNames" VALUES(12046,'bs','be','bjeloruski');
INSERT INTO "languageNames" VALUES(12047,'bs','bg','bugarski');
INSERT INTO "languageNames" VALUES(12048,'bs','bi','bislama');
INSERT INTO "languageNames" VALUES(12049,'bs','bn','bengalski');
INSERT INTO "languageNames" VALUES(12050,'bs','br','bretonski');
INSERT INTO "languageNames" VALUES(12051,'bs','bs','bosanski');
INSERT INTO "languageNames" VALUES(12052,'bs','bua','buriat');
INSERT INTO "languageNames" VALUES(12053,'bs','byv','medumba');
INSERT INTO "languageNames" VALUES(12054,'bs','ca','katalonski');
INSERT INTO "languageNames" VALUES(12055,'bs','ceb','cebuano');
INSERT INTO "languageNames" VALUES(12056,'bs','chm','mari');
INSERT INTO "languageNames" VALUES(12057,'bs','ckb','centralnokurdski');
INSERT INTO "languageNames" VALUES(12058,'bs','co','korzikanski');
INSERT INTO "languageNames" VALUES(12059,'bs','crh','krimski turski');
INSERT INTO "languageNames" VALUES(12060,'bs','cs','češki');
INSERT INTO "languageNames" VALUES(12061,'bs','csb','kašubijanski');
INSERT INTO "languageNames" VALUES(12062,'bs','cu','staroslavenski');
INSERT INTO "languageNames" VALUES(12063,'bs','cv','čuvaški');
INSERT INTO "languageNames" VALUES(12064,'bs','cy','velški');
INSERT INTO "languageNames" VALUES(12065,'bs','da','danski');
INSERT INTO "languageNames" VALUES(12066,'bs','dar','dargva');
INSERT INTO "languageNames" VALUES(12067,'bs','de','njemački');
INSERT INTO "languageNames" VALUES(12068,'bs','dsb','donjolužičkosrpski');
INSERT INTO "languageNames" VALUES(12069,'bs','el','grčki');
INSERT INTO "languageNames" VALUES(12070,'bs','en','engleski');
INSERT INTO "languageNames" VALUES(12071,'bs','eo','esperanto');
INSERT INTO "languageNames" VALUES(12072,'bs','es','španski');
INSERT INTO "languageNames" VALUES(12073,'bs','et','estonski');
INSERT INTO "languageNames" VALUES(12074,'bs','eu','baskijski');
INSERT INTO "languageNames" VALUES(12075,'bs','fa','perzijski');
INSERT INTO "languageNames" VALUES(12076,'bs','fi','finski');
INSERT INTO "languageNames" VALUES(12077,'bs','fo','farski');
INSERT INTO "languageNames" VALUES(12078,'bs','fr','francuski');
INSERT INTO "languageNames" VALUES(12079,'bs','fy','zapadni frizijski');
INSERT INTO "languageNames" VALUES(12080,'bs','ga','irski');
INSERT INTO "languageNames" VALUES(12081,'bs','gag','gagauški');
INSERT INTO "languageNames" VALUES(12082,'bs','gd','škotski galski');
INSERT INTO "languageNames" VALUES(12083,'bs','gl','galicijski');
INSERT INTO "languageNames" VALUES(12084,'bs','gn','gvarani');
INSERT INTO "languageNames" VALUES(12085,'bs','gu','gudžarati');
INSERT INTO "languageNames" VALUES(12086,'bs','gv','manks');
INSERT INTO "languageNames" VALUES(12087,'bs','ha','hausa');
INSERT INTO "languageNames" VALUES(12088,'bs','haw','havajski');
INSERT INTO "languageNames" VALUES(12089,'bs','he','hebrejski');
INSERT INTO "languageNames" VALUES(12090,'bs','hi','hindi');
INSERT INTO "languageNames" VALUES(12091,'bs','hr','hrvatski');
INSERT INTO "languageNames" VALUES(12092,'bs','hsb','gornjolužičkosrpski');
INSERT INTO "languageNames" VALUES(12093,'bs','ht','haićanski kreolski');
INSERT INTO "languageNames" VALUES(12094,'bs','hu','mađarski');
INSERT INTO "languageNames" VALUES(12095,'bs','hy','armenski');
INSERT INTO "languageNames" VALUES(12096,'bs','ia','interlingva');
INSERT INTO "languageNames" VALUES(12097,'bs','id','indonezijski');
INSERT INTO "languageNames" VALUES(12098,'bs','ig','igbo');
INSERT INTO "languageNames" VALUES(12099,'bs','is','islandski');
INSERT INTO "languageNames" VALUES(12100,'bs','it','talijanski');
INSERT INTO "languageNames" VALUES(12101,'bs','ka','gruzijski');
INSERT INTO "languageNames" VALUES(12102,'bs','kaa','kara-kalpak');
INSERT INTO "languageNames" VALUES(12103,'bs','kk','kazaški');
INSERT INTO "languageNames" VALUES(12104,'bs','ko','korejski');
INSERT INTO "languageNames" VALUES(12105,'bs','krc','karačaj-balkar');
INSERT INTO "languageNames" VALUES(12106,'bs','krl','karelijski');
INSERT INTO "languageNames" VALUES(12107,'bs','ks','kašmirski');
INSERT INTO "languageNames" VALUES(12108,'bs','kum','kumik');
INSERT INTO "languageNames" VALUES(12109,'bs','kv','komi');
INSERT INTO "languageNames" VALUES(12110,'bs','ky','kirgiški');
INSERT INTO "languageNames" VALUES(12111,'bs','la','latinski');
INSERT INTO "languageNames" VALUES(12112,'bs','lb','luksemburški');
INSERT INTO "languageNames" VALUES(12113,'bs','lg','ganda');
INSERT INTO "languageNames" VALUES(12114,'bs','ln','lingala');
INSERT INTO "languageNames" VALUES(12115,'bs','lo','laoski');
INSERT INTO "languageNames" VALUES(12116,'bs','lt','litvanski');
INSERT INTO "languageNames" VALUES(12117,'bs','lv','latvijski');
INSERT INTO "languageNames" VALUES(12118,'bs','mdf','mokša');
INSERT INTO "languageNames" VALUES(12119,'bs','mfe','mauricijski kreolski');
INSERT INTO "languageNames" VALUES(12120,'bs','mk','makedonski');
INSERT INTO "languageNames" VALUES(12121,'bs','ml','malajalam');
INSERT INTO "languageNames" VALUES(12122,'bs','mr','marati');
INSERT INTO "languageNames" VALUES(12123,'bs','ms','malajski');
INSERT INTO "languageNames" VALUES(12124,'bs','mt','malteški');
INSERT INTO "languageNames" VALUES(12125,'bs','myv','erzija');
INSERT INTO "languageNames" VALUES(12126,'bs','nap','napolitanski');
INSERT INTO "languageNames" VALUES(12127,'bs','nb','norveški (Bokmal)');
INSERT INTO "languageNames" VALUES(12128,'bs','ne','nepalski');
INSERT INTO "languageNames" VALUES(12129,'bs','nl','holandski');
INSERT INTO "languageNames" VALUES(12130,'bs','nn','norveški (Nynorsk)');
INSERT INTO "languageNames" VALUES(12131,'bs','no','norveški');
INSERT INTO "languageNames" VALUES(12132,'bs','nog','nogai');
INSERT INTO "languageNames" VALUES(12133,'bs','oc','oksitanski');
INSERT INTO "languageNames" VALUES(12134,'bs','os','osetski');
INSERT INTO "languageNames" VALUES(12135,'bs','ota','osmanski turski');
INSERT INTO "languageNames" VALUES(12136,'bs','pa','pandžapski');
INSERT INTO "languageNames" VALUES(12137,'bs','pl','poljski');
INSERT INTO "languageNames" VALUES(12138,'bs','pt','portugalski');
INSERT INTO "languageNames" VALUES(12139,'bs','rm','retoromanski');
INSERT INTO "languageNames" VALUES(12140,'bs','rn','rundi');
INSERT INTO "languageNames" VALUES(12141,'bs','ro','rumunski');
INSERT INTO "languageNames" VALUES(12142,'bs','ru','ruski');
INSERT INTO "languageNames" VALUES(12143,'bs','rup','arumunski');
INSERT INTO "languageNames" VALUES(12144,'bs','sa','sanskrit');
INSERT INTO "languageNames" VALUES(12145,'bs','sah','jakutski');
INSERT INTO "languageNames" VALUES(12146,'bs','sc','sardinijski');
INSERT INTO "languageNames" VALUES(12147,'bs','scn','sicilijanski');
INSERT INTO "languageNames" VALUES(12148,'bs','sco','škotski');
INSERT INTO "languageNames" VALUES(12149,'bs','sd','sindi');
INSERT INTO "languageNames" VALUES(12150,'bs','se','sjeverni sami');
INSERT INTO "languageNames" VALUES(12151,'bs','sh','srpskohrvatski');
INSERT INTO "languageNames" VALUES(12152,'bs','si','sinhaleški');
INSERT INTO "languageNames" VALUES(12153,'bs','sk','slovački');
INSERT INTO "languageNames" VALUES(12154,'bs','sl','slovenski');
INSERT INTO "languageNames" VALUES(12155,'bs','sma','južni sami');
INSERT INTO "languageNames" VALUES(12156,'bs','smj','lule sami');
INSERT INTO "languageNames" VALUES(12157,'bs','smn','inari sami');
INSERT INTO "languageNames" VALUES(12158,'bs','sq','albanski');
INSERT INTO "languageNames" VALUES(12159,'bs','sr','srpski');
INSERT INTO "languageNames" VALUES(12160,'bs','srn','srananski tongo');
INSERT INTO "languageNames" VALUES(12161,'bs','ss','svati');
INSERT INTO "languageNames" VALUES(12162,'bs','sv','švedski');
INSERT INTO "languageNames" VALUES(12163,'bs','sw','svahili');
INSERT INTO "languageNames" VALUES(12164,'bs','ta','tamilski');
INSERT INTO "languageNames" VALUES(12165,'bs','te','telugu');
INSERT INTO "languageNames" VALUES(12166,'bs','tet','tetum');
INSERT INTO "languageNames" VALUES(12167,'bs','tg','tadžički');
INSERT INTO "languageNames" VALUES(12168,'bs','th','tajlandski');
INSERT INTO "languageNames" VALUES(12169,'bs','tk','turkmenski');
INSERT INTO "languageNames" VALUES(12170,'bs','tl','tagalog');
INSERT INTO "languageNames" VALUES(12171,'bs','tr','turski');
INSERT INTO "languageNames" VALUES(12172,'bs','tt','tatarski');
INSERT INTO "languageNames" VALUES(12173,'bs','tyv','tuvinijski');
INSERT INTO "languageNames" VALUES(12174,'bs','udm','udmurt');
INSERT INTO "languageNames" VALUES(12175,'bs','ug','ujgurski');
INSERT INTO "languageNames" VALUES(12176,'bs','uk','ukrajinski');
INSERT INTO "languageNames" VALUES(12177,'bs','ur','urdu');
INSERT INTO "languageNames" VALUES(12178,'bs','uz','uzbečki');
INSERT INTO "languageNames" VALUES(12179,'bs','vi','vijetnamski');
INSERT INTO "languageNames" VALUES(12180,'bs','wal','valamo');
INSERT INTO "languageNames" VALUES(12181,'bs','xh','hosa');
INSERT INTO "languageNames" VALUES(12182,'bs','yi','jidiš');
INSERT INTO "languageNames" VALUES(12183,'bs','yo','jorubanski');
INSERT INTO "languageNames" VALUES(12184,'bs','zh','kineski');
INSERT INTO "languageNames" VALUES(12185,'bs','zu','zulu');
INSERT INTO "languageNames" VALUES(12186,'tk','af','Afrikaans dili');
INSERT INTO "languageNames" VALUES(12187,'tk','alt','Günorta Altaý dili');
INSERT INTO "languageNames" VALUES(12188,'tk','an','Aragon dili');
INSERT INTO "languageNames" VALUES(12189,'tk','ar','Arap dili');
INSERT INTO "languageNames" VALUES(12190,'tk','as','Assam dili');
INSERT INTO "languageNames" VALUES(12191,'tk','ast','Asturiý dili');
INSERT INTO "languageNames" VALUES(12192,'tk','av','Awar dili');
INSERT INTO "languageNames" VALUES(12194,'tk','az','Azeri dili');
INSERT INTO "languageNames" VALUES(12195,'tk','ba','Başgyrt dili');
INSERT INTO "languageNames" VALUES(12196,'tk','be','Belarus dili');
INSERT INTO "languageNames" VALUES(12197,'tk','bg','Bolgar dili');
INSERT INTO "languageNames" VALUES(12198,'tk','bi','Bislama dili');
INSERT INTO "languageNames" VALUES(12199,'tk','bn','Bengal dili');
INSERT INTO "languageNames" VALUES(12200,'tk','br','Breton dili');
INSERT INTO "languageNames" VALUES(12201,'tk','bs','Boşnak dili');
INSERT INTO "languageNames" VALUES(12202,'tk','ca','Katalan dili');
INSERT INTO "languageNames" VALUES(12203,'tk','ceb','Sebuan dili');
INSERT INTO "languageNames" VALUES(12204,'tk','chm','Mariý dili');
INSERT INTO "languageNames" VALUES(12205,'tk','ckb','Merkezi kürt dili');
INSERT INTO "languageNames" VALUES(12206,'tk','co','Korsikan dili');
INSERT INTO "languageNames" VALUES(12207,'tk','cs','Çeh dili');
INSERT INTO "languageNames" VALUES(12208,'tk','cu','Buthana slaw dili');
INSERT INTO "languageNames" VALUES(12209,'tk','cv','Çuwaş dili');
INSERT INTO "languageNames" VALUES(12210,'tk','cy','Walliý dili');
INSERT INTO "languageNames" VALUES(12211,'tk','da','Daniýa dili');
INSERT INTO "languageNames" VALUES(12212,'tk','dar','Dargi dili');
INSERT INTO "languageNames" VALUES(12213,'tk','de','Nemes dili');
INSERT INTO "languageNames" VALUES(12214,'tk','dsb','Aşaky lužits dili');
INSERT INTO "languageNames" VALUES(12215,'tk','el','Grek dili');
INSERT INTO "languageNames" VALUES(12216,'tk','en','Iňlis dili');
INSERT INTO "languageNames" VALUES(12217,'tk','eo','Esperanto dili');
INSERT INTO "languageNames" VALUES(12218,'tk','es','Ispan dili');
INSERT INTO "languageNames" VALUES(12219,'tk','et','Eston dili');
INSERT INTO "languageNames" VALUES(12220,'tk','eu','Bask dili');
INSERT INTO "languageNames" VALUES(12221,'tk','fa','Pars dili');
INSERT INTO "languageNames" VALUES(12222,'tk','fi','Fin dili');
INSERT INTO "languageNames" VALUES(12223,'tk','fo','Farer dili');
INSERT INTO "languageNames" VALUES(12224,'tk','fr','Fransuz dili');
INSERT INTO "languageNames" VALUES(12225,'tk','fy','Günbatar friz dili');
INSERT INTO "languageNames" VALUES(12226,'tk','ga','Irland dili');
INSERT INTO "languageNames" VALUES(12227,'tk','gd','Şotland kelt dili');
INSERT INTO "languageNames" VALUES(12228,'tk','gl','Galisiý dili');
INSERT INTO "languageNames" VALUES(12229,'tk','gn','Guarani dili');
INSERT INTO "languageNames" VALUES(12230,'tk','gu','Gujarati dili');
INSERT INTO "languageNames" VALUES(12231,'tk','gv','Men dili');
INSERT INTO "languageNames" VALUES(12232,'tk','ha','Hausa dili');
INSERT INTO "languageNames" VALUES(12233,'tk','haw','Gawaý dili');
INSERT INTO "languageNames" VALUES(12234,'tk','he','Ýewreý dili');
INSERT INTO "languageNames" VALUES(12235,'tk','hi','Hindi dili');
INSERT INTO "languageNames" VALUES(12236,'tk','hr','Horwat dili');
INSERT INTO "languageNames" VALUES(12237,'tk','hsb','Ýokarky lužits dili');
INSERT INTO "languageNames" VALUES(12238,'tk','ht','Gaiti kreol dili');
INSERT INTO "languageNames" VALUES(12239,'tk','hu','Wenger dili');
INSERT INTO "languageNames" VALUES(12240,'tk','hy','Ermeni dili');
INSERT INTO "languageNames" VALUES(12241,'tk','ia','Interlingwa dili');
INSERT INTO "languageNames" VALUES(12242,'tk','id','Indonez dili');
INSERT INTO "languageNames" VALUES(12243,'tk','ig','Igbo dili');
INSERT INTO "languageNames" VALUES(12244,'tk','is','Island dili');
INSERT INTO "languageNames" VALUES(12245,'tk','it','Italýan dili');
INSERT INTO "languageNames" VALUES(12246,'tk','ka','Gruzin dili');
INSERT INTO "languageNames" VALUES(12247,'tk','kk','Gazak dili');
INSERT INTO "languageNames" VALUES(12248,'tk','ko','Koreý dili');
INSERT INTO "languageNames" VALUES(12249,'tk','krc','Karaçaý-balkar dili');
INSERT INTO "languageNames" VALUES(12250,'tk','krl','Karel dili');
INSERT INTO "languageNames" VALUES(12251,'tk','ks','Kaşmiri dili');
INSERT INTO "languageNames" VALUES(12252,'tk','kum','Kumyk dili');
INSERT INTO "languageNames" VALUES(12253,'tk','kv','Komi dili');
INSERT INTO "languageNames" VALUES(12254,'tk','ky','Gyrgyz dili');
INSERT INTO "languageNames" VALUES(12255,'tk','la','Latyn dili');
INSERT INTO "languageNames" VALUES(12256,'tk','lb','Lýuksemburg dili');
INSERT INTO "languageNames" VALUES(12257,'tk','lg','Ganda dili');
INSERT INTO "languageNames" VALUES(12258,'tk','ln','Lingala dili');
INSERT INTO "languageNames" VALUES(12259,'tk','lo','Laos dili');
INSERT INTO "languageNames" VALUES(12260,'tk','lt','Litwa dili');
INSERT INTO "languageNames" VALUES(12261,'tk','lv','Latyş dili');
INSERT INTO "languageNames" VALUES(12262,'tk','mdf','Mokşa dili');
INSERT INTO "languageNames" VALUES(12263,'tk','mfe','Morisýen dili');
INSERT INTO "languageNames" VALUES(12264,'tk','mk','Makedon dili');
INSERT INTO "languageNames" VALUES(12265,'tk','ml','Malaýalam dili');
INSERT INTO "languageNames" VALUES(12266,'tk','mr','Marathi dili');
INSERT INTO "languageNames" VALUES(12267,'tk','ms','Malaý dili');
INSERT INTO "languageNames" VALUES(12268,'tk','mt','Malta dili');
INSERT INTO "languageNames" VALUES(12269,'tk','myv','Erzýan dili');
INSERT INTO "languageNames" VALUES(12270,'tk','nap','Neapolitan dili');
INSERT INTO "languageNames" VALUES(12271,'tk','nb','Norwegiýa bukmol dili');
INSERT INTO "languageNames" VALUES(12272,'tk','ne','Nepal dili');
INSERT INTO "languageNames" VALUES(12273,'tk','nl','Niderland dili');
INSERT INTO "languageNames" VALUES(12274,'tk','nn','Norwegiýa nýunorsk dili');
INSERT INTO "languageNames" VALUES(12275,'tk','nog','Nogaý dili');
INSERT INTO "languageNames" VALUES(12276,'tk','oc','Oksitan dili');
INSERT INTO "languageNames" VALUES(12277,'tk','os','Osetin dili');
INSERT INTO "languageNames" VALUES(12278,'tk','pa','Penjab dili');
INSERT INTO "languageNames" VALUES(12279,'tk','pl','Polýak dili');
INSERT INTO "languageNames" VALUES(12280,'tk','pt','Portugal dili');
INSERT INTO "languageNames" VALUES(12281,'tk','rm','Retoroman dili');
INSERT INTO "languageNames" VALUES(12282,'tk','rn','Rundi dili');
INSERT INTO "languageNames" VALUES(12283,'tk','ro','Rumyn dili');
INSERT INTO "languageNames" VALUES(12284,'tk','ru','Rus dili');
INSERT INTO "languageNames" VALUES(12285,'tk','rup','Aromun dili');
INSERT INTO "languageNames" VALUES(12286,'tk','sa','Sanskrit dili');
INSERT INTO "languageNames" VALUES(12287,'tk','sah','Ýakut dili');
INSERT INTO "languageNames" VALUES(12288,'tk','sc','Sardin dili');
INSERT INTO "languageNames" VALUES(12289,'tk','scn','Sisiliýa dili');
INSERT INTO "languageNames" VALUES(12290,'tk','sco','Şotland dili');
INSERT INTO "languageNames" VALUES(12291,'tk','sd','Sindhi dili');
INSERT INTO "languageNames" VALUES(12292,'tk','se','Demirgazyk saam dili');
INSERT INTO "languageNames" VALUES(12293,'tk','si','Singal dili');
INSERT INTO "languageNames" VALUES(12294,'tk','sk','Slowak dili');
INSERT INTO "languageNames" VALUES(12295,'tk','sl','Slowen dili');
INSERT INTO "languageNames" VALUES(12296,'tk','sma','Günorta saam dili');
INSERT INTO "languageNames" VALUES(12297,'tk','smj','Lule-saam dili');
INSERT INTO "languageNames" VALUES(12298,'tk','smn','Inari-saam dili');
INSERT INTO "languageNames" VALUES(12299,'tk','sq','Alban dili');
INSERT INTO "languageNames" VALUES(12300,'tk','sr','Serb dili');
INSERT INTO "languageNames" VALUES(12301,'tk','srn','Sranan-tongo dili');
INSERT INTO "languageNames" VALUES(12302,'tk','ss','Swati dili');
INSERT INTO "languageNames" VALUES(12303,'tk','sv','Şwed dili');
INSERT INTO "languageNames" VALUES(12304,'tk','sw','Suahili dili');
INSERT INTO "languageNames" VALUES(12305,'tk','ta','Tamil dili');
INSERT INTO "languageNames" VALUES(12306,'tk','te','Telugu dili');
INSERT INTO "languageNames" VALUES(12307,'tk','tet','Tetum dili');
INSERT INTO "languageNames" VALUES(12308,'tk','tg','Täjik dili');
INSERT INTO "languageNames" VALUES(12309,'tk','th','Taý dili');
INSERT INTO "languageNames" VALUES(12310,'tk','tk','Türkmen dili');
INSERT INTO "languageNames" VALUES(12311,'tk','tr','Türk dili');
INSERT INTO "languageNames" VALUES(12312,'tk','tt','Tatar dili');
INSERT INTO "languageNames" VALUES(12313,'tk','tyv','Tuwa dili');
INSERT INTO "languageNames" VALUES(12314,'tk','udm','Udmurt dili');
INSERT INTO "languageNames" VALUES(12315,'tk','ug','Uýgur dili');
INSERT INTO "languageNames" VALUES(12316,'tk','uk','Ukrain dili');
INSERT INTO "languageNames" VALUES(12317,'tk','ur','Urdu');
INSERT INTO "languageNames" VALUES(12318,'tk','uz','Özbek dili');
INSERT INTO "languageNames" VALUES(12319,'tk','vi','Wýetnam dili');
INSERT INTO "languageNames" VALUES(12320,'tk','wal','Wolaýta dili');
INSERT INTO "languageNames" VALUES(12321,'tk','xh','Kosa dili');
INSERT INTO "languageNames" VALUES(12322,'tk','yi','Idiş dili');
INSERT INTO "languageNames" VALUES(12323,'tk','yo','Ýoruba dili');
INSERT INTO "languageNames" VALUES(12324,'tk','zh','Hytaý dili');
INSERT INTO "languageNames" VALUES(12325,'tk','zu','Zulu dili');
INSERT INTO "languageNames" VALUES(12326,'mr','af','अफ्रिकान्स');
INSERT INTO "languageNames" VALUES(12327,'mr','alt','दक्षिणात्य अल्ताई');
INSERT INTO "languageNames" VALUES(12328,'mr','an','अर्गोनीज');
INSERT INTO "languageNames" VALUES(12329,'mr','ar','अरबी');
INSERT INTO "languageNames" VALUES(12330,'mr','as','आसामी');
INSERT INTO "languageNames" VALUES(12331,'mr','ast','अस्तुरियन');
INSERT INTO "languageNames" VALUES(12332,'mr','av','अ‍ॅव्हेरिक');
INSERT INTO "languageNames" VALUES(12334,'mr','az','अझेरी');
INSERT INTO "languageNames" VALUES(12335,'mr','ba','बष्किर');
INSERT INTO "languageNames" VALUES(12336,'mr','be','बेलारुशियन');
INSERT INTO "languageNames" VALUES(12337,'mr','bg','बल्गेरियन');
INSERT INTO "languageNames" VALUES(12338,'mr','bi','बिस्लामा');
INSERT INTO "languageNames" VALUES(12339,'mr','bn','बंगाली');
INSERT INTO "languageNames" VALUES(12340,'mr','br','ब्रेतॉन');
INSERT INTO "languageNames" VALUES(12341,'mr','bs','बोस्नियन');
INSERT INTO "languageNames" VALUES(12342,'mr','bua','बुरियात');
INSERT INTO "languageNames" VALUES(12343,'mr','ca','कातालान');
INSERT INTO "languageNames" VALUES(12344,'mr','ceb','सिबुआनो');
INSERT INTO "languageNames" VALUES(12345,'mr','chm','मारी');
INSERT INTO "languageNames" VALUES(12346,'mr','ckb','मध्य कुर्दिश');
INSERT INTO "languageNames" VALUES(12347,'mr','co','कॉर्सिकन');
INSERT INTO "languageNames" VALUES(12348,'mr','crh','क्राइमीन तुर्की');
INSERT INTO "languageNames" VALUES(12349,'mr','cs','झेक');
INSERT INTO "languageNames" VALUES(12350,'mr','csb','काशुबियन');
INSERT INTO "languageNames" VALUES(12351,'mr','cu','चर्च स्लाव्हिक');
INSERT INTO "languageNames" VALUES(12352,'mr','cv','चूवाश');
INSERT INTO "languageNames" VALUES(12353,'mr','cy','वेल्श');
INSERT INTO "languageNames" VALUES(12354,'mr','da','डॅनिश');
INSERT INTO "languageNames" VALUES(12355,'mr','dar','दार्गवा');
INSERT INTO "languageNames" VALUES(12356,'mr','de','जर्मन');
INSERT INTO "languageNames" VALUES(12357,'mr','dsb','लोअर सोर्बियन');
INSERT INTO "languageNames" VALUES(12358,'mr','el','ग्रीक');
INSERT INTO "languageNames" VALUES(12359,'mr','en','इंग्रजी');
INSERT INTO "languageNames" VALUES(12360,'mr','eo','एस्परान्टो');
INSERT INTO "languageNames" VALUES(12361,'mr','es','स्पॅनिश');
INSERT INTO "languageNames" VALUES(12362,'mr','et','इस्टोनियन');
INSERT INTO "languageNames" VALUES(12363,'mr','eu','बास्क');
INSERT INTO "languageNames" VALUES(12364,'mr','fa','फारसी');
INSERT INTO "languageNames" VALUES(12365,'mr','fi','फिन्निश');
INSERT INTO "languageNames" VALUES(12366,'mr','fo','फरोइज');
INSERT INTO "languageNames" VALUES(12367,'mr','fr','फ्रेंच');
INSERT INTO "languageNames" VALUES(12368,'mr','fy','पश्चिमी फ्रिशियन');
INSERT INTO "languageNames" VALUES(12369,'mr','ga','आयरिश');
INSERT INTO "languageNames" VALUES(12370,'mr','gag','गागाउझ');
INSERT INTO "languageNames" VALUES(12371,'mr','gd','स्कॉट्स गेलिक');
INSERT INTO "languageNames" VALUES(12372,'mr','gl','गॅलिशियन');
INSERT INTO "languageNames" VALUES(12373,'mr','gn','गुआरनी');
INSERT INTO "languageNames" VALUES(12374,'mr','gu','गुजराती');
INSERT INTO "languageNames" VALUES(12375,'mr','gv','मांक्स');
INSERT INTO "languageNames" VALUES(12376,'mr','ha','हौसा');
INSERT INTO "languageNames" VALUES(12377,'mr','haw','हवाईयन');
INSERT INTO "languageNames" VALUES(12378,'mr','he','हिब्रू');
INSERT INTO "languageNames" VALUES(12379,'mr','hi','हिंदी');
INSERT INTO "languageNames" VALUES(12380,'mr','hr','क्रोएशियन');
INSERT INTO "languageNames" VALUES(12381,'mr','hsb','अप्पर सॉर्बियन');
INSERT INTO "languageNames" VALUES(12382,'mr','ht','हैतीयन');
INSERT INTO "languageNames" VALUES(12383,'mr','hu','हंगेरियन');
INSERT INTO "languageNames" VALUES(12384,'mr','hy','आर्मेनियन');
INSERT INTO "languageNames" VALUES(12385,'mr','ia','इंटरलिंग्वा');
INSERT INTO "languageNames" VALUES(12386,'mr','id','इंडोनेशियन');
INSERT INTO "languageNames" VALUES(12387,'mr','ig','ईग्बो');
INSERT INTO "languageNames" VALUES(12388,'mr','is','आईसलँडिक');
INSERT INTO "languageNames" VALUES(12389,'mr','it','इटालियन');
INSERT INTO "languageNames" VALUES(12390,'mr','ka','जॉर्जियन');
INSERT INTO "languageNames" VALUES(12391,'mr','kaa','कारा-कल्पक');
INSERT INTO "languageNames" VALUES(12392,'mr','kk','कझाक');
INSERT INTO "languageNames" VALUES(12393,'mr','ko','कोरियन');
INSERT INTO "languageNames" VALUES(12394,'mr','krc','कराचय-बाल्कर');
INSERT INTO "languageNames" VALUES(12395,'mr','krl','करेलियन');
INSERT INTO "languageNames" VALUES(12396,'mr','ks','काश्मीरी');
INSERT INTO "languageNames" VALUES(12397,'mr','kum','कुमीक');
INSERT INTO "languageNames" VALUES(12398,'mr','kv','कोमी');
INSERT INTO "languageNames" VALUES(12399,'mr','ky','किरगीझ');
INSERT INTO "languageNames" VALUES(12400,'mr','la','लॅटिन');
INSERT INTO "languageNames" VALUES(12401,'mr','lb','लक्झेंबर्गिश');
INSERT INTO "languageNames" VALUES(12402,'mr','lg','गांडा');
INSERT INTO "languageNames" VALUES(12403,'mr','ln','लिंगाला');
INSERT INTO "languageNames" VALUES(12404,'mr','lo','लाओ');
INSERT INTO "languageNames" VALUES(12405,'mr','lt','लिथुआनियन');
INSERT INTO "languageNames" VALUES(12406,'mr','lv','लात्व्हियन');
INSERT INTO "languageNames" VALUES(12407,'mr','mdf','मोक्ष');
INSERT INTO "languageNames" VALUES(12408,'mr','mfe','मोरिस्येन');
INSERT INTO "languageNames" VALUES(12409,'mr','mk','मॅसेडोनियन');
INSERT INTO "languageNames" VALUES(12410,'mr','ml','मल्याळम');
INSERT INTO "languageNames" VALUES(12411,'mr','mr','मराठी');
INSERT INTO "languageNames" VALUES(12412,'mr','ms','मलय');
INSERT INTO "languageNames" VALUES(12413,'mr','mt','माल्टिज्');
INSERT INTO "languageNames" VALUES(12414,'mr','myv','एर्झ्या');
INSERT INTO "languageNames" VALUES(12415,'mr','nap','नेपोलिटान');
INSERT INTO "languageNames" VALUES(12416,'mr','nb','नॉर्वेजियन बोकमाल');
INSERT INTO "languageNames" VALUES(12417,'mr','ne','नेपाळी');
INSERT INTO "languageNames" VALUES(12418,'mr','nl','डच');
INSERT INTO "languageNames" VALUES(12419,'mr','nn','नॉर्वेजियन न्योर्स्क');
INSERT INTO "languageNames" VALUES(12420,'mr','no','नोर्वेजियन');
INSERT INTO "languageNames" VALUES(12421,'mr','nog','नोगाई');
INSERT INTO "languageNames" VALUES(12422,'mr','oc','ऑक्सितान');
INSERT INTO "languageNames" VALUES(12423,'mr','os','ओस्सेटिक');
INSERT INTO "languageNames" VALUES(12424,'mr','ota','ओटोमान तुर्किश');
INSERT INTO "languageNames" VALUES(12425,'mr','pa','पंजाबी');
INSERT INTO "languageNames" VALUES(12426,'mr','pl','पोलिश');
INSERT INTO "languageNames" VALUES(12427,'mr','pt','पोर्तुगीज');
INSERT INTO "languageNames" VALUES(12428,'mr','rm','रोमान्श');
INSERT INTO "languageNames" VALUES(12429,'mr','rn','रुन्दी');
INSERT INTO "languageNames" VALUES(12430,'mr','ro','रोमानियन');
INSERT INTO "languageNames" VALUES(12431,'mr','ru','रशियन');
INSERT INTO "languageNames" VALUES(12432,'mr','rup','अरोमानियन');
INSERT INTO "languageNames" VALUES(12433,'mr','sa','संस्कृत');
INSERT INTO "languageNames" VALUES(12434,'mr','sah','साखा');
INSERT INTO "languageNames" VALUES(12435,'mr','sc','सर्दिनियन');
INSERT INTO "languageNames" VALUES(12436,'mr','scn','सिसिलियन');
INSERT INTO "languageNames" VALUES(12437,'mr','sco','स्कॉट्स');
INSERT INTO "languageNames" VALUES(12438,'mr','sd','सिंधी');
INSERT INTO "languageNames" VALUES(12439,'mr','se','उत्तरी सामी');
INSERT INTO "languageNames" VALUES(12440,'mr','sh','सर्बो-क्रोएशियन');
INSERT INTO "languageNames" VALUES(12441,'mr','si','सिंहला');
INSERT INTO "languageNames" VALUES(12442,'mr','sk','स्लोव्हाक');
INSERT INTO "languageNames" VALUES(12443,'mr','sl','स्लोव्हेनियन');
INSERT INTO "languageNames" VALUES(12444,'mr','sma','दक्षिणात्य सामी');
INSERT INTO "languageNames" VALUES(12445,'mr','smj','ल्युल सामी');
INSERT INTO "languageNames" VALUES(12446,'mr','smn','इनारी सामी');
INSERT INTO "languageNames" VALUES(12447,'mr','sq','अल्बानियन');
INSERT INTO "languageNames" VALUES(12448,'mr','sr','सर्बियन');
INSERT INTO "languageNames" VALUES(12449,'mr','srn','स्रानान टॉन्गो');
INSERT INTO "languageNames" VALUES(12450,'mr','ss','स्वाती');
INSERT INTO "languageNames" VALUES(12451,'mr','sv','स्वीडिश');
INSERT INTO "languageNames" VALUES(12452,'mr','sw','स्वाहिली');
INSERT INTO "languageNames" VALUES(12453,'mr','ta','तामिळ');
INSERT INTO "languageNames" VALUES(12454,'mr','te','तेलगू');
INSERT INTO "languageNames" VALUES(12455,'mr','tet','तेतुम');
INSERT INTO "languageNames" VALUES(12456,'mr','tg','ताजिक');
INSERT INTO "languageNames" VALUES(12457,'mr','th','थाई');
INSERT INTO "languageNames" VALUES(12458,'mr','tk','तुर्कमेन');
INSERT INTO "languageNames" VALUES(12459,'mr','tl','टागालोग');
INSERT INTO "languageNames" VALUES(12460,'mr','tr','तुर्की');
INSERT INTO "languageNames" VALUES(12461,'mr','tt','तातर');
INSERT INTO "languageNames" VALUES(12462,'mr','tyv','टुवीनियन');
INSERT INTO "languageNames" VALUES(12463,'mr','udm','उदमुर्त');
INSERT INTO "languageNames" VALUES(12464,'mr','ug','उइगुर');
INSERT INTO "languageNames" VALUES(12465,'mr','uk','युक्रेनियन');
INSERT INTO "languageNames" VALUES(12466,'mr','ur','उर्दू');
INSERT INTO "languageNames" VALUES(12467,'mr','uz','उझ्बेक');
INSERT INTO "languageNames" VALUES(12468,'mr','vi','व्हिएतनामी');
INSERT INTO "languageNames" VALUES(12469,'mr','wal','वोलायता');
INSERT INTO "languageNames" VALUES(12470,'mr','xh','खोसा');
INSERT INTO "languageNames" VALUES(12471,'mr','yi','यिद्दिश');
INSERT INTO "languageNames" VALUES(12472,'mr','yo','योरुबा');
INSERT INTO "languageNames" VALUES(12473,'mr','zh','चीनी');
INSERT INTO "languageNames" VALUES(12474,'mr','zu','झुलू');
INSERT INTO "languageNames" VALUES(12475,'sv','af','afrikaans');
INSERT INTO "languageNames" VALUES(12476,'sv','alt','sydaltaiska');
INSERT INTO "languageNames" VALUES(12477,'sv','an','aragonesiska');
INSERT INTO "languageNames" VALUES(12478,'sv','ar','arabiska');
INSERT INTO "languageNames" VALUES(12479,'sv','as','assamesiska');
INSERT INTO "languageNames" VALUES(12480,'sv','ast','asturiska');
INSERT INTO "languageNames" VALUES(12481,'sv','av','avariska');
INSERT INTO "languageNames" VALUES(12483,'sv','az','azeriska');
INSERT INTO "languageNames" VALUES(12484,'sv','ba','basjkiriska');
INSERT INTO "languageNames" VALUES(12485,'sv','be','vitryska');
INSERT INTO "languageNames" VALUES(12486,'sv','bg','bulgariska');
INSERT INTO "languageNames" VALUES(12487,'sv','bi','bislama');
INSERT INTO "languageNames" VALUES(12488,'sv','bn','bengali');
INSERT INTO "languageNames" VALUES(12489,'sv','br','bretonska');
INSERT INTO "languageNames" VALUES(12490,'sv','bs','bosniska');
INSERT INTO "languageNames" VALUES(12491,'sv','bua','burjätiska');
INSERT INTO "languageNames" VALUES(12492,'sv','byv','bagangte');
INSERT INTO "languageNames" VALUES(12493,'sv','ca','katalanska');
INSERT INTO "languageNames" VALUES(12494,'sv','ceb','cebuano');
INSERT INTO "languageNames" VALUES(12495,'sv','chm','mariska');
INSERT INTO "languageNames" VALUES(12496,'sv','ckb','soranisk kurdiska');
INSERT INTO "languageNames" VALUES(12497,'sv','co','korsikanska');
INSERT INTO "languageNames" VALUES(12498,'sv','crh','krimtatariska');
INSERT INTO "languageNames" VALUES(12499,'sv','cs','tjeckiska');
INSERT INTO "languageNames" VALUES(12500,'sv','csb','kasjubiska');
INSERT INTO "languageNames" VALUES(12501,'sv','cu','kyrkslaviska');
INSERT INTO "languageNames" VALUES(12502,'sv','cv','tjuvasjiska');
INSERT INTO "languageNames" VALUES(12503,'sv','cy','walesiska');
INSERT INTO "languageNames" VALUES(12504,'sv','da','danska');
INSERT INTO "languageNames" VALUES(12505,'sv','dar','darginska');
INSERT INTO "languageNames" VALUES(12506,'sv','de','tyska');
INSERT INTO "languageNames" VALUES(12507,'sv','dsb','lågsorbiska');
INSERT INTO "languageNames" VALUES(12508,'sv','el','grekiska');
INSERT INTO "languageNames" VALUES(12509,'sv','en','engelska');
INSERT INTO "languageNames" VALUES(12510,'sv','eo','esperanto');
INSERT INTO "languageNames" VALUES(12511,'sv','es','spanska');
INSERT INTO "languageNames" VALUES(12512,'sv','et','estniska');
INSERT INTO "languageNames" VALUES(12513,'sv','eu','baskiska');
INSERT INTO "languageNames" VALUES(12514,'sv','fa','persiska');
INSERT INTO "languageNames" VALUES(12515,'sv','fi','finska');
INSERT INTO "languageNames" VALUES(12516,'sv','fo','färöiska');
INSERT INTO "languageNames" VALUES(12517,'sv','fr','franska');
INSERT INTO "languageNames" VALUES(12518,'sv','fy','västfrisiska');
INSERT INTO "languageNames" VALUES(12519,'sv','ga','iriska');
INSERT INTO "languageNames" VALUES(12520,'sv','gag','gagauziska');
INSERT INTO "languageNames" VALUES(12521,'sv','gd','skotsk gäliska');
INSERT INTO "languageNames" VALUES(12522,'sv','gl','galiciska');
INSERT INTO "languageNames" VALUES(12523,'sv','glk','gilaki');
INSERT INTO "languageNames" VALUES(12524,'sv','gn','guaraní');
INSERT INTO "languageNames" VALUES(12525,'sv','gu','gujarati');
INSERT INTO "languageNames" VALUES(12526,'sv','guc','wayuu');
INSERT INTO "languageNames" VALUES(12527,'sv','gv','manx');
INSERT INTO "languageNames" VALUES(12528,'sv','ha','hausa');
INSERT INTO "languageNames" VALUES(12529,'sv','haw','hawaiiska');
INSERT INTO "languageNames" VALUES(12530,'sv','he','hebreiska');
INSERT INTO "languageNames" VALUES(12531,'sv','hi','hindi');
INSERT INTO "languageNames" VALUES(12532,'sv','hr','kroatiska');
INSERT INTO "languageNames" VALUES(12533,'sv','hsb','högsorbiska');
INSERT INTO "languageNames" VALUES(12534,'sv','ht','haitiska');
INSERT INTO "languageNames" VALUES(12535,'sv','hu','ungerska');
INSERT INTO "languageNames" VALUES(12536,'sv','hy','armeniska');
INSERT INTO "languageNames" VALUES(12537,'sv','ia','interlingua');
INSERT INTO "languageNames" VALUES(12538,'sv','id','indonesiska');
INSERT INTO "languageNames" VALUES(12539,'sv','ig','igbo');
INSERT INTO "languageNames" VALUES(12540,'sv','is','isländska');
INSERT INTO "languageNames" VALUES(12541,'sv','it','italienska');
INSERT INTO "languageNames" VALUES(12542,'sv','ka','georgiska');
INSERT INTO "languageNames" VALUES(12543,'sv','kaa','karakalpakiska');
INSERT INTO "languageNames" VALUES(12544,'sv','kk','kazakiska');
INSERT INTO "languageNames" VALUES(12545,'sv','ko','koreanska');
INSERT INTO "languageNames" VALUES(12546,'sv','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(12547,'sv','krl','karelska');
INSERT INTO "languageNames" VALUES(12548,'sv','ks','kashmiriska');
INSERT INTO "languageNames" VALUES(12549,'sv','kum','kumykiska');
INSERT INTO "languageNames" VALUES(12550,'sv','kv','kome');
INSERT INTO "languageNames" VALUES(12551,'sv','ky','kirgisiska');
INSERT INTO "languageNames" VALUES(12552,'sv','la','latin');
INSERT INTO "languageNames" VALUES(12553,'sv','lb','luxemburgiska');
INSERT INTO "languageNames" VALUES(12554,'sv','lg','luganda');
INSERT INTO "languageNames" VALUES(12555,'sv','liv','livoniska');
INSERT INTO "languageNames" VALUES(12556,'sv','ln','lingala');
INSERT INTO "languageNames" VALUES(12557,'sv','lo','laotiska');
INSERT INTO "languageNames" VALUES(12558,'sv','lt','litauiska');
INSERT INTO "languageNames" VALUES(12559,'sv','lv','lettiska');
INSERT INTO "languageNames" VALUES(12560,'sv','mdf','moksja');
INSERT INTO "languageNames" VALUES(12561,'sv','mfe','mauritansk kreol');
INSERT INTO "languageNames" VALUES(12562,'sv','mk','makedonska');
INSERT INTO "languageNames" VALUES(12563,'sv','ml','malayalam');
INSERT INTO "languageNames" VALUES(12564,'sv','mr','marathi');
INSERT INTO "languageNames" VALUES(12565,'sv','mrj','västmariska');
INSERT INTO "languageNames" VALUES(12566,'sv','ms','malajiska');
INSERT INTO "languageNames" VALUES(12567,'sv','mt','maltesiska');
INSERT INTO "languageNames" VALUES(12568,'sv','myv','erjya');
INSERT INTO "languageNames" VALUES(12569,'sv','nap','napolitanska');
INSERT INTO "languageNames" VALUES(12570,'sv','nb','norskt bokmål');
INSERT INTO "languageNames" VALUES(12571,'sv','ne','nepalesiska');
INSERT INTO "languageNames" VALUES(12572,'sv','nl','nederländska');
INSERT INTO "languageNames" VALUES(12573,'sv','nn','nynorska');
INSERT INTO "languageNames" VALUES(12574,'sv','no','norska');
INSERT INTO "languageNames" VALUES(12575,'sv','nog','nogai');
INSERT INTO "languageNames" VALUES(12576,'sv','oc','occitanska');
INSERT INTO "languageNames" VALUES(12577,'sv','os','ossetiska');
INSERT INTO "languageNames" VALUES(12578,'sv','ota','ottomanska');
INSERT INTO "languageNames" VALUES(12579,'sv','pa','punjabi');
INSERT INTO "languageNames" VALUES(12580,'sv','pl','polska');
INSERT INTO "languageNames" VALUES(12581,'sv','pt','portugisiska');
INSERT INTO "languageNames" VALUES(12582,'sv','rm','rätoromanska');
INSERT INTO "languageNames" VALUES(12583,'sv','rn','rundi');
INSERT INTO "languageNames" VALUES(12584,'sv','ro','rumänska');
INSERT INTO "languageNames" VALUES(12585,'sv','ru','ryska');
INSERT INTO "languageNames" VALUES(12586,'sv','rup','arumänska');
INSERT INTO "languageNames" VALUES(12587,'sv','sa','sanskrit');
INSERT INTO "languageNames" VALUES(12588,'sv','sah','jakutiska');
INSERT INTO "languageNames" VALUES(12589,'sv','sc','sardinska');
INSERT INTO "languageNames" VALUES(12590,'sv','scn','sicilianska');
INSERT INTO "languageNames" VALUES(12591,'sv','sco','skotska');
INSERT INTO "languageNames" VALUES(12592,'sv','sd','sindhi');
INSERT INTO "languageNames" VALUES(12593,'sv','se','nordsamiska');
INSERT INTO "languageNames" VALUES(12594,'sv','sh','serbokroatiska');
INSERT INTO "languageNames" VALUES(12595,'sv','si','singalesiska');
INSERT INTO "languageNames" VALUES(12596,'sv','sk','slovakiska');
INSERT INTO "languageNames" VALUES(12597,'sv','sl','slovenska');
INSERT INTO "languageNames" VALUES(12598,'sv','sma','sydsamiska');
INSERT INTO "languageNames" VALUES(12599,'sv','smj','lulesamiska');
INSERT INTO "languageNames" VALUES(12600,'sv','smn','enaresamiska');
INSERT INTO "languageNames" VALUES(12601,'sv','sq','albanska');
INSERT INTO "languageNames" VALUES(12602,'sv','sr','serbiska');
INSERT INTO "languageNames" VALUES(12603,'sv','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(12604,'sv','ss','swati');
INSERT INTO "languageNames" VALUES(12605,'sv','sv','svenska');
INSERT INTO "languageNames" VALUES(12606,'sv','sw','swahili');
INSERT INTO "languageNames" VALUES(12607,'sv','ta','tamil');
INSERT INTO "languageNames" VALUES(12608,'sv','te','telugu');
INSERT INTO "languageNames" VALUES(12609,'sv','tet','tetum');
INSERT INTO "languageNames" VALUES(12610,'sv','tg','tadzjikiska');
INSERT INTO "languageNames" VALUES(12611,'sv','th','thailändska');
INSERT INTO "languageNames" VALUES(12612,'sv','tk','turkmeniska');
INSERT INTO "languageNames" VALUES(12613,'sv','tl','tagalog');
INSERT INTO "languageNames" VALUES(12614,'sv','tr','turkiska');
INSERT INTO "languageNames" VALUES(12615,'sv','tt','tatariska');
INSERT INTO "languageNames" VALUES(12616,'sv','tyv','tuviniska');
INSERT INTO "languageNames" VALUES(12617,'sv','udm','udmurtiska');
INSERT INTO "languageNames" VALUES(12619,'sv','ug','östturkiska');
INSERT INTO "languageNames" VALUES(12620,'sv','uk','ukrainska');
INSERT INTO "languageNames" VALUES(12621,'sv','ur','urdu');
INSERT INTO "languageNames" VALUES(12622,'sv','uz','uzbekiska');
INSERT INTO "languageNames" VALUES(12623,'sv','vi','vietnamesiska');
INSERT INTO "languageNames" VALUES(12624,'sv','vro','võru');
INSERT INTO "languageNames" VALUES(12625,'sv','wal','walamo');
INSERT INTO "languageNames" VALUES(12626,'sv','xh','xhosa');
INSERT INTO "languageNames" VALUES(12627,'sv','yi','jiddisch');
INSERT INTO "languageNames" VALUES(12628,'sv','yo','yoruba');
INSERT INTO "languageNames" VALUES(12629,'sv','zh','kinesiska');
INSERT INTO "languageNames" VALUES(12630,'sv','zu','zulu');
INSERT INTO "languageNames" VALUES(12631,'zu','af','i-Afrikaans');
INSERT INTO "languageNames" VALUES(12632,'zu','alt','i-Southern Altai');
INSERT INTO "languageNames" VALUES(12633,'zu','an','isi-Aragonese');
INSERT INTO "languageNames" VALUES(12634,'zu','ar','isi-Arabic');
INSERT INTO "languageNames" VALUES(12635,'zu','as','isi-Assamese');
INSERT INTO "languageNames" VALUES(12636,'zu','ast','isi-Asturian');
INSERT INTO "languageNames" VALUES(12637,'zu','av','isi-Avaric');
INSERT INTO "languageNames" VALUES(12639,'zu','az','isi-Azeria');
INSERT INTO "languageNames" VALUES(12640,'zu','ba','isi-Bashkir');
INSERT INTO "languageNames" VALUES(12641,'zu','be','isi-Belarusian');
INSERT INTO "languageNames" VALUES(12642,'zu','bg','isi-Bulgari');
INSERT INTO "languageNames" VALUES(12643,'zu','bi','i-Bislama');
INSERT INTO "languageNames" VALUES(12644,'zu','bn','isi-Bengali');
INSERT INTO "languageNames" VALUES(12645,'zu','br','isi-Breton');
INSERT INTO "languageNames" VALUES(12646,'zu','bs','isi-Bosnian');
INSERT INTO "languageNames" VALUES(12647,'zu','ca','isi-Catalan');
INSERT INTO "languageNames" VALUES(12648,'zu','ceb','isi-Cebuano');
INSERT INTO "languageNames" VALUES(12649,'zu','chm','isi-Mari');
INSERT INTO "languageNames" VALUES(12650,'zu','ckb','isi-Central Kurdish');
INSERT INTO "languageNames" VALUES(12651,'zu','co','isi-Corsican');
INSERT INTO "languageNames" VALUES(12652,'zu','cs','isi-Czech');
INSERT INTO "languageNames" VALUES(12653,'zu','cu','isi-Church Slavic');
INSERT INTO "languageNames" VALUES(12654,'zu','cv','isi-Chuvash');
INSERT INTO "languageNames" VALUES(12655,'zu','cy','isi-Welsh');
INSERT INTO "languageNames" VALUES(12656,'zu','da','isi-Danish');
INSERT INTO "languageNames" VALUES(12657,'zu','dar','isi-Dargwa');
INSERT INTO "languageNames" VALUES(12658,'zu','de','isi-German');
INSERT INTO "languageNames" VALUES(12659,'zu','dsb','isi-Lower Sorbian');
INSERT INTO "languageNames" VALUES(12660,'zu','el','isi-Greek');
INSERT INTO "languageNames" VALUES(12661,'zu','en','i-English');
INSERT INTO "languageNames" VALUES(12662,'zu','eo','isi-Esperanto');
INSERT INTO "languageNames" VALUES(12663,'zu','es','isi-Spanish');
INSERT INTO "languageNames" VALUES(12664,'zu','et','isi-Estonia');
INSERT INTO "languageNames" VALUES(12665,'zu','eu','isi-Basque');
INSERT INTO "languageNames" VALUES(12666,'zu','fa','isi-Persian');
INSERT INTO "languageNames" VALUES(12667,'zu','fi','isi-Finnish');
INSERT INTO "languageNames" VALUES(12668,'zu','fo','isi-Faroese');
INSERT INTO "languageNames" VALUES(12669,'zu','fr','isi-French');
INSERT INTO "languageNames" VALUES(12670,'zu','fy','isi-Western Frisian');
INSERT INTO "languageNames" VALUES(12671,'zu','ga','isi-Irish');
INSERT INTO "languageNames" VALUES(12672,'zu','gag','isi-Gagauz');
INSERT INTO "languageNames" VALUES(12673,'zu','gd','i-Scottish Gaelic');
INSERT INTO "languageNames" VALUES(12674,'zu','gl','isi-Galicia');
INSERT INTO "languageNames" VALUES(12675,'zu','gn','isi-Guarani');
INSERT INTO "languageNames" VALUES(12676,'zu','gu','isi-Gujarati');
INSERT INTO "languageNames" VALUES(12677,'zu','gv','isi-Manx');
INSERT INTO "languageNames" VALUES(12678,'zu','ha','isi-Hausa');
INSERT INTO "languageNames" VALUES(12679,'zu','haw','isi-Hawaiian');
INSERT INTO "languageNames" VALUES(12680,'zu','he','isi-Hebrew');
INSERT INTO "languageNames" VALUES(12681,'zu','hi','isi-Hindi');
INSERT INTO "languageNames" VALUES(12682,'zu','hr','isi-Croatian');
INSERT INTO "languageNames" VALUES(12683,'zu','hsb','isi-Upper Sorbian');
INSERT INTO "languageNames" VALUES(12684,'zu','ht','isi-Haitian');
INSERT INTO "languageNames" VALUES(12685,'zu','hu','isi-Hungarian');
INSERT INTO "languageNames" VALUES(12686,'zu','hy','isi-Armenia');
INSERT INTO "languageNames" VALUES(12687,'zu','ia','izilimi ezihlangene');
INSERT INTO "languageNames" VALUES(12688,'zu','id','isi-Indonesian');
INSERT INTO "languageNames" VALUES(12689,'zu','ig','isi-Igbo');
INSERT INTO "languageNames" VALUES(12690,'zu','is','isi-Icelandic');
INSERT INTO "languageNames" VALUES(12691,'zu','it','isi-Italian');
INSERT INTO "languageNames" VALUES(12692,'zu','ka','isi-Georgian');
INSERT INTO "languageNames" VALUES(12693,'zu','kk','isi-Kazakh');
INSERT INTO "languageNames" VALUES(12694,'zu','ko','isi-Korean');
INSERT INTO "languageNames" VALUES(12695,'zu','krc','isi-Karachay-Balkar');
INSERT INTO "languageNames" VALUES(12696,'zu','krl','isi-Karelian');
INSERT INTO "languageNames" VALUES(12697,'zu','ks','isi-Kashmiri');
INSERT INTO "languageNames" VALUES(12698,'zu','kum','isi-Kumyk');
INSERT INTO "languageNames" VALUES(12699,'zu','kv','isi-Komi');
INSERT INTO "languageNames" VALUES(12700,'zu','ky','isi-Kyrgyz');
INSERT INTO "languageNames" VALUES(12701,'zu','la','isi-Latin');
INSERT INTO "languageNames" VALUES(12702,'zu','lb','isi-Luxembourgish');
INSERT INTO "languageNames" VALUES(12703,'zu','lg','isi-Ganda');
INSERT INTO "languageNames" VALUES(12704,'zu','ln','isi-Lingala');
INSERT INTO "languageNames" VALUES(12705,'zu','lo','i-Lao');
INSERT INTO "languageNames" VALUES(12706,'zu','lt','isi-Lithuanian');
INSERT INTO "languageNames" VALUES(12707,'zu','lv','isi-Latvian');
INSERT INTO "languageNames" VALUES(12708,'zu','mdf','isi-Moksha');
INSERT INTO "languageNames" VALUES(12709,'zu','mfe','isi-Morisyen');
INSERT INTO "languageNames" VALUES(12710,'zu','mk','isi-Macedonian');
INSERT INTO "languageNames" VALUES(12711,'zu','ml','isi-Malayalam');
INSERT INTO "languageNames" VALUES(12712,'zu','mr','isi-Marathi');
INSERT INTO "languageNames" VALUES(12713,'zu','ms','isi-Malay');
INSERT INTO "languageNames" VALUES(12714,'zu','mt','isi-Maltese');
INSERT INTO "languageNames" VALUES(12715,'zu','myv','isi-Erzya');
INSERT INTO "languageNames" VALUES(12716,'zu','nap','isi-Neapolitan');
INSERT INTO "languageNames" VALUES(12717,'zu','nb','isi-Norwegian Bokmål');
INSERT INTO "languageNames" VALUES(12718,'zu','ne','isi-Nepali');
INSERT INTO "languageNames" VALUES(12719,'zu','nl','isi-Dutch');
INSERT INTO "languageNames" VALUES(12720,'zu','nn','i-Norwegian Nynorsk');
INSERT INTO "languageNames" VALUES(12721,'zu','no','isi-Norwegian');
INSERT INTO "languageNames" VALUES(12722,'zu','nog','isi-Nogai');
INSERT INTO "languageNames" VALUES(12723,'zu','oc','isi-Occitan');
INSERT INTO "languageNames" VALUES(12724,'zu','os','isi-Ossetic');
INSERT INTO "languageNames" VALUES(12725,'zu','pa','isi-Punjabi');
INSERT INTO "languageNames" VALUES(12726,'zu','pl','isi-Polish');
INSERT INTO "languageNames" VALUES(12727,'zu','pt','isi-Portuguese');
INSERT INTO "languageNames" VALUES(12728,'zu','rm','isi-Romansh');
INSERT INTO "languageNames" VALUES(12729,'zu','rn','isi-Rundi');
INSERT INTO "languageNames" VALUES(12730,'zu','ro','isi-Romanian');
INSERT INTO "languageNames" VALUES(12731,'zu','ru','isi-Russian');
INSERT INTO "languageNames" VALUES(12732,'zu','rup','isi-Aromanian');
INSERT INTO "languageNames" VALUES(12733,'zu','sa','isi-Sanskrit');
INSERT INTO "languageNames" VALUES(12734,'zu','sah','i-Sakha');
INSERT INTO "languageNames" VALUES(12735,'zu','sc','i-Sardinian');
INSERT INTO "languageNames" VALUES(12736,'zu','scn','i-Sicilian');
INSERT INTO "languageNames" VALUES(12737,'zu','sco','i-Scots');
INSERT INTO "languageNames" VALUES(12738,'zu','sd','isi-Sindhi');
INSERT INTO "languageNames" VALUES(12739,'zu','se','isi-Northern Sami');
INSERT INTO "languageNames" VALUES(12740,'zu','sh','isi-Serbo-Croatian');
INSERT INTO "languageNames" VALUES(12741,'zu','si','i-Sinhala');
INSERT INTO "languageNames" VALUES(12742,'zu','sk','isi-Slovak');
INSERT INTO "languageNames" VALUES(12743,'zu','sl','isi-Slovenian');
INSERT INTO "languageNames" VALUES(12744,'zu','sma','i-Southern Sami');
INSERT INTO "languageNames" VALUES(12745,'zu','smj','isi-Lule Sami');
INSERT INTO "languageNames" VALUES(12746,'zu','smn','isi-Inari Sami');
INSERT INTO "languageNames" VALUES(12747,'zu','sq','isi-Albania');
INSERT INTO "languageNames" VALUES(12748,'zu','sr','isi-Serbian');
INSERT INTO "languageNames" VALUES(12749,'zu','srn','i-Sranan Tongo');
INSERT INTO "languageNames" VALUES(12750,'zu','ss','isiSwati');
INSERT INTO "languageNames" VALUES(12751,'zu','sv','isi-Swedish');
INSERT INTO "languageNames" VALUES(12752,'zu','sw','isiSwahili');
INSERT INTO "languageNames" VALUES(12753,'zu','ta','isi-Tamil');
INSERT INTO "languageNames" VALUES(12754,'zu','te','isi-Telugu');
INSERT INTO "languageNames" VALUES(12755,'zu','tet','isi-Tetum');
INSERT INTO "languageNames" VALUES(12756,'zu','tg','isi-Tajik');
INSERT INTO "languageNames" VALUES(12757,'zu','th','isi-Thai');
INSERT INTO "languageNames" VALUES(12758,'zu','tk','isi-Turkmen');
INSERT INTO "languageNames" VALUES(12759,'zu','tr','isi-Turkish');
INSERT INTO "languageNames" VALUES(12760,'zu','tt','isi-Tatar');
INSERT INTO "languageNames" VALUES(12761,'zu','tyv','isi-Tuvinian');
INSERT INTO "languageNames" VALUES(12762,'zu','udm','isi-Udmurt');
INSERT INTO "languageNames" VALUES(12763,'zu','ug','isi-Uighur');
INSERT INTO "languageNames" VALUES(12764,'zu','uk','isi-Ukrainian');
INSERT INTO "languageNames" VALUES(12765,'zu','ur','isi-Urdu');
INSERT INTO "languageNames" VALUES(12766,'zu','uz','isi-Uzbek');
INSERT INTO "languageNames" VALUES(12767,'zu','vi','isi-Vietnamese');
INSERT INTO "languageNames" VALUES(12768,'zu','wal','isi-Wolaytta');
INSERT INTO "languageNames" VALUES(12769,'zu','xh','isiXhosa');
INSERT INTO "languageNames" VALUES(12770,'zu','yi','isi-Yiddish');
INSERT INTO "languageNames" VALUES(12771,'zu','yo','isi-Yoruba');
INSERT INTO "languageNames" VALUES(12772,'zu','zh','isi-Chinese');
INSERT INTO "languageNames" VALUES(12773,'zu','zu','isiZulu');
INSERT INTO "languageNames" VALUES(12774,'af','af','Afrikaans');
INSERT INTO "languageNames" VALUES(12775,'af','alt','Suid-Altai');
INSERT INTO "languageNames" VALUES(12776,'af','an','Aragonees');
INSERT INTO "languageNames" VALUES(12777,'af','ar','Arabies');
INSERT INTO "languageNames" VALUES(12778,'af','as','Assamees');
INSERT INTO "languageNames" VALUES(12779,'af','ast','Asturies');
INSERT INTO "languageNames" VALUES(12780,'af','av','Avaries');
INSERT INTO "languageNames" VALUES(12782,'af','az','Azeri');
INSERT INTO "languageNames" VALUES(12783,'af','ba','Baskir');
INSERT INTO "languageNames" VALUES(12784,'af','be','Belarussies');
INSERT INTO "languageNames" VALUES(12785,'af','bg','Bulgaars');
INSERT INTO "languageNames" VALUES(12786,'af','bi','Bislama');
INSERT INTO "languageNames" VALUES(12787,'af','bn','Bengaals');
INSERT INTO "languageNames" VALUES(12788,'af','br','Bretons');
INSERT INTO "languageNames" VALUES(12789,'af','bs','Bosnies');
INSERT INTO "languageNames" VALUES(12790,'af','ca','Katalaans');
INSERT INTO "languageNames" VALUES(12791,'af','ceb','Cebuano');
INSERT INTO "languageNames" VALUES(12792,'af','chm','Mari');
INSERT INTO "languageNames" VALUES(12793,'af','ckb','Sorani');
INSERT INTO "languageNames" VALUES(12794,'af','co','Korsikaans');
INSERT INTO "languageNames" VALUES(12795,'af','cs','Tsjeggies');
INSERT INTO "languageNames" VALUES(12796,'af','cu','Kerkslawies');
INSERT INTO "languageNames" VALUES(12797,'af','cv','Chuvash');
INSERT INTO "languageNames" VALUES(12798,'af','cy','Wallies');
INSERT INTO "languageNames" VALUES(12799,'af','da','Deens');
INSERT INTO "languageNames" VALUES(12800,'af','dar','Dakota');
INSERT INTO "languageNames" VALUES(12801,'af','de','Duits');
INSERT INTO "languageNames" VALUES(12802,'af','dsb','Lae Sorbies');
INSERT INTO "languageNames" VALUES(12803,'af','el','Grieks');
INSERT INTO "languageNames" VALUES(12804,'af','en','Engels');
INSERT INTO "languageNames" VALUES(12805,'af','eo','Esperanto');
INSERT INTO "languageNames" VALUES(12806,'af','es','Spaans');
INSERT INTO "languageNames" VALUES(12807,'af','et','Estnies');
INSERT INTO "languageNames" VALUES(12808,'af','eu','Baskies');
INSERT INTO "languageNames" VALUES(12809,'af','fa','Persies');
INSERT INTO "languageNames" VALUES(12810,'af','fi','Fins');
INSERT INTO "languageNames" VALUES(12811,'af','fo','Faroëes');
INSERT INTO "languageNames" VALUES(12812,'af','fr','Frans');
INSERT INTO "languageNames" VALUES(12813,'af','fy','Fries');
INSERT INTO "languageNames" VALUES(12814,'af','ga','Iers');
INSERT INTO "languageNames" VALUES(12815,'af','gag','Gagauz');
INSERT INTO "languageNames" VALUES(12816,'af','gd','Skotse Gallies');
INSERT INTO "languageNames" VALUES(12817,'af','gl','Galisies');
INSERT INTO "languageNames" VALUES(12818,'af','gn','Guarani');
INSERT INTO "languageNames" VALUES(12819,'af','gu','Goedjarati');
INSERT INTO "languageNames" VALUES(12820,'af','gv','Manx');
INSERT INTO "languageNames" VALUES(12821,'af','ha','Hausa');
INSERT INTO "languageNames" VALUES(12822,'af','haw','Hawaiies');
INSERT INTO "languageNames" VALUES(12823,'af','he','Hebreeus');
INSERT INTO "languageNames" VALUES(12824,'af','hi','Hindi');
INSERT INTO "languageNames" VALUES(12825,'af','hr','Kroaties');
INSERT INTO "languageNames" VALUES(12826,'af','hsb','Oppersorbies');
INSERT INTO "languageNames" VALUES(12827,'af','ht','Haïtiaans');
INSERT INTO "languageNames" VALUES(12828,'af','hu','Hongaars');
INSERT INTO "languageNames" VALUES(12829,'af','hy','Armeens');
INSERT INTO "languageNames" VALUES(12830,'af','ia','Interlingua');
INSERT INTO "languageNames" VALUES(12831,'af','id','Indonesies');
INSERT INTO "languageNames" VALUES(12832,'af','ig','Igbo');
INSERT INTO "languageNames" VALUES(12833,'af','is','Yslands');
INSERT INTO "languageNames" VALUES(12834,'af','it','Italiaans');
INSERT INTO "languageNames" VALUES(12835,'af','ka','Georgies');
INSERT INTO "languageNames" VALUES(12836,'af','kk','Kazaks');
INSERT INTO "languageNames" VALUES(12837,'af','ko','Koreaans');
INSERT INTO "languageNames" VALUES(12838,'af','krc','Karachay-Balkar');
INSERT INTO "languageNames" VALUES(12839,'af','krl','Karelies');
INSERT INTO "languageNames" VALUES(12840,'af','ks','Kasjmirs');
INSERT INTO "languageNames" VALUES(12841,'af','kum','Kumyk');
INSERT INTO "languageNames" VALUES(12842,'af','kv','Komi');
INSERT INTO "languageNames" VALUES(12843,'af','ky','Kirgisies');
INSERT INTO "languageNames" VALUES(12844,'af','la','Latyn');
INSERT INTO "languageNames" VALUES(12845,'af','lb','Luxemburgs');
INSERT INTO "languageNames" VALUES(12846,'af','lg','Ganda');
INSERT INTO "languageNames" VALUES(12847,'af','ln','Lingaals');
INSERT INTO "languageNames" VALUES(12848,'af','lo','Lao');
INSERT INTO "languageNames" VALUES(12849,'af','lt','Litaus');
INSERT INTO "languageNames" VALUES(12850,'af','lv','Letties');
INSERT INTO "languageNames" VALUES(12851,'af','mdf','Moksha');
INSERT INTO "languageNames" VALUES(12852,'af','mfe','Morisjen');
INSERT INTO "languageNames" VALUES(12853,'af','mk','Masedonies');
INSERT INTO "languageNames" VALUES(12854,'af','ml','Malabaars');
INSERT INTO "languageNames" VALUES(12855,'af','mr','Marathi');
INSERT INTO "languageNames" VALUES(12856,'af','ms','Maleis');
INSERT INTO "languageNames" VALUES(12857,'af','mt','Maltees');
INSERT INTO "languageNames" VALUES(12858,'af','myv','Erzya');
INSERT INTO "languageNames" VALUES(12859,'af','nap','Neapolitaans');
INSERT INTO "languageNames" VALUES(12860,'af','nb','Noorse Bokmål');
INSERT INTO "languageNames" VALUES(12861,'af','ne','Nepalees');
INSERT INTO "languageNames" VALUES(12862,'af','nl','Nederlands');
INSERT INTO "languageNames" VALUES(12863,'af','nn','Noorweegse Nynorsk');
INSERT INTO "languageNames" VALUES(12864,'af','no','Noors');
INSERT INTO "languageNames" VALUES(12865,'af','nog','Nogai');
INSERT INTO "languageNames" VALUES(12866,'af','oc','Oksitaans');
INSERT INTO "languageNames" VALUES(12867,'af','os','Osseties');
INSERT INTO "languageNames" VALUES(12868,'af','pa','Pandjabi');
INSERT INTO "languageNames" VALUES(12869,'af','pl','Pools');
INSERT INTO "languageNames" VALUES(12870,'af','pt','Portugees');
INSERT INTO "languageNames" VALUES(12871,'af','rm','Reto-Romaans');
INSERT INTO "languageNames" VALUES(12872,'af','rn','Rundi');
INSERT INTO "languageNames" VALUES(12873,'af','ro','Roemeens');
INSERT INTO "languageNames" VALUES(12874,'af','ru','Russies');
INSERT INTO "languageNames" VALUES(12875,'af','rup','Aromanies');
INSERT INTO "languageNames" VALUES(12876,'af','sa','Sanskrit');
INSERT INTO "languageNames" VALUES(12877,'af','sah','Sakhaans');
INSERT INTO "languageNames" VALUES(12878,'af','sc','Sardinies');
INSERT INTO "languageNames" VALUES(12879,'af','scn','Sisiliaans');
INSERT INTO "languageNames" VALUES(12880,'af','sco','Skots');
INSERT INTO "languageNames" VALUES(12881,'af','sd','Sindhi');
INSERT INTO "languageNames" VALUES(12882,'af','se','Noord-Sami');
INSERT INTO "languageNames" VALUES(12883,'af','sh','Serwo-Kroaties');
INSERT INTO "languageNames" VALUES(12884,'af','si','Sinhala');
INSERT INTO "languageNames" VALUES(12885,'af','sk','Slowaaks');
INSERT INTO "languageNames" VALUES(12886,'af','sl','Sloweens');
INSERT INTO "languageNames" VALUES(12887,'af','sma','Suid-Sami');
INSERT INTO "languageNames" VALUES(12888,'af','smj','Lule Sami');
INSERT INTO "languageNames" VALUES(12889,'af','smn','Inari Sami');
INSERT INTO "languageNames" VALUES(12890,'af','sq','Albanees');
INSERT INTO "languageNames" VALUES(12891,'af','sr','Serwies');
INSERT INTO "languageNames" VALUES(12892,'af','srn','Sranan Tongo');
INSERT INTO "languageNames" VALUES(12893,'af','ss','Swazi');
INSERT INTO "languageNames" VALUES(12894,'af','sv','Sweeds');
INSERT INTO "languageNames" VALUES(12895,'af','sw','Swahili');
INSERT INTO "languageNames" VALUES(12896,'af','ta','Tamil');
INSERT INTO "languageNames" VALUES(12897,'af','te','Teloegoe');
INSERT INTO "languageNames" VALUES(12898,'af','tet','Tetoem');
INSERT INTO "languageNames" VALUES(12899,'af','tg','Tadzjieks');
INSERT INTO "languageNames" VALUES(12900,'af','th','Thai');
INSERT INTO "languageNames" VALUES(12901,'af','tk','Turkmeens');
INSERT INTO "languageNames" VALUES(12902,'af','tr','Turks');
INSERT INTO "languageNames" VALUES(12903,'af','tt','Tataars');
INSERT INTO "languageNames" VALUES(12904,'af','tyv','Tuvinees');
INSERT INTO "languageNames" VALUES(12905,'af','udm','Udmurt');
INSERT INTO "languageNames" VALUES(12906,'af','ug','Uighur');
INSERT INTO "languageNames" VALUES(12907,'af','uk','Oekraïens');
INSERT INTO "languageNames" VALUES(12908,'af','ur','Oerdoe');
INSERT INTO "languageNames" VALUES(12909,'af','uz','Oezbeeks');
INSERT INTO "languageNames" VALUES(12910,'af','vi','Viëtnamees');
INSERT INTO "languageNames" VALUES(12911,'af','wal','Wolaytta');
INSERT INTO "languageNames" VALUES(12912,'af','xh','Xhosa');
INSERT INTO "languageNames" VALUES(12913,'af','yi','Jiddisj');
INSERT INTO "languageNames" VALUES(12914,'af','yo','Yoruba');
INSERT INTO "languageNames" VALUES(12915,'af','zh','Sjinees');
INSERT INTO "languageNames" VALUES(12916,'af','zu','Zoeloe');
INSERT INTO "languageNames" VALUES(12917,'ne','af','अफ्रिकान्स');
INSERT INTO "languageNames" VALUES(12918,'ne','alt','दक्षिणी आल्टाइ');
INSERT INTO "languageNames" VALUES(12919,'ne','an','अरागोनी');
INSERT INTO "languageNames" VALUES(12920,'ne','ar','अरबी');
INSERT INTO "languageNames" VALUES(12921,'ne','as','आसामी');
INSERT INTO "languageNames" VALUES(12922,'ne','ast','अस्टुरियाली');
INSERT INTO "languageNames" VALUES(12923,'ne','av','अवारिक');
INSERT INTO "languageNames" VALUES(12925,'ne','az','अजेरी');
INSERT INTO "languageNames" VALUES(12926,'ne','ba','बास्किर');
INSERT INTO "languageNames" VALUES(12927,'ne','be','बेलारुसी');
INSERT INTO "languageNames" VALUES(12928,'ne','bg','बुल्गेरियाली');
INSERT INTO "languageNames" VALUES(12929,'ne','bi','बिस्लाम');
INSERT INTO "languageNames" VALUES(12930,'ne','bn','बंगाली');
INSERT INTO "languageNames" VALUES(12931,'ne','br','ब्रेटन');
INSERT INTO "languageNames" VALUES(12932,'ne','bs','बोस्नियाली');
INSERT INTO "languageNames" VALUES(12933,'ne','bua','बुरिआत');
INSERT INTO "languageNames" VALUES(12934,'ne','byv','मेडुम्बा');
INSERT INTO "languageNames" VALUES(12935,'ne','ca','क्याटालन');
INSERT INTO "languageNames" VALUES(12936,'ne','ceb','सेबुआनो');
INSERT INTO "languageNames" VALUES(12937,'ne','chm','मारी');
INSERT INTO "languageNames" VALUES(12938,'ne','ckb','केन्द्रीय कुर्दी');
INSERT INTO "languageNames" VALUES(12939,'ne','co','कोर्सिकन');
INSERT INTO "languageNames" VALUES(12940,'ne','crh','क्रिमियाली तुर्क');
INSERT INTO "languageNames" VALUES(12941,'ne','cs','चेक');
INSERT INTO "languageNames" VALUES(12942,'ne','csb','कासुवियन');
INSERT INTO "languageNames" VALUES(12943,'ne','cu','चर्च स्लाभिक');
INSERT INTO "languageNames" VALUES(12944,'ne','cv','चुभास');
INSERT INTO "languageNames" VALUES(12945,'ne','cy','वेल्श');
INSERT INTO "languageNames" VALUES(12946,'ne','da','डेनिस');
INSERT INTO "languageNames" VALUES(12947,'ne','dar','दार्ग्वा');
INSERT INTO "languageNames" VALUES(12948,'ne','de','जर्मन');
INSERT INTO "languageNames" VALUES(12949,'ne','dsb','तल्लो सोर्बियन');
INSERT INTO "languageNames" VALUES(12950,'ne','el','ग्रीक');
INSERT INTO "languageNames" VALUES(12951,'ne','en','अङ्ग्रेजी');
INSERT INTO "languageNames" VALUES(12952,'ne','eo','एस्पेरान्तो');
INSERT INTO "languageNames" VALUES(12953,'ne','es','स्पेनी');
INSERT INTO "languageNames" VALUES(12954,'ne','et','इस्टोनियन');
INSERT INTO "languageNames" VALUES(12955,'ne','eu','बास्क');
INSERT INTO "languageNames" VALUES(12956,'ne','fa','फारसी');
INSERT INTO "languageNames" VALUES(12957,'ne','fi','फिनिस');
INSERT INTO "languageNames" VALUES(12958,'ne','fo','फारोज');
INSERT INTO "languageNames" VALUES(12959,'ne','fr','फ्रान्सेली');
INSERT INTO "languageNames" VALUES(12960,'ne','fy','पश्चिमी फ्रिसियन');
INSERT INTO "languageNames" VALUES(12961,'ne','ga','आइरिस');
INSERT INTO "languageNames" VALUES(12962,'ne','gag','गगाउज');
INSERT INTO "languageNames" VALUES(12963,'ne','gd','स्कटिस गाएलिक');
INSERT INTO "languageNames" VALUES(12964,'ne','gl','गलिसियाली');
INSERT INTO "languageNames" VALUES(12965,'ne','glk','गिलाकी');
INSERT INTO "languageNames" VALUES(12966,'ne','gn','गुवारानी');
INSERT INTO "languageNames" VALUES(12967,'ne','gu','गुजराती');
INSERT INTO "languageNames" VALUES(12968,'ne','gv','मान्क्स');
INSERT INTO "languageNames" VALUES(12969,'ne','ha','हाउसा');
INSERT INTO "languageNames" VALUES(12970,'ne','haw','हवाइयन');
INSERT INTO "languageNames" VALUES(12971,'ne','he','हिब्रु');
INSERT INTO "languageNames" VALUES(12972,'ne','hi','हिन्दी');
INSERT INTO "languageNames" VALUES(12973,'ne','hr','क्रोयसियाली');
INSERT INTO "languageNames" VALUES(12974,'ne','hsb','माथिल्लो सोर्बियन');
INSERT INTO "languageNames" VALUES(12975,'ne','ht','हैटियाली क्रियोल');
INSERT INTO "languageNames" VALUES(12976,'ne','hu','हङ्गेरियाली');
INSERT INTO "languageNames" VALUES(12977,'ne','hy','आर्मेनियाली');
INSERT INTO "languageNames" VALUES(12978,'ne','ia','इन्टर्लिङ्गुआ');
INSERT INTO "languageNames" VALUES(12979,'ne','id','इन्डोनेसियाली');
INSERT INTO "languageNames" VALUES(12980,'ne','ig','इग्बो');
INSERT INTO "languageNames" VALUES(12981,'ne','is','आइसल्यान्डियाली');
INSERT INTO "languageNames" VALUES(12982,'ne','it','इटालेली');
INSERT INTO "languageNames" VALUES(12983,'ne','ka','जर्जियाली');
INSERT INTO "languageNames" VALUES(12984,'ne','kaa','कारा-काल्पाक');
INSERT INTO "languageNames" VALUES(12985,'ne','kk','काजाख');
INSERT INTO "languageNames" VALUES(12986,'ne','ko','कोरियाली');
INSERT INTO "languageNames" VALUES(12987,'ne','krc','काराचाय-बाल्कर');
INSERT INTO "languageNames" VALUES(12988,'ne','krl','करेलियन');
INSERT INTO "languageNames" VALUES(12989,'ne','ks','कास्मिरी');
INSERT INTO "languageNames" VALUES(12990,'ne','kum','कुमिक');
INSERT INTO "languageNames" VALUES(12991,'ne','kv','कोमी');
INSERT INTO "languageNames" VALUES(12992,'ne','ky','किर्गिज');
INSERT INTO "languageNames" VALUES(12993,'ne','la','ल्याटिन');
INSERT INTO "languageNames" VALUES(12994,'ne','lb','लक्जेम्बर्गी');
INSERT INTO "languageNames" VALUES(12995,'ne','lg','गान्डा');
INSERT INTO "languageNames" VALUES(12996,'ne','liv','लिभोनियाली');
INSERT INTO "languageNames" VALUES(12997,'ne','ln','लिङ्गाला');
INSERT INTO "languageNames" VALUES(12998,'ne','lo','लाओ');
INSERT INTO "languageNames" VALUES(12999,'ne','lt','लिथुआनियाली');
INSERT INTO "languageNames" VALUES(13000,'ne','lv','लात्भियाली');
INSERT INTO "languageNames" VALUES(13001,'ne','mdf','मोक्ष');
INSERT INTO "languageNames" VALUES(13002,'ne','mfe','मोरिसेन');
INSERT INTO "languageNames" VALUES(13003,'ne','mk','म्यासेडोनियन');
INSERT INTO "languageNames" VALUES(13004,'ne','ml','मलयालम');
INSERT INTO "languageNames" VALUES(13005,'ne','mr','मराठी');
INSERT INTO "languageNames" VALUES(13006,'ne','ms','मलाय');
INSERT INTO "languageNames" VALUES(13007,'ne','mt','माल्टिज');
INSERT INTO "languageNames" VALUES(13008,'ne','myv','इर्ज्या');
INSERT INTO "languageNames" VALUES(13009,'ne','nap','नेपोलिटान');
INSERT INTO "languageNames" VALUES(13010,'ne','nb','नर्वेली बोकमाल');
INSERT INTO "languageNames" VALUES(13011,'ne','ne','नेपाली');
INSERT INTO "languageNames" VALUES(13012,'ne','nl','डच');
INSERT INTO "languageNames" VALUES(13013,'ne','nn','नर्वेली नाइनोर्स्क');
INSERT INTO "languageNames" VALUES(13014,'ne','no','नर्वेली');
INSERT INTO "languageNames" VALUES(13015,'ne','nog','नोगाइ');
INSERT INTO "languageNames" VALUES(13016,'ne','oc','अक्सिटन');
INSERT INTO "languageNames" VALUES(13017,'ne','os','अोस्सेटिक');
INSERT INTO "languageNames" VALUES(13018,'ne','ota','अटोमन तुर्की');
INSERT INTO "languageNames" VALUES(13019,'ne','pa','पंजाबी');
INSERT INTO "languageNames" VALUES(13020,'ne','pl','पोलिस');
INSERT INTO "languageNames" VALUES(13021,'ne','pt','पोर्तुगी');
INSERT INTO "languageNames" VALUES(13022,'ne','rm','रोमानिस');
INSERT INTO "languageNames" VALUES(13023,'ne','rn','रुन्डी');
INSERT INTO "languageNames" VALUES(13024,'ne','ro','रोमानियाली');
INSERT INTO "languageNames" VALUES(13025,'ne','ru','रसियाली');
INSERT INTO "languageNames" VALUES(13026,'ne','rup','अरोमानीयाली');
INSERT INTO "languageNames" VALUES(13027,'ne','sa','संस्कृत');
INSERT INTO "languageNames" VALUES(13028,'ne','sah','साखा');
INSERT INTO "languageNames" VALUES(13029,'ne','sc','सार्डिनियाली');
INSERT INTO "languageNames" VALUES(13030,'ne','scn','सिसिलियाली');
INSERT INTO "languageNames" VALUES(13031,'ne','sco','स्कट्स');
INSERT INTO "languageNames" VALUES(13032,'ne','sd','सिन्धी');
INSERT INTO "languageNames" VALUES(13033,'ne','se','उत्तरी सामी');
INSERT INTO "languageNames" VALUES(13034,'ne','si','सिन्हाली');
INSERT INTO "languageNames" VALUES(13035,'ne','sk','स्लोभाकियाली');
INSERT INTO "languageNames" VALUES(13036,'ne','sl','स्लोभेनियाली');
INSERT INTO "languageNames" VALUES(13037,'ne','sma','दक्षिणी सामी');
INSERT INTO "languageNames" VALUES(13038,'ne','smj','लुले सामी');
INSERT INTO "languageNames" VALUES(13039,'ne','smn','इनारी सामी');
INSERT INTO "languageNames" VALUES(13040,'ne','sq','अल्बानियाली');
INSERT INTO "languageNames" VALUES(13041,'ne','sr','सर्बियाली');
INSERT INTO "languageNames" VALUES(13042,'ne','srn','स्रानान टोङ्गो');
INSERT INTO "languageNames" VALUES(13043,'ne','ss','स्वाती');
INSERT INTO "languageNames" VALUES(13044,'ne','sv','स्विडिस');
INSERT INTO "languageNames" VALUES(13045,'ne','sw','स्वाहिली');
INSERT INTO "languageNames" VALUES(13046,'ne','ta','तामिल');
INSERT INTO "languageNames" VALUES(13047,'ne','te','तेलुगु');
INSERT INTO "languageNames" VALUES(13048,'ne','tet','टेटुम');
INSERT INTO "languageNames" VALUES(13049,'ne','tg','ताजिक');
INSERT INTO "languageNames" VALUES(13050,'ne','th','थाई');
INSERT INTO "languageNames" VALUES(13051,'ne','tk','टर्कमेन');
INSERT INTO "languageNames" VALUES(13052,'ne','tr','टर्किश');
INSERT INTO "languageNames" VALUES(13053,'ne','tt','तातार');
INSERT INTO "languageNames" VALUES(13054,'ne','tyv','टुभिनियाली');
INSERT INTO "languageNames" VALUES(13055,'ne','udm','उड्मुर्ट');
INSERT INTO "languageNames" VALUES(13056,'ne','ug','उइघुर');
INSERT INTO "languageNames" VALUES(13057,'ne','uk','युक्रेनी');
INSERT INTO "languageNames" VALUES(13058,'ne','ur','उर्दु');
INSERT INTO "languageNames" VALUES(13059,'ne','uz','उज्बेकी');
INSERT INTO "languageNames" VALUES(13060,'ne','vi','भियतनामी');
INSERT INTO "languageNames" VALUES(13061,'ne','wal','वोलेट्टा');
INSERT INTO "languageNames" VALUES(13062,'ne','xh','खोसा');
INSERT INTO "languageNames" VALUES(13063,'ne','yi','यिद्दिस');
INSERT INTO "languageNames" VALUES(13064,'ne','yo','योरूवा');
INSERT INTO "languageNames" VALUES(13065,'ne','zh','चिनियाँ');
INSERT INTO "languageNames" VALUES(13066,'ne','zu','जुलु');
INSERT INTO "languageNames" VALUES(13067,'es','af','afrikáans');
INSERT INTO "languageNames" VALUES(13068,'es','alt','altái meridional');
INSERT INTO "languageNames" VALUES(13069,'es','an','aragonés');
INSERT INTO "languageNames" VALUES(13070,'es','ar','árabe');
INSERT INTO "languageNames" VALUES(13071,'es','as','asamés');
INSERT INTO "languageNames" VALUES(13072,'es','ast','asturiano');
INSERT INTO "languageNames" VALUES(13073,'es','av','avar');
INSERT INTO "languageNames" VALUES(13075,'es','az','azerí');
INSERT INTO "languageNames" VALUES(13076,'es','ba','baskir');
INSERT INTO "languageNames" VALUES(13077,'es','be','bielorruso');
INSERT INTO "languageNames" VALUES(13078,'es','bg','búlgaro');
INSERT INTO "languageNames" VALUES(13079,'es','bi','bislama');
INSERT INTO "languageNames" VALUES(13080,'es','bn','bengalí');
INSERT INTO "languageNames" VALUES(13081,'es','br','bretón');
INSERT INTO "languageNames" VALUES(13082,'es','bs','bosnio');
INSERT INTO "languageNames" VALUES(13083,'es','bua','buriato');
INSERT INTO "languageNames" VALUES(13084,'es','byv','medumba');
INSERT INTO "languageNames" VALUES(13085,'es','ca','catalán');
INSERT INTO "languageNames" VALUES(13086,'es','ceb','cebuano');
INSERT INTO "languageNames" VALUES(13087,'es','chm','marí');
INSERT INTO "languageNames" VALUES(13088,'es','ckb','kurdo sorani');
INSERT INTO "languageNames" VALUES(13089,'es','co','corso');
INSERT INTO "languageNames" VALUES(13090,'es','crh','tártaro de Crimea');
INSERT INTO "languageNames" VALUES(13091,'es','cs','checo');
INSERT INTO "languageNames" VALUES(13092,'es','csb','casubio');
INSERT INTO "languageNames" VALUES(13093,'es','cu','eslavo eclesiástico');
INSERT INTO "languageNames" VALUES(13094,'es','cv','chuvasio');
INSERT INTO "languageNames" VALUES(13095,'es','cy','galés');
INSERT INTO "languageNames" VALUES(13096,'es','da','danés');
INSERT INTO "languageNames" VALUES(13097,'es','dar','dargva');
INSERT INTO "languageNames" VALUES(13098,'es','de','alemán');
INSERT INTO "languageNames" VALUES(13099,'es','dsb','bajo sorbio');
INSERT INTO "languageNames" VALUES(13100,'es','el','griego');
INSERT INTO "languageNames" VALUES(13101,'es','en','inglés');
INSERT INTO "languageNames" VALUES(13102,'es','eo','esperanto');
INSERT INTO "languageNames" VALUES(13103,'es','es','español');
INSERT INTO "languageNames" VALUES(13104,'es','et','estonio');
INSERT INTO "languageNames" VALUES(13105,'es','eu','euskera');
INSERT INTO "languageNames" VALUES(13106,'es','fa','persa');
INSERT INTO "languageNames" VALUES(13107,'es','fi','finés');
INSERT INTO "languageNames" VALUES(13108,'es','fo','feroés');
INSERT INTO "languageNames" VALUES(13109,'es','fr','francés');
INSERT INTO "languageNames" VALUES(13110,'es','fy','frisón occidental');
INSERT INTO "languageNames" VALUES(13111,'es','ga','irlandés');
INSERT INTO "languageNames" VALUES(13112,'es','gag','gagauzo');
INSERT INTO "languageNames" VALUES(13113,'es','gd','gaélico escocés');
INSERT INTO "languageNames" VALUES(13114,'es','gl','gallego');
INSERT INTO "languageNames" VALUES(13115,'es','gn','guaraní');
INSERT INTO "languageNames" VALUES(13116,'es','gu','guyaratí');
INSERT INTO "languageNames" VALUES(13117,'es','gv','manés');
INSERT INTO "languageNames" VALUES(13118,'es','ha','hausa');
INSERT INTO "languageNames" VALUES(13119,'es','haw','hawaiano');
INSERT INTO "languageNames" VALUES(13120,'es','he','hebreo');
INSERT INTO "languageNames" VALUES(13121,'es','hi','hindi');
INSERT INTO "languageNames" VALUES(13122,'es','hr','croata');
INSERT INTO "languageNames" VALUES(13123,'es','hsb','alto sorbio');
INSERT INTO "languageNames" VALUES(13124,'es','ht','criollo haitiano');
INSERT INTO "languageNames" VALUES(13125,'es','hu','húngaro');
INSERT INTO "languageNames" VALUES(13126,'es','hy','armenio');
INSERT INTO "languageNames" VALUES(13127,'es','ia','interlingua');
INSERT INTO "languageNames" VALUES(13128,'es','id','indonesio');
INSERT INTO "languageNames" VALUES(13129,'es','ig','igbo');
INSERT INTO "languageNames" VALUES(13130,'es','is','islandés');
INSERT INTO "languageNames" VALUES(13131,'es','it','italiano');
INSERT INTO "languageNames" VALUES(13132,'es','ka','georgiano');
INSERT INTO "languageNames" VALUES(13133,'es','kaa','karakalpako');
INSERT INTO "languageNames" VALUES(13134,'es','kk','kazajo');
INSERT INTO "languageNames" VALUES(13135,'es','ko','coreano');
INSERT INTO "languageNames" VALUES(13136,'es','krc','karachay-balkar');
INSERT INTO "languageNames" VALUES(13137,'es','krl','carelio');
INSERT INTO "languageNames" VALUES(13138,'es','ks','cachemiro');
INSERT INTO "languageNames" VALUES(13139,'es','kum','kumyk');
INSERT INTO "languageNames" VALUES(13140,'es','kv','komi');
INSERT INTO "languageNames" VALUES(13141,'es','ky','kirguís');
INSERT INTO "languageNames" VALUES(13142,'es','la','latín');
INSERT INTO "languageNames" VALUES(13143,'es','lb','luxemburgués');
INSERT INTO "languageNames" VALUES(13144,'es','lg','ganda');
INSERT INTO "languageNames" VALUES(13145,'es','ln','lingala');
INSERT INTO "languageNames" VALUES(13146,'es','lo','lao');
INSERT INTO "languageNames" VALUES(13147,'es','lt','lituano');
INSERT INTO "languageNames" VALUES(13148,'es','lv','letón');
INSERT INTO "languageNames" VALUES(13149,'es','mdf','moksha');
INSERT INTO "languageNames" VALUES(13150,'es','mfe','criollo mauriciano');
INSERT INTO "languageNames" VALUES(13151,'es','mk','macedonio');
INSERT INTO "languageNames" VALUES(13152,'es','ml','malayalam');
INSERT INTO "languageNames" VALUES(13153,'es','mr','maratí');
INSERT INTO "languageNames" VALUES(13154,'es','ms','malayo');
INSERT INTO "languageNames" VALUES(13155,'es','mt','maltés');
INSERT INTO "languageNames" VALUES(13156,'es','myv','erzya');
INSERT INTO "languageNames" VALUES(13157,'es','nap','napolitano');
INSERT INTO "languageNames" VALUES(13158,'es','nb','noruego bokmal');
INSERT INTO "languageNames" VALUES(13159,'es','ne','nepalí');
INSERT INTO "languageNames" VALUES(13160,'es','nl','neerlandés');
INSERT INTO "languageNames" VALUES(13161,'es','nn','noruego nynorsk');
INSERT INTO "languageNames" VALUES(13162,'es','no','noruego');
INSERT INTO "languageNames" VALUES(13163,'es','nog','nogai');
INSERT INTO "languageNames" VALUES(13164,'es','oc','occitano');
INSERT INTO "languageNames" VALUES(13165,'es','os','osético');
INSERT INTO "languageNames" VALUES(13166,'es','ota','turco otomano');
INSERT INTO "languageNames" VALUES(13167,'es','pa','panyabí');
INSERT INTO "languageNames" VALUES(13168,'es','pl','polaco');
INSERT INTO "languageNames" VALUES(13169,'es','pt','portugués');
INSERT INTO "languageNames" VALUES(13170,'es','rm','romanche');
INSERT INTO "languageNames" VALUES(13171,'es','rn','kirundi');
INSERT INTO "languageNames" VALUES(13172,'es','ro','rumano');
INSERT INTO "languageNames" VALUES(13173,'es','ru','ruso');
INSERT INTO "languageNames" VALUES(13174,'es','rup','arrumano');
INSERT INTO "languageNames" VALUES(13175,'es','sa','sánscrito');
INSERT INTO "languageNames" VALUES(13176,'es','sah','sakha');
INSERT INTO "languageNames" VALUES(13177,'es','sc','sardo');
INSERT INTO "languageNames" VALUES(13178,'es','scn','siciliano');
INSERT INTO "languageNames" VALUES(13179,'es','sco','escocés');
INSERT INTO "languageNames" VALUES(13180,'es','sd','sindhi');
INSERT INTO "languageNames" VALUES(13181,'es','se','sami septentrional');
INSERT INTO "languageNames" VALUES(13182,'es','sh','serbocroata');
INSERT INTO "languageNames" VALUES(13183,'es','si','cingalés');
INSERT INTO "languageNames" VALUES(13184,'es','sk','eslovaco');
INSERT INTO "languageNames" VALUES(13185,'es','sl','esloveno');
INSERT INTO "languageNames" VALUES(13186,'es','sma','sami meridional');
INSERT INTO "languageNames" VALUES(13187,'es','smj','sami lule');
INSERT INTO "languageNames" VALUES(13188,'es','smn','sami inari');
INSERT INTO "languageNames" VALUES(13189,'es','sq','albanés');
INSERT INTO "languageNames" VALUES(13190,'es','sr','serbio');
INSERT INTO "languageNames" VALUES(13191,'es','srn','sranan tongo');
INSERT INTO "languageNames" VALUES(13192,'es','ss','suazi');
INSERT INTO "languageNames" VALUES(13193,'es','sv','sueco');
INSERT INTO "languageNames" VALUES(13194,'es','sw','suajili');
INSERT INTO "languageNames" VALUES(13195,'es','ta','tamil');
INSERT INTO "languageNames" VALUES(13196,'es','te','telugu');
INSERT INTO "languageNames" VALUES(13197,'es','tet','tetún');
INSERT INTO "languageNames" VALUES(13198,'es','tg','tayiko');
INSERT INTO "languageNames" VALUES(13199,'es','th','tailandés');
INSERT INTO "languageNames" VALUES(13200,'es','tk','turcomano');
INSERT INTO "languageNames" VALUES(13201,'es','tl','tagalo');
INSERT INTO "languageNames" VALUES(13202,'es','tr','turco');
INSERT INTO "languageNames" VALUES(13203,'es','tt','tártaro');
INSERT INTO "languageNames" VALUES(13204,'es','tyv','tuviniano');
INSERT INTO "languageNames" VALUES(13205,'es','udm','udmurt');
INSERT INTO "languageNames" VALUES(13207,'es','ug','uygur');
INSERT INTO "languageNames" VALUES(13208,'es','uk','ucraniano');
INSERT INTO "languageNames" VALUES(13209,'es','ur','urdu');
INSERT INTO "languageNames" VALUES(13210,'es','uz','uzbeko');
INSERT INTO "languageNames" VALUES(13211,'es','vi','vietnamita');
INSERT INTO "languageNames" VALUES(13212,'es','wal','wolayta');
INSERT INTO "languageNames" VALUES(13213,'es','xh','xhosa');
INSERT INTO "languageNames" VALUES(13214,'es','yi','yidis');
INSERT INTO "languageNames" VALUES(13215,'es','yo','yoruba');
INSERT INTO "languageNames" VALUES(13216,'es','zh','chino');
INSERT INTO "languageNames" VALUES(13217,'es','zu','zulú');
INSERT INTO "languageNames" VALUES(13218,'ko','af','아프리칸스어');
INSERT INTO "languageNames" VALUES(13219,'ko','alt','남부 알타이어');
INSERT INTO "languageNames" VALUES(13220,'ko','an','아라곤어');
INSERT INTO "languageNames" VALUES(13221,'ko','ar','아랍어');
INSERT INTO "languageNames" VALUES(13222,'ko','as','아삼어');
INSERT INTO "languageNames" VALUES(13223,'ko','ast','아스투리아어');
INSERT INTO "languageNames" VALUES(13224,'ko','av','아바릭어');
INSERT INTO "languageNames" VALUES(13226,'ko','az','아제리어');
INSERT INTO "languageNames" VALUES(13227,'ko','ba','바슈키르어');
INSERT INTO "languageNames" VALUES(13228,'ko','be','벨라루스어');
INSERT INTO "languageNames" VALUES(13229,'ko','bg','불가리아어');
INSERT INTO "languageNames" VALUES(13230,'ko','bi','비슬라마어');
INSERT INTO "languageNames" VALUES(13231,'ko','bn','벵골어');
INSERT INTO "languageNames" VALUES(13232,'ko','br','브르타뉴어');
INSERT INTO "languageNames" VALUES(13233,'ko','bs','보스니아어');
INSERT INTO "languageNames" VALUES(13234,'ko','bua','부리아타');
INSERT INTO "languageNames" VALUES(13235,'ko','byv','메둠바어');
INSERT INTO "languageNames" VALUES(13236,'ko','ca','카탈로니아어');
INSERT INTO "languageNames" VALUES(13237,'ko','ceb','세부아노어');
INSERT INTO "languageNames" VALUES(13238,'ko','chm','마리어');
INSERT INTO "languageNames" VALUES(13239,'ko','ckb','소라니 쿠르드어');
INSERT INTO "languageNames" VALUES(13240,'ko','co','코르시카어');
INSERT INTO "languageNames" VALUES(13241,'ko','crh','크리민 터키어; 크리민 타타르어');
INSERT INTO "languageNames" VALUES(13242,'ko','cs','체코어');
INSERT INTO "languageNames" VALUES(13243,'ko','csb','카슈비아어');
INSERT INTO "languageNames" VALUES(13244,'ko','cu','교회 슬라브어');
INSERT INTO "languageNames" VALUES(13245,'ko','cv','추바시어');
INSERT INTO "languageNames" VALUES(13246,'ko','cy','웨일스어');
INSERT INTO "languageNames" VALUES(13247,'ko','da','덴마크어');
INSERT INTO "languageNames" VALUES(13248,'ko','dar','다르그와어');
INSERT INTO "languageNames" VALUES(13249,'ko','de','독일어');
INSERT INTO "languageNames" VALUES(13250,'ko','dsb','저지 소르비아어');
INSERT INTO "languageNames" VALUES(13251,'ko','el','그리스어');
INSERT INTO "languageNames" VALUES(13252,'ko','en','영어');
INSERT INTO "languageNames" VALUES(13253,'ko','eo','에스페란토어');
INSERT INTO "languageNames" VALUES(13254,'ko','es','스페인어');
INSERT INTO "languageNames" VALUES(13255,'ko','et','에스토니아어');
INSERT INTO "languageNames" VALUES(13256,'ko','eu','바스크어');
INSERT INTO "languageNames" VALUES(13257,'ko','fa','페르시아어');
INSERT INTO "languageNames" VALUES(13258,'ko','fi','핀란드어');
INSERT INTO "languageNames" VALUES(13259,'ko','fo','페로어');
INSERT INTO "languageNames" VALUES(13260,'ko','fr','프랑스어');
INSERT INTO "languageNames" VALUES(13261,'ko','fy','서부 프리지아어');
INSERT INTO "languageNames" VALUES(13262,'ko','ga','아일랜드어');
INSERT INTO "languageNames" VALUES(13263,'ko','gag','가가우스어');
INSERT INTO "languageNames" VALUES(13264,'ko','gd','스코틀랜드 게일어');
INSERT INTO "languageNames" VALUES(13265,'ko','gl','갈리시아어');
INSERT INTO "languageNames" VALUES(13266,'ko','glk','길라키어');
INSERT INTO "languageNames" VALUES(13267,'ko','gn','과라니어');
INSERT INTO "languageNames" VALUES(13268,'ko','gu','구자라트어');
INSERT INTO "languageNames" VALUES(13269,'ko','gv','맹크스어');
INSERT INTO "languageNames" VALUES(13270,'ko','ha','하우사어');
INSERT INTO "languageNames" VALUES(13271,'ko','haw','하와이어');
INSERT INTO "languageNames" VALUES(13272,'ko','he','히브리어');
INSERT INTO "languageNames" VALUES(13273,'ko','hi','힌디어');
INSERT INTO "languageNames" VALUES(13274,'ko','hr','크로아티아어');
INSERT INTO "languageNames" VALUES(13275,'ko','hsb','고지 소르비아어');
INSERT INTO "languageNames" VALUES(13276,'ko','ht','아이티어');
INSERT INTO "languageNames" VALUES(13277,'ko','hu','헝가리어');
INSERT INTO "languageNames" VALUES(13278,'ko','hy','아르메니아어');
INSERT INTO "languageNames" VALUES(13279,'ko','ia','인터링구아');
INSERT INTO "languageNames" VALUES(13280,'ko','id','인도네시아어');
INSERT INTO "languageNames" VALUES(13281,'ko','ig','이그보어');
INSERT INTO "languageNames" VALUES(13282,'ko','is','아이슬란드어');
INSERT INTO "languageNames" VALUES(13283,'ko','it','이탈리아어');
INSERT INTO "languageNames" VALUES(13284,'ko','ka','조지아어');
INSERT INTO "languageNames" VALUES(13285,'ko','kaa','카라칼파크어');
INSERT INTO "languageNames" VALUES(13286,'ko','kk','카자흐어');
INSERT INTO "languageNames" VALUES(13287,'ko','ko','한국어');
INSERT INTO "languageNames" VALUES(13288,'ko','krc','카라챠이-발카르어');
INSERT INTO "languageNames" VALUES(13289,'ko','krl','카렐리야어');
INSERT INTO "languageNames" VALUES(13290,'ko','ks','카슈미르어');
INSERT INTO "languageNames" VALUES(13291,'ko','kum','쿠믹어');
INSERT INTO "languageNames" VALUES(13292,'ko','kv','코미어');
INSERT INTO "languageNames" VALUES(13293,'ko','ky','키르기스어');
INSERT INTO "languageNames" VALUES(13294,'ko','la','라틴어');
INSERT INTO "languageNames" VALUES(13295,'ko','lb','룩셈부르크어');
INSERT INTO "languageNames" VALUES(13296,'ko','lg','간다어');
INSERT INTO "languageNames" VALUES(13297,'ko','ln','링갈라어');
INSERT INTO "languageNames" VALUES(13298,'ko','lo','라오어');
INSERT INTO "languageNames" VALUES(13299,'ko','lt','리투아니아어');
INSERT INTO "languageNames" VALUES(13300,'ko','lv','라트비아어');
INSERT INTO "languageNames" VALUES(13301,'ko','mdf','모크샤어');
INSERT INTO "languageNames" VALUES(13302,'ko','mfe','모리스얀어');
INSERT INTO "languageNames" VALUES(13303,'ko','mk','마케도니아어');
INSERT INTO "languageNames" VALUES(13304,'ko','ml','말라얄람어');
INSERT INTO "languageNames" VALUES(13305,'ko','mr','마라티어');
INSERT INTO "languageNames" VALUES(13306,'ko','mrj','서부 마리어');
INSERT INTO "languageNames" VALUES(13307,'ko','ms','말레이어');
INSERT INTO "languageNames" VALUES(13308,'ko','mt','몰타어');
INSERT INTO "languageNames" VALUES(13309,'ko','myv','엘즈야어');
INSERT INTO "languageNames" VALUES(13310,'ko','nap','나폴리어');
INSERT INTO "languageNames" VALUES(13311,'ko','nb','노르웨이어(보크말)');
INSERT INTO "languageNames" VALUES(13312,'ko','ne','네팔어');
INSERT INTO "languageNames" VALUES(13313,'ko','nl','네덜란드어');
INSERT INTO "languageNames" VALUES(13314,'ko','nn','노르웨이어(니노르스크)');
INSERT INTO "languageNames" VALUES(13315,'ko','no','노르웨이어');
INSERT INTO "languageNames" VALUES(13316,'ko','nog','노가이어');
INSERT INTO "languageNames" VALUES(13317,'ko','oc','오크어');
INSERT INTO "languageNames" VALUES(13318,'ko','os','오세트어');
INSERT INTO "languageNames" VALUES(13319,'ko','ota','오스만 터키어');
INSERT INTO "languageNames" VALUES(13320,'ko','pa','펀잡어');
INSERT INTO "languageNames" VALUES(13321,'ko','pl','폴란드어');
INSERT INTO "languageNames" VALUES(13322,'ko','pt','포르투갈어');
INSERT INTO "languageNames" VALUES(13323,'ko','rm','로만시어');
INSERT INTO "languageNames" VALUES(13324,'ko','rn','룬디어');
INSERT INTO "languageNames" VALUES(13325,'ko','ro','루마니아어');
INSERT INTO "languageNames" VALUES(13326,'ko','ru','러시아어');
INSERT INTO "languageNames" VALUES(13327,'ko','rup','아로마니아어');
INSERT INTO "languageNames" VALUES(13328,'ko','sa','산스크리트어');
INSERT INTO "languageNames" VALUES(13329,'ko','sah','야쿠트어');
INSERT INTO "languageNames" VALUES(13330,'ko','sc','사르디니아어');
INSERT INTO "languageNames" VALUES(13331,'ko','scn','시칠리아어');
INSERT INTO "languageNames" VALUES(13332,'ko','sco','스코틀랜드어');
INSERT INTO "languageNames" VALUES(13333,'ko','sd','신디어');
INSERT INTO "languageNames" VALUES(13334,'ko','se','북부 사미어');
INSERT INTO "languageNames" VALUES(13335,'ko','sh','세르비아-크로아티아어');
INSERT INTO "languageNames" VALUES(13336,'ko','si','스리랑카어');
INSERT INTO "languageNames" VALUES(13337,'ko','sk','슬로바키아어');
INSERT INTO "languageNames" VALUES(13338,'ko','sl','슬로베니아어');
INSERT INTO "languageNames" VALUES(13339,'ko','sma','남부 사미어');
INSERT INTO "languageNames" VALUES(13340,'ko','smj','룰레 사미어');
INSERT INTO "languageNames" VALUES(13341,'ko','smn','이나리 사미어');
INSERT INTO "languageNames" VALUES(13342,'ko','sq','알바니아어');
INSERT INTO "languageNames" VALUES(13343,'ko','sr','세르비아어');
INSERT INTO "languageNames" VALUES(13344,'ko','srn','스라난 통가어');
INSERT INTO "languageNames" VALUES(13345,'ko','ss','시스와티어');
INSERT INTO "languageNames" VALUES(13346,'ko','sv','스웨덴어');
INSERT INTO "languageNames" VALUES(13347,'ko','sw','스와힐리어');
INSERT INTO "languageNames" VALUES(13348,'ko','ta','타밀어');
INSERT INTO "languageNames" VALUES(13349,'ko','te','텔루구어');
INSERT INTO "languageNames" VALUES(13350,'ko','tet','테툼어');
INSERT INTO "languageNames" VALUES(13351,'ko','tg','타지크어');
INSERT INTO "languageNames" VALUES(13352,'ko','th','태국어');
INSERT INTO "languageNames" VALUES(13353,'ko','tk','투르크멘어');
INSERT INTO "languageNames" VALUES(13354,'ko','tl','타갈로그어');
INSERT INTO "languageNames" VALUES(13355,'ko','tr','터키어');
INSERT INTO "languageNames" VALUES(13356,'ko','tt','타타르어');
INSERT INTO "languageNames" VALUES(13357,'ko','tyv','투비니안어');
INSERT INTO "languageNames" VALUES(13358,'ko','udm','우드말트어');
INSERT INTO "languageNames" VALUES(13359,'ko','ug','위구르어');
INSERT INTO "languageNames" VALUES(13360,'ko','uk','우크라이나어');
INSERT INTO "languageNames" VALUES(13361,'ko','ur','우르두어');
INSERT INTO "languageNames" VALUES(13362,'ko','uz','우즈베크어');
INSERT INTO "languageNames" VALUES(13363,'ko','vi','베트남어');
INSERT INTO "languageNames" VALUES(13364,'ko','wal','월라이타어');
INSERT INTO "languageNames" VALUES(13365,'ko','xh','코사어');
INSERT INTO "languageNames" VALUES(13366,'ko','yi','이디시어');
INSERT INTO "languageNames" VALUES(13367,'ko','yo','요루바어');
INSERT INTO "languageNames" VALUES(13368,'ko','zh','중국어');
INSERT INTO "languageNames" VALUES(13369,'ko','zu','줄루어');
INSERT INTO "languageNames" VALUES(13370,'ig','ar','Arabiikị');
INSERT INTO "languageNames" VALUES(13371,'ig','be','Belaruusu');
INSERT INTO "languageNames" VALUES(13372,'ig','bg','Bọlụgarịa');
INSERT INTO "languageNames" VALUES(13373,'ig','bn','Bengali');
INSERT INTO "languageNames" VALUES(13374,'ig','cs','Cheekị');
INSERT INTO "languageNames" VALUES(13375,'ig','de','Jamaan');
INSERT INTO "languageNames" VALUES(13376,'ig','el','Giriikị');
INSERT INTO "languageNames" VALUES(13377,'ig','en','Oyibo');
INSERT INTO "languageNames" VALUES(13378,'ig','es','Panya');
INSERT INTO "languageNames" VALUES(13379,'ig','fa','Peshan');
INSERT INTO "languageNames" VALUES(13380,'ig','fr','Fụrench');
INSERT INTO "languageNames" VALUES(13381,'ig','ha','Awụsa');
INSERT INTO "languageNames" VALUES(13382,'ig','hi','Hindi');
INSERT INTO "languageNames" VALUES(13383,'ig','hu','Magịya');
INSERT INTO "languageNames" VALUES(13384,'ig','id','Indonisia');
INSERT INTO "languageNames" VALUES(13385,'ig','ig','Igbo');
INSERT INTO "languageNames" VALUES(13386,'ig','it','Italo');
INSERT INTO "languageNames" VALUES(13387,'ig','ko','Koria');
INSERT INTO "languageNames" VALUES(13388,'ig','ms','Maleyi');
INSERT INTO "languageNames" VALUES(13389,'ig','ne','Nepali');
INSERT INTO "languageNames" VALUES(13390,'ig','nl','Dọọch');
INSERT INTO "languageNames" VALUES(13391,'ig','pa','Punjabi');
INSERT INTO "languageNames" VALUES(13392,'ig','pl','Poliishi');
INSERT INTO "languageNames" VALUES(13393,'ig','pt','Potoki');
INSERT INTO "languageNames" VALUES(13394,'ig','ro','Rumenia');
INSERT INTO "languageNames" VALUES(13395,'ig','ru','Rọshan');
INSERT INTO "languageNames" VALUES(13396,'ig','sv','Sụwidiishi');
INSERT INTO "languageNames" VALUES(13397,'ig','ta','Tamụlụ');
INSERT INTO "languageNames" VALUES(13398,'ig','th','Taị');
INSERT INTO "languageNames" VALUES(13399,'ig','tr','Tọkiishi');
INSERT INTO "languageNames" VALUES(13400,'ig','uk','Ukureenị');
INSERT INTO "languageNames" VALUES(13401,'ig','ur','Urudu');
INSERT INTO "languageNames" VALUES(13402,'ig','vi','Viyetịnaamụ');
INSERT INTO "languageNames" VALUES(13403,'ig','yo','Yoruba');
INSERT INTO "languageNames" VALUES(13404,'ig','zh','Mandarịịnị');
INSERT INTO "languageNames" VALUES(13405,'ig','zu','Zulu');
COMMIT;
