BEGIN TRANSACTION;
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aaa","Ghotuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aab","Alumu-Tesu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aac","Ari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aad","Amal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aae","Arbëreshë Albanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aaf","Aranadan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aag","Ambrak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aah","Abu' Arapesh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aai","Arifama-Miniafia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aak","Ankave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aal","Afade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aan","Anambé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aao","Algerian Saharan Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aap","Pará Arára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aaq","Eastern Abnaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aa","Afar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aas","Aasáx");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aat","Arvanitika Albanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aau","Abau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aaw","Solong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aax","Mandobo Atas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aaz","Amarasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aba","Abé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abb","Bankon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abc","Ambala Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abd","Manide");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abe","Western Abnaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abf","Abai Sungai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abg","Abaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abh","Tajiki Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abi","Abidji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abj","Aka-Bea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ab","Abkhazian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abl","Lampung Nyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abm","Abanyom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abn","Abua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abo","Abon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abp","Abellen Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abq","Abaza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abr","Abron");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abs","Ambonese Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abt","Ambulas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abu","Abure");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abv","Baharna Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abw","Pal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abx","Inabaknon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aby","Aneme Wake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","abz","Abui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aca","Achagua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acb","Áncá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acd","Gikyode");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ace","Achinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acf","Saint Lucian Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ach","Acoli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aci","Aka-Cari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ack","Aka-Kora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acl","Akar-Bale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acm","Mesopotamian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acn","Achang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acp","Eastern Acipa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acq","Ta'izzi-Adeni Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acr","Achi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acs","Acroá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","act","Achterhoeks");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acu","Achuar-Shiwiar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acv","Achumawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acw","Hijazi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acx","Omani Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acy","Cypriot Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","acz","Acheron");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ada","Adangme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adb","Adabe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","add","Dzodinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ade","Adele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adf","Dhofari Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adg","Andegerebinha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adh","Adhola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adi","Adi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adj","Adioukrou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adl","Galo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adn","Adang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ado","Abu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adq","Adangbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adr","Adonara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ads","Adamorobe Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adt","Adnyamathanha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adu","Aduge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adw","Amundava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adx","Amdo Tibetan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ady","Adyghe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","adz","Adzera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aea","Areba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aeb","Tunisian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aec","Saidi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aed","Argentine Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aee","Northeast Pashai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aek","Haeke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ael","Ambele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aem","Arem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aen","Armenian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aeq","Aer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aer","Eastern Arrernte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aes","Alsea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aeu","Akeu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aew","Ambakich");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aey","Amele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aez","Aeka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afb","Gulf Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afd","Andai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afe","Putukwam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afg","Afghan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afh","Afrihili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afi","Akrukay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afk","Nanubae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afn","Defaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afo","Eloyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afp","Tapei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","af","Afrikaans");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afs","Afro-Seminole Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aft","Afitti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afu","Awutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","afz","Obokuitai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aga","Aguano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agb","Legbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agc","Agatu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agd","Agarabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","age","Angal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agf","Arguni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agg","Angor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agh","Ngelima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agi","Agariya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agj","Argobba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agk","Isarog Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agl","Fembe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agm","Angaataha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agn","Agutaynen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ago","Tainae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agq","Aghem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agr","Aguaruna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ags","Esimbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agt","Central Cagayan Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agu","Aguacateco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agv","Remontado Dumagat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agw","Kahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agx","Aghul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agy","Southern Alta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","agz","Mt. Iriga Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aha","Ahanta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahb","Axamb");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahg","Qimant");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahh","Aghu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahi","Tiagbamrin Aizi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahk","Akha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahl","Igo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahm","Mobumrin Aizi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahn","Àhàn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aho","Ahom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahp","Aproumu Aizi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahr","Ahirani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ahs","Ashe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aht","Ahtena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aia","Arosi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aib","Ainu (China)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aic","Ainbai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aid","Alngith");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aie","Amara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aif","Agi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aig","Antigua and Barbuda Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aih","Ai-Cham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aii","Assyrian Neo-Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aij","Lishanid Noshan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aik","Ake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ail","Aimele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aim","Aimol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ain","Ainu (Japan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aio","Aiton");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aip","Burumakok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aiq","Aimaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","air","Airoran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ais","Nataoran Amis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ait","Arikem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aiw","Aari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aix","Aighon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aiy","Ali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aja","Aja (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajg","Aja (Benin)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aji","Ajië");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajn","Andajin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajp","South Levantine Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajt","Judeo-Tunisian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aju","Judeo-Moroccan Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajw","Ajawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ajz","Amri Karbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ak","Akan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akb","Batak Angkola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akc","Mpur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akd","Ukpet-Ehom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ake","Akawaio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akf","Akpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akg","Anakalangu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akh","Angal Heneng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aki","Aiome");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akj","Aka-Jeru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akk","Akkadian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akl","Aklanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akm","Aka-Bo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ako","Akurio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akp","Siwu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akq","Ak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akr","Araki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aks","Akaselem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akt","Akolet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aku","Akum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akv","Akhvakh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akw","Akwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akx","Aka-Kede");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aky","Aka-Kol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","akz","Alabama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ala","Alago");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alc","Qawasqar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ald","Alladian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ale","Aleut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alf","Alege");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alh","Alawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ali","Amaimon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alj","Alangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alk","Alak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","all","Allar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alm","Amblong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aln","Gheg Albanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alo","Larike-Wakasihu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alp","Alune");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alq","Algonquin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alr","Alutor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","als","Tosk Albanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alt","Southern Altai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alu","'Are'are");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alw","Alaba-K’abeena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alx","Amol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aly","Alyawarr");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","alz","Alur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ama","Amanayé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amb","Ambo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amc","Amahuaca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ame","Yanesha'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amf","Hamer-Banna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amg","Amurdak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","am","Amharic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ami","Amis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amj","Amdang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amk","Ambai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aml","War-Jaintia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amm","Ama (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amn","Amanab");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amo","Amo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amp","Alamblak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amq","Amahai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amr","Amarakaeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ams","Southern Amami-Oshima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amt","Amto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amu","Guerrero Amuzgo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amv","Ambelau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amw","Western Neo-Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amx","Anmatyerre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amy","Ami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","amz","Atampaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ana","Andaqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anb","Andoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anc","Ngas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","and","Ansus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ane","Xârâcùù");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anf","Animere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ang","Old English (ca. 450-1100)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anh","Nend");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ani","Andi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anj","Anor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ank","Goemai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anl","Anu-Hkongso Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anm","Anal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ann","Obolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ano","Andoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anp","Angika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anq","Jarawa (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anr","Andh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ans","Anserma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ant","Antakarinya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anu","Anuak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anv","Denya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anw","Anaang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anx","Andra-Hus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","any","Anyin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","anz","Anem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoa","Angolar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aob","Abom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoc","Pemon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aod","Andarum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoe","Angal Enen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aof","Bragat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aog","Angoram");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoh","Arma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoi","Anindilyakwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoj","Mufian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aok","Arhö");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aol","Alor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aom","Ömie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aon","Bumbita Arapesh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aor","Aore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aos","Taikat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aot","Atong (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aou","A'ou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aox","Atorada");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aoz","Uab Meto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apb","Sa'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apc","North Levantine Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apd","Sudanese Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ape","Bukiyip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apf","Pahanan Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apg","Ampanang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aph","Athpariya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","api","Apiaká");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apj","Jicarilla Apache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apk","Kiowa Apache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apl","Lipan Apache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apm","Mescalero-Chiricahua Apache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apn","Apinayé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apo","Ambul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","app","Apma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apq","A-Pucikwar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apr","Arop-Lokep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aps","Arop-Sissano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apt","Apatani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apu","Apurinã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apv","Alapmunte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apw","Western Apache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apx","Aputai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apy","Apalaí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","apz","Safeyoka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqc","Archi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqd","Ampari Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqg","Arigidi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqm","Atohwaim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqn","Northern Alta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqp","Atakapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqr","Arhâ");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqt","Angaité");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aqz","Akuntsu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ar","Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arb","Standard Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arc","Official Aramaic (700-300 BCE)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ard","Arabana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","are","Western Arrarnta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","an","Aragonese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arh","Arhuaco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ari","Arikara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arj","Arapaso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ark","Arikapú");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arl","Arabela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arn","Mapudungun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aro","Araona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arp","Arapaho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arq","Algerian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arr","Karo (Brazil)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ars","Najdi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aru","Aruá (Amazonas State)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arv","Arbore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arw","Arawak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arx","Aruá (Rodonia State)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ary","Moroccan Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","arz","Egyptian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asa","Asu (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asb","Assiniboine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asc","Casuarina Coast Asmat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asd","Asas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ase","American Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asf","Australian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asg","Cishingini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ash","Abishira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asi","Buruwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asj","Sari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ask","Ashkun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asl","Asilulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","as","Assamese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asn","Xingú Asuriní");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aso","Dano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asp","Algerian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asq","Austrian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asr","Asuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ass","Ipulo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ast","Asturian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asu","Tocantins Asurini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asv","Asoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asw","Australian Aborigines Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asx","Muratayak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asy","Yaosakor Asmat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","asz","As");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ata","Pele-Ata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atb","Zaiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atc","Atsahuaca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atd","Ata Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ate","Atemble");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atg","Ivbie North-Okpela-Arhe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ati","Attié");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atj","Atikamekw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atk","Ati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atl","Mt. Iraya Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atm","Ata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atn","Ashtiani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ato","Atong (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atp","Pudtol Atta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atq","Aralle-Tabulahan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atr","Waimiri-Atroari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ats","Gros Ventre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","att","Pamplona Atta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atu","Reel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atv","Northern Altai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atw","Atsugewi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atx","Arutani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aty","Aneityum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","atz","Arta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aua","Asumboa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aub","Alugu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auc","Waorani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aud","Anuta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aug","Aguna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auh","Aushi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aui","Anuki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auj","Awjilah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auk","Heyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aul","Aulua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aum","Asu (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aun","Molmo One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auo","Auyokawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aup","Makayam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auq","Anus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aur","Aruek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aut","Austral");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auu","Auye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auw","Awyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aux","Aurá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auy","Awiyaana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","auz","Uzbeki Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","av","Avaric");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avb","Avau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avd","Alviri-Vidari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ae","Avestan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avi","Avikam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avk","Kotava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avl","Eastern Egyptian Bedawi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avm","Angkamuthi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avn","Avatime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avo","Agavotaguerra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avs","Aushiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avt","Au");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avu","Avokaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","avv","Avá-Canoeiro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awa","Awadhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awb","Awa (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awc","Cicipu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awe","Awetí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awg","Anguthimri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awh","Awbono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awi","Aekyom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awk","Awabakal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awm","Arawum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awn","Awngi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awo","Awak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awr","Awera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aws","South Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awt","Araweté");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awu","Central Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awv","Jair Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aww","Awun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awx","Awara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","awy","Edera Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axb","Abipon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axe","Ayerrerenge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axg","Mato Grosso Arára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axk","Yaka (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axl","Lower Southern Aranda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axm","Middle Armenian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","axx","Xârâgurè");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aya","Awar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayb","Ayizo Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayc","Southern Aymara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayd","Ayabadhu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aye","Ayere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayg","Ginyanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayh","Hadrami Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayi","Leyigha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayk","Akuku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayl","Libyan Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ay","Aymara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayn","Sanaani Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayo","Ayoreo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayp","North Mesopotamian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayq","Ayi (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayr","Central Aymara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ays","Sorsogon Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayt","Magbukun Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayu","Ayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayy","Tayabas Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ayz","Mai Brat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","aza","Azha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azb","South Azerbaijani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azd","Eastern Durango Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","az","Azerbaijani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azg","San Pedro Amuzgos Amuzgo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azj","North Azerbaijani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azm","Ipalapa Amuzgo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azn","Western Durango Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azo","Awing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azt","Faire Atta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","azz","Highland Puebla Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","baa","Babatana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bab","Bainouk-Gunyuño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bac","Badui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bae","Baré");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","baf","Nubaca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bag","Tuki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bah","Bahamas Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","baj","Barakai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ba","Bashkir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bal","Baluchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bm","Bambara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ban","Balinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bao","Waimaha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bap","Bantawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bar","Bavarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bas","Basa (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bau","Bada (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bav","Vengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","baw","Bambili-Bambui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bax","Bamun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bay","Batuley");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bba","Baatonum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbb","Barai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbc","Batak Toba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbd","Bau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbe","Bangba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbf","Baibai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbg","Barama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbh","Bugan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbi","Barombi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbj","Ghomálá'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbk","Babanki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbl","Bats");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbm","Babango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbn","Uneapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbo","Northern Bobo Madaré");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbp","West Central Banda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbq","Bamali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbr","Girawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbs","Bakpinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbt","Mburku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbu","Kulung (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbv","Karnai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbw","Baba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbx","Bubia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bby","Befang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bbz","Babalia Creole Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bca","Central Bai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcb","Bainouk-Samik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcc","Southern Balochi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcd","North Babar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bce","Bamenyam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcf","Bamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcg","Baga Pokur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bch","Bariai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bci","Baoulé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcj","Bardi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bck","Bunaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcl","Central Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcm","Bannoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcn","Bali (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bco","Kaluli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcp","Bali (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcq","Bench");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcr","Babine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcs","Kohumono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bct","Bendi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcu","Awad Bing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcv","Shoo-Minda-Nye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcw","Bana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcy","Bacama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bcz","Bainouk-Gunyaamolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bda","Bayot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdb","Basap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdc","Emberá-Baudó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdd","Bunama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bde","Bade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdf","Biage");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdg","Bonggi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdh","Baka (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdi","Burun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdj","Bai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdk","Budukh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdl","Indonesian Bajau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdm","Buduma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdn","Baldemu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdo","Morom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdp","Bende");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdq","Bahnar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdr","West Coast Bajau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bds","Burunge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdt","Bokoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdu","Oroko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdv","Bodo Parja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdw","Baham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdx","Budong-Budong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdy","Bandjalang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bdz","Badeshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bea","Beaver");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beb","Bebele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bec","Iceve-Maci");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bed","Bedoanas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bee","Byangsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bef","Benabena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beg","Belait");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beh","Biali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bei","Bekati'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bej","Beja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bek","Bebeli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","be","Belarusian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bem","Bemba (Zambia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bn","Bengali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beo","Beami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bep","Besoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beq","Beembe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bes","Besme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bet","Guiberoua Béte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","beu","Blagar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bev","Daloa Bété");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bew","Betawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bex","Jur Modo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bey","Beli (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bez","Bena (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfa","Bari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfb","Pauri Bareli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfc","Panyi Bai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfd","Bafut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfe","Betaf");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bff","Bofi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfg","Busang Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfh","Blafe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfi","British Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfj","Bafanji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfk","Ban Khor Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfl","Banda-Ndélé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfm","Mmen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfn","Bunak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfo","Malba Birifor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfp","Beba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfq","Badaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfr","Bazigar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfs","Southern Bai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bft","Balti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfu","Gahri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfw","Bondo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfx","Bantayanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfy","Bagheli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bfz","Mahasu Pahari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bga","Gwamhi-Wuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgb","Bobongko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgc","Haryanvi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgd","Rathwi Bareli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bge","Bauria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgf","Bangandu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgg","Bugun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgi","Giangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgj","Bangolan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgk","Bit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgl","Bo (Laos)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgn","Western Balochi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgo","Baga Koga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgp","Eastern Balochi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgq","Bagri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgr","Bawm Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgs","Tagabawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgt","Bughotu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgu","Mbongno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgv","Warkay-Bipim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgw","Bhatri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgx","Balkan Gagauz Turkish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgy","Benggoi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bgz","Banggai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bha","Bharia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhb","Bhili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhc","Biga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhd","Bhadrawahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhe","Bhaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhf","Odiai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhg","Binandere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhh","Bukharic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhi","Bhilali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhj","Bahing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhl","Bimin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhm","Bathari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhn","Bohtan Neo-Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bho","Bhojpuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhp","Bima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhq","Tukang Besi South");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhr","Bara Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhs","Buwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bht","Bhattiyali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhu","Bhunjia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhv","Bahau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhw","Biak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhx","Bhalay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhy","Bhele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bhz","Bada (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bia","Badimaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bib","Bissa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bic","Bikaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bid","Bidiyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bie","Bepour");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bif","Biafada");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","big","Biangai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bij","Vaghat-Ya-Bijim-Legeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bik","Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bil","Bile");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bim","Bimoba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bin","Bini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bio","Nai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bip","Bila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biq","Bipi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bir","Bisorio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bi","Bislama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bit","Berinomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biu","Biete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biv","Southern Birifor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biw","Kol (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bix","Bijori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biy","Birhor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","biz","Baloi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bja","Budza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjb","Banggarla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjc","Bariji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bje","Biao-Jiao Mien");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjf","Barzani Jewish Neo-Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjg","Bidyogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjh","Bahinemo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bji","Burji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjj","Kanauji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjk","Barok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjl","Bulu (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjm","Bajelani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjn","Banjar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjo","Mid-Southern Banda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjp","Fanamaket");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjr","Binumarien");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjs","Bajan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjt","Balanta-Ganja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bju","Busuu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjv","Bedjond");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjw","Bakwé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjx","Banao Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjy","Bayali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bjz","Baruga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bka","Kyak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkc","Baka (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkd","Binukid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkf","Beeke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkg","Buraka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkh","Bakoko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bki","Baki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkj","Pande");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkk","Brokskat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkl","Berik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkm","Kom (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkn","Bukitan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bko","Kwa'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkp","Boko (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkq","Bakairí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkr","Bakumpai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bks","Northern Sorsoganon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkt","Boloki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bku","Buhid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkv","Bekwarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkw","Bekwel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkx","Baikeno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bky","Bokyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bkz","Bungku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bla","Siksika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blb","Bilua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blc","Bella Coola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bld","Bolango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ble","Balanta-Kentohe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blf","Buol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blg","Balau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blh","Kuwaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bli","Bolia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blj","Bolongan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blk","Pa'o Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bll","Biloxi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blm","Beli (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bln","Southern Catanduanes Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blo","Anii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blp","Blablanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blq","Baluan-Pam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blr","Blang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bls","Balaesang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blt","Tai Dam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blv","Kibala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blw","Balangao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blx","Mag-Indi Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bly","Notre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","blz","Balantak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bma","Lame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmb","Bembe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmc","Biem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmd","Baga Manduri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bme","Limassa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmf","Bom-Kim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmg","Bamwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmh","Kein");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmi","Bagirmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmj","Bote-Majhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmk","Ghayavi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bml","Bomboli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmm","Northern Betsimisaraka Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmn","Bina (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmo","Bambalang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmp","Bulgebi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmq","Bomu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmr","Muinane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bms","Bilma Kanuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmt","Biao Mon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmu","Somba-Siawari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmv","Bum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmw","Bomwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmx","Baimak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bmz","Baramu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bna","Bonerate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnb","Bookan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnc","Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnd","Banda (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bne","Bintauna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnf","Masiwang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bng","Benga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bni","Bangi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnj","Eastern Tawbuid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnk","Bierebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnl","Boon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnm","Batanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnn","Bunun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bno","Bantoanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnp","Bola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnq","Bantik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnr","Butmas-Tur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bns","Bundeli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnu","Bentong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnv","Bonerif");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnw","Bisis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnx","Bangubangu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bny","Bintulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bnz","Beezen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boa","Bora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bob","Aweer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bo","Tibetan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boe","Mundabli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bof","Bolon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bog","Bamako Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boh","Boma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boi","Barbareño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boj","Anjam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bok","Bonjo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bol","Bole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bom","Berom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bon","Bine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boo","Tiemacèwè Bozo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bop","Bonkiman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boq","Bogaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bor","Borôro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bs","Bosnian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bot","Bongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bou","Bondei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bov","Tuwuli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bow","Rema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","box","Buamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boy","Bodo (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","boz","Tiéyaxo Bozo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpa","Daakaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpb","Barbacoas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpd","Banda-Banda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpg","Bonggo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bph","Botlikh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpi","Bagupi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpj","Binji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpk","Orowe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpl","Broome Pearling Lugger Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpm","Biyom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpn","Dzao Min");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpo","Anasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpp","Kaure");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpq","Banda Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpr","Koronadal Blaan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bps","Sarangani Blaan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpt","Barrow Point");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpu","Bongu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpv","Bian Marind");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpw","Bo (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpx","Palya Bareli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpy","Bishnupriya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bpz","Bilba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqa","Tchumbuli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqb","Bagusa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqc","Boko (Benin)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqd","Bung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqf","Baga Kaloum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqg","Bago-Kusuntu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqh","Baima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqi","Bakhtiari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqj","Bandial");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqk","Banda-Mbrès");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bql","Bilakura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqm","Wumboko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqn","Bulgarian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqo","Balo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqp","Busa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqq","Biritai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqr","Burusu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqs","Bosngun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqt","Bamukumbit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqu","Boguru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqv","Koro Wachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqw","Buru (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqx","Baangi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqy","Bengkala Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bqz","Bakaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bra","Braj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brb","Lave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brc","Berbice Creole Dutch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brd","Baraamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","br","Breton");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brf","Bera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brg","Baure");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brh","Brahui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bri","Mokpwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brj","Bieria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brk","Birked");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brl","Birwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brm","Barambu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brn","Boruca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bro","Brokkat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brp","Barapasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brq","Breri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brr","Birao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brs","Baras");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brt","Bitare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bru","Eastern Bru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brv","Western Bru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brw","Bellari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brx","Bodo (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bry","Burui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","brz","Bilbil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsa","Abinomn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsb","Brunei Bisaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsc","Bassari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bse","Wushi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsf","Bauchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsg","Bashkardi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsh","Kati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsi","Bassossi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsj","Bangwinji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsk","Burushaski");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsl","Basa-Gumna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsm","Busami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsn","Barasana-Eduria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bso","Buso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsp","Baga Sitemu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsq","Bassa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsr","Bassa-Kontagora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bss","Akoose");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bst","Basketo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsu","Bahonsuai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsv","Baga Sobané");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsw","Baiso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsx","Yangkam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bsy","Sabah Bisaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bta","Bata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btc","Bati (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btd","Batak Dairi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bte","Gamo-Ningi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btf","Birgit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btg","Gagnoa Bété");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bth","Biatah Bidayuh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bti","Burate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btj","Bacanese Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btm","Batak Mandailing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btn","Ratagnon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bto","Rinconada Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btp","Budibud");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btq","Batek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btr","Baetora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bts","Batak Simalungun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btt","Bete-Bendi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btu","Batu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btv","Bateri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btw","Butuanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btx","Batak Karo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bty","Bobot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","btz","Batak Alas-Kluet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bua","Buriat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bub","Bua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buc","Bushi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bud","Ntcham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bue","Beothuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buf","Bushoong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bug","Buginese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buh","Younuo Bunu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bui","Bongili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buj","Basa-Gurmana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buk","Bugawac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bg","Bulgarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bum","Bulu (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bun","Sherbro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buo","Terei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bup","Busoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buq","Brem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bus","Bokobaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","but","Bungain");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buu","Budu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buv","Bun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buw","Bubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bux","Boghom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buy","Bullom So");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","buz","Bukwen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bva","Barein");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvb","Bube");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvc","Baelelea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvd","Baeggu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bve","Berau Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvf","Boor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvg","Bonkeng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvh","Bure");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvi","Belanda Viri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvj","Baan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvk","Bukat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvl","Bolivian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvm","Bamunka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvn","Buna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvo","Bolgo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvp","Bumang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvq","Birri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvr","Burarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvt","Bati (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvu","Bukit Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvv","Baniva");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvw","Boga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvx","Dibole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvy","Baybayanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bvz","Bauzi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwa","Bwatoo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwb","Namosi-Naitasiri-Serua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwc","Bwile");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwd","Bwaidoka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwe","Bwe Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwf","Boselewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwg","Barwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwh","Bishuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwi","Baniwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwj","Láá Láá Bwamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwk","Bauwaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwl","Bwela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwm","Biwat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwn","Wunai Bunu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwo","Boro (Ethiopia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwp","Mandobo Bawah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwq","Southern Bobo Madaré");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwr","Bura-Pabir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bws","Bomboma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwt","Bafaw-Balong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwu","Buli (Ghana)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bww","Bwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwx","Bu-Nao Bunu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwy","Cwi Bwamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bwz","Bwisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxa","Tairaha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxb","Belanda Bor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxc","Molengue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxd","Pela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxe","Birale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxf","Bilur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxg","Bangala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxh","Buhutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxi","Pirlatapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxj","Bayungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxk","Bukusu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxl","Jalkunan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxm","Mongolia Buriat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxn","Burduna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxo","Barikanchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxp","Bebil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxq","Beele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxr","Russia Buriat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxs","Busam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxu","China Buriat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxv","Berakou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxw","Bankagooma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bxz","Binahari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bya","Batak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byb","Bikya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byc","Ubaghara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byd","Benyadu'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bye","Pouye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byf","Bete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byg","Baygo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byh","Bhujel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byi","Buyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byj","Bina (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byk","Biao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byl","Bayono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bym","Bidyara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byn","Bilin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byo","Biyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byp","Bumaji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byq","Basay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byr","Baruya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bys","Burak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byt","Berti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byv","Medumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byw","Belhariya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byx","Qaqet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","byz","Banaro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bza","Bandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzb","Andio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzc","Southern Betsimisaraka Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzd","Bribri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bze","Jenaama Bozo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzf","Boikin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzg","Babuza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzh","Mapos Buang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzi","Bisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzj","Belize Kriol English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzk","Nicaragua Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzl","Boano (Sulawesi)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzm","Bolondo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzn","Boano (Maluku)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzo","Bozaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzp","Kemberano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzq","Buli (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzr","Biri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzs","Brazilian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzt","Brithenig");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzu","Burmeso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzv","Naami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzw","Basa (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzx","Kɛlɛngaxo Bozo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzy","Obanliku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","bzz","Evant");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caa","Chortí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cab","Garifuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cac","Chuj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cad","Caddo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cae","Lehar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caf","Southern Carrier");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cag","Nivaclé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cah","Cahuarano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caj","Chané");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cak","Kaqchikel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cal","Carolinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cam","Cemuhî");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","can","Chambri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cao","Chácobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cap","Chipaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caq","Car Nicobarese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","car","Galibi Carib");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cas","Tsimané");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ca","Catalan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cav","Cavineña");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caw","Callawalla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cax","Chiquitano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cay","Cayuga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","caz","Canichana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbb","Cabiyarí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbc","Carapana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbd","Carijona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbg","Chimila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbi","Chachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbj","Ede Cabe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbk","Chavacano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbl","Bualkhaw Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbn","Nyahkur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbo","Izora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbq","Tsucuba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbr","Cashibo-Cacataibo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbs","Cashinahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbt","Chayahuita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbu","Candoshi-Shapra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbv","Cacua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cbw","Kinabalian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cby","Carabayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cca","Cauca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccc","Chamicuro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccd","Cafundo Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cce","Chopi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccg","Samba Daka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cch","Atsam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccj","Kasanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccl","Cutchi-Swahili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccm","Malaccan Creole Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cco","Comaltepec Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccp","Chakma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ccr","Cacaopera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cda","Choni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cde","Chenchu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdf","Chiru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdg","Chamari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdh","Chambeali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdi","Chodri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdj","Churahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdm","Chepang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdn","Chaudangsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdo","Min Dong Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdr","Cinda-Regi-Tiyal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cds","Chadian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdy","Chadong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cdz","Koda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cea","Lower Chehalis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ceb","Cebuano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ceg","Chamacoco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cek","Eastern Khumi Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cen","Cen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cs","Czech");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cet","Centúúm");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cfa","Dijim-Bwilim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cfd","Cara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cfg","Como Karim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cfm","Falam Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cga","Changriwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cgc","Kagayanen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cgg","Chiga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cgk","Chocangacakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ch","Chamorro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chb","Chibcha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chc","Catawba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chd","Highland Oaxaca Chontal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ce","Chechen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chf","Tabasco Chontal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chg","Chagatai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chh","Chinook");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chj","Ojitlán Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chk","Chuukese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chl","Cahuilla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chm","Mari (Russia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chn","Chinook jargon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cho","Choctaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chp","Chipewyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chq","Quiotepec Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chr","Cherokee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cht","Cholón");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cu","Church Slavic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cv","Chuvash");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chw","Chuwabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chx","Chantyal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chy","Cheyenne");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","chz","Ozumacín Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cia","Cia-Cia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cib","Ci Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cic","Chickasaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cid","Chimariko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cie","Cineni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cih","Chinali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cik","Chitkuli Kinnauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cim","Cimbrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cin","Cinta Larga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cip","Chiapanec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cir","Tiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ciw","Chippewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ciy","Chaima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cja","Western Cham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cje","Chru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjh","Upper Chehalis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cji","Chamalal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjk","Chokwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjm","Eastern Cham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjn","Chenapian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjo","Ashéninka Pajonal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjp","Cabécar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjs","Shor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjv","Chuave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cjy","Jinyu Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckb","Central Kurdish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckh","Chak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckl","Cibak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckn","Kaang Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cko","Anufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckq","Kajakse");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckr","Kairak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cks","Tayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckt","Chukot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cku","Koasati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckv","Kavalan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckx","Caka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cky","Cakfem-Mushere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ckz","Cakchiquel-Quiché Mixed Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cla","Ron");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clc","Chilcotin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cld","Chaldean Neo-Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cle","Lealao Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clh","Chilisso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cli","Chakali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clj","Laitu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clk","Idu-Mishmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cll","Chala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clm","Clallam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clo","Lowland Oaxaca Chontal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clt","Lautu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clu","Caluyanun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","clw","Chulym");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cly","Eastern Highland Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cma","Maa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cme","Cerma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmg","Classical Mongolian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmi","Emberá-Chamí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cml","Campalagian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmm","Michigamea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmn","Mandarin Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmo","Central Mnong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmr","Mro-Khimi Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cms","Messapic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cmt","Camtho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cna","Changthang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnb","Chinbon Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnc","Côông");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cng","Northern Qiang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnh","Hakha Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cni","Asháninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnk","Khumi Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnl","Lalana Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cno","Con");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cns","Central Asmat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnt","Tepetotutla Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnu","Chenoua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnw","Ngawn Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cnx","Middle Cornish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coa","Cocos Islands Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cob","Chicomuceltec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coc","Cocopa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cod","Cocama-Cocamilla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coe","Koreguaje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cof","Colorado");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cog","Chong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coh","Chonyi-Dzihana-Kauma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coj","Cochimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cok","Santa Teresa Cora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","col","Columbia-Wenatchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","com","Comanche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","con","Cofán");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coo","Comox");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cop","Coptic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coq","Coquille");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kw","Cornish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","co","Corsican");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cot","Caquinte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cou","Wamey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cov","Cao Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cow","Cowlitz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cox","Nanti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","coz","Chochotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpa","Palantla Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpb","Ucayali-Yurúa Ashéninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpc","Ajyíninka Apurucayali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpg","Cappadocian Greek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpi","Chinese Pidgin English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpn","Cherepon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpo","Kpeego");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cps","Capiznon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpu","Pichis Ashéninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpx","Pu-Xian Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cpy","South Ucayali Ashéninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cqd","Chuanqiandian Cluster Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cra","Chara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crb","Island Carib");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crc","Lonwolwol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crd","Coeur d'Alene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cr","Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crf","Caramanta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crg","Michif");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crh","Crimean Tatar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cri","Sãotomense");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crj","Southern East Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crk","Plains Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crl","Northern East Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crm","Moose Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crn","El Nayar Cora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cro","Crow");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crq","Iyo'wujwa Chorote");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crr","Carolina Algonquian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crs","Seselwa Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crt","Iyojwa'ja Chorote");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crv","Chaura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crw","Chrau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crx","Carrier");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cry","Cori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","crz","Cruzeño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csa","Chiltepec Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csb","Kashubian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csc","Catalan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csd","Chiangmai Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cse","Czech Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csf","Cuba Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csg","Chilean Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csh","Asho Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csi","Coast Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csj","Songlai Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csk","Jola-Kasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csl","Chinese Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csm","Central Sierra Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csn","Colombian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cso","Sochiapam Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csq","Croatia Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csr","Costa Rican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","css","Southern Ohlone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cst","Northern Ohlone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csv","Sumtu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csw","Swampy Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csy","Siyin Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","csz","Coos");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cta","Tataltepec Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctc","Chetco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctd","Tedim Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cte","Tepinapa Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctg","Chittagonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cth","Thaiphum Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctl","Tlacoatzintepec Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctm","Chitimacha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctn","Chhintange");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cto","Emberá-Catío");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctp","Western Highland Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cts","Northern Catanduanes Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctt","Wayanad Chetti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctu","Chol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ctz","Zacatepec Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cua","Cua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cub","Cubeo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuc","Usila Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cug","Chungmboko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuh","Chuka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cui","Cuiba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuj","Mashco Piro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuk","San Blas Kuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cul","Culina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuo","Cumanagoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cup","Cupeño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuq","Cun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cur","Chhulung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cut","Teutila Cuicatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuu","Tai Ya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuv","Cuvok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cuw","Chukwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cux","Tepeuxila Cuicatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cvg","Chug");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cvn","Valle Nacional Chinantec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwa","Kabwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwb","Maindo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwd","Woods Cree");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwe","Kwere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwg","Chewong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cwt","Kuwaataay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cya","Nopala Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cyb","Cayubaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cy","Welsh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","cyo","Cuyonon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","czh","Huizhou Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","czk","Knaanic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","czn","Zenzontepec Chatino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","czo","Min Zhong Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","czt","Zotung Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","daa","Dangaléat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dac","Dambi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dad","Marik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dae","Duupa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dag","Dagbani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dah","Gwahatike");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dai","Day");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","daj","Dar Fur Daju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dak","Dakota");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dal","Dahalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dam","Damakawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","da","Danish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dao","Daai Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","daq","Dandami Maria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dar","Dargwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","das","Daho-Doo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dau","Dar Sila Daju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dav","Taita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","daw","Davawenyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dax","Dayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","daz","Dao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dba","Bangime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbb","Deno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbd","Dadiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbe","Dabe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbf","Edopi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbg","Dogul Dom Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbi","Doka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbj","Ida'an");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbl","Dyirbal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbm","Duguri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbn","Duriankere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbo","Dulbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbp","Duwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbq","Daba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbr","Dabarre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbt","Ben Tey Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbu","Bondum Dom Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbv","Dungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dbw","Bankan Tey Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dby","Dibiyaso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dcc","Deccan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dcr","Negerhollands");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dda","Dadi Dadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddd","Dongotono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dde","Doondo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddg","Fataluku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddi","West Goodenough");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddj","Jaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddn","Dendi (Benin)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddo","Dido");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddr","Dhudhuroa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dds","Donno So Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ddw","Dawera-Daweloor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dec","Dagik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ded","Dedua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dee","Dewoin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","def","Dezfuli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","deg","Degema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","deh","Dehwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dei","Demisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dek","Dek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","del","Delaware");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dem","Dem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","den","Slave (Athapascan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dep","Pidgin Delaware");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","deq","Dendi (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","der","Deori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","des","Desano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","de","German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dev","Domung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dez","Dengese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dga","Southern Dagaare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgb","Bunoge Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgc","Casiguran Dumagat Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgd","Dagaari Dioula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dge","Degenan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgg","Doga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgh","Dghwede");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgi","Northern Dagara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgk","Dagba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgl","Andaandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgn","Dagoman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgo","Dogri (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgr","Dogrib");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgs","Dogoso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgt","Ndra'ngith");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgu","Degaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgw","Daungwurrung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgx","Doghoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dgz","Daga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhd","Dhundari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhg","Dhangu-Djangu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhi","Dhimal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhl","Dhalandji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhm","Zemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhn","Dhanki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dho","Dhodia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhr","Dhargari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhs","Dhaiso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhu","Dhurga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhv","Dehu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhw","Dhanwar (Nepal)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dhx","Dhungaloo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dia","Dia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dib","South Central Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dic","Lakota Dida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","did","Didinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dif","Dieri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dig","Digo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dih","Kumiai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dii","Dimbong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dij","Dai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dik","Southwestern Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dil","Dilling");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dim","Dime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","din","Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dio","Dibo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dip","Northeastern Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","diq","Dimli (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dir","Dirim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dis","Dimasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dit","Dirari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","diu","Diriku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dv","Dhivehi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","diw","Northwestern Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dix","Dixon Reef");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","diy","Diuwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","diz","Ding");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dja","Djadjawurrung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djb","Djinba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djc","Dar Daju Daju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djd","Djamindjung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dje","Zarma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djf","Djangun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dji","Djinang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djj","Djeebbana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djk","Eastern Maroon Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djm","Jamsay Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djn","Djauan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djo","Jangkang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djr","Djambarrpuyngu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dju","Kapriman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","djw","Djawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dka","Dakpakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dkk","Dakka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dkr","Kuijau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dks","Southeastern Dinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dkx","Mazagway");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dlg","Dolgan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dlk","Dahalik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dlm","Dalmatian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dln","Darlong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dma","Duma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmb","Mombo Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmc","Gavak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmd","Madhi Madhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dme","Dugwor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmg","Upper Kinabatangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmk","Domaaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dml","Dameli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmm","Dama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmo","Kemedzung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmr","East Damar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dms","Dampelas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmu","Dubu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmv","Dumpas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmw","Mudburra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmx","Dema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dmy","Demta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dna","Upper Grand Valley Dani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnd","Daonda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dne","Ndendeule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dng","Dungan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dni","Lower Grand Valley Dani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnj","Dan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnk","Dengka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnn","Dzùùngoo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnr","Danaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnt","Mid Grand Valley Dani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnu","Danau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnv","Danu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dnw","Western Dani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dny","Dení");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doa","Dom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dob","Dobu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doc","Northern Dong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doe","Doe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dof","Domu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doh","Dong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doi","Dogri (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dok","Dondo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dol","Doso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","don","Toura (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doo","Dongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dop","Lukpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doq","Dominican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dor","Dori'o");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dos","Dogosé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dot","Dass");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dov","Dombe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dow","Doyayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dox","Bussa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doy","Dompo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","doz","Dorze");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dpp","Papar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drb","Dair");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drc","Minderico");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drd","Darmiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dre","Dolpo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drg","Rungus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dri","C'Lela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drl","Paakantyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drn","West Damar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dro","Daro-Matu Melanau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drq","Dura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drr","Dororo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drs","Gedeo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","drt","Drents");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dru","Rukai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dry","Darai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsb","Lower Sorbian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dse","Dutch Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsh","Daasanach");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsi","Disa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsl","Danish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsn","Dusner");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dso","Desiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dsq","Tadaksahak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dta","Daur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtb","Labuk-Kinabatangan Kadazan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtd","Ditidaht");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dth","Adithinngithigh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dti","Ana Tinga Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtk","Tene Kan Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtm","Tomo Kan Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtn","Daatsʼíin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dto","Tommo So Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtp","Kadazan Dusun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtr","Lotud");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dts","Toro So Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtt","Toro Tegu Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dtu","Tebul Ure Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dty","Dotyali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dua","Duala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dub","Dubli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duc","Duna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dud","Hun-Saare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","due","Umiray Dumaget Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duf","Dumbea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dug","Duruma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duh","Dungra Bhil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dui","Dumun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duk","Uyajitaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dul","Alabat Island Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dum","Middle Dutch (ca. 1050-1350)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dun","Dusun Deyah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duo","Dupaninan Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dup","Duano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duq","Dusun Malang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dur","Dii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dus","Dumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duu","Drung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duv","Duvle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duw","Dusun Witu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dux","Duungooma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duy","Dicamay Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","duz","Duli-Gey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dva","Duau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dwa","Diri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dwr","Dawro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dws","Dutton World Speedwords");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dwu","Dhuwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dww","Dawawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dwy","Dhuwaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dya","Dyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyb","Dyaberdyaber");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyd","Dyugun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyg","Villa Viciosa Agta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyi","Djimini Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dym","Yanda Dom Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyn","Dyangadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyo","Jola-Fonyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyu","Dyula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dyy","Dyaabugay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dza","Tunzu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dze","Djiwarli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dzg","Dazaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dzl","Dzalakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dzn","Dzando");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","dz","Dzongkha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eaa","Karenggapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ebg","Ebughu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ebk","Eastern Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ebo","Teke-Ebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ebr","Ebrié");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ebu","Embu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ecr","Eteocretan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ecs","Ecuadorian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ecy","Eteocypriot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eee","E");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","efa","Efai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","efe","Efe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","efi","Efik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ega","Ega");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","egl","Emilian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ego","Eggon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","egy","Egyptian (Ancient)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ehu","Ehueun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eip","Eipomek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eit","Eitiep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eiv","Askopan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eja","Ejamat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eka","Ekajuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekc","Eastern Karnic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eke","Ekit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekg","Ekari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eki","Eki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekk","Standard Estonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekl","Kol (Bangladesh)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekm","Elip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eko","Koti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekp","Ekpeye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ekr","Yace");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eky","Eastern Kayah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ele","Elepi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elh","El Hugeirat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eli","Nding");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elk","Elkei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","el","Modern Greek (1453-)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elm","Eleme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elo","El Molo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elu","Elu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","elx","Elamite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ema","Emai-Iuleha-Ora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emb","Embaloh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eme","Emerillon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emg","Eastern Meohang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emi","Mussau-Emira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emk","Eastern Maninkakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emm","Mamulique");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emn","Eman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emp","Northern Emberá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ems","Pacific Gulf Yupik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emu","Eastern Muria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emw","Emplawas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emx","Erromintxela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","emy","Epigraphic Mayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ena","Apali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enb","Markweeta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enc","En");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","end","Ende");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enf","Forest Enets");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","en","English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enh","Tundra Enets");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enl","Enlhet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enm","Middle English (1100-1500)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enn","Engenni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eno","Enggano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enq","Enga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enr","Emumu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enu","Enu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","env","Enwan (Edu State)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enw","Enwan (Akwa Ibom State)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","enx","Enxet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eot","Beti (Côte d'Ivoire)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","epi","Epie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eo","Esperanto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","era","Eravallan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","erg","Sie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","erh","Eruwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eri","Ogea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","erk","South Efate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ero","Horpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","err","Erre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ers","Ersu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ert","Eritai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","erw","Erokwanas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ese","Ese Ejja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esg","Aheri Gondi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esh","Eshtehardi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esi","North Alaskan Inupiatun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esk","Northwest Alaska Inupiatun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esl","Egypt Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esm","Esuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esn","Salvadoran Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eso","Estonian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esq","Esselen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ess","Central Siberian Yupik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","et","Estonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esu","Central Yupik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","esy","Eskayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etb","Etebi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etc","Etchemin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eth","Ethiopian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etn","Eton (Vanuatu)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eto","Eton (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etr","Edolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ets","Yekhee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ett","Etruscan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etu","Ejagham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etx","Eten");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","etz","Semimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eu","Basque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eve","Even");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","evh","Uvbie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","evn","Evenki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ee","Ewe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ewo","Ewondo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ext","Extremaduran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eya","Eyak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eyo","Keiyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eza","Ezaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","eze","Uzekwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","faa","Fasu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fab","Fa d'Ambu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fad","Wagi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","faf","Fagani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fag","Finongan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fah","Baissa Fali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fai","Faiwol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","faj","Faita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fak","Fang (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fal","South Fali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fam","Fam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fan","Fang (Equatorial Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fo","Faroese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fap","Palor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","far","Fataleka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fa","Persian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fat","Fanti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fau","Fayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fax","Fala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fay","Southwestern Fars");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","faz","Northwestern Fars");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fbl","West Albay Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fcs","Quebec Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fer","Feroge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ffi","Foia Foia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ffm","Maasina Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fgr","Fongoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fia","Nobiin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fie","Fyer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fj","Fijian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fil","Filipino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fi","Finnish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fip","Fipa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fir","Firan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fit","Tornedalen Finnish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fiw","Fiwaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fkk","Kirya-Konzəl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fkv","Kven Finnish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fla","Kalispel-Pend d'Oreille");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","flh","Foau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fli","Fali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fll","North Fali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fln","Flinders Island");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","flr","Fuliiru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fly","Flaaitaal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fmp","Fe'fe'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fmu","Far Western Muria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fnb","Fanbak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fng","Fanagalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fni","Fania");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fod","Foodo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","foi","Foi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fom","Foma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fon","Fon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","for","Fore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fos","Siraya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fpe","Fernando Po Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fqs","Fas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fr","French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frc","Cajun French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frd","Fordata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frk","Frankish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frm","Middle French (ca. 1400-1600)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fro","Old French (842-ca. 1400)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frp","Arpitan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frq","Forak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frr","Northern Frisian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frs","Eastern Frisian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","frt","Fortsenal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fy","Western Frisian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fse","Finnish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fsl","French Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fss","Finland-Swedish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fub","Adamawa Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuc","Pulaar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fud","East Futuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fue","Borgu Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuf","Pular");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuh","Western Niger Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fui","Bagirmi Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuj","Ko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ff","Fulah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fum","Fum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fun","Fulniô");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuq","Central-Eastern Niger Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fur","Friulian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fut","Futuna-Aniwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuu","Furu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuv","Nigerian Fulfulde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fuy","Fuyug");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fvr","Fur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fwa","Fwâi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","fwe","Fwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaa","Ga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gab","Gabri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gac","Mixed Great Andamanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gad","Gaddang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gae","Guarequena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaf","Gende");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gag","Gagauz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gah","Alekano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gai","Borei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaj","Gadsup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gak","Gamkonora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gal","Galolen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gam","Kandawo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gan","Gan Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gao","Gants");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gap","Gal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaq","Gata'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gar","Galeya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gas","Adiwasi Garasia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gat","Kenati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gau","Mudhili Gadaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaw","Nobonob");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gax","Borana-Arsi-Guji Oromo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gay","Gayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gaz","West Central Oromo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gba","Gbaya (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbb","Kaytetye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbd","Karadjeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbe","Niksek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbf","Gaikundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbg","Gbanziri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbh","Defi Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbi","Galela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbj","Bodo Gadaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbk","Gaddi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbl","Gamit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbm","Garhwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbn","Mo'da");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbo","Northern Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbp","Gbaya-Bossangoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbq","Gbaya-Bozoum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbr","Gbagyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbs","Gbesi Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbu","Gagadu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbv","Gbanu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbw","Gabi-Gabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbx","Eastern Xwla Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gby","Gbari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gbz","Zoroastrian Dari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcc","Mali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcd","Ganggalida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gce","Galice");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcf","Guadeloupean Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcl","Grenadian Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcn","Gaina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gcr","Guianese Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gct","Colonia Tovar German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gda","Gade Lohar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdb","Pottangi Ollar Gadaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdc","Gugu Badhun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdd","Gedaged");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gde","Gude");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdf","Guduf-Gava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdg","Ga'dang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdh","Gadjerawang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdi","Gundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdj","Gurdjar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdk","Gadang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdl","Dirasha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdm","Laal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdn","Umanakaina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdo","Ghodoberi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdq","Mehri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdr","Wipi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gds","Ghandruk Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdt","Kungardutyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdu","Gudu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gdx","Godwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gea","Geruma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","geb","Kire");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gec","Gboloo Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ged","Gade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","geg","Gengle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","geh","Hutterite German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gei","Gebe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gej","Gen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gek","Ywom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gel","ut-Ma'in");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","geq","Geme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ges","Geser-Gorom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gev","Eviya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gew","Gera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gex","Garre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gey","Enya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gez","Geez");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gfk","Patpatar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gft","Gafat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gga","Gao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggb","Gbii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggd","Gugadj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gge","Guragone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggg","Gurgula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggk","Kungarakany");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggl","Ganglau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggt","Gitua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggu","Gagu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ggw","Gogodala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gha","Ghadamès");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghc","Hiberno-Scottish Gaelic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghe","Southern Ghale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghh","Northern Ghale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghk","Geko Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghl","Ghulfan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghn","Ghanongga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gho","Ghomara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghr","Ghera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ghs","Guhu-Samane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ght","Kuke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gia","Kitja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gib","Gibanawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gic","Gail");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gid","Gidar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gie","Gaɓogbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gig","Goaria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gih","Githabul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gil","Gilbertese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gim","Gimi (Eastern Highlands)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gin","Hinukh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gip","Gimi (West New Britain)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","giq","Green Gelao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gir","Red Gelao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gis","North Giziga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","git","Gitxsan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","giu","Mulao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","giw","White Gelao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gix","Gilima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","giy","Giyug");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","giz","South Giziga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gji","Geji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gjk","Kachi Koli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gjm","Gunditjmara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gjn","Gonja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gjr","Gurindji Kriol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gju","Gujari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gka","Guya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gke","Ndai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gkn","Gokana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gko","Kok-Nar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gkp","Guinea Kpelle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gku","ǂUngkue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gd","Scottish Gaelic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glc","Bon Gula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gld","Nanai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ga","Irish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gl","Galician");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glh","Northwest Pashai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gli","Guliguli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glj","Gula Iro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glk","Gilaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gll","Garlali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glo","Galambu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glr","Glaro-Twabo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glu","Gula (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gv","Manx");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","glw","Glavda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gly","Gule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gma","Gambera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmb","Gula'alaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmd","Mághdì");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmg","Magɨyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmh","Middle High German (ca. 1050-1500)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gml","Middle Low German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmm","Gbaya-Mbodomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmn","Gimnime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmu","Gumalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmv","Gamo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmx","Magoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmy","Mycenaean Greek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gmz","Mgbolizhia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gna","Kaansa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnb","Gangte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnc","Guanche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnd","Zulgo-Gemzek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gne","Ganang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gng","Ngangam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnh","Lere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gni","Gooniyandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnk","//Gana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnl","Gangulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnm","Ginuman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnn","Gumatj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gno","Northern Gondi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnq","Gana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnr","Gureng Gureng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnt","Guntai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnu","Gnau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnw","Western Bolivian Guaraní");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gnz","Ganzi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goa","Guro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gob","Playero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goc","Gorakor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","god","Godié");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goe","Gongduk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gof","Gofa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gog","Gogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goh","Old High German (ca. 750-1050)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goi","Gobasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goj","Gowlan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gok","Gowli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gol","Gola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gom","Goan Konkani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gon","Gondi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goo","Gone Dau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gop","Yeretuar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goq","Gorap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gor","Gorontalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gos","Gronings");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","got","Gothic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gou","Gavar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gow","Gorowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gox","Gobu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goy","Goundo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","goz","Gozarkhani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gpa","Gupa-Abawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gpe","Ghanaian Pidgin English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gpn","Taiap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gqa","Ga'anda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gqi","Guiqiong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gqn","Guana (Brazil)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gqr","Gor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gqu","Qau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gra","Rajput Garasia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grb","Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grc","Ancient Greek (to 1453)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grd","Guruntum-Mbaaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grg","Madi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grh","Gbiri-Niragu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gri","Ghari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grj","Southern Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grm","Kota Marudu Talantang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gn","Guarani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gro","Groma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grq","Gorovu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grr","Taznatit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grs","Gresi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grt","Garo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gru","Kistane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grv","Central Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grw","Gweda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grx","Guriaso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gry","Barclayville Grebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","grz","Guramalum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gse","Ghanaian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsg","German Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsl","Gusilay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsm","Guatemalan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsn","Nema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gso","Southwest Gbaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsp","Wasembo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gss","Greek Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gsw","Swiss German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gta","Guató");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gtu","Aghu-Tharnggala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gua","Shiki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gub","Guajajára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guc","Wayuu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gud","Yocoboué Dida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gue","Gurinji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guf","Gupapuyngu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gug","Paraguayan Guaraní");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guh","Guahibo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gui","Eastern Bolivian Guaraní");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gu","Gujarati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guk","Gumuz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gul","Sea Island Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gum","Guambiano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gun","Mbyá Guaraní");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guo","Guayabero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gup","Gunwinggu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guq","Aché");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gur","Farefare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gus","Guinean Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gut","Maléku Jaíka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guu","Yanomamö");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guw","Gun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gux","Gourmanchéma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","guz","Gusii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gva","Guana (Paraguay)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvc","Guanano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gve","Duwet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvf","Golin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvj","Guajá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvl","Gulay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvm","Gurmana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvn","Kuku-Yalanji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvo","Gavião Do Jiparaná");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvp","Pará Gavião");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvr","Gurung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvs","Gumawana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gvy","Guyani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwa","Mbato");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwb","Gwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwc","Kalami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwd","Gawwada");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwe","Gweno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwf","Gowro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwg","Moo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwi","Gwichʼin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwj","/Gwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwm","Awngthim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwn","Gwandara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwr","Gwere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwt","Gawar-Bati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwu","Guwamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gww","Kwini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gwx","Gua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gxx","Wè Southern");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gya","Northwest Gbaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyb","Garus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyd","Kayardild");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gye","Gyem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyf","Gungabula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyg","Gbayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyi","Gyele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyl","Gayil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gym","Ngäbere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyn","Guyanese Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyr","Guarayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gyy","Gunya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gza","Ganza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gzi","Gazi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","gzn","Gane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haa","Han");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hab","Hanoi Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hac","Gurani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","had","Hatam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hae","Eastern Oromo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haf","Haiphong Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hag","Hanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hah","Hahon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hai","Haida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haj","Hajong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hak","Hakka Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hal","Halang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ham","Hewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","han","Hangaza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hao","Hakö");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hap","Hupla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haq","Ha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","har","Harari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","has","Haisla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ht","Haitian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ha","Hausa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hav","Havu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haw","Hawaiian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hax","Southern Haida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hay","Haya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","haz","Hazaragi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hba","Hamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hbb","Huba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hbn","Heiban");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hbo","Ancient Hebrew");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sh","Serbo-Croatian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hbu","Habu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hca","Andaman Creole Hindi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hch","Huichol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hdn","Northern Haida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hds","Honduras Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hdy","Hadiyya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hea","Northern Qiandong Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","he","Hebrew");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hed","Herdé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","heg","Helong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","heh","Hehe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hei","Heiltsuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hem","Hemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hz","Herero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hgm","Hai//om");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hgw","Haigwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hhi","Hoia Hoia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hhr","Kerak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hhy","Hoyahoya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hia","Lamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hib","Hibito");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hid","Hidatsa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hif","Fiji Hindi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hig","Kamwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hih","Pamosu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hii","Hinduri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hij","Hijuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hik","Seit-Kaitetu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hil","Hiligaynon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hi","Hindi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hio","Tsoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hir","Himarimã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hit","Hittite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hiw","Hiw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hix","Hixkaryána");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hji","Haji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hka","Kahe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hke","Hunde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hkk","Hunjara-Kaina Ke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hks","Hong Kong Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hla","Halia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hlb","Halbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hld","Halang Doan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hle","Hlersu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hlt","Matu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hlu","Hieroglyphic Luwian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hma","Southern Mashan Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmb","Humburi Senni Songhay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmc","Central Huishui Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmd","Large Flowery Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hme","Eastern Huishui Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmf","Hmong Don");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmg","Southwestern Guiyang Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmh","Southwestern Huishui Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmi","Northern Huishui Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmj","Ge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmk","Maek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hml","Luopohe Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmm","Central Mashan Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmn","Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ho","Hiri Motu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmp","Northern Mashan Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmq","Eastern Qiandong Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmr","Hmar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hms","Southern Qiandong Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmt","Hamtai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmu","Hamap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmv","Hmong Dô");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmw","Western Mashan Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmy","Southern Guiyang Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hmz","Hmong Shua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hna","Mina (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hnd","Southern Hindko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hne","Chhattisgarhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hnh","//Ani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hni","Hani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hnj","Hmong Njua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hnn","Hanunoo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hno","Northern Hindko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hns","Caribbean Hindustani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hnu","Hung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoa","Hoava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hob","Mari (Madang Province)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoc","Ho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hod","Holma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoe","Horom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoh","Hobyót");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoi","Holikachuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoj","Hadothi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hol","Holu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hom","Homa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoo","Holoholo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hop","Hopi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hor","Horo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hos","Ho Chi Minh City Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hot","Hote");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hov","Hovongan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","how","Honi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoy","Holiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hoz","Hozo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hpo","Hpon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hps","Hawai'i Sign Language (HSL)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hra","Hrangkhol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrc","Niwer Mil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hre","Hre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrk","Haruku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrm","Horned Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hro","Haroi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrp","Nhirrpi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrt","Hértevin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hru","Hruso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hr","Croatian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrw","Warwar Feni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrx","Hunsrik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hrz","Harzani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hsb","Upper Sorbian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hsh","Hungarian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hsl","Hausa Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hsn","Xiang Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hss","Harsusi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hti","Hoti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hto","Minica Huitoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hts","Hadza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","htu","Hitu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","htx","Middle Hittite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hub","Huambisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huc","=/Hua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hud","Huaulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hue","San Francisco Del Mar Huave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huf","Humene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hug","Huachipaeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huh","Huilliche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hui","Huli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huj","Northern Guiyang Hmong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huk","Hulung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hul","Hula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hum","Hungana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hu","Hungarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huo","Hu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hup","Hupa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huq","Tsat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hur","Halkomelem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hus","Huastec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hut","Humla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huu","Murui Huitoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huv","San Mateo Del Mar Huave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huw","Hukumina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hux","Nüpode Huitoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huy","Hulaulá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","huz","Hunzib");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hvc","Haitian Vodoun Culture Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hve","San Dionisio Del Mar Huave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hvk","Haveke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hvn","Sabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hvv","Santa María Del Mar Huave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hwa","Wané");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hwc","Hawai'i Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hwo","Hwana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hya","Hya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","hy","Armenian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iai","Iaai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ian","Iatmul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iar","Purari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iba","Iban");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibb","Ibibio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibd","Iwaidja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibe","Akpes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibg","Ibanag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibh","Bih");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibl","Ibaloi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibm","Agoi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibn","Ibino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ig","Igbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibr","Ibuoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ibu","Ibu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iby","Ibani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ica","Ede Ica");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ich","Etkywan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","icl","Icelandic Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","icr","Islander Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ida","Idakho-Isukha-Tiriki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idb","Indo-Portuguese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idc","Idon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idd","Ede Idaca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ide","Idere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idi","Idi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","io","Ido");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idr","Indri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ids","Idesa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idt","Idaté");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","idu","Idoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ifa","Amganad Ifugao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ifb","Batad Ifugao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ife","Ifè");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iff","Ifo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ifk","Tuwali Ifugao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ifm","Teke-Fuumu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ifu","Mayoyao Ifugao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ify","Keley-I Kallahan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igb","Ebira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ige","Igede");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igg","Igana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igl","Igala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igm","Kanggape");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ign","Ignaciano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igo","Isebe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igs","Interglossa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","igw","Igwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ihb","Iha Based Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ihi","Ihievbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ihp","Iha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ihw","Bidhawal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ii","Sichuan Yi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iin","Thiin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ijc","Izon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ije","Biseni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ijj","Ede Ije");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ijn","Kalabari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ijs","Southeast Ijo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ike","Eastern Canadian Inuktitut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iki","Iko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikk","Ika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikl","Ikulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iko","Olulumo-Ikom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikp","Ikpeshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikr","Ikaranggal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iks","Inuit Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikt","Inuinnaqtun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iu","Inuktitut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikv","Iku-Gora-Ankwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikw","Ikwere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikx","Ik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ikz","Ikizu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ila","Ile Ape");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilb","Ila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ie","Interlingue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilg","Garig-Ilgar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ili","Ili Turki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilk","Ilongot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilm","Iranun (Malaysia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilo","Iloko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilp","Iranun (Philippines)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ils","International Sign");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilu","Ili'uun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ilv","Ilue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ima","Mala Malasar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","imi","Anamgura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iml","Miluk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","imn","Imonda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","imo","Imbongu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","imr","Imroing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ims","Marsian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","imy","Milyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ia","Interlingua (International Auxiliary Language Association)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inb","Inga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","id","Indonesian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ing","Degexit'an");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inh","Ingush");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inj","Jungle Inga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inl","Indonesian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inm","Minaean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inn","Isinai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ino","Inoke-Yate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inp","Iñapari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ins","Indian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","int","Intha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","inz","Ineseño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ior","Inor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iou","Tuma-Irumu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iow","Iowa-Oto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ipi","Ipili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ik","Inupiaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ipo","Ipiko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iqu","Iquito");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iqw","Ikwo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ire","Iresim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","irh","Irarutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iri","Irigwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","irk","Iraqw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","irn","Irántxe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","irr","Ir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iru","Irula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","irx","Kamberau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iry","Iraya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isa","Isabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isc","Isconahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isd","Isnag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ise","Italian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isg","Irish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ish","Esan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isi","Nkem-Nkum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isk","Ishkashimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","is","Icelandic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ism","Masimasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isn","Isanzu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iso","Isoko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isr","Israeli Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ist","Istriot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","isu","Isu (Menchum Division)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","it","Italian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itb","Binongan Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itd","Southern Tidung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ite","Itene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iti","Inlaod Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itk","Judeo-Italian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itl","Itelmen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itm","Itu Mbon Uzo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ito","Itonama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itr","Iteri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","its","Isekiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itt","Maeng Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itv","Itawit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itw","Ito");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itx","Itik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ity","Moyadan Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","itz","Itzá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ium","Iu Mien");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ivb","Ibatan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ivv","Ivatan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iwk","I-Wak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iwm","Iwam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iwo","Iwur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iws","Sepik Iwam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ixc","Ixcatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ixl","Ixil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iya","Iyayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iyo","Mesaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","iyx","Yaka (Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","izh","Ingrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","izr","Izere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","izz","Izii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jaa","Jamamadí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jab","Hyam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jac","Popti'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jad","Jahanka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jae","Yabem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jaf","Jara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jah","Jah Hut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jaj","Zazao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jak","Jakun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jal","Yalahatan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jam","Jamaican Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jan","Jandai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jao","Yanyuwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jaq","Yaqay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jas","New Caledonian Javanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jat","Jakati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jau","Yaur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jv","Javanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jax","Jambi Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jay","Yan-nhangu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jaz","Jawe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbe","Judeo-Berber");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbi","Badjiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbj","Arandai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbk","Barikewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbn","Nafusi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbo","Lojban");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbr","Jofotek-Bromnya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbt","Jabutí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbu","Jukun Takum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jbw","Yawijibaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jcs","Jamaican Country Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jct","Krymchak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jda","Jad");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jdg","Jadgali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jdt","Judeo-Tat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jeb","Jebero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jee","Jerung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jeh","Jeh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jei","Yei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jek","Jeri Kuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jel","Yelmek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jen","Dza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jer","Jere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jet","Manem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jeu","Jonkor Bourmataguil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jgb","Ngbee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jge","Judeo-Georgian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jgk","Gwak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jgo","Ngomba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jhi","Jehai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jhs","Jhankot Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jia","Jina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jib","Jibu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jic","Tol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jid","Bu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jie","Jilbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jig","Djingili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jih","sTodsde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jii","Jiiddu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jil","Jilim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jim","Jimi (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jio","Jiamao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jiq","Guanyinqiao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jit","Jita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jiu","Youle Jinuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jiv","Shuar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jiy","Buyuan Jinuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jje","Jejueo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jjr","Bankal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jka","Kaera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jkm","Mobwa Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jko","Kubo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jkp","Paku Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jkr","Koro (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jku","Labir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jle","Ngile");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jls","Jamaican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jma","Dima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmb","Zumbun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmc","Machame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmd","Yamdena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmi","Jimi (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jml","Jumli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmn","Makuri Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmr","Kamara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jms","Mashi (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmw","Mouwase");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jmx","Western Juxtlahuaca Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jna","Jangshung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jnd","Jandavra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jng","Yangman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jni","Janji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jnj","Yemsa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jnl","Rawat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jns","Jaunsari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","job","Joba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jod","Wojenaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jog","Jogi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jor","Jorá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jos","Jordanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jow","Jowulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jpa","Jewish Palestinian Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ja","Japanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jpr","Judeo-Persian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jqr","Jaqaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jra","Jarai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jrb","Judeo-Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jrr","Jiru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jrt","Jorto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jru","Japrería");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jsl","Japanese Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jua","Júma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jub","Wannu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juc","Jurchen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jud","Worodougou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juh","Hõne");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jui","Ngadjuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juk","Wapan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jul","Jirel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jum","Jumjum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jun","Juang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juo","Jiba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jup","Hupdë");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jur","Jurúna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jus","Jumla Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jut","Jutish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juu","Ju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juw","Wãpha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","juy","Juray");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jvd","Javindo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jvn","Caribbean Javanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jwi","Jwira-Pepesa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jya","Jiarong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jye","Judeo-Yemeni Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","jyy","Jaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kaa","Kara-Kalpak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kab","Kabyle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kac","Kachin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kad","Adara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kae","Ketangalan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kaf","Katso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kag","Kajaman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kah","Kara (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kai","Karekare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kaj","Jju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kak","Kalanguya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kl","Kalaallisut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kam","Kamba (Kenya)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kn","Kannada");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kao","Xaasongaxango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kap","Bezhta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kaq","Capanahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ks","Kashmiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ka","Georgian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kr","Kanuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kav","Katukína");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kaw","Kawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kax","Kao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kay","Kamayurá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kk","Kazakh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kba","Kalarko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbb","Kaxuiâna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbc","Kadiwéu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbd","Kabardian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbe","Kanju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbg","Khamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbh","Camsá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbi","Kaptiau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbj","Kari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbk","Grass Koiari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbl","Kanembu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbm","Iwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbn","Kare (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbo","Keliko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbp","Kabiyè");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbq","Kamano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbr","Kafa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbs","Kande");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbt","Abadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbu","Kabutra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbv","Dera (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbw","Kaiep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbx","Ap Ma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kby","Manga Kanuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kbz","Duhwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kca","Khanty");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcb","Kawacha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcc","Lubila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcd","Ngkâlmpw Kanum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kce","Kaivi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcf","Ukaan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcg","Tyap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kch","Vono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kci","Kamantan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcj","Kobiana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kck","Kalanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcl","Kela (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcm","Gula (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcn","Nubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kco","Kinalakna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcp","Kanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcq","Kamo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcr","Katla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcs","Koenoem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kct","Kaian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcu","Kami (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcv","Kete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcw","Kabwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcx","Kachama-Ganjule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcy","Korandje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kcz","Konongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kda","Worimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdc","Kutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdd","Yankunytjatjara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kde","Makonde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdf","Mamusi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdg","Seba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdh","Tem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdi","Kumam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdj","Karamojong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdk","Numèè");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdl","Tsikimba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdm","Kagoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdn","Kunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdp","Kaningdon-Nindem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdq","Koch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdr","Karaim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdt","Kuy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdu","Kadaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdw","Koneraw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdx","Kam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdy","Keder");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kdz","Kwaja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kea","Kabuverdianu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keb","Kélé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kec","Keiga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ked","Kerewe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kee","Eastern Keres");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kef","Kpessi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keg","Tese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keh","Keak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kei","Kei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kej","Kadar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kek","Kekchí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kel","Kela (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kem","Kemak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ken","Kenyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keo","Kakwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kep","Kaikadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keq","Kamar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ker","Kera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kes","Kugbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ket","Ket");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","keu","Akebu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kev","Kanikkaran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kew","West Kewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kex","Kukna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","key","Kupia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kez","Kukele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfa","Kodava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfb","Northwestern Kolami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfc","Konda-Dora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfd","Korra Koraga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfe","Kota (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kff","Koya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfg","Kudiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfh","Kurichiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfi","Kannada Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfj","Kemiehua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfk","Kinnauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfl","Kung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfm","Khunsari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfn","Kuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfo","Koro (Côte d'Ivoire)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfp","Korwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfq","Korku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfr","Kachhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfs","Bilaspuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kft","Kanjari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfu","Katkari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfv","Kurmukar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfw","Kharam Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfx","Kullu Pahari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfy","Kumaoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kfz","Koromfé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kga","Koyaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgb","Kawe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kge","Komering");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgf","Kube");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgg","Kusunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgi","Selangor Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgj","Gamale Kham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgk","Kaiwá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgl","Kunggari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgm","Karipúna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgn","Karingani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgo","Krongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgp","Kaingang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgq","Kamoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgr","Abun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgs","Kumbainggar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgt","Somyev");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgu","Kobol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgv","Karas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgw","Karon Dori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgx","Kamaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kgy","Kyerung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kha","Khasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khb","Lü");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khc","Tukang Besi North");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khd","Bädi Kanum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khe","Korowai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khf","Khuen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khg","Khams Tibetan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khh","Kehu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khj","Kuturmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khk","Halh Mongolian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khl","Lusi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","km","Central Khmer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khn","Khandesi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kho","Khotanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khp","Kapori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khq","Koyra Chiini Songhay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khr","Kharia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khs","Kasua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kht","Khamti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khu","Nkhumbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khv","Khvarshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khw","Khowar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khx","Kanu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khy","Kele (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","khz","Keapara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kia","Kim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kib","Koalib");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kic","Kickapoo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kid","Koshin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kie","Kibet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kif","Eastern Parbate Kham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kig","Kimaama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kih","Kilmeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kii","Kitsai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kij","Kilivila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ki","Kikuyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kil","Kariya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kim","Karagas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rw","Kinyarwanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kio","Kiowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kip","Sheshi Kham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiq","Kosadle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ky","Kirghiz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kis","Kis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kit","Agob");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiu","Kirmanjki (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiv","Kimbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiw","Northeast Kiwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kix","Khiamniungan Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiy","Kirikiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kiz","Kisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kja","Mlap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjb","Q'anjob'al");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjc","Coastal Konjo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjd","Southern Kiwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kje","Kisar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjf","Khalaj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjg","Khmu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjh","Khakas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kji","Zabana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjj","Khinalugh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjk","Highland Konjo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjl","Western Parbate Kham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjm","Kháng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjn","Kunjen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjo","Harijan Kinnauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjp","Pwo Eastern Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjq","Western Keres");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjr","Kurudu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjs","East Kewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjt","Phrae Pwo Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kju","Kashaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjv","Kaikavian Literary Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjx","Ramopa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjy","Erave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kjz","Bumthangkha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kka","Kakanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkb","Kwerisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkc","Odoodee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkd","Kinuku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kke","Kakabe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkf","Kalaktang Monpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkg","Mabaka Valley Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkh","Khün");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kki","Kagulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkj","Kako");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkk","Kokota");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkl","Kosarek Yale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkm","Kiong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkn","Kon Keu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kko","Karko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkp","Gugubera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkq","Kaiku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkr","Kir-Balar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kks","Giiwo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkt","Koi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kku","Tumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkv","Kangean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkw","Teke-Kukuya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkx","Kohin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kky","Guguyimidjir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kkz","Kaska");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kla","Klamath-Modoc");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klb","Kiliwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klc","Kolbila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kld","Gamilaraay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kle","Kulung (Nepal)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klf","Kendeje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klg","Tagakaulo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klh","Weliki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kli","Kalumpang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klj","Turkic Khalaj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klk","Kono (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kll","Kagan Kalagan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klm","Migum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kln","Kalenjin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klo","Kapya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klp","Kamasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klq","Rumu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klr","Khaling");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kls","Kalasha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klt","Nukna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klu","Klao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klv","Maskelynes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klw","Tado");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klx","Koluwawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kly","Kalao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","klz","Kabola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kma","Konni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmb","Kimbundu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmc","Southern Dong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmd","Majukayang Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kme","Bakole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmf","Kare (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmg","Kâte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmh","Kalam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmi","Kami (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmj","Kumarbhag Paharia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmk","Limos Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kml","Tanudan Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmm","Kom (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmn","Awtuw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmo","Kwoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmp","Gimme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmq","Kwama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmr","Northern Kurdish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kms","Kamasau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmt","Kemtuik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmu","Kanite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmv","Karipúna Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmw","Komo (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmx","Waboda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmy","Koma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kmz","Khorasani Turkish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kna","Dera (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knb","Lubuagan Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knc","Central Kanuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knd","Konda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kne","Kankanaey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knf","Mankanya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kng","Koongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kni","Kanufi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knj","Western Kanjobal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knk","Kuranko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knl","Keninjal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knm","Kanamarí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knn","Konkani (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kno","Kono (Sierra Leone)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knp","Kwanja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knq","Kintaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knr","Kaningra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kns","Kensiu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knt","Panoan Katukína");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knu","Kono (Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knv","Tabo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knw","Kung-Ekoka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knx","Kendayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kny","Kanyok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","knz","Kalamsé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koa","Konomala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koc","Kpati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kod","Kodi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koe","Kacipo-Balesi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kof","Kubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kog","Cogui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koh","Koyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koi","Komi-Permyak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kok","Konkani (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kol","Kol (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kv","Komi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kg","Kongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koo","Konzo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kop","Waube");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koq","Kota (Gabon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ko","Korean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kos","Kosraean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kot","Lagwan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kou","Koke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kov","Kudu-Camo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kow","Kugama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koy","Koyukon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","koz","Korak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpa","Kutto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpb","Mullu Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpc","Curripaco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpd","Koba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpe","Kpelle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpf","Komba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpg","Kapingamarangi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kph","Kplang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpi","Kofei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpj","Karajá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpk","Kpan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpl","Kpala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpm","Koho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpn","Kepkiriwát");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpo","Ikposo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpq","Korupun-Sela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpr","Korafe-Yegha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kps","Tehit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpt","Karata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpu","Kafoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpv","Komi-Zyrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpw","Kobon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpx","Mountain Koiali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpy","Koryak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kpz","Kupsabiny");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqa","Mum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqb","Kovai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqc","Doromu-Koki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqd","Koy Sanjaq Surat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqe","Kalagan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqf","Kakabai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqg","Khe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqh","Kisankasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqi","Koitabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqj","Koromira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqk","Kotafon Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kql","Kyenele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqm","Khisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqn","Kaonde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqo","Eastern Krahn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqp","Kimré");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqq","Krenak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqr","Kimaragang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqs","Northern Kissi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqt","Klias River Kadazan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqu","Seroa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqv","Okolod");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqw","Kandas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqx","Mser");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqy","Koorete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kqz","Korana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kra","Kumhali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krb","Karkin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krc","Karachay-Balkar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krd","Kairui-Midiki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kre","Panará");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krf","Koro (Vanuatu)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krh","Kurama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kri","Krio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krj","Kinaray-A");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krk","Kerek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krl","Karelian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krn","Sapo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krp","Korop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krr","Krung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krs","Gbaya (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krt","Tumari Kanuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kru","Kurukh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krv","Kavet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krw","Western Krahn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krx","Karon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kry","Kryts");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","krz","Sota Kanum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksa","Shuwa-Zamani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksb","Shambala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksc","Southern Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksd","Kuanua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kse","Kuni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksf","Bafia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksg","Kusaghe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksh","Kölsch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksi","Krisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksj","Uare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksk","Kansa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksl","Kumalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksm","Kumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksn","Kasiguranin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kso","Kofa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksp","Kaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksq","Kwaami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksr","Borong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kss","Southern Kisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kst","Winyé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksu","Khamyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksv","Kusu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksw","S'gaw Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksx","Kedang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksy","Kharia Thar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ksz","Kodaku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kta","Katua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktb","Kambaata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktc","Kholok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktd","Kokata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kte","Nubri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktf","Kwami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktg","Kalkutung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kth","Karanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kti","North Muyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktj","Plapo Krumen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktk","Kaniet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktl","Koroshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktm","Kurti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktn","Karitiâna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kto","Kuot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktp","Kaduo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktq","Katabaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kts","South Muyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktt","Ketum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktu","Kituba (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktv","Eastern Katu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktw","Kato");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktx","Kaxararí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kty","Kango (Bas-Uélé District)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ktz","Ju/'hoan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kj","Kuanyama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kub","Kutep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuc","Kwinsu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kud","'Auhelawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kue","Kuman (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuf","Western Katu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kug","Kupa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuh","Kushi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kui","Kuikúro-Kalapálo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuj","Kuria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuk","Kepo'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kul","Kulere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kum","Kumyk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kun","Kunama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuo","Kumukio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kup","Kunimaipa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuq","Karipuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ku","Kurdish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kus","Kusaal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kut","Kutenai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuu","Upper Kuskokwim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuv","Kur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuw","Kpagua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kux","Kukatja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuy","Kuuku-Ya'u");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kuz","Kunza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kva","Bagvalal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvb","Kubu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvc","Kove");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvd","Kui (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kve","Kalabakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvf","Kabalai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvg","Kuni-Boazi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvh","Komodo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvi","Kwang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvj","Psikye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvk","Korean Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvl","Kayaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvm","Kendem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvn","Border Kuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvo","Dobel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvp","Kompane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvq","Geba Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvr","Kerinci");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvt","Lahta Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvu","Yinbaw Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvv","Kola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvw","Wersing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvx","Parkari Koli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvy","Yintale Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kvz","Tsakwambo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwa","Dâw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwb","Kwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwc","Likwala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwd","Kwaio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwe","Kwerba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwf","Kwara'ae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwg","Sara Kaba Deme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwh","Kowiai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwi","Awa-Cuaiquer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwj","Kwanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwk","Kwakiutl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwl","Kofyar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwm","Kwambi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwn","Kwangali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwo","Kwomtari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwp","Kodia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwr","Kwer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kws","Kwese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwt","Kwesten");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwu","Kwakum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwv","Sara Kaba Náà");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kww","Kwinti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwx","Khirwar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwy","San Salvador Kongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kwz","Kwadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxa","Kairiru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxb","Krobu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxc","Konso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxd","Brunei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxf","Manumanaw Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxh","Karo (Ethiopia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxi","Keningau Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxj","Kulfa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxk","Zayein Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxl","Nepali Kurux");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxm","Northern Khmer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxn","Kanowit-Tanjong Melanau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxo","Kanoé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxp","Wadiyara Koli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxq","Smärky Kanum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxr","Koro (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxs","Kangjia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxt","Koiwat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxu","Kui (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxv","Kuvi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxw","Konai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxx","Likuba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxy","Kayong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kxz","Kerewo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kya","Kwaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyb","Butbut Kalinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyc","Kyaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyd","Karey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kye","Krache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyf","Kouya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyg","Keyagana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyh","Karok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyi","Kiput");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyj","Karao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyk","Kamayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyl","Kalapuya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kym","Kpatili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyn","Northern Binukidnon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyo","Kelon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyp","Kang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyq","Kenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyr","Kuruáya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kys","Baram Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyt","Kayagar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyu","Western Kayah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyv","Kayort");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyw","Kudmali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyx","Rapoisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyy","Kambaira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kyz","Kayabí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kza","Western Karaboro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzb","Kaibobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzc","Bondoukou Kulango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzd","Kadai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kze","Kosena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzf","Da'a Kaili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzg","Kikai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzi","Kelabit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzk","Kazukuru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzl","Kayeli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzm","Kais");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzn","Kokola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzo","Kaningi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzp","Kaidipang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzq","Kaike");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzr","Karang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzs","Sugut Dusun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzu","Kayupulau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzv","Komyandaret");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzw","Karirí-Xocó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzx","Kamarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzy","Kango (Tshopo District)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","kzz","Kalabra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","laa","Southern Subanen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lab","Linear A");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lac","Lacandon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lad","Ladino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lae","Pattani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","laf","Lafofa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lag","Langi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lah","Lahnda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lai","Lambya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","laj","Lango (Uganda)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lak","Laka (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lal","Lalia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lam","Lamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lan","Laru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lo","Lao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lap","Laka (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","laq","Qabiao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lar","Larteh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","las","Lama (Togo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","la","Latin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lau","Laba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lv","Latvian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","law","Lauje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lax","Tiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lay","Lama Bai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","laz","Aribwatsa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lba","Lui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbb","Label");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbc","Lakkia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbe","Lak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbf","Tinani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbg","Laopang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbi","La'bi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbj","Ladakhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbk","Central Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbl","Libon Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbm","Lodhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbn","Lamet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbo","Laven");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbq","Wampar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbr","Lohorung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbs","Libyan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbt","Lachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbu","Labu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbv","Lavatbura-Lamusong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbw","Tolaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbx","Lawangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lby","Lamu-Lamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lbz","Lardil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcc","Legenyem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcd","Lola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lce","Loncong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcf","Lubu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lch","Luchazi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcl","Lisela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcm","Tungag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcp","Western Lawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcq","Luhu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lcs","Lisabata-Nuniali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lda","Kla-Dan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldb","Dũya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldd","Luri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldg","Lenyima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldh","Lamja-Dengsa-Tola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldi","Laari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldj","Lemoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldk","Leelau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldl","Kaan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldm","Landoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldn","Láadan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldo","Loo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldp","Tso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ldq","Lufu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lea","Lega-Shabunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","leb","Lala-Bisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lec","Leco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","led","Lendu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lee","Lyélé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lef","Lelemi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","leh","Lenje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lei","Lemio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lej","Lengola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lek","Leipon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lel","Lele (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lem","Nomaande");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","len","Lenca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","leo","Leti (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lep","Lepcha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","leq","Lembena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ler","Lenkau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","les","Lese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","let","Lesing-Gelimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","leu","Kara (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lev","Lamma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lew","Ledo Kaili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lex","Luang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ley","Lemolang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lez","Lezghian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lfa","Lefa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lfn","Lingua Franca Nova");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lga","Lungga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgb","Laghu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgg","Lugbara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgh","Laghuu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgi","Lengilu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgk","Lingarak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgl","Wala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgm","Lega-Mwenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgn","T'apo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgq","Logba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgr","Lengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgt","Pahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgu","Longgu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lgz","Ligenza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lha","Laha (Viet Nam)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhh","Laha (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhi","Lahu Shi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhl","Lahul Lohar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhm","Lhomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhn","Lahanan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhp","Lhokpu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhs","Mlahsö");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lht","Lo-Toga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lhu","Lahu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lia","West-Central Limba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lib","Likum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lic","Hlai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lid","Nyindrou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lie","Likila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lif","Limbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lig","Ligbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lih","Lihir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lij","Ligurian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lik","Lika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lil","Lillooet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","li","Limburgan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ln","Lingala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lio","Liki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lip","Sekpele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liq","Libido");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lir","Liberian English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lis","Lisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lt","Lithuanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liu","Logorik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liv","Liv");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liw","Col");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lix","Liabuku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liy","Banda-Bambari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","liz","Libinza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lja","Golpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lje","Rampi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lji","Laiyolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ljl","Li'o");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ljp","Lampung Api");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ljw","Yirandali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ljx","Yuru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lka","Lakalei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkb","Kabras");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkc","Kucong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkd","Lakondê");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lke","Kenyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkh","Lakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lki","Laki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkj","Remun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkl","Laeko-Libuat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkm","Kalaamaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkn","Lakon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lko","Khayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkr","Päri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lks","Kisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lkt","Lakota");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lku","Kungkari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lky","Lokoya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lla","Lala-Roba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llb","Lolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llc","Lele (Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lld","Ladin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lle","Lele (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llf","Hermit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llg","Lole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llh","Lamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lli","Teke-Laali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llj","Ladji Ladji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llk","Lelak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lll","Lilau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llm","Lasalimu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lln","Lele (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llo","Khlor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llp","North Efate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llq","Lolak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lls","Lithuanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llu","Lau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","llx","Lauan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lma","East Limba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmb","Merei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmc","Limilngan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmd","Lumun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lme","Pévé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmf","South Lembata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmg","Lamogai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmh","Lambichhong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmi","Lombi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmj","West Lembata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmk","Lamkang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lml","Hano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmn","Lambadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmo","Lombard");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmp","Limbum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmq","Lamatuka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmr","Lamalera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmu","Lamenu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmv","Lomaiviti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmw","Lake Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmx","Laimbue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmy","Lamboya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lmz","Lumbee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lna","Langbashe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnb","Mbalanhu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnd","Lundayeh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lng","Langobardic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnh","Lanoh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lni","Daantanai'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnj","Leningitij");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnl","South Central Banda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnm","Langam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnn","Lorediakarkar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lno","Lango (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lns","Lamnso'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnu","Longuda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnw","Lanima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lnz","Lonzo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loa","Loloda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lob","Lobi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loc","Inonhan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loe","Saluan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lof","Logol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","log","Logo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loh","Narim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loi","Loma (Côte d'Ivoire)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loj","Lou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lok","Loko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lol","Mongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lom","Loma (Liberia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lon","Malawi Lomwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loo","Lombo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lop","Lopa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loq","Lobala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lor","Téén");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","los","Loniu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lot","Otuho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lou","Louisiana Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lov","Lopi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","low","Tampias Lobu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lox","Loun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loy","Loke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","loz","Lozi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lpa","Lelepa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lpe","Lepki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lpn","Long Phuri Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lpo","Lipo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lpx","Lopit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lra","Rara Bakati'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrc","Northern Luri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lre","Laurentian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrg","Laragia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lri","Marachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrk","Loarki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrl","Lari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrm","Marama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrn","Lorang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lro","Laro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrr","Southern Yamphu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrt","Larantuka Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrv","Larevat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lrz","Lemerig");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsa","Lasgerdi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsd","Lishana Deni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lse","Lusengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsg","Lyons Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsh","Lish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsi","Lashi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsl","Latvian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsm","Saamia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lso","Laos Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsp","Panamanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsr","Aruop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lss","Lasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lst","Trinidad and Tobago Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lsy","Mauritian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ltc","Late Middle Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ltg","Latgalian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lth","Thur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lti","Leti (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ltn","Latundê");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lto","Tsotso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lts","Tachoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ltu","Latu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lb","Luxembourgish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lua","Luba-Lulua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lu","Luba-Katanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luc","Aringa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lud","Ludian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lue","Luvale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luf","Laua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lg","Ganda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lui","Luiseno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luj","Luna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luk","Lunanakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lul","Olu'bo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lum","Luimbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lun","Lunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luo","Luo (Kenya and Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lup","Lumbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luq","Lucumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lur","Laura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lus","Lushai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lut","Lushootseed");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luu","Lumba-Yakkha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luv","Luwati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luw","Luo (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luy","Luyia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","luz","Southern Luri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lva","Maku'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lvk","Lavukaleve");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lvs","Standard Latvian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lvu","Levuka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwa","Lwalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwe","Lewo Eleng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwg","Wanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwh","White Lachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwl","Eastern Lawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwm","Laomian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwo","Luwo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwt","Lewotobi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lwu","Lawu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lww","Lewo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lya","Layakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lyg","Lyngngam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lyn","Luyana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lzh","Literary Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lzl","Litzlitz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lzn","Leinong Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","lzz","Laz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maa","San Jerónimo Tecóatl Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mab","Yutanduchi Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mad","Madurese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mae","Bo-Rukul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maf","Mafa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mag","Magahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mh","Marshallese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mai","Maithili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maj","Jalapa De Díaz Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mak","Makasar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ml","Malayalam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mam","Mam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","man","Mandingo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maq","Chiquihuitlán Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mr","Marathi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mas","Masai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mat","San Francisco Matlatzinca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mau","Huautla Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mav","Sateré-Mawé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maw","Mampruli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","max","North Moluccan Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","maz","Central Mazahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mba","Higaonon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbb","Western Bukidnon Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbc","Macushi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbd","Dibabawon Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbe","Molale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbf","Baba Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbh","Mangseng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbi","Ilianen Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbj","Nadëb");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbk","Malol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbl","Maxakalí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbm","Ombamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbn","Macaguán");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbo","Mbo (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbp","Malayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbq","Maisin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbr","Nukak Makú");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbs","Sarangani Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbt","Matigsalug Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbu","Mbula-Bwazza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbv","Mbulungish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbw","Maring");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbx","Mari (East Sepik Province)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mby","Memoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mbz","Amoltepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mca","Maca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcb","Machiguenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcc","Bitur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcd","Sharanahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mce","Itundujia Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcf","Matsés");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcg","Mapoyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mch","Maquiritari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mci","Mese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcj","Mvanip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mck","Mbunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcl","Macaguaje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcm","Malaccan Creole Portuguese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcn","Masana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mco","Coatlán Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcp","Makaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcq","Ese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcr","Menya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcs","Mambai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mct","Mengisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcu","Cameroon Mambila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcv","Minanibai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcw","Mawa (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcx","Mpiemo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcy","South Watut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mcz","Mawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mda","Mada (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdb","Morigi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdc","Male (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdd","Mbum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mde","Maba (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdf","Moksha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdg","Massalat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdh","Maguindanaon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdi","Mamvu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdj","Mangbetu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdk","Mangbutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdl","Maltese Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdm","Mayogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdn","Mbati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdp","Mbala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdq","Mbole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdr","Mandar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mds","Maria (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdt","Mbere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdu","Mboko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdv","Santa Lucía Monteverde Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdw","Mbosi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdx","Dizin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdy","Male (Ethiopia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mdz","Suruí Do Pará");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mea","Menka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","meb","Ikobi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mec","Mara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","med","Melpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mee","Mengen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mef","Megam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","meh","Southwestern Tlaxiaco Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mei","Midob");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mej","Meyah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mek","Mekeo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mel","Central Melanau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mem","Mangala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","men","Mende (Sierra Leone)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","meo","Kedah Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mep","Miriwung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","meq","Merey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mer","Meru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mes","Masmaje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","met","Mato");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","meu","Motu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mev","Mano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mew","Maaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mey","Hassaniyya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mez","Menominee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfa","Pattani Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfb","Bangka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfc","Mba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfd","Mendankwe-Nkwen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfe","Morisyen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mff","Naki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfg","Mogofin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfh","Matal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfi","Wandala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfj","Mefele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfk","North Mofu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfl","Putai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfm","Marghi South");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfn","Cross River Mbembe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfo","Mbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfp","Makassar Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfq","Moba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfr","Marithiel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfs","Mexican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mft","Mokerang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfu","Mbwela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfv","Mandjak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfw","Mulaha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfx","Melo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfy","Mayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mfz","Mabaan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mga","Middle Irish (900-1200)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgb","Mararit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgc","Morokodo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgd","Moru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mge","Mango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgf","Maklew");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgg","Mpumpong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgh","Makhuwa-Meetto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgi","Lijili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgj","Abureni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgk","Mawes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgl","Maleu-Kilenge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgm","Mambae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgn","Mbangi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgo","Meta'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgp","Eastern Magar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgq","Malila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgr","Mambwe-Lungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgs","Manda (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgt","Mongol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgu","Mailu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgv","Matengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgw","Matumbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgy","Mbunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mgz","Mbugwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mha","Manda (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhb","Mahongwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhc","Mocho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhd","Mbugu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhe","Besisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhf","Mamaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhg","Margu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhi","Ma'di");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhj","Mogholi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhk","Mungaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhl","Mauwake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhm","Makhuwa-Moniga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhn","Mócheno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mho","Mashi (Zambia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhp","Balinese Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhq","Mandan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhr","Eastern Mari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhs","Buru (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mht","Mandahuaca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhu","Digaro-Mishmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhw","Mbukushu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhx","Maru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhy","Ma'anyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mhz","Mor (Mor Islands)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mia","Miami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mib","Atatláhuca Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mic","Mi'kmaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mid","Mandaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mie","Ocotepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mif","Mofu-Gudur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mig","San Miguel El Grande Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mih","Chayuco Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mii","Chigmecatitlán Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mij","Abar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mik","Mikasuki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mil","Peñoles Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mim","Alacatlatzala Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","min","Minangkabau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mio","Pinotepa Nacional Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mip","Apasco-Apoala Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","miq","Mískito");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mir","Isthmus Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mis","Uncoded languages");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mit","Southern Puebla Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","miu","Cacaloxtepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","miw","Akoye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mix","Mixtepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","miy","Ayutla Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","miz","Coatzospan Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjb","Makalero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjc","San Juan Colorado Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjd","Northwest Maidu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mje","Muskum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjg","Tu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjh","Mwera (Nyasa)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mji","Kim Mun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjj","Mawak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjk","Matukar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjl","Mandeali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjm","Medebur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjn","Ma (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjo","Malankuravan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjp","Malapandaram");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjq","Malaryan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjr","Malavedan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjs","Miship");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjt","Sauria Paharia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mju","Manna-Dora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjv","Mannan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjw","Karbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjx","Mahali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjy","Mahican");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mjz","Majhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mka","Mbre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkb","Mal Paharia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkc","Siliput");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mk","Macedonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mke","Mawchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkf","Miya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkg","Mak (China)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mki","Dhatki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkj","Mokilese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkk","Byep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkl","Mokole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkm","Moklen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkn","Kupang Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mko","Mingang Doso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkp","Moikodi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkq","Bay Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkr","Malas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mks","Silacayoapan Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkt","Vamale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mku","Konyanka Maninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkv","Mafea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkw","Kituba (Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkx","Kinamiging Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mky","East Makian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mkz","Makasae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mla","Malo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlb","Mbule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlc","Cao Lan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mle","Manambu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlf","Mal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mg","Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlh","Mape");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mli","Malimpung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlj","Miltu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlk","Ilwana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mll","Malua Bay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlm","Mulam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mln","Malango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlo","Mlomp");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlp","Bargam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlq","Western Maninkakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlr","Vame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mls","Masalit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mt","Maltese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlu","To'abaita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlv","Motlav");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlw","Moloko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlx","Malfaxal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mlz","Malaynon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mma","Mama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmb","Momina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmc","Michoacán Mazahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmd","Maonan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mme","Mae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmf","Mundat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmg","North Ambrym");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmh","Mehináku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmi","Musar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmj","Majhwar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmk","Mukha-Dora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mml","Man Met");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmm","Maii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmn","Mamanwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmo","Mangga Buang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmp","Siawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmq","Musak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmr","Western Xiangxi Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmt","Malalamai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmu","Mmaala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmv","Miriti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmw","Emae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmx","Madak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmy","Migaama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mmz","Mabaale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mna","Mbula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnb","Muna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnc","Manchu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnd","Mondé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mne","Naba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnf","Mundani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mng","Eastern Mnong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnh","Mono (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mni","Manipuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnj","Munji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnk","Mandinka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnl","Tiale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnm","Mapena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnn","Southern Mnong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnp","Min Bei Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnq","Minriq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnr","Mono (USA)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mns","Mansi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnu","Mer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnv","Rennell-Bellona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnw","Mon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnx","Manikion");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mny","Manyawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mnz","Moni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moa","Mwan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moc","Mocoví");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mod","Mobilian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moe","Montagnais");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mog","Mongondow");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moh","Mohawk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moi","Mboi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moj","Monzombo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mok","Morori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mom","Mangue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mn","Mongolian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moo","Monom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mop","Mopán Maya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moq","Mor (Bomberai Peninsula)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mor","Moro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mos","Mossi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mot","Barí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mou","Mogum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mov","Mohave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mow","Moi (Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mox","Molima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moy","Shekkacho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","moz","Mukulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpa","Mpoto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpb","Mullukmulluk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpc","Mangarayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpd","Machinere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpe","Majang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpg","Marba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mph","Maung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpi","Mpade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpj","Martu Wangka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpk","Mbara (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpl","Middle Watut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpm","Yosondúa Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpn","Mindiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpo","Miu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpp","Migabac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpq","Matís");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpr","Vangunu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mps","Dadibi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpt","Mian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpu","Makuráp");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpv","Mungkip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpw","Mapidian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpx","Misima-Panaeati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpy","Mapia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mpz","Mpi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqa","Maba (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqb","Mbuko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqc","Mangole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqe","Matepi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqf","Momuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqg","Kota Bangun Kutai Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqh","Tlazoyaltepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqi","Mariri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqj","Mamasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqk","Rajah Kabunsuwan Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mql","Mbelime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqm","South Marquesan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqn","Moronene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqo","Modole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqp","Manipa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqq","Minokok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqr","Mander");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqs","West Makian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqt","Mok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqu","Mandari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqv","Mosimo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqw","Murupi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqx","Mamuju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqy","Manggarai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mqz","Pano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mra","Mlabri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrb","Marino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrc","Maricopa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrd","Western Magar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mre","Martha's Vineyard Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrf","Elseng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrg","Mising");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrh","Mara Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mi","Maori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrj","Western Mari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrk","Hmwaveke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrl","Mortlockese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrm","Merlav");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrn","Cheke Holo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mro","Mru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrp","Morouas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrq","North Marquesan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrr","Maria (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrs","Maragus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrt","Marghi Central");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mru","Mono (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrv","Mangareva");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrw","Maranao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrx","Maremgi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mry","Mandaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mrz","Marind");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ms","Malay (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msb","Masbatenyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msc","Sankaran Maninka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msd","Yucatec Maya Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mse","Musey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msf","Mekwei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msg","Moraid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msh","Masikoro Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msi","Sabah Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msj","Ma (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msk","Mansaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msl","Molof");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msm","Agusan Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msn","Vurës");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mso","Mombum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msp","Maritsauá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msq","Caac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msr","Mongolian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mss","West Masela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msu","Musom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msv","Maslam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msw","Mansoanka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msx","Moresada");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msy","Aruamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","msz","Momare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mta","Cotabato Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtb","Anyin Morofo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtc","Munit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtd","Mualang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mte","Mono (Solomon Islands)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtf","Murik (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtg","Una");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mth","Munggui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mti","Maiwa (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtj","Moskona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtk","Mbe'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtl","Montol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtm","Mator");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtn","Matagalpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mto","Totontepec Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtp","Wichí Lhamtés Nocten");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtq","Muong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtr","Mewari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mts","Yora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtt","Mota");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtu","Tututepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtv","Asaro'o");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtw","Southern Binukidnon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mtx","Tidaá Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mty","Nabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mua","Mundang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mub","Mubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muc","Ajumbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mud","Mednyj Aleut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mue","Media Lengua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mug","Musgu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muh","Mündü");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mui","Musi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muj","Mabire");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muk","Mugom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mul","Multiple languages");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mum","Maiwala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muo","Nyong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mup","Malvi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muq","Eastern Xiangxi Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mur","Murle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mus","Creek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mut","Western Muria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muu","Yaaku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muv","Muthuvan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mux","Bo-Ung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muy","Muyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","muz","Mursi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mva","Manam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvb","Mattole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvd","Mamboru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mve","Marwari (Pakistan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvf","Peripheral Mongolian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvg","Yucuañe Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvh","Mulgi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvi","Miyako");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvk","Mekmek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvl","Mbara (Australia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvm","Muya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvn","Minaveha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvo","Marovo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvp","Duri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvq","Moere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvr","Marau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvs","Massep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvt","Mpotovoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvu","Marfa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvv","Tagal Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvw","Machinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvx","Meoswar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvy","Indus Kohistani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mvz","Mesqan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwa","Mwatebu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwb","Juwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwc","Are");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwe","Mwera (Chimwera)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwf","Murrinh-Patha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwg","Aiklep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwh","Mouk-Aria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwi","Labo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwk","Kita Maninkakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwl","Mirandese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwm","Sar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwn","Nyamwanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwo","Central Maewo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwp","Kala Lagaw Ya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwq","Mün Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwr","Marwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mws","Mwimbi-Muthambi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwt","Moken");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwu","Mittu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwv","Mentawai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mww","Hmong Daw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwx","Mediak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwy","Mosiro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mwz","Moingi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxa","Northwest Oaxaca Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxb","Tezoatlán Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxc","Manyika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxd","Modang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxe","Mele-Fila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxf","Malgbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxg","Mbangala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxh","Mvuba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxi","Mozarabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxj","Miju-Mishmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxk","Monumbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxl","Maxi Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxm","Meramera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxn","Moi (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxo","Mbowe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxp","Tlahuitoltepec Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxq","Juquila Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxr","Murik (Malaysia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxs","Huitepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxt","Jamiltepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxu","Mada (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxv","Metlatónoc Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxw","Namo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxx","Mahou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxy","Southeastern Nochixtlán Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mxz","Central Masela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","my","Burmese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myb","Mbay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myc","Mayeka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myd","Maramba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mye","Myene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myf","Bambassi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myg","Manta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myh","Makah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myi","Mina (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myj","Mangayat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myk","Mamara Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myl","Moma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mym","Me'en");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myo","Anfillo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myp","Pirahã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myr","Muniche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mys","Mesmes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myu","Mundurukú");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myv","Erzya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myw","Muyuw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myx","Masaaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myy","Macuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","myz","Classical Mandaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mza","Santa María Zacatepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzb","Tumzabt");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzc","Madagascar Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzd","Malimba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mze","Morawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzg","Monastic Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzh","Wichí Lhamtés Güisnay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzi","Ixcatlán Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzj","Manya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzk","Nigeria Mambila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzl","Mazatlán Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzm","Mumuye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzn","Mazanderani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzo","Matipuhy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzp","Movima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzq","Mori Atas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzr","Marúbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzs","Macanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzt","Mintil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzu","Inapang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzv","Manza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzw","Deg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzx","Mawayana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzy","Mozambican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","mzz","Maiadomu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naa","Namla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nab","Southern Nambikuára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nac","Narak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nae","Naka'ela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naf","Nabak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nag","Naga Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naj","Nalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nak","Nakanai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nal","Nalik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nam","Ngan'gityemerri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nan","Min Nan Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nao","Naaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nap","Neapolitan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naq","Khoekhoe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nar","Iguta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nas","Naasioi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nat","Ca̱hungwa̱rya̱");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","na","Nauru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nv","Navajo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naw","Nawuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nax","Nakwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nay","Narrinyeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","naz","Coatepec Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nba","Nyemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbb","Ndoe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbc","Chang Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbd","Ngbinda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbe","Konyak Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbg","Nagarchal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbh","Ngamo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbi","Mao Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbj","Ngarinman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbk","Nake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nr","South Ndebele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbm","Ngbaka Ma'bo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbn","Kuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbo","Nkukoli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbp","Nnam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbq","Nggem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbr","Numana-Nunku-Gbantu-Numbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbs","Namibian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbt","Na");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbu","Rongmei Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbv","Ngamambo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nbw","Southern Ngbandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nby","Ningera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nca","Iyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncb","Central Nicobarese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncc","Ponam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncd","Nachering");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nce","Yale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncf","Notsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncg","Nisga'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nch","Central Huasteca Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nci","Classical Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncj","Northern Puebla Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nck","Nakara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncl","Michoacán Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncm","Nambo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncn","Nauna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nco","Sibe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncp","Ndaktup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncq","Northern Katang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncr","Ncane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncs","Nicaraguan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nct","Chothe Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncu","Chumburung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncx","Central Puebla Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ncz","Natchez");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nda","Ndasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndb","Kenswei Nsei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndc","Ndau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndd","Nde-Nsele-Nta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nd","North Ndebele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndf","Nadruvian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndg","Ndengereko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndh","Ndali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndi","Samba Leko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndj","Ndamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndk","Ndaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndl","Ndolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndm","Ndam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndn","Ngundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ng","Ndonga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndp","Ndo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndq","Ndombe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndr","Ndoola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nds","Low German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndt","Ndunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndu","Dugun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndv","Ndut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndw","Ndobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndx","Nduga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndy","Lutos");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ndz","Ndogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nea","Eastern Ngad'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neb","Toura (Côte d'Ivoire)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nec","Nedebang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ned","Nde-Gbite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nee","Nêlêmwa-Nixumwak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nef","Nefamese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neg","Negidal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neh","Nyenkha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nei","Neo-Hittite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nej","Neko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nek","Neku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nem","Nemi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nen","Nengone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neo","Ná-Meo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ne","Nepali (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neq","North Central Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ner","Yahadian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nes","Bhoti Kinnauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","net","Nete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","neu","Neo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nev","Nyaheun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","new","Newari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nex","Neme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ney","Neyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nez","Nez Perce");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nfa","Dhao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nfd","Ahwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nfl","Ayiwo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nfr","Nafaanra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nfu","Mfumte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nga","Ngbaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngb","Northern Ngbandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngc","Ngombe (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngd","Ngando (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nge","Ngemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngg","Ngbaka Manza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngh","N/u");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngi","Ngizim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngj","Ngie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngk","Dalabon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngl","Lomwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngm","Ngatik Men's Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngn","Ngwo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngo","Ngoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngp","Ngulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngq","Ngurimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngr","Engdewu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngs","Gvoko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngt","Kriang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngu","Guerrero Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngv","Nagumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngw","Ngwaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngx","Nggwahyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngy","Tibea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ngz","Ngungwel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nha","Nhanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhb","Beng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhc","Tabasco Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhd","Chiripá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhe","Eastern Huasteca Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhf","Nhuwala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhg","Tetelcingo Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhh","Nahari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhi","Zacatlán-Ahuacatlán-Tepetzintla Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhk","Isthmus-Cosoleacaque Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhm","Morelos Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhn","Central Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nho","Takuu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhp","Isthmus-Pajapan Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhq","Huaxcaleca Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhr","Naro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nht","Ometepec Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhu","Noone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhv","Temascaltepec Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhw","Western Huasteca Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhx","Isthmus-Mecayapan Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhy","Northern Oaxaca Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nhz","Santa María La Alta Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nia","Nias");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nib","Nakame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nid","Ngandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nie","Niellim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nif","Nek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nig","Ngalakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nih","Nyiha (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nii","Nii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nij","Ngaju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nik","Southern Nicobarese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nil","Nila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nim","Nilamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nin","Ninzo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nio","Nganasan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niq","Nandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nir","Nimboran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nis","Nimi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nit","Southeastern Kolami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niu","Niuean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niv","Gilyak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niw","Nimo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nix","Hema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niy","Ngiti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","niz","Ningil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nja","Nzanyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njb","Nocte Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njd","Ndonde Hamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njh","Lotha Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nji","Gudanji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njj","Njen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njl","Njalgulgule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njm","Angami Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njn","Liangmai Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njo","Ao Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njr","Njerep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njs","Nisa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njt","Ndyuka-Trio Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nju","Ngadjunmaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njx","Kunyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njy","Njyem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","njz","Nyishi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nka","Nkoya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkb","Khoibu Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkc","Nkongho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkd","Koireng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nke","Duke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkf","Inpui Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkg","Nekgini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkh","Khezha Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nki","Thangal Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkj","Nakai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkk","Nokuku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkm","Namat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkn","Nkangala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nko","Nkonya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkp","Niuatoputapu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkq","Nkami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkr","Nukuoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nks","North Asmat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkt","Nyika (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nku","Bouna Kulango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkv","Nyika (Malawi and Zambia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkw","Nkutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkx","Nkoroo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nkz","Nkari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nla","Ngombale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlc","Nalca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nl","Dutch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nle","East Nyala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlg","Gela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nli","Grangali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlj","Nyali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlk","Ninia Yali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nll","Nihali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlo","Ngul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlq","Lao Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlu","Nchumbulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlv","Orizaba Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlw","Walangama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlx","Nahali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nly","Nyamal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nlz","Nalögo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nma","Maram Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmb","Big Nambas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmc","Ngam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmd","Ndumu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nme","Mzieme Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmf","Tangkhul Naga (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmg","Kwasio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmh","Monsang Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmi","Nyam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmj","Ngombe (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmk","Namakura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nml","Ndemli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmm","Manangba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmn","!Xóõ");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmo","Moyon Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmp","Nimanbur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmq","Nambya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmr","Nimbari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nms","Letemboi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmt","Namonuito");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmu","Northeast Maidu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmv","Ngamini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmw","Nimoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmx","Nama (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmy","Namuyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nmz","Nawdm");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nna","Nyangumarta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnb","Nande");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnc","Nancere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnd","West Ambae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nne","Ngandyera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnf","Ngaing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nng","Maring Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnh","Ngiemboon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nni","North Nuaulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnj","Nyangatom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnk","Nankina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnl","Northern Rengma Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnm","Namia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnn","Ngete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nn","Norwegian Nynorsk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnp","Wancho Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnq","Ngindo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnr","Narungga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nns","Ningye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnt","Nanticoke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnu","Dwang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnv","Nugunu (Australia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnw","Southern Nuni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nny","Nyangga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nnz","Nda'nda'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noa","Woun Meu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nb","Norwegian Bokmål");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noc","Nuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nod","Northern Thai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noe","Nimadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nof","Nomane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nog","Nogai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noh","Nomu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noi","Noiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noj","Nonuya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nok","Nooksack");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nol","Nomlaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nom","Nocamán");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","non","Old Norse");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nop","Numanggang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noq","Ngongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","no","Norwegian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nos","Eastern Nisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","not","Nomatsiguenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nou","Ewage-Notu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nov","Novial");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","now","Nyambo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noy","Noy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","noz","Nayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npa","Nar Phu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npb","Nupbikha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npg","Ponyo-Gongwang Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nph","Phom Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npi","Nepali (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npl","Southeastern Puebla Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npn","Mondropolon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npo","Pochuri Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nps","Nipsan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npu","Puimei Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npx","Noipx");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","npy","Napu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqg","Southern Nago");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqk","Kura Ede Nago");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nql","Ngendelengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqm","Ndom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqn","Nen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqo","N'Ko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqq","Kyan-Karyaw Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nqy","Akyaung Ari Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nra","Ngom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrb","Nara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrc","Noric");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nre","Southern Rengma Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrf","Jèrriais");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrg","Narango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nri","Chokri Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrk","Ngarla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrl","Ngarluma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrm","Narom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrn","Norn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrp","North Picene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrr","Norra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrt","Northern Kalapuya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nru","Narua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrx","Ngurmbur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nrz","Lala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsa","Sangtam Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsc","Nshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsd","Southern Nisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nse","Nsenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsf","Northwestern Nisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsg","Ngasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsh","Ngoshie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsi","Nigerian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsk","Naskapi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsl","Norwegian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsm","Sumi Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsn","Nehan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nso","Pedi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsp","Nepalese Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsq","Northern Sierra Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsr","Maritime Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nss","Nali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nst","Tase Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsu","Sierra Negra Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsv","Southwestern Nisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsw","Navut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsx","Nsongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsy","Nasal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nsz","Nisenan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntd","Northern Tidung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nte","Nathembo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntg","Ngantangarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nti","Natioro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntj","Ngaanyatjarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntk","Ikoma-Nata-Isenye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntm","Nateni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nto","Ntomba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntp","Northern Tepehuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntr","Delo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntu","Natügu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntw","Nottoway");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntx","Tangkhul Naga (Myanmar)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nty","Mantsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ntz","Natanzi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nua","Yuanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuc","Nukuini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nud","Ngala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nue","Ngundu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuf","Nusu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nug","Nungali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuh","Ndunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nui","Ngumbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuj","Nyole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuk","Nuu-chah-nulth");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nul","Nusa Laut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","num","Niuafo'ou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nun","Anong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuo","Nguôn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nup","Nupe-Nupe-Tako");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuq","Nukumanu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nur","Nukuria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nus","Nuer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nut","Nung (Viet Nam)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuu","Ngbundu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuv","Northern Nuni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuw","Nguluwan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nux","Mehek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuy","Nunggubuyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nuz","Tlamacazapa Nahuatl");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nvh","Nasarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nvm","Namiae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nvo","Nyokon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwa","Nawathinehena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwb","Nyabwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwc","Classical Newari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwe","Ngwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwg","Ngayawung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwi","Southwest Tanna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwm","Nyamusa-Molo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwo","Nauo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwr","Nawaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwx","Middle Newar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nwy","Nottoway-Meherrin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxa","Nauete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxd","Ngando (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxe","Nage");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxg","Ngad'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxi","Nindi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxk","Koki Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxl","South Nuaulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxm","Numidian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxn","Ngawun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxo","Ndambomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxq","Naxi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxr","Ninggerum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxu","Narau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nxx","Nafri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ny","Nyanja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyb","Nyangbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyc","Nyanga-li");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyd","Nyore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nye","Nyengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyf","Giryama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyg","Nyindu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyh","Nyigina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyi","Ama (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyj","Nyanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyk","Nyaneka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyl","Nyeu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nym","Nyamwezi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyn","Nyankole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyo","Nyoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyp","Nyang'i");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyq","Nayini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyr","Nyiha (Malawi)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nys","Nyunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyt","Nyawaygi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyu","Nyungwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyv","Nyulnyul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyw","Nyaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyx","Nganyaywana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nyy","Nyakyusa-Ngonde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nza","Tigon Mbembe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzb","Njebi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzi","Nzima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzk","Nzakara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzm","Zeme Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzs","New Zealand Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzu","Teke-Nzikou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzy","Nzakambay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","nzz","Nanga Dama Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oaa","Orok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oac","Oroch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oar","Old Aramaic (up to 700 BCE)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oav","Old Avar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obi","Obispeño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obk","Southern Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obl","Oblo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obm","Moabite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obo","Obo Manobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obr","Old Burmese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obt","Old Breton");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","obu","Obulom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oca","Ocaina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","och","Old Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oc","Occitan (post 1500)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oco","Old Cornish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ocu","Atzingo Matlatzinca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oda","Odut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","odk","Od");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","odt","Old Dutch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","odu","Odual");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ofo","Ofo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ofs","Old Frisian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ofu","Efutop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ogb","Ogbia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ogc","Ogbah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oge","Old Georgian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ogg","Ogbogolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ogo","Khana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ogu","Ogbronuagum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oht","Old Hittite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ohu","Old Hungarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oia","Oirata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oin","Inebu One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojb","Northwestern Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojc","Central Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojg","Eastern Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oj","Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojp","Old Japanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojs","Severn Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojv","Ontong Java");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ojw","Western Ojibwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oka","Okanagan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okb","Okobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okd","Okodia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oke","Okpe (Southwestern Edo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okg","Koko Babangk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okh","Koresh-e Rostam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oki","Okiek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okj","Oko-Juwoi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okk","Kwamtim One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okl","Old Kentish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okm","Middle Korean (10th-16th cent.)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okn","Oki-No-Erabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oko","Old Korean (3rd-9th cent.)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okr","Kirike");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oks","Oko-Eni-Osayen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oku","Oku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okv","Orokaiva");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","okx","Okpe (Northwestern Edo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ola","Walungge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","old","Mochi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ole","Olekha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olk","Olkol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olm","Oloma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olo","Livvi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olr","Olrat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olt","Old Lithuanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","olu","Kuvale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oma","Omaha-Ponca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omb","East Ambae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omc","Mochica");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omg","Omagua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omi","Omi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omk","Omok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oml","Ombo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omn","Minoan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omo","Utarmbung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omp","Old Manipuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omr","Old Marathi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omt","Omotik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omu","Omurano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omw","South Tairora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","omx","Old Mon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ona","Ona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onb","Lingao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","one","Oneida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ong","Olo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oni","Onin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onj","Onjob");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onk","Kabore One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onn","Onobasulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ono","Onondaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onp","Sartang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onr","Northern One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ons","Ono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ont","Ontenu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onu","Unua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onw","Old Nubian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","onx","Onin Based Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ood","Tohono O'odham");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oog","Ong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oon","Önge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oor","Oorlams");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oos","Old Ossetic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opa","Okpamheri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opk","Kopkaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opm","Oksapmin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opo","Opao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opt","Opata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","opy","Ofayé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ora","Oroha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orc","Orma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ore","Orejón");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","org","Oring");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orh","Oroqen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","or","Oriya (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","om","Oromo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orn","Orang Kanaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oro","Orokolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orr","Oruma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ors","Orang Seletar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ort","Adivasi Oriya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oru","Ormuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orv","Old Russian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orw","Oro Win");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orx","Oro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ory","Odia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","orz","Ormu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osa","Osage");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osc","Oscan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osi","Osing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oso","Ososo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osp","Old Spanish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","os","Ossetian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ost","Osatu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osu","Southern One");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","osx","Old Saxon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ota","Ottoman Turkish (1500-1928)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otb","Old Tibetan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otd","Ot Danum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ote","Mezquital Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oti","Oti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otk","Old Turkish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otl","Tilapa Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otm","Eastern Highland Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otn","Tenango Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otq","Querétaro Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otr","Otoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ots","Estado de México Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ott","Temoaya Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otu","Otuke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otw","Ottawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otx","Texcatepec Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oty","Old Tamil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","otz","Ixtenco Otomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oua","Tagargrent");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oub","Glio-Oubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oue","Oune");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oui","Old Uighur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oum","Ouma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ovd","Elfdalian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","owi","Owiniga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","owl","Old Welsh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oyb","Oy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oyd","Oyda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oym","Wayampi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","oyy","Oya'oya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ozm","Koonzime");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pab","Parecís");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pac","Pacoh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pad","Paumarí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pae","Pagibete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","paf","Paranawát");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pag","Pangasinan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pah","Tenharim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pai","Pe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pak","Parakanã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pal","Pahlavi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pam","Pampanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pa","Panjabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pao","Northern Paiute");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pap","Papiamento");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","paq","Parya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","par","Panamint");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pas","Papasena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pat","Papitalai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pau","Palauan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pav","Pakaásnovos");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","paw","Pawnee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pax","Pankararé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pay","Pech");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","paz","Pankararú");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbb","Páez");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbc","Patamona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbe","Mezontla Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbf","Coyotepec Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbg","Paraujano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbh","E'ñapa Woromaipu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbi","Parkwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbl","Mak (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbn","Kpasam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbo","Papel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbp","Badyara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbr","Pangwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbs","Central Pame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbt","Southern Pashto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbu","Northern Pashto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pbv","Pnar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pby","Pyu (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pca","Santa Inés Ahuatempan Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcb","Pear");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcc","Bouyei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcd","Picard");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pce","Ruching Palaung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcf","Paliyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcg","Paniya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pch","Pardhan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pci","Duruwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcj","Parenga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pck","Paite Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcl","Pardhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcm","Nigerian Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcn","Piti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcp","Pacahuara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pcw","Pyapun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pda","Anam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdc","Pennsylvania German");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdi","Pa Di");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdn","Podena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdo","Padoe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdt","Plautdietsch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pdu","Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pea","Peranakan Indonesian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","peb","Eastern Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ped","Mala (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pee","Taje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pef","Northeastern Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","peg","Pengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","peh","Bonan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pei","Chichimeca-Jonaz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pej","Northern Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pek","Penchal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pel","Pekal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pem","Phende");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","peo","Old Persian (ca. 600-400 B.C.)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pep","Kunja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","peq","Southern Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pes","Iranian Persian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pev","Pémono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pex","Petats");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pey","Petjo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pez","Eastern Penan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pfa","Pááfang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pfe","Peere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pfl","Pfaelzisch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pga","Sudanese Creole Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgd","Gāndhārī");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgg","Pangwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgi","Pagi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgk","Rerep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgl","Primitive Irish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgn","Paelignian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgs","Pangseng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgu","Pagu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pgz","Papua New Guinean Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pha","Pa-Hng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phd","Phudagi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phg","Phuong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phh","Phukha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phk","Phake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phl","Phalura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phm","Phimbi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phn","Phoenician");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pho","Phunoi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phq","Phana'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phr","Pahari-Potwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pht","Phu Thai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phu","Phuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phv","Pahlavani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","phw","Phangduwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pia","Pima Bajo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pib","Yine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pic","Pinji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pid","Piaroa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pie","Piro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pif","Pingelapese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pig","Pisabo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pih","Pitcairn-Norfolk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pii","Pini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pij","Pijao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pil","Yom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pim","Powhatan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pin","Piame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pio","Piapoco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pip","Pero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pir","Piratapuyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pis","Pijin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pit","Pitta Pitta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","piu","Pintupi-Luritja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","piv","Pileni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","piw","Pimbwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pix","Piu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","piy","Piya-Kwonci");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","piz","Pije");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pjt","Pitjantjatjara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pka","Ardhamāgadhī Prākrit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkb","Pokomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkc","Paekche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkg","Pak-Tong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkh","Pankhu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkn","Pakanha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pko","Pökoot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkp","Pukapuka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkr","Attapady Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pks","Pakistan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pkt","Maleng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pku","Paku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pla","Miani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plb","Polonombauk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plc","Central Palawano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pld","Polari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ple","Palu'e");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plg","Pilagá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plh","Paulohi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pi","Pali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plj","Polci");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plk","Kohistani Shina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pll","Shwe Palaung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pln","Palenquero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plo","Oluta Popoluca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plp","Palpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plq","Palaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plr","Palaka Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pls","San Marcos Tlacoyalco Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plt","Plateau Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plu","Palikúr");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plv","Southwest Palawano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plw","Brooke's Point Palawano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ply","Bolyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","plz","Paluan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pma","Paama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmb","Pambia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmd","Pallanganmiddang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pme","Pwaamei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmf","Pamona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmh","Māhārāṣṭri Prākrit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmi","Northern Pumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmj","Southern Pumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmk","Pamlico");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pml","Lingua Franca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmm","Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmn","Pam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmo","Pom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmq","Northern Pame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmr","Paynamar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pms","Piemontese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmt","Tuamotuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmw","Plains Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmx","Poumei Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmy","Papuan Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pmz","Southern Pame");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pna","Punan Bah-Biau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnb","Western Panjabi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnc","Pannei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pne","Western Penan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","png","Pongu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnh","Penrhyn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pni","Aoheng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnj","Pinjarup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnk","Paunaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnl","Paleni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnm","Punan Batu 1");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnn","Pinai-Hagahai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pno","Panobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnp","Pancana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnq","Pana (Burkina Faso)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnr","Panim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pns","Ponosakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnt","Pontic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnu","Jiongnai Bunu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnv","Pinigura");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnw","Panytyima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnx","Phong-Kniang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pny","Pinyin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pnz","Pana (Central African Republic)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poc","Poqomam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poe","San Juan Atzingo Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pof","Poke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pog","Potiguára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poh","Poqomchi'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poi","Highland Popoluca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pok","Pokangá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pl","Polish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pom","Southeastern Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pon","Pohnpeian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poo","Central Pomo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pop","Pwapwâ");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poq","Texistepec Popoluca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pt","Portuguese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pos","Sayula Popoluca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pot","Potawatomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pov","Upper Guinea Crioulo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pow","San Felipe Otlaltepec Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pox","Polabian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","poy","Pogolo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppe","Papi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppi","Paipai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppk","Uma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppl","Pipil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppm","Papuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppn","Papapana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppo","Folopa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppp","Pelende");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppq","Pei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pps","San Luís Temalacayuca Popoloca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppt","Pare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ppu","Papora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pqa","Pa'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pqm","Malecite-Passamaquoddy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prc","Parachi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prd","Parsi-Dari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pre","Principense");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prf","Paranan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prg","Prussian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prh","Porohanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pri","Paicî");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prk","Parauk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prl","Peruvian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prm","Kibiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prn","Prasuni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pro","Old Provençal (to 1500)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prp","Parsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prq","Ashéninka Perené");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prr","Puri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prs","Dari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prt","Phai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pru","Puragi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prw","Parawen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prx","Purik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","prz","Providencia Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psa","Asue Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psc","Persian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psd","Plains Indian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pse","Central Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psg","Penang Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psh","Southwest Pashai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psi","Southeast Pashai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psl","Puerto Rican Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psm","Pauserna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psn","Panasuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pso","Polish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psp","Philippine Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psq","Pasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psr","Portuguese Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pss","Kaulong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pst","Central Pashto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psu","Sauraseni Prākrit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psw","Port Sandwich");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","psy","Piscataway");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pta","Pai Tavytera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pth","Pataxó Hã-Ha-Hãe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pti","Pintiini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptn","Patani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pto","Zo'é");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptp","Patep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptq","Pattapu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptr","Piamatsina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptt","Enrekang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptu","Bambam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptv","Port Vato");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ptw","Pentlatch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pty","Pathiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pua","Western Highland Purepecha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pub","Purum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puc","Punan Merap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pud","Punan Aput");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pue","Puelche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puf","Punan Merah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pug","Phuie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pui","Puinave");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puj","Punan Tubu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pum","Puma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puo","Puoc");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pup","Pulabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puq","Puquina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pur","Puruborá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ps","Pushto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","put","Putoh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puu","Punu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puw","Puluwatese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pux","Puare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","puy","Purisimeño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwa","Pawaia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwb","Panawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwg","Gapapaiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwi","Patwin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwm","Molbog");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwn","Paiwan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwo","Pwo Western Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pwr","Powari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pww","Pwo Northern Karen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pxm","Quetzaltepec Mixe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pye","Pye Krumen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pym","Fyam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pyn","Poyanáwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pys","Paraguayan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pyu","Puyuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pyx","Pyu (Myanmar)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pyy","Pyen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","pzn","Para Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qua","Quapaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qub","Huallaga Huánuco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quc","K'iche'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qud","Calderón Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qu","Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quf","Lambayeque Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qug","Chimborazo Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quh","South Bolivian Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qui","Quileute");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quk","Chachapoyas Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qul","North Bolivian Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qum","Sipacapense");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qun","Quinault");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qup","Southern Pastaza Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quq","Quinqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qur","Yanahuanca Pasco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qus","Santiago del Estero Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quv","Sacapulteco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quw","Tena Lowland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qux","Yauyos Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quy","Ayacucho Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","quz","Cusco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qva","Ambo-Pasco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvc","Cajamarca Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qve","Eastern Apurímac Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvh","Huamalíes-Dos de Mayo Huánuco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvi","Imbabura Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvj","Loja Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvl","Cajatambo North Lima Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvm","Margos-Yarowilca-Lauricocha Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvn","North Junín Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvo","Napo Lowland Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvp","Pacaraos Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvs","San Martín Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvw","Huaylla Wanca Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvy","Queyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qvz","Northern Pastaza Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qwa","Corongo Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qwc","Classical Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qwh","Huaylas Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qwm","Kuman (Russia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qws","Sihuas Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qwt","Kwalhioqua-Tlatskanai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxa","Chiquián Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxc","Chincha Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxh","Panao Huánuco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxl","Salasaca Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxn","Northern Conchucos Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxo","Southern Conchucos Ancash Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxp","Puno Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxq","Qashqa'i");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxr","Cañar Highland Quichua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxs","Southern Qiang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxt","Santa Ana de Tusi Pasco Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxu","Arequipa-La Unión Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qxw","Jauja Wanca Quechua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qya","Quenya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","qyp","Quiripi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raa","Dungmali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rab","Camling");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rac","Rasawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rad","Rade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raf","Western Meohang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rag","Logooli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rah","Rabha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rai","Ramoaaina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raj","Rajasthani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rak","Tulu-Bohuai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ral","Ralte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ram","Canela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ran","Riantana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rao","Rao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rap","Rapanui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raq","Saam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rar","Rarotongan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ras","Tegali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rat","Razajerdi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rau","Raute");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rav","Sampang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raw","Rawang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rax","Rang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ray","Rapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","raz","Rahambuu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rbb","Rumai Palaung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rbk","Northern Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rbl","Miraya Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rbp","Barababaraba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rcf","Réunion Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rdb","Rudbari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rea","Rerau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","reb","Rembong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ree","Rejang Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","reg","Kara (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rei","Reli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rej","Rejang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rel","Rendille");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rem","Remo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ren","Rengao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rer","Rer Bare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","res","Reshe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ret","Retta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rey","Reyesano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rga","Roria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rge","Romano-Greek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rgk","Rangkas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rgn","Romagnol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rgr","Resígaro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rgs","Southern Roglai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rgu","Ringgou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rhg","Rohingya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rhp","Yahang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ria","Riang (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rif","Tarifit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ril","Riang (Myanmar)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rim","Nyaturu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rin","Nungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rir","Ribun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rit","Ritarungo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","riu","Riung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rjg","Rajong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rji","Raji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rjs","Rajbanshi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rka","Kraol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rkb","Rikbaktsa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rkh","Rakahanga-Manihiki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rki","Rakhine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rkm","Marka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rkt","Rangpuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rkw","Arakwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rma","Rama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmb","Rembarunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmc","Carpathian Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmd","Traveller Danish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rme","Angloromani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmf","Kalo Finnish Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmg","Traveller Norwegian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmh","Murkim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmi","Lomavren");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmk","Romkun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rml","Baltic Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmm","Roma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmn","Balkan Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmo","Sinte Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmp","Rempi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmq","Caló");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rms","Romanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmt","Domari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmu","Tavringer Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmv","Romanova");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmw","Welsh Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmx","Romam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmy","Vlax Romani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rmz","Marma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnd","Ruund");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rng","Ronga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnl","Ranglong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnn","Roon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnp","Rongpo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnr","Nari Nari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rnw","Rungwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rob","Tae'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","roc","Cacgia Roglai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rod","Rogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","roe","Ronji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rof","Rombo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rog","Northern Roglai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rm","Romansh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rol","Romblomanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rom","Romany");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ro","Romanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","roo","Rotokas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rop","Kriol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ror","Rongga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rou","Runga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","row","Dela-Oenale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rpn","Repanbitip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rpt","Rapting");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rri","Ririo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rro","Waima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rrt","Arritinngithigh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rsb","Romano-Serbian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rsl","Russian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rsm","Miriwoong Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rtc","Rungtu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rth","Ratahan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rtm","Rotuman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rts","Yurats");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rtw","Rathawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rub","Gungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruc","Ruuli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rue","Rusyn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruf","Luguru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rug","Roviana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruh","Ruga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rui","Rufiji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruk","Che");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rn","Rundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruo","Istro Romanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rup","Macedo-Romanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruq","Megleno Romanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ru","Russian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rut","Rutul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruu","Lanas Lobu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruy","Mala (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ruz","Ruma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rwa","Rawo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rwk","Rwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rwm","Amba (Uganda)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rwo","Rawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rwr","Marwari (India)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rxd","Ngardi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rxw","Karuwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ryn","Northern Amami-Oshima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rys","Yaeyama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ryu","Central Okinawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","rzh","Rāziḥī");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saa","Saba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sab","Buglere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sac","Meskwaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sad","Sandawe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sae","Sabanê");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saf","Safaliba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sg","Sango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sah","Yakut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saj","Sahu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sak","Sake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sam","Samaritan Aramaic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sa","Sanskrit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sao","Sause");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saq","Samburu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sar","Saraveca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sas","Sasak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sat","Santali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sau","Saleman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sav","Saafi-Saafi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saw","Sawi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sax","Sa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","say","Saya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","saz","Saurashtra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sba","Ngambay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbb","Simbo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbc","Kele (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbd","Southern Samo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbe","Saliba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbf","Chabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbg","Seget");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbh","Sori-Harengan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbi","Seti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbj","Surbakhal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbk","Safwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbl","Botolan Sambal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbm","Sagala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbn","Sindhi Bhil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbo","Sabüm");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbp","Sangu (Tanzania)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbq","Sileibi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbr","Sembakung Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbs","Subiya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbt","Kimki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbu","Stod Bhoti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbv","Sabine");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbw","Simba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbx","Seberuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sby","Soli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sbz","Sara Kaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scb","Chut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sce","Dongxiang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scf","San Miguel Creole French");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scg","Sanggau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sch","Sakachep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sci","Sri Lankan Creole Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sck","Sadri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scl","Shina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scn","Sicilian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sco","Scots");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scp","Helambu Sherpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scq","Sa'och");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scs","North Slavey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sct","Southern Katang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scu","Shumcho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scv","Sheni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scw","Sha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","scx","Sicel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sda","Toraja-Sa'dan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdb","Shabak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdc","Sassarese Sardinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sde","Surubu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdf","Sarli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdg","Savi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdh","Southern Kurdish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdj","Suundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdk","Sos Kundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdl","Saudi Arabian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdm","Semandang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdn","Gallurese Sardinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdo","Bukar-Sadung Bidayuh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdp","Sherdukpen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdr","Oraon Sadri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sds","Sened");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdt","Shuadit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdu","Sarudu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdx","Sibu Melanau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sdz","Sallands");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sea","Semai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seb","Shempire Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sec","Sechelt");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sed","Sedang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","see","Seneca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sef","Cebaara Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seg","Segeju");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seh","Sena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sei","Seri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sej","Sene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sek","Sekani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sel","Selkup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sen","Nanerigé Sénoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seo","Suarmin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sep","Sìcìté Sénoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seq","Senara Sénoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ser","Serrano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ses","Koyraboro Senni Songhai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","set","Sentani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","seu","Serui-Laut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sev","Nyarafolo Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sew","Sewa Bay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sey","Secoya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sez","Senthang Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sfb","Langue des signes de Belgique Francophone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sfe","Eastern Subanen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sfm","Small Flowery Miao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sfs","South African Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sfw","Sehwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sga","Old Irish (to 900)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgb","Mag-antsi Ayta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgc","Kipsigis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgd","Surigaonon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sge","Segai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgg","Swiss-German Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgh","Shughni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgi","Suga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgj","Surgujia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgk","Sangkong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgm","Singa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgp","Singpho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgr","Sangisari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgs","Samogitian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgt","Brokpake");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgu","Salas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgw","Sebat Bet Gurage");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgx","Sierra Leone Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgy","Sanglechi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sgz","Sursurunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sha","Shall-Zwall");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shb","Ninam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shc","Sonde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shd","Kundal Shahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","she","Sheko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shg","Shua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shh","Shoshoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shi","Tachelhit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shj","Shatt");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shk","Shilluk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shl","Shendu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shm","Shahrudi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shn","Shan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sho","Shanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shp","Shipibo-Conibo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shq","Sala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shr","Shi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shs","Shuswap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sht","Shasta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shu","Chadian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shv","Shehri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shw","Shwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shx","She");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shy","Tachawit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","shz","Syenara Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sia","Akkala Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sib","Sebop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sid","Sidamo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sie","Simaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sif","Siamou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sig","Paasaal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sih","Zire");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sii","Shom Peng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sij","Numbami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sik","Sikiana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sil","Tumulung Sisaala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sim","Mende (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","si","Sinhala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sip","Sikkimese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siq","Sonia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sir","Siri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sis","Siuslaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siu","Sinagen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siv","Sumariup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siw","Siwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","six","Sumau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siy","Sivandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","siz","Siwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sja","Epena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjb","Sajau Basap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjd","Kildin Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sje","Pite Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjg","Assangori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjk","Kemi Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjl","Sajalong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjm","Mapun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjn","Sindarin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjo","Xibe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjp","Surjapuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjr","Siar-Lak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjs","Senhaja De Srair");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjt","Ter Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sju","Ume Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sjw","Shawnee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ska","Skagit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skb","Saek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skc","Ma Manda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skd","Southern Sierra Miwok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ske","Seke (Vanuatu)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skf","Sakirabiá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skg","Sakalava Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skh","Sikule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ski","Sika");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skj","Seke (Nepal)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skm","Kutong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skn","Kolibugan Subanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sko","Seko Tengah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skp","Sekapan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skq","Sininkere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skr","Saraiki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sks","Maia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skt","Sakata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sku","Sakao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skv","Skou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skw","Skepi Creole Dutch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skx","Seko Padang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sky","Sikaiana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","skz","Sekar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slc","Sáliba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sld","Sissala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sle","Sholaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slf","Swiss-Italian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slg","Selungai Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slh","Southern Puget Sound Salish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sli","Lower Silesian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slj","Salumá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sk","Slovak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sll","Salt-Yui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slm","Pangutaran Sama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sln","Salinan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slp","Lamaholot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slq","Salchuq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slr","Salar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sls","Singapore Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slt","Sila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slu","Selaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sl","Slovenian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slw","Sialum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slx","Salampasu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sly","Selayar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","slz","Ma'ya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sma","Southern Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smb","Simbari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smc","Som");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smd","Sama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","se","Northern Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smf","Auwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smg","Simbali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smh","Samei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smj","Lule Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smk","Bolinao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sml","Central Sama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smm","Musasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smn","Inari Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sm","Samoan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smp","Samaritan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smq","Samo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smr","Simeulue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sms","Skolt Sami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smt","Simte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smu","Somray");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smv","Samvedi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smw","Sumbawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smx","Samba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smy","Semnani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","smz","Simeku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sn","Shona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snb","Sebuyau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snc","Sinaugoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sd","Sindhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sne","Bau Bidayuh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snf","Noon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sng","Sanga (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sni","Sensi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snj","Riverain Sango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snk","Soninke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snl","Sangil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snm","Southern Ma'di");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snn","Siona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sno","Snohomish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snp","Siane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snq","Sangu (Gabon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snr","Sihan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sns","South West Bay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snu","Senggi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snv","Sa'ban");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snw","Selee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snx","Sam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sny","Saniyo-Hiyewe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","snz","Sinsauru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soa","Thai Song");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sob","Sobei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soc","So (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sod","Songoora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soe","Songomeno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sog","Sogdian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soh","Aka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soi","Sonha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soj","Soi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sok","Sokoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sol","Solos");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","so","Somali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soo","Songo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sop","Songe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soq","Kanasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sor","Somrai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sos","Seeku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","st","Southern Sotho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sou","Southern Thai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sov","Sonsorol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sow","Sowanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sox","Swo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soy","Miyobe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","soz","Temi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","es","Spanish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spb","Sepa (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spc","Sapé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spd","Saep");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spe","Sepa (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spg","Sian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spi","Saponi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spk","Sengo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spl","Selepet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spm","Akukem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spn","Sanapaná");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spo","Spokane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spp","Supyire Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spq","Loreto-Ucayali Spanish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spr","Saparua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sps","Saposa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spt","Spiti Bhoti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spu","Sapuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spv","Sambalpuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spx","South Picene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","spy","Sabaot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqa","Shama-Sambuga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqh","Shau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sq","Albanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqk","Albanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqm","Suma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqn","Susquehannock");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqo","Sorkhei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqq","Sou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqr","Siculo Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqs","Sri Lankan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sqt","Soqotri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","squ","Squamish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sra","Saruga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srb","Sora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","src","Logudorese Sardinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sc","Sardinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sre","Sara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srf","Nafi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srg","Sulod");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srh","Sarikoli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sri","Siriano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srk","Serudung Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srl","Isirawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srm","Saramaccan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srn","Sranan Tongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sro","Campidanese Sardinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sr","Serbian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srq","Sirionó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srr","Serer");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srs","Sarsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srt","Sauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sru","Suruí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srv","Southern Sorsoganon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srw","Serua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srx","Sirmauri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sry","Sera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","srz","Shahmirzadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssb","Southern Sama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssc","Suba-Simbiti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssd","Siroi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sse","Balangingi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssf","Thao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssg","Seimat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssh","Shihhi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssi","Sansi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssj","Sausi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssk","Sunam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssl","Western Sisaala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssm","Semnam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssn","Waata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sso","Sissano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssp","Spanish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssq","So'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssr","Swiss-French Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sss","Sô");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sst","Sinasina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssu","Susuami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssv","Shark Bay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ss","Swati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssx","Samberigi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssy","Saho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ssz","Sengseng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sta","Settla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stb","Northern Subanen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","std","Sentinel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ste","Liana-Seti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stf","Seta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stg","Trieng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sth","Shelta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sti","Bulo Stieng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stj","Matya Samo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stk","Arammba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stl","Stellingwerfs");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stm","Setaman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stn","Owa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sto","Stoney");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stp","Southeastern Tepehuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stq","Saterfriesisch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","str","Straits Salish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sts","Shumashti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stt","Budeh Stieng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stu","Samtao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stv","Silt'e");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","stw","Satawalese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sty","Siberian Tatar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sua","Sulka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sub","Suku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suc","Western Subanon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sue","Suena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sug","Suganga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sui","Suki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suj","Shubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suk","Sukuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","su","Sundanese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suq","Suri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sur","Mwaghavul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sus","Susu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sut","Subtiaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suv","Puroik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suw","Sumbwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sux","Sumerian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suy","Suyá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","suz","Sunwar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sva","Svan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svb","Ulau-Suain");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svc","Vincentian Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sve","Serili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svk","Slovakian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svm","Slavomolisano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svs","Savosavo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","svx","Skalvian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sw","Swahili (macrolanguage)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swb","Maore Comorian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swc","Congo Swahili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sv","Swedish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swf","Sere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swg","Swabian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swh","Swahili (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swi","Sui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swj","Sira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swk","Malawi Sena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swl","Swedish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swm","Samosa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swn","Sawknah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swo","Shanenawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swp","Suau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swq","Sharwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swr","Saweru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sws","Seluwasan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swt","Sawila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swu","Suwawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swv","Shekhawati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sww","Sowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swx","Suruahá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","swy","Sarua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxb","Suba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxc","Sicanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxe","Sighu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxg","Shixing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxk","Southern Kalapuya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxl","Selian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxm","Samre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxn","Sangir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxo","Sorothaptic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxr","Saaroa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxs","Sasaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxu","Upper Saxon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sxw","Saxwe Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sya","Siang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syb","Central Subanen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syc","Classical Syriac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syi","Seki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syk","Sukur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syl","Sylheti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sym","Maya Samo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syn","Senaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syo","Suoy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syr","Syriac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sys","Sinyar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syw","Kagate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syx","Samay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","syy","Al-Sayyid Bedouin Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sza","Semelai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szb","Ngalum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szc","Semaq Beri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szd","Seru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","sze","Seze");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szg","Sengele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szl","Silesian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szn","Sula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szp","Suabo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szs","Solomon Islands Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szv","Isu (Fako Division)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","szw","Sawai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taa","Lower Tanana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tab","Tabassaran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tac","Lowland Tarahumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tad","Tause");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tae","Tariana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taf","Tapirapé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tag","Tagoi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ty","Tahitian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taj","Eastern Tamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tak","Tala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tal","Tal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ta","Tamil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tan","Tangale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tao","Yami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tap","Taabwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taq","Tamasheq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tar","Central Tarahumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tas","Tay Boi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tt","Tatar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tau","Upper Tanana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tav","Tatuyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taw","Tai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tax","Tamki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tay","Atayal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","taz","Tocho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tba","Aikanã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbb","Tapeba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbc","Takia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbd","Kaki Ae");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbe","Tanimbili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbf","Mandara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbg","North Tairora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbh","Thurawal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbi","Gaam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbj","Tiang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbk","Calamian Tagbanwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbl","Tboli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbm","Tagbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbn","Barro Negro Tunebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbo","Tawala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbp","Taworta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbr","Tumtum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbs","Tanguat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbt","Tembo (Kitembo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbu","Tubar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbv","Tobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbw","Tagbanwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbx","Kapin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tby","Tabaru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tbz","Ditammari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tca","Ticuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcb","Tanacross");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcc","Datooga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcd","Tafi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tce","Southern Tutchone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcf","Malinaltepec Me'phaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcg","Tamagario");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tch","Turks And Caicos Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tci","Wára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tck","Tchitchege");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcl","Taman (Myanmar)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcm","Tanahmerah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcn","Tichurong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tco","Taungyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcp","Tawr Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcq","Kaiy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcs","Torres Strait Creole");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tct","T'en");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcu","Southeastern Tarahumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcw","Tecpatlán Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcx","Toda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcy","Tulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tcz","Thado Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tda","Tagdal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdb","Panchpargania");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdc","Emberá-Tadó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdd","Tai Nüa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tde","Tiranige Diga Dogon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdf","Talieng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdg","Western Tamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdh","Thulung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdi","Tomadino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdj","Tajio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdk","Tambas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdl","Sur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdm","Taruma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdn","Tondano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdo","Teme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdq","Tita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdr","Todrah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tds","Doutai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdt","Tetun Dili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdv","Toro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdx","Tandroy-Mahafaly Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tdy","Tadyawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tea","Temiar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teb","Tetete");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tec","Terik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ted","Tepo Krumen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tee","Huehuetla Tepehua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tef","Teressa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teg","Teke-Tege");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teh","Tehuelche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tei","Torricelli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tek","Ibali Teke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","te","Telugu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tem","Timne");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ten","Tama (Colombia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teo","Teso");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tep","Tepecano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teq","Temein");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ter","Tereno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tes","Tengger");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tet","Tetum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","teu","Soo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tev","Teor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tew","Tewa (USA)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tex","Tennet");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tey","Tulishi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tfi","Tofin Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tfn","Tanaina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tfo","Tefaro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tfr","Teribe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tft","Ternate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tga","Sagalla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgb","Tobilung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgc","Tigak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgd","Ciwogai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tge","Eastern Gorkha Tamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgf","Chalikha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgh","Tobagonian Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgi","Lawunuia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgj","Tagin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tg","Tajik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tl","Tagalog");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgn","Tandaganon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgo","Sudest");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgp","Tangoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgq","Tring");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgr","Tareng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgs","Nume");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgt","Central Tagbanwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgu","Tanggu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgv","Tingui-Boto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgw","Tagwana Senoufo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgx","Tagish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgy","Togoyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tgz","Tagalaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","th","Thai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thd","Thayore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","the","Chitwania Tharu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thf","Thangmi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thh","Northern Tarahumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thi","Tai Long");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thk","Tharaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thl","Dangaura Tharu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thm","Aheu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thn","Thachanadan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thp","Thompson");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thq","Kochila Tharu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thr","Rana Tharu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ths","Thakali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tht","Tahltan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thu","Thuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thv","Tahaggart Tamahaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thw","Thudam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thy","Tha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","thz","Tayart Tamajeq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tia","Tidikelt Tamazight");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tic","Tira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tif","Tifal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tig","Tigre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tih","Timugon Murut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tii","Tiene");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tij","Tilung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tik","Tikar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","til","Tillamook");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tim","Timbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tin","Tindi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tio","Teop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tip","Trimuris");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiq","Tiéfo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ti","Tigrinya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tis","Masadiit Itneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tit","Tinigua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiu","Adasen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiv","Tiv");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiw","Tiwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tix","Southern Tiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiy","Tiruray");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tiz","Tai Hongjin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tja","Tajuasohn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjg","Tunjung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tji","Northern Tujia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjl","Tai Laing");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjm","Timucua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjn","Tonjon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjo","Temacine Tamazight");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjs","Southern Tujia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tju","Tjurruru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tjw","Djabwurrung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tka","Truká");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkb","Buksa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkd","Tukudede");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tke","Takwane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkf","Tukumanféd");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkg","Tesaka Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkl","Tokelau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkm","Takelma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkn","Toku-No-Shima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkp","Tikopia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkq","Tee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkr","Tsakhur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tks","Takestani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkt","Kathoriya Tharu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tku","Upper Necaxa Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkv","Mur Pano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkw","Teanu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkx","Tangko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tkz","Takua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tla","Southwestern Tepehuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlb","Tobelo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlc","Yecuatla Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tld","Talaud");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlf","Telefol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlg","Tofanma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlh","Klingon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tli","Tlingit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlj","Talinga-Bwisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlk","Taloki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tll","Tetela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlm","Tolomako");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tln","Talondo'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlo","Talodi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlp","Filomena Mata-Coahuitlán Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlq","Tai Loi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlr","Talise");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tls","Tambotalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlt","Sou Nama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlu","Tulehu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlv","Taliabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tlx","Khehek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tly","Talysh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tma","Tama (Chad)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmb","Katbol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmc","Tumak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmd","Haruai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tme","Tremembé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmf","Toba-Maskoy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmg","Ternateño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmh","Tamashek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmi","Tutuba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmj","Samarokena");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmk","Northwestern Tamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tml","Tamnim Citak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmm","Tai Thanh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmn","Taman (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmo","Temoq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmq","Tumleo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmr","Jewish Babylonian Aramaic (ca. 200-1200 CE)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tms","Tima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmt","Tasmate");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmu","Iau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmv","Tembo (Motembo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmw","Temuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmy","Tami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tmz","Tamanaku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tna","Tacana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnb","Western Tunebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnc","Tanimuca-Retuarã");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnd","Angosturas Tunebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tng","Tobanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnh","Maiani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tni","Tandia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnk","Kwamera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnl","Lenakel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnm","Tabla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnn","North Tanna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tno","Toromono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnp","Whitesands");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnq","Taino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnr","Ménik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tns","Tenis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnt","Tontemboan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnu","Tay Khang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnv","Tangchangya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnw","Tonsawang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnx","Tanema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tny","Tongwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tnz","Ten'edn");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tob","Toba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toc","Coyutla Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tod","Toma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tof","Gizrra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tog","Tonga (Nyasa)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toh","Gitonga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toi","Tonga (Zambia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toj","Tojolabal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tol","Tolowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tom","Tombulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","to","Tonga (Tonga Islands)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","too","Xicotepec De Juárez Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","top","Papantla Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toq","Toposa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tor","Togbo-Vara Banda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tos","Highland Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tou","Tho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tov","Upper Taromi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tow","Jemez");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tox","Tobian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toy","Topoiyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","toz","To");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpa","Taupota");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpc","Azoyú Me'phaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpe","Tippera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpf","Tarpia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpg","Kula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpi","Tok Pisin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpj","Tapieté");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpk","Tupinikin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpl","Tlacoapa Me'phaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpm","Tampulma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpn","Tupinambá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpo","Tai Pao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpp","Pisaflores Tepehua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpq","Tukpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpr","Tuparí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpt","Tlachichilco Tepehua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpu","Tampuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpv","Tanapag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpw","Tupí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpx","Acatepec Me'phaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpy","Trumai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tpz","Tinputz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqb","Tembé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tql","Lehali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqm","Turumsa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqn","Tenino");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqo","Toaripi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqp","Tomoip");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqq","Tunni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqr","Torona");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqt","Western Totonac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqu","Touo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tqw","Tonkawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tra","Tirahi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trb","Terebu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trc","Copala Triqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trd","Turi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tre","East Tarangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trf","Trinidadian Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trg","Lishán Didán");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trh","Turaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tri","Trió");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trj","Toram");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trl","Traveller Scottish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trm","Tregami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trn","Trinitario");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tro","Tarao Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trp","Kok Borok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trq","San Martín Itunyoso Triqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trr","Taushiro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trs","Chicahuaxtla Triqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trt","Tunggare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tru","Turoyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trv","Taroko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trw","Torwali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trx","Tringgus-Sembaan Bidayuh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","try","Turung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","trz","Torá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsa","Tsaangi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsb","Tsamai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsc","Tswa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsd","Tsakonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tse","Tunisian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsg","Tausug");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsh","Tsuvan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsi","Tsimshian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsj","Tshangla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsk","Tseku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsl","Ts'ün-Lao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsm","Turkish Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tn","Tswana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ts","Tsonga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsp","Northern Toussian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsq","Thai Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsr","Akei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tss","Taiwan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tst","Tondi Songway Kiini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsu","Tsou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsv","Tsogo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsw","Tsishingini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsx","Mubami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsy","Tebul Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tsz","Purepecha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tta","Tutelo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttb","Gaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttc","Tektiteko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttd","Tauade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tte","Bwanabwana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttf","Tuotomb");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttg","Tutong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tth","Upper Ta'oih");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tti","Tobati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttj","Tooro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttk","Totoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttl","Totela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttm","Northern Tutchone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttn","Towei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tto","Lower Ta'oih");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttp","Tombelala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttq","Tawallammat Tamajaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttr","Tera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tts","Northeastern Thai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttt","Muslim Tat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttu","Torau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttv","Titan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttw","Long Wat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tty","Sikaritai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ttz","Tsum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tua","Wiarumus");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tub","Tübatulabal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuc","Mutu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tud","Tuxá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tue","Tuyuca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuf","Central Tunebo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tug","Tunia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuh","Taulil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tui","Tupuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuj","Tugutil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tk","Turkmen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tul","Tula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tum","Tumbuka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tun","Tunica");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuo","Tucano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuq","Tedaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tr","Turkish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tus","Tuscarora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuu","Tututni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuv","Turkana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tux","Tuxináwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuy","Tugen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tuz","Turka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tva","Vaghua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvd","Tsuvadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tve","Te'un");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvk","Southeast Ambrym");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvl","Tuvalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvm","Tela-Masbuar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvn","Tavoyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvo","Tidore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvs","Taveta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvt","Tutsa Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvu","Tunen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvw","Sedoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tvy","Timor Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twa","Twana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twb","Western Tawbuid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twc","Teshenawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twd","Twents");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twe","Tewa (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twf","Northern Tiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twg","Tereweng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twh","Tai Dón");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tw","Twi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twl","Tawara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twm","Tawang Monpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twn","Twendi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","two","Tswapong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twp","Ere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twq","Tasawaq");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twr","Southwestern Tarahumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twt","Turiwára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twu","Termanu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tww","Tuwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twx","Tewe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","twy","Tawoyan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txa","Tombonuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txb","Tokharian B");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txc","Tsetsaut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txe","Totoli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txg","Tangut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txh","Thracian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txi","Ikpeng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txj","Tarjumo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txm","Tomini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txn","West Tarangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txo","Toto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txq","Tii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txr","Tartessian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txs","Tonsea");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txt","Citak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txu","Kayapó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txx","Tatana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","txy","Tanosy Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tya","Tauya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tye","Kyanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyh","O'du");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyi","Teke-Tsaayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyj","Tai Do");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyl","Thu Lao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyn","Kombai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","typ","Thaypan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyr","Tai Daeng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tys","Tày Sa Pa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyt","Tày Tac");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyu","Kua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyv","Tuvinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyx","Teke-Tyee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tyz","Tày");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tza","Tanzanian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzh","Tzeltal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzj","Tz'utujil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzl","Talossan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzm","Central Atlas Tamazight");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzn","Tugun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzo","Tzotzil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","tzx","Tabriak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uam","Uamué");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uan","Kuan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uar","Tairuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uba","Ubang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ubi","Ubi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ubl","Buhi'non Bikol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ubr","Ubir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ubu","Umbu-Ungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uby","Ubykh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uda","Uda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ude","Udihe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udg","Muduga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udi","Udi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udj","Ujir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udl","Wuzlam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udm","Udmurt");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","udu","Uduk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ues","Kioko");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ufi","Ufim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uga","Ugaritic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ugb","Kuku-Ugbanh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uge","Ughele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ugn","Ugandan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ugo","Ugong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ugy","Uruguayan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uha","Uhami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uhn","Damal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ug","Uighur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uis","Uisai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uiv","Iyive");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uji","Tanjijili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uka","Kaburi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukg","Ukuriguma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukh","Ukhwejo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukk","Muak Sa-aak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukl","Ukrainian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukp","Ukpe-Bayobiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukq","Ukwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uk","Ukrainian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uks","Urubú-Kaapor Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uku","Ukue");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ukw","Ukwuani-Aboh-Ndoni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uky","Kuuk-Yak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ula","Fungwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulb","Ulukwumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulc","Ulch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ule","Lule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulf","Usku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uli","Ulithian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulk","Meriam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ull","Ullatan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulm","Ulumanda'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uln","Unserdeutsch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulu","Uma' Lung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ulw","Ulwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uma","Umatilla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umb","Umbundu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umc","Marrucinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umd","Umbindhamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umg","Umbuygamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umi","Ukit");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umm","Umon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umn","Makyan Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umo","Umotína");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ump","Umpila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umr","Umbugarla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ums","Pendau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","umu","Munsee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","una","North Watut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","und","Undetermined");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","une","Uneme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ung","Ngarinyin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unk","Enawené-Nawé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unm","Unami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unn","Kurnai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unr","Mundari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unu","Unubahe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unx","Munda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","unz","Unde Kaili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","upi","Umeda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","upv","Uripiv-Wala-Rano-Atchin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ura","Urarina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urb","Urubú-Kaapor");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urc","Urningangg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ur","Urdu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ure","Uru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urf","Uradhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urg","Urigina");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urh","Urhobo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uri","Urim");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urk","Urak Lawoi'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","url","Urali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urm","Urapmin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urn","Uruangnirin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uro","Ura (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urp","Uru-Pa-In");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urr","Lehalurup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urt","Urat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uru","Urumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urv","Uruava");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urw","Sop");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urx","Urimo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ury","Orya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","urz","Uru-Eu-Wau-Wau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","usa","Usarufa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ush","Ushojo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","usi","Usui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","usk","Usaghade");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","usp","Uspanteco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","usu","Uya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uta","Otank");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ute","Ute-Southern Paiute");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","utp","Amba (Solomon Islands)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","utr","Etulo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","utu","Utu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uum","Urum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uun","Kulon-Pazeh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uur","Ura (Vanuatu)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uuu","U");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uve","West Uvean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uvh","Uri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uvl","Lote");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uwa","Kuku-Uwanh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uya","Doko-Uyanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uz","Uzbek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uzn","Northern Uzbek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","uzs","Southern Uzbek");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vaa","Vaagri Booli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vae","Vale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vaf","Vafsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vag","Vagla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vah","Varhadi-Nagpuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vai","Vai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vaj","Sekele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","val","Vehes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vam","Vanimo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","van","Valman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vao","Vao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vap","Vaiphei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","var","Huarijio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vas","Vasavi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vau","Vanuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vav","Varli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vay","Wayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vbb","Southeast Babar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vbk","Southwestern Bontok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vec","Venetian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ved","Veddah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vel","Veluws");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vem","Vemgo-Mabas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ve","Venda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","veo","Ventureño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vep","Veps");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ver","Mom Jango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vgr","Vaghri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vgt","Vlaamse Gebarentaal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vic","Virgin Islands Creole English");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vid","Vidunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vi","Vietnamese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vif","Vili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vig","Viemo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vil","Vilela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vin","Vinza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vis","Vishavan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vit","Viti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","viv","Iduna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vka","Kariyarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vki","Ija-Zuba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkj","Kujarge");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkk","Kaur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkl","Kulisusu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkm","Kamakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vko","Kodeoha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkp","Korlai Creole Portuguese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vkt","Tenggarong Kutai Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vku","Kurrama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vlp","Valpei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vls","Vlaams");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vma","Martuyhunira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmb","Barbaram");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmc","Juxtlahuaca Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmd","Mudu Koraga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vme","East Masela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmf","Mainfränkisch");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmg","Lungalunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmh","Maraghei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmi","Miwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmj","Ixtayutla Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmk","Makhuwa-Shirima");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vml","Malgana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmm","Mitlatongo Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmp","Soyaltepec Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmq","Soyaltepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmr","Marenje");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vms","Moksela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmu","Muluridyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmv","Valley Maidu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmw","Makhuwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmx","Tamazola Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmy","Ayautla Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vmz","Mazatlán Mazatec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vnk","Vano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vnm","Vinmavis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vnp","Vunapu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vo","Volapük");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vor","Voro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vot","Votic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vra","Vera'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vro","Võro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vrs","Varisi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vrt","Burmbar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vsi","Moldova Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vsl","Venezuelan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vsv","Valencian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vto","Vitou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vum","Vumbu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vun","Vunjo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vut","Vute");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","vwa","Awa (China)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waa","Walla Walla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wab","Wab");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wac","Wasco-Wishram");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wad","Wandamen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wae","Walser");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waf","Wakoná");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wag","Wa'ema");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wah","Watubela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wai","Wares");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waj","Waffa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wal","Wolaytta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wam","Wampanoag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wan","Wan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wao","Wappo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wap","Wapishana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waq","Wageman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","war","Waray (Philippines)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","was","Washo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wat","Kaninuwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wau","Waurá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wav","Waka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waw","Waiwai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wax","Watam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","way","Wayana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","waz","Wampur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wba","Warao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbb","Wabo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbe","Waritai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbf","Wara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbh","Wanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbi","Vwanji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbj","Alagwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbk","Waigali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbl","Wakhi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbm","Wa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbp","Warlpiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbq","Waddar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbr","Wagdi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbs","West Bengal Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbt","Wanman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbv","Wajarri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wbw","Woi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wca","Yanomámi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wci","Waci Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdd","Wandji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdg","Wadaginam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdj","Wadjiginy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdk","Wadikali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdu","Wadjigu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wdy","Wadjabangayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wea","Wewaw");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wec","Wè Western");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wed","Wedau");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","weg","Wergaia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","weh","Weh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wei","Kiunum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wem","Weme Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","weo","Wemale");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wep","Westphalien");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wer","Weri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wes","Cameroon Pidgin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wet","Perai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","weu","Rawngtu Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wew","Wejewa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wfg","Yafi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wga","Wagaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgb","Wagawaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgg","Wangganguru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgi","Wahgi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgo","Waigeo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgu","Wirangu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wgy","Warrgamay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wha","Sou Upaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","whg","North Wahgi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","whk","Wahau Kenyah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","whu","Wahau Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wib","Southern Toussian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wic","Wichita");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wie","Wik-Epa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wif","Wik-Keyangan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wig","Wik-Ngathana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wih","Wik-Me'anha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wii","Minidien");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wij","Wik-Iiyanh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wik","Wikalkan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wil","Wilawila");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wim","Wik-Mungkan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","win","Ho-Chunk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wir","Wiraféd");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wiu","Wiru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wiv","Vitu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wiy","Wiyot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wja","Waja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wji","Warji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wka","Kw'adza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wkb","Kumbaran");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wkd","Wakde");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wkl","Kalanadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wku","Kunduvadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wkw","Wakawaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wky","Wangkayutyuru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wla","Walio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlc","Mwali Comorian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wle","Wolane");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlg","Kunbarlang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wli","Waioli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlk","Wailaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wll","Wali (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlm","Middle Welsh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wa","Walloon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlo","Wolio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlr","Wailapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wls","Wallisian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlu","Wuliwuli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlv","Wichí Lhamtés Vejoz");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlw","Walak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wlx","Wali (Ghana)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wly","Waling");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wma","Mawa (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmb","Wambaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmc","Wamas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmd","Mamaindé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wme","Wambule");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmh","Waima'a");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmi","Wamin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmm","Maiwa (Indonesia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmn","Waamwang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmo","Wom (Papua New Guinea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wms","Wambon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmt","Walmajarri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmw","Mwani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wmx","Womo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnb","Wanambre");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnc","Wantoat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnd","Wandarang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wne","Waneci");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wng","Wanggom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wni","Ndzwani Comorian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnk","Wanukaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnm","Wanggamala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnn","Wunumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wno","Wano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnp","Wanap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnu","Usan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wnw","Wintu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wny","Wanyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woa","Tyaraity");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wob","Wè Northern");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woc","Wogeo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wod","Wolani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woe","Woleaian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wof","Gambian Wolof");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wog","Wogamusin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woi","Kamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wok","Longto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wo","Wolof");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wom","Wom (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","won","Wongo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woo","Manombai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wor","Woria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wos","Hanga Hundi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wow","Wawonii");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","woy","Weyto");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wpc","Maco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wra","Warapu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrb","Warluwara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrd","Warduji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrg","Warungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrh","Wiradhuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wri","Wariyangga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrk","Garrwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrl","Warlmanpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrm","Warumungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrn","Warnang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wro","Worrorra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrp","Waropen");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrr","Wardaman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrs","Waris");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wru","Waru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrv","Waruna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrw","Gugu Warra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrx","Wae Rana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wry","Merwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wrz","Waray (Australia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsa","Warembori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsg","Adilabad Gondi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsi","Wusi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsk","Waskia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsr","Owenia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wss","Wasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsu","Wasu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wsv","Wotapuri-Katarqalai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wtf","Watiwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wth","Wathawurrung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wti","Berta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wtk","Watakataui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wtm","Mewati");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wtw","Wotu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wua","Wikngenchera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wub","Wunambal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wud","Wudu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wuh","Wutunhua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wul","Silimo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wum","Wumbvu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wun","Bungu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wur","Wurrugu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wut","Wutung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wuu","Wu Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wuv","Wuvulu-Aua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wux","Wulna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wuy","Wauyai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wwa","Waama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wwb","Wakabunga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wwo","Wetamut");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wwr","Warrwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","www","Wawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wxa","Waxianghua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wxw","Wardandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wya","Wyandot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wyb","Wangaaybuwan-Ngiyambaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wyi","Woiwurrung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wym","Wymysorys");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wyr","Wayoró");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","wyy","Western Fijian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xaa","Andalusian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xab","Sambe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xac","Kachari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xad","Adai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xae","Aequian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xag","Aghwan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xai","Kaimbé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xaj","Ararandewára");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xak","Máku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xal","Kalmyk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xam","/Xam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xan","Xamtanga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xao","Khao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xap","Apalachee");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xaq","Aquitanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xar","Karami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xas","Kamas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xat","Katawixi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xau","Kauwera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xav","Xavánte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xaw","Kawaiisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xay","Kayan Mahakam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbb","Lower Burdekin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbc","Bactrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbd","Bindal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbe","Bigambal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbg","Bunganditj");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbi","Kombio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbj","Birrpayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbm","Middle Breton");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbn","Kenaboi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbo","Bolgarian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbp","Bibbulman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbr","Kambera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xbw","Kambiwá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xby","Batyala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcb","Cumbric");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcc","Camunic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xce","Celtiberian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcg","Cisalpine Gaulish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xch","Chemakum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcl","Classical Armenian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcm","Comecrudo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcn","Cotoname");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xco","Chorasmian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcr","Carian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xct","Classical Tibetan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcu","Curonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcv","Chuvantsy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcw","Coahuilteco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xcy","Cayuse");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xda","Darkinyung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xdc","Dacian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xdk","Dharuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xdm","Edomite");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xdo","Kwandu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xdy","Malayic Dayak");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xeb","Eblan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xed","Hdi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xeg","//Xegwi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xel","Kelo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xem","Kembayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xep","Epi-Olmec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xer","Xerénte");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xes","Kesawai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xet","Xetá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xeu","Keoru-Ahia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xfa","Faliscan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xga","Galatian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgb","Gbin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgd","Gudang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgf","Gabrielino-Fernandeño");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgg","Goreng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgi","Garingbal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgl","Galindan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgm","Dharumbal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgr","Garza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgu","Unggumi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xgw","Guwa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xha","Harami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhc","Hunnic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhd","Hadrami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhe","Khetrani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xh","Xhosa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhr","Hernican");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xht","Hattic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhu","Hurrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xhv","Khua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xib","Iberian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xii","Xiri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xil","Illyrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xin","Xinca");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xir","Xiriâna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xis","Kisan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xiv","Indus Valley Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xiy","Xipaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xjb","Minjungbal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xjt","Jaitmatang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xka","Kalkoti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkb","Northern Nago");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkc","Kho'ini");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkd","Mendalam Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xke","Kereho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkf","Khengkha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkg","Kagoro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xki","Kenyan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkj","Kajali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkk","Kaco'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkl","Mainstream Kenyah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkn","Kayan River Kayan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xko","Kiorr");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkp","Kabatei");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkq","Koroni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkr","Xakriabá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xks","Kumbewaha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkt","Kantosi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xku","Kaamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkv","Kgalagadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkw","Kembra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkx","Karore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xky","Uma' Lasan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xkz","Kurtokha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xla","Kamula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlb","Loup B");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlc","Lycian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xld","Lydian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xle","Lemnian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlg","Ligurian (Ancient)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xli","Liburnian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xln","Alanic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlo","Loup A");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlp","Lepontic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xls","Lusitanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xlu","Cuneiform Luwian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xly","Elymian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xma","Mushungulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmb","Mbonga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmc","Makhuwa-Marrevone");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmd","Mbudum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xme","Median");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmf","Mingrelian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmg","Mengaka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmh","Kuku-Muminh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmj","Majera");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmk","Ancient Macedonian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xml","Malaysian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmm","Manado Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmn","Manichaean Middle Persian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmo","Morerebi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmp","Kuku-Mu'inh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmq","Kuku-Mangk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmr","Meroitic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xms","Moroccan Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmt","Matbat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmu","Kamu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmv","Antankarana Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmw","Tsimihety Malagasy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmx","Maden");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmy","Mayaguduna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xmz","Mori Bawah");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xna","Ancient North Arabian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnb","Kanakanabu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xng","Middle Mongolian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnh","Kuanhua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xni","Ngarigu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnk","Nganakarti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnn","Northern Kankanay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xno","Anglo-Norman");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnr","Kangri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xns","Kanashi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnt","Narragansett");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnu","Nukunul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xny","Nyiyaparli");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xnz","Kenzi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xoc","O'chi'chi'");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xod","Kokoda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xog","Soga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xoi","Kominimung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xok","Xokleng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xom","Komo (Sudan)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xon","Konkomba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xoo","Xukurú");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xop","Kopar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xor","Korubo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xow","Kowaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpa","Pirriya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpc","Pecheneg");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpe","Liberia Kpelle");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpg","Phrygian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpi","Pictish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpj","Mpalitjanh");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpk","Kulina Pano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpm","Pumpokol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpn","Kapinawá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpo","Pochutec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpp","Puyo-Paekche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpq","Mohegan-Pequot");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpr","Parthian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xps","Pisidian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpt","Punthamara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpu","Punic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xpy","Puyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xqa","Karakhanid");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xqt","Qatabanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xra","Krahô");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrb","Eastern Karaboro");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrd","Gundungurra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xre","Kreye");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrg","Minang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xri","Krikati-Timbira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrm","Armazic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrn","Arin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrq","Karranga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrr","Raetic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrt","Aranama-Tamique");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xru","Marriammu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xrw","Karawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsa","Sabaean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsb","Sambal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsc","Scythian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsd","Sidetic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xse","Sempan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsh","Shamang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsi","Sio");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsl","South Slavey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsm","Kasem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsn","Sanga (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xso","Solano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsp","Silopi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsq","Makhuwa-Saka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsr","Sherpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xss","Assan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsu","Sanumá");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsv","Sudovian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xsy","Saisiyat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xta","Alcozauca Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtb","Chazumba Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtc","Katcha-Kadugli-Miri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtd","Diuxi-Tilantongo Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xte","Ketengban");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtg","Transalpine Gaulish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xth","Yitha Yitha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xti","Sinicahua Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtj","San Juan Teita Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtl","Tijaltepec Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtm","Magdalena Peñasco Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtn","Northern Tlaxiaco Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xto","Tokharian A");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtp","San Miguel Piedras Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtq","Tumshuqese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtr","Early Tripuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xts","Sindihui Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtt","Tacahua Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtu","Cuyamecalco Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtv","Thawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtw","Tawandê");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xty","Yoloxochitl Mixtec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xtz","Tasmanian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xua","Alu Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xub","Betta Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xud","Umiida");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xug","Kunigami");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xuj","Jennu Kurumba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xul","Ngunawal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xum","Umbrian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xun","Unggaranggu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xuo","Kuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xup","Upper Umpqua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xur","Urartian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xut","Kuthant");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xuu","Kxoe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xve","Venetic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xvi","Kamviri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xvn","Vandalic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xvo","Volscian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xvs","Vestinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwa","Kwaza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwc","Woccon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwd","Wadi Wadi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwe","Xwela Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwg","Kwegu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwj","Wajuk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwk","Wangkumara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwl","Western Xwla Gbe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwo","Written Oirat");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwr","Kwerba Mamberamo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xwt","Wotjobaluk");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xww","Wemba Wemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xxb","Boro (Ghana)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xxk","Ke'o");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xxm","Minkin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xxr","Koropó");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xxt","Tambora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xya","Yaygir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyb","Yandjibara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyj","Mayi-Yapi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyk","Mayi-Kulan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyl","Yalakalore");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyt","Mayi-Thakurti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xyy","Yorta Yorta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xzh","Zhang-Zhung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xzm","Zemgalian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","xzp","Ancient Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaa","Yaminahua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yab","Yuhup");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yac","Pass Valley Yali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yad","Yagua");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yae","Pumé");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaf","Yaka (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yag","Yámana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yah","Yazgulyam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yai","Yagnobi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaj","Banda-Yangere");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yak","Yakama");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yal","Yalunka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yam","Yamba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yan","Mayangna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yao","Yao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yap","Yapese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaq","Yaqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yar","Yabarana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yas","Nugunu (Cameroon)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yat","Yambeta");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yau","Yuwana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yav","Yangben");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaw","Yawalapití");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yax","Yauma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yay","Agwagwune");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yaz","Lokaa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yba","Yala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybb","Yemba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybe","West Yugur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybh","Yakha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybi","Yamphu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybj","Hasha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybk","Bokha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybl","Yukuben");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybm","Yaben");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybn","Yabaâna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybo","Yabong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ybx","Yawiyo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yby","Yaweyuha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ych","Chesu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ycl","Lolopo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ycn","Yucuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ycp","Chepya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yda","Yanda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ydd","Eastern Yiddish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yde","Yangum Dey");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ydg","Yidgha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ydk","Yoidik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yea","Ravula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yec","Yeniche");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yee","Yimas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yei","Yeni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yej","Yevanic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yel","Yela");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yer","Tarok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yes","Nyankpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yet","Yetfa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yeu","Yerukula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yev","Yapunda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yey","Yeyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yga","Malyangapa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygi","Yiningayi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygl","Yangum Gel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygm","Yagomi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygp","Gepo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygr","Yagaria");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygs","Yolŋu Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygu","Yugul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ygw","Yagwoia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yha","Baha Buyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yhd","Judeo-Iraqi Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yhl","Hlepho Phowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yhs","Yan-nhaŋu Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yia","Yinggarda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yi","Yiddish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yif","Ache");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yig","Wusa Nasu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yih","Western Yiddish");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yii","Yidiny");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yij","Yindjibarndi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yik","Dongshanba Lalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yil","Yindjilandji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yim","Yimchungru Naga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yin","Yinchia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yip","Pholo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yiq","Miqie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yir","North Awyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yis","Yis");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yit","Eastern Lalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yiu","Awu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yiv","Northern Nisu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yix","Axi Yi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yiz","Azhe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yka","Yakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykg","Northern Yukaghir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yki","Yoke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykk","Yakaikeke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykl","Khlula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykm","Kap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykn","Kua-nsi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yko","Yasa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykr","Yekora");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ykt","Kathu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yku","Kuamasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yky","Yakoma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yla","Yaul");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylb","Yaleba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yle","Yele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylg","Yelogu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yli","Angguruk Yali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yll","Yil");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylm","Limi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yln","Langnian Buyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylo","Naluo Yi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylr","Yalarnnga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ylu","Aribwaung");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yly","Nyâlayu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymb","Yambes");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymc","Southern Muji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymd","Muda");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yme","Yameo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymg","Yamongeri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymh","Mili");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymi","Moji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymk","Makwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yml","Iamalele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymm","Maay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymn","Yamna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymo","Yangum Mon");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymp","Yamap");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymq","Qila Muji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymr","Malasar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yms","Mysian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymx","Northern Muji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ymz","Muzi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yna","Aluo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynd","Yandruwandha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yne","Lang'e");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yng","Yango");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynk","Naukan Yupik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynl","Yangulam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynn","Yana");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yno","Yong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynq","Yendang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yns","Yansi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ynu","Yahuna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yob","Yoba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yog","Yogad");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yoi","Yonaguni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yok","Yokuts");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yol","Yola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yom","Yombe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yon","Yongkom");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yo","Yoruba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yot","Yotti");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yox","Yoron");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yoy","Yoy");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypa","Phala");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypb","Labo Phowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypg","Phola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yph","Phupha");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypm","Phuma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypn","Ani Phowa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypo","Alo Phola");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypp","Phupa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ypz","Phuza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yra","Yerakai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrb","Yareba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yre","Yaouré");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrk","Nenets");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrl","Nhengatu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrm","Yirrk-Mel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrn","Yerong");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yro","Yaroamë");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrs","Yarsun");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yrw","Yarawata");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yry","Yarluyandi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysc","Yassic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysd","Samatao");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysg","Sonaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysl","Yugoslavian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysn","Sani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yso","Nisi (China)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysp","Southern Lolopo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysr","Sirenik Yupik");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yss","Yessan-Mayo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ysy","Sanie");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yta","Talu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ytl","Tanglang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ytp","Thopho");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ytw","Yout Wam");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yty","Yatay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yua","Yucateco");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yub","Yugambal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuc","Yuchi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yud","Judeo-Tripolitanian Arabic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yue","Yue Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuf","Havasupai-Walapai-Yavapai");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yug","Yug");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yui","Yurutí");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuj","Karkar-Yuri");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuk","Yuki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yul","Yulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yum","Quechan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yun","Bena (Nigeria)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yup","Yukpa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuq","Yuqui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yur","Yurok");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yut","Yopno");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuw","Yau (Morobe Province)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yux","Southern Yukaghir");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuy","East Yugur");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yuz","Yuracare");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yva","Yawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yvt","Yavitero");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywa","Kalou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywg","Yinhawangka");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywl","Western Lalu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywn","Yawanawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywq","Wuding-Luquan Yi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywr","Yawuru");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywt","Xishanba Lalo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ywu","Wumeng Nasu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yww","Yawarawarga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxa","Mayawali");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxg","Yagara");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxl","Yardliyawarra");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxm","Yinwum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxu","Yuyu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yxy","Yabula Yabula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yyr","Yir Yoront");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yyu","Yau (Sandaun Province)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yyz","Ayizi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yzg","E'ma Buyang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","yzk","Zokhuo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaa","Sierra de Juárez Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zab","Western Tlacolula Valley Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zac","Ocotlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zad","Cajonos Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zae","Yareni Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaf","Ayoquesco Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zag","Zaghawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zah","Zangwal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zai","Isthmus Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaj","Zaramo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zak","Zanaki");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zal","Zauzou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zam","Miahuatlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zao","Ozolotepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zap","Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaq","Aloápam Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zar","Rincón Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zas","Santo Domingo Albarradas Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zat","Tabaa Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zau","Zangskari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zav","Yatzachi Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaw","Mitla Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zax","Xadani Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zay","Zayse-Zergulla");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zaz","Zari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zbc","Central Berawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zbe","East Berawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zbl","Blissymbols");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zbt","Batui");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zbw","West Berawan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zca","Coatecas Altas Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zch","Central Hongshuihe Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zdj","Ngazidja Comorian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zea","Zeeuws");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zeg","Zenag");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zeh","Eastern Hongshuihe Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zen","Zenaga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zga","Kinga");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zgb","Guibei Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zgh","Standard Moroccan Tamazight");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zgm","Minz Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zgn","Guibian Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zgr","Magori");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","za","Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zhb","Zhaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zhd","Dai Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zhi","Zhire");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zhn","Nong Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zh","Chinese");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zhw","Zhoa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zia","Zia");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zib","Zimbabwe Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zik","Zimakani");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zil","Zialo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zim","Mesme");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zin","Zinza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zir","Ziriya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ziw","Zigula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ziz","Zizilivakan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zka","Kaimbulawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkb","Koibal");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkd","Kadu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkg","Koguryo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkh","Khorezmian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkk","Karankawa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkn","Kanan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zko","Kott");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkp","São Paulo Kaingáng");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkr","Zakhring");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkt","Kitan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zku","Kaurna");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkv","Krevinian");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zkz","Khazar");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zlj","Liujiang Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zlm","Malay (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zln","Lianshan Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zlq","Liuqian Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zma","Manda (Australia)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmb","Zimba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmc","Margany");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmd","Maridan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zme","Mangerr");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmf","Mfinu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmg","Marti Ke");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmh","Makolkol");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmi","Negeri Sembilan Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmj","Maridjabin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmk","Mandandanyi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zml","Madngele");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmm","Marimanindji");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmn","Mbangwe");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmo","Molo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmp","Mpuono");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmq","Mituku");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmr","Maranunggu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zms","Mbesa");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmt","Maringarr");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmu","Muruwari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmv","Mbariman-Gudhinma");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmw","Mbo (Democratic Republic of Congo)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmx","Bomitaba");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmy","Mariyedi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zmz","Mbandja");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zna","Zan Gula");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zne","Zande (individual language)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zng","Mang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","znk","Manangkari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zns","Mangas");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zoc","Copainalá Zoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zoh","Chimalapa Zoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zom","Zou");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zoo","Asunción Mixtepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zoq","Tabasco Zoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zor","Rayón Zoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zos","Francisco León Zoque");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpa","Lachiguiri Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpb","Yautepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpc","Choapan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpd","Southeastern Ixtlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpe","Petapa Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpf","San Pedro Quiatoni Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpg","Guevea De Humboldt Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zph","Totomachapan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpi","Santa María Quiegolani Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpj","Quiavicuzas Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpk","Tlacolulita Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpl","Lachixío Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpm","Mixtepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpn","Santa Inés Yatzechi Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpo","Amatlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpp","El Alto Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpq","Zoogocho Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpr","Santiago Xanica Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zps","Coatlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpt","San Vicente Coatlán Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpu","Yalálag Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpv","Chichicapan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpw","Zaniza Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpx","San Baltazar Loxicha Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpy","Mazaltepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zpz","Texmelucan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zqe","Qiubei Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zra","Kara (Korea)");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zrg","Mirgan");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zrn","Zerenkel");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zro","Záparo");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zrp","Zarphatic");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zrs","Mairasi");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsa","Sarasira");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsk","Kaskean");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsl","Zambian Sign Language");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsm","Standard Malay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsr","Southern Rincon Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zsu","Sukurum");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zte","Elotepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztg","Xanaguía Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztl","Lapaguía-Guivini Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztm","San Agustín Mixtepec Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztn","Santa Catarina Albarradas Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztp","Loxicha Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztq","Quioquitani-Quierí Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zts","Tilquiapan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztt","Tejalapan Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztu","Güilá Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","ztx","Zaachila Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zty","Yatee Zapotec");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zua","Zeem");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zuh","Tokano");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zu","Zulu");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zum","Kumzari");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zun","Zuni");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zuy","Zumaya");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zwa","Zay");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zxx","No linguistic content");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zyb","Yongbei Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zyg","Yang Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zyj","Youjiang Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zyn","Yongnan Zhuang");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zyp","Zyphe Chin");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zza","Zaza");
INSERT OR IGNORE INTO "languageNames" VALUES(NULL,"en","zzj","Zuojiang Zhuang");
COMMIT;
